<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

/*
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License.
    A copy is also available from http://www.gnu.org/licenses/lgpl.txt
 */

/**
 * Zipcode_search Class
 *
 * @package		ExpressionEngine
 * @category		Plugin
 * @author		Anthony W. Rainer <anthony@keycreative.com>
 * @copyright		Copyright (c) 2012, Key 7 Creative LLC.
 * @link 		http://www.keycreative.com
 * @version		2010
 * @description		ZIP Code Tabulation Data from the 2010 Census @ http://www.census.gov/geo/www/gazetteer/gazetteer2010.html
 */
 
$plugin_info = array(
	'pi_name'       => 'Zipcode Search',
	'pi_version'    => '2010 Census',
	'pi_author'     => 'Anthony W. Rainer &lt;anthony@keycreative.com&gt;',
	'pi_author_url' => 'http://www.keycreative.com/',
	'pi_description'=> 'ZIP Code Tabulation Data from the 2010 Census @ http://www.census.gov/geo/www/gazetteer/gazetteer2010.html',
	'pi_usage'      => Zipcode_search::usage()
);

class Zipcode_search {
	
	public $return_data;
	
	public function Zipcode_search() { $this->__construct(); }
	public function __construct() {
		$this->EE =& get_instance(); 
	}
	
	public function getSearchString() {
		$params = array(
			"zip_search_name"=>$this->EE->TMPL->fetch_param("zip_search_name", null), 
			"zipcode"=>intval($this->EE->TMPL->fetch_param("zipcode", 0)), 
			"max_distance"=>intval($this->EE->TMPL->fetch_param("max_distance", 20))
		);
		
		if(!array_key_exists($params['zipcode'], $this->zipcodes)) {
			if(isset($params['zip_search_name']) && $this->EE->input->post($params['zip_search_name'], null) != null)
				$params['zipcode'] = intval($this->EE->input->post($params['zip_search_name']));
			
			// invalid zipcode so return all results
			if(!array_key_exists($params['zipcode'], $this->zipcodes))
				return "IS_EMPTY|not IS_EMPTY";
		}
		if($params['max_distance'] <=0 || $params['max_distance'] > 10000) 
			$params['max_distance'] = 20;
		
		list($c_long, $c_lat) = $this->zipcodes[$params['zipcode']];
		
		$results = array();
		foreach($this->zipcodes as $zc=>$c) {
			if($zc == $params['zipcode']) continue;
			if($this->getDistance($c_long, $c_lat, $c[0], $c[1]) <= $params['max_distance']) {
				$results[] = str_pad($zc, 5, "0", STR_PAD_LEFT);
			}
		}
		return $params['zipcode'].(!empty($results) ? "|".implode("|", $results) : "");
	}
	
	public function getDistance($long1=null,$lat1=null,$long2=null,$lat2=null) {
		$round = 2;
		if(empty($long1) || empty($lat1) || empty($long2) || empty($lat2)) {
			$params = array(
				"from"=>$this->EE->TMPL->fetch_param("from", null), 
				"to"=>$this->EE->TMPL->fetch_param("to", null)
			);
			$round = $this->EE->TMPL->fetch_param("round", 2);
			if($params['from'] === null || $params['to'] === null || !isset($this->zipcodes[intval($params['from'])]) || !isset($this->zipcodes[intval($params['to'])]))
				return 0;
			$long1 = $this->zipcodes[intval($params['from'])][0];
			$lat1 = $this->zipcodes[intval($params['from'])][1];
			$long2 = $this->zipcodes[intval($params['to'])][0];
			$lat2 = $this->zipcodes[intval($params['to'])][1];
		}
		return round(sqrt((pow((69.1*($lat1-$lat2)),2))+(pow((69.1*($long1-$long2)*cos($lat2/57.3)),2))),$round);
	}
	
	public function getSearchData() {
		return $this->EE->input->post($this->EE->TMPL->fetch_param("name", "zipcode"), "");
	}
	
	public static function usage() {
		ob_start();?>
There are 3 template tag available:

======================================================================
{exp:zipcode_search:getSearchString}
If an invalid zip code is provided either through "zipcode=" or from the POST variable provided by "zip_search_name=" then, "IS_EMPTY|not IS_EMPTY", is returned which usually will return all results.
The output from this is designed to be used with the "search:fieldname=" parameter of "exp:channel:entries".

---PARAMETERS:
zipcode= (optional, required if zip_search_name= is not present)
_________________Used to specify the zip code to search by.  Must be numeric and 5 digits.

max_distance= (optional, default=20)
_________________Used to specify the max distance that a zipcode should match. should be greater than 0 and less then 10,000.

zip_search_name= (optional, required if zipcode= is not present)
_________________This is used to get the zip code to search by from a POST vraiable. Specify the element name here. This will NOT OVERRIDE "zipcode=".


---RETURNS:
A pipe delimited string containing all of the zip codes that are within the "max_distance=" in miles of the "zipcode="

======================================================================
{exp:zipcode_search:getDistance}
This is designed to return the distance in miles from one zip code to another.

---PARAMETERS:
from= (required)
_________________The starting zip code.

to= (required)
_________________The ending zip code.

round= (optional, default=2)
_________________Used to round the floating point result to a set number of decimal places


---RETURNS:
A floating point number that represents the distance in miles between the 2 zip codes.

======================================================================
{exp:zipcode_search:getSearchData}
Used to get the value of a POST variable.  This can be used on any post variable.

---PARAMETERS:
name= (required)
_________________The name of the form element that was submitted via POST.


---RETURNS:
The value of the POST variable as specified by the name provided.

======================================================================
======================================================================
EXAMPLES:
======================================================================
{exp:channel:entries channel='locations' dynamic='no' search:zipcode={exp:zipcode_search:getSearchString zipcode='12345' max_distance='20'}}
The distance is {exp:zipcode_search:getDistance from='12345' to={zipcode} round="5"} miles.
{/exp:channel:entries}

-------------------------------------------

{exp:channel:entries channel='locations' dynamic='no' search:zipcode={exp:zipcode_search:getSearchString zip_search_name='specify_zipcode' max_distance='100'}}
The distance is {exp:zipcode_search:getDistance from={exp:zipcode_search:getSearchData name='specify_zipcode'} to={zipcode}} miles.
{/exp:channel:entries}
<?php
		$d = ob_get_contents();
		ob_end_clean();
		return $d;
	}
	
	public $zipcodes=array(601=>array(-66.749961,18.180555),602=>array(-67.17613,18.362268),603=>array(-67.119887,18.455183),606=>array(-66.932911,18.158345),610=>array(-67.125868,18.290955),612=>array(-66.7114,18.402239),616=>array(-66.671979,18.420412),617=>array(-66.559696,18.445147),622=>array(-67.153993,17.991245),623=>array(-67.153877,18.083435),624=>array(-66.715966,18.063275),627=>array(-66.861879,18.41503),631=>array(-66.832041,18.190607),637=>array(-66.947389,18.076713),638=>array(-66.513306,18.291088),641=>array(-66.71402,18.262962),646=>array(-66.285941,18.433167),647=>array(-66.947127,17.963613),650=>array(-66.578079,18.349416),652=>array(-66.603113,18.451934),653=>array(-66.888933,17.985452),656=>array(-66.792931,18.053539),659=>array(-66.809008,18.407222),660=>array(-67.116158,18.134644),662=>array(-67.015974,18.467481),664=>array(-66.589613,18.213419),667=>array(-67.03581,18.003422),669=>array(-66.866375,18.270899),670=>array(-66.990114,18.236832),674=>array(-66.489337,18.422908),676=>array(-67.080344,18.377751),677=>array(-67.227006,18.33256),678=>array(-66.927384,18.434099),680=>array(-67.133802,18.181938),682=>array(-67.156062,18.221443),683=>array(-67.037263,18.1078),685=>array(-66.959875,18.332927),687=>array(-66.418034,18.318386),688=>array(-66.626438,18.382264),690=>array(-67.098671,18.49551),692=>array(-66.336556,18.410188),693=>array(-66.39723,18.423024),694=>array(-66.391079,18.48237),698=>array(-66.856319,18.064848),703=>array(-66.130662,18.248401),704=>array(-66.219555,17.96577),705=>array(-66.266683,18.128961),707=>array(-65.920712,18.013648),714=>array(-66.042943,18.000198),715=>array(-66.560065,18.011233),716=>array(-66.607542,17.990567),717=>array(-66.614037,18.003222),718=>array(-65.759623,18.231988),719=>array(-66.25344,18.289927),720=>array(-66.428076,18.217946),723=>array(-66.015578,18.043822),725=>array(-66.042375,18.218819),727=>array(-66.073565,18.215308),728=>array(-66.664116,17.989853),729=>array(-65.885142,18.329829),730=>array(-66.616838,18.030831),731=>array(-66.634653,18.108039),735=>array(-65.682494,18.252604),736=>array(-66.151667,18.103624),738=>array(-65.698711,18.304458),739=>array(-66.160577,18.177265),740=>array(-65.63412,18.33116),741=>array(-65.754021,18.163745),745=>array(-65.817813,18.35284),751=>array(-66.252183,18.001317),754=>array(-65.976289,18.14713),757=>array(-66.391334,17.995441),765=>array(-65.439369,18.130096),766=>array(-66.476916,18.133196),767=>array(-65.89649,18.069413),769=>array(-66.357586,18.1038),771=>array(-65.871196,18.187201),772=>array(-65.905174,18.438969),773=>array(-65.726378,18.343799),775=>array(-65.295977,18.327485),777=>array(-65.908542,18.224133),778=>array(-65.979078,18.263023),780=>array(-66.568105,18.102834),782=>array(-66.221633,18.225708),783=>array(-66.326179,18.30391),784=>array(-66.133613,18.010721),786=>array(-66.229907,18.155424),791=>array(-65.821487,18.136752),794=>array(-66.309782,18.199014),795=>array(-66.499473,18.060532),901=>array(-66.104723,18.465424),906=>array(-66.094995,18.46446),907=>array(-66.078113,18.452679),909=>array(-66.067132,18.44161),911=>array(-66.056223,18.451128),912=>array(-66.060139,18.445289),913=>array(-66.042664,18.44997),915=>array(-66.045571,18.437179),917=>array(-66.050105,18.420674),918=>array(-66.065789,18.421022),920=>array(-66.088042,18.414292),921=>array(-66.088552,18.392273),923=>array(-66.038888,18.409307),924=>array(-66.012452,18.399196),925=>array(-66.050602,18.400296),926=>array(-66.051545,18.3454),927=>array(-66.072098,18.387953),934=>array(-66.124234,18.411313),936=>array(-66.073772,18.395463),949=>array(-66.212833,18.430696),950=>array(-66.234559,18.463692),951=>array(-66.253789,18.42753),952=>array(-66.182032,18.427441),953=>array(-66.251526,18.360727),956=>array(-66.168891,18.319539),957=>array(-66.187693,18.368533),959=>array(-66.154999,18.388924),960=>array(-66.145795,18.416919),961=>array(-66.165168,18.41223),962=>array(-66.145357,18.442299),965=>array(-66.114752,18.433757),966=>array(-66.117584,18.401536),968=>array(-66.101223,18.406077),969=>array(-66.108062,18.368062),971=>array(-66.119215,18.318832),976=>array(-65.994057,18.336408),979=>array(-66.030129,18.444389),982=>array(-65.992045,18.411261),983=>array(-65.97707,18.418007),985=>array(-65.946933,18.408588),987=>array(-65.941083,18.338161),1001=>array(-72.628274,42.062332),1002=>array(-72.458507,42.363977),1003=>array(-72.524108,42.389941),1005=>array(-72.106598,42.418848),1007=>array(-72.400468,42.27901),1008=>array(-72.957325,42.191846),1009=>array(-72.341433,42.211969),1010=>array(-72.205302,42.129477),1011=>array(-72.968716,42.300281),1012=>array(-72.858192,42.375425),1013=>array(-72.602804,42.154904),1020=>array(-72.561835,42.172698),1022=>array(-72.542713,42.197741),1026=>array(-72.918267,42.465495),1027=>array(-72.751877,42.295008),1028=>array(-72.501234,42.059614),1029=>array(-73.044647,42.193395),1030=>array(-72.686972,42.072925),1031=>array(-72.19819,42.329398),1032=>array(-72.81478,42.457613),1033=>array(-72.500034,42.244958),1034=>array(-72.961272,42.098207),1035=>array(-72.568576,42.356482),1036=>array(-72.417297,42.062946),1037=>array(-72.18871,42.367961),1038=>array(-72.606929,42.385496),1039=>array(-72.688922,42.404278),1040=>array(-72.642448,42.211656),1050=>array(-72.869693,42.28675),1053=>array(-72.713584,42.356301),1054=>array(-72.484502,42.469588),1056=>array(-72.459078,42.188865),1057=>array(-72.321494,42.093596),1060=>array(-72.630588,42.321488),1062=>array(-72.703923,42.328314),1063=>array(-72.63853,42.318882),1066=>array(-72.655018,42.406903),1068=>array(-72.044248,42.350862),1069=>array(-72.308469,42.187794),1070=>array(-72.919017,42.518446),1071=>array(-72.873853,42.16006),1072=>array(-72.417244,42.456968),1073=>array(-72.741588,42.226949),1074=>array(-72.09323,42.387603),1075=>array(-72.580763,42.256346),1077=>array(-72.777353,42.05257),1079=>array(-72.32702,42.197424),1080=>array(-72.365654,42.182218),1081=>array(-72.234411,42.061313),1082=>array(-72.278599,42.293533),1083=>array(-72.194599,42.203642),1084=>array(-72.882235,42.39237),1085=>array(-72.771602,42.153503),1086=>array(-72.793967,42.130446),1088=>array(-72.646494,42.391709),1089=>array(-72.649734,42.125451),1092=>array(-72.235108,42.191868),1093=>array(-72.654963,42.435121),1094=>array(-72.1368,42.359108),1095=>array(-72.427404,42.127327),1096=>array(-72.763572,42.39714),1097=>array(-72.832612,42.178038),1098=>array(-72.943115,42.394315),1103=>array(-72.592027,42.104106),1104=>array(-72.565378,42.134009),1105=>array(-72.577579,42.095207),1106=>array(-72.57113,42.047565),1107=>array(-72.607068,42.12106),1108=>array(-72.560791,42.080692),1109=>array(-72.549726,42.119674),1118=>array(-72.525905,42.093732),1119=>array(-72.51121,42.124978),1128=>array(-72.489135,42.092296),1129=>array(-72.487401,42.119062),1151=>array(-72.509131,42.15186),1199=>array(-72.604468,42.120563),1201=>array(-73.273727,42.448236),1220=>array(-73.116736,42.623799),1222=>array(-73.322175,42.058703),1223=>array(-73.110124,42.312225),1224=>array(-73.195594,42.513356),1225=>array(-73.153566,42.563363),1226=>array(-73.135073,42.481119),1229=>array(-73.335896,42.276338),1230=>array(-73.324463,42.172941),1235=>array(-73.064073,42.43062),1236=>array(-73.378393,42.266496),1237=>array(-73.268033,42.547818),1238=>array(-73.230148,42.297501),1240=>array(-73.269768,42.367862),1242=>array(-73.249199,42.333734),1243=>array(-73.024112,42.350122),1244=>array(-73.257497,42.118094),1245=>array(-73.223105,42.186893),1247=>array(-73.08409,42.698437),1253=>array(-73.113214,42.206683),1254=>array(-73.365492,42.382019),1255=>array(-73.118607,42.107496),1256=>array(-73.02232,42.594166),1257=>array(-73.367482,42.085245),1258=>array(-73.462886,42.10928),1259=>array(-73.234376,42.075469),1260=>array(-73.342543,42.295696),1262=>array(-73.319209,42.292202),1264=>array(-73.202428,42.23159),1266=>array(-73.387824,42.312338),1267=>array(-73.246981,42.671616),1270=>array(-73.031166,42.515272),1301=>array(-72.60153,42.626761),1330=>array(-72.821517,42.513947),1331=>array(-72.19108,42.562408),1337=>array(-72.582249,42.689307),1338=>array(-72.824428,42.572652),1339=>array(-72.889644,42.603776),1340=>array(-72.711079,42.694726),1341=>array(-72.709414,42.496937),1342=>array(-72.609458,42.543889),1343=>array(-72.978931,42.657625),1344=>array(-72.426427,42.613418),1346=>array(-72.823113,42.693275),1347=>array(-72.518753,42.559294),1349=>array(-72.482122,42.563061),1350=>array(-72.985346,42.727772),1351=>array(-72.521689,42.53988),1354=>array(-72.508643,42.624076),1355=>array(-72.327219,42.458522),1360=>array(-72.453876,42.677091),1364=>array(-72.289902,42.615152),1366=>array(-72.192468,42.475621),1367=>array(-72.909148,42.695532),1368=>array(-72.176935,42.679456),1370=>array(-72.726941,42.593338),1373=>array(-72.615612,42.473862),1375=>array(-72.546855,42.466762),1376=>array(-72.555002,42.59528),1378=>array(-72.353213,42.673533),1379=>array(-72.407148,42.55631),1420=>array(-71.816862,42.584925),1430=>array(-71.923442,42.657005),1431=>array(-71.832523,42.676293),1432=>array(-71.575135,42.566573),1434=>array(-71.611613,42.539088),1436=>array(-72.088395,42.603374),1438=>array(-72.031402,42.562243),1440=>array(-71.988062,42.586516),1450=>array(-71.565269,42.61176),1451=>array(-71.568201,42.501908),1452=>array(-72.002878,42.489598),1453=>array(-71.763075,42.51996),1460=>array(-71.490569,42.535931),1462=>array(-71.720464,42.582607),1463=>array(-71.602858,42.670643),1464=>array(-71.640986,42.573654),1467=>array(-71.609303,42.492367),1468=>array(-72.068345,42.542767),1469=>array(-71.695333,42.665059),1473=>array(-71.90544,42.5546),1474=>array(-71.752751,42.669685),1475=>array(-72.055644,42.66816),1501=>array(-71.846006,42.198708),1503=>array(-71.633889,42.384929),1504=>array(-71.532406,42.039991),1505=>array(-71.716157,42.355049),1506=>array(-72.107473,42.181793),1507=>array(-71.968025,42.133935),1510=>array(-71.690005,42.411887),1515=>array(-72.040178,42.209682),1516=>array(-71.752241,42.053072),1518=>array(-72.118818,42.127477),1519=>array(-71.679739,42.203404),1520=>array(-71.850626,42.336372),1521=>array(-72.180149,42.046798),1522=>array(-71.867382,42.375634),1523=>array(-71.675513,42.482819),1524=>array(-71.919217,42.249603),1525=>array(-71.630518,42.106794),1527=>array(-71.777649,42.192246),1529=>array(-71.578779,42.036642),1531=>array(-72.130814,42.319125),1532=>array(-71.646236,42.323342),1534=>array(-71.643348,42.142074),1535=>array(-72.066876,42.267564),1536=>array(-71.692642,42.231309),1537=>array(-71.897051,42.158966),1540=>array(-71.857369,42.116167),1541=>array(-71.87754,42.454125),1542=>array(-71.908907,42.204251),1543=>array(-71.970514,42.388977),1545=>array(-71.714228,42.284767),1550=>array(-72.03404,42.059669),1560=>array(-71.674223,42.175395),1561=>array(-71.685583,42.44397),1562=>array(-71.991867,42.247211),1564=>array(-71.776045,42.447924),1566=>array(-72.079545,42.103214),1568=>array(-71.603588,42.176526),1569=>array(-71.631294,42.055892),1570=>array(-71.846952,42.047532),1571=>array(-71.935075,42.053778),1581=>array(-71.613309,42.268426),1583=>array(-71.785036,42.369417),1585=>array(-72.162645,42.240796),1588=>array(-71.671822,42.119228),1590=>array(-71.750318,42.132051),1602=>array(-71.849991,42.271563),1603=>array(-71.843925,42.244637),1604=>array(-71.767957,42.253254),1605=>array(-71.787793,42.289683),1606=>array(-71.795741,42.315249),1607=>array(-71.78891,42.22596),1608=>array(-71.801462,42.26198),1609=>array(-71.829987,42.285114),1610=>array(-71.808366,42.247049),1611=>array(-71.875838,42.237604),1612=>array(-71.929607,42.296636),1701=>array(-71.440409,42.320169),1702=>array(-71.43676,42.282576),1718=>array(-71.429283,42.519816),1719=>array(-71.520985,42.485985),1720=>array(-71.438495,42.483953),1721=>array(-71.473526,42.257755),1730=>array(-71.281905,42.499331),1731=>array(-71.279484,42.456748),1740=>array(-71.601876,42.439937),1741=>array(-71.361832,42.53662),1742=>array(-71.364496,42.462911),1745=>array(-71.499163,42.293073),1746=>array(-71.45343,42.195951),1747=>array(-71.533416,42.12408),1748=>array(-71.540484,42.224104),1749=>array(-71.545864,42.389071),1752=>array(-71.547214,42.349617),1754=>array(-71.456256,42.425955),1756=>array(-71.544902,42.09447),1757=>array(-71.521419,42.158692),1760=>array(-71.348811,42.284822),1770=>array(-71.37469,42.23357),1772=>array(-71.530828,42.302877),1773=>array(-71.310812,42.425506),1775=>array(-71.512514,42.429688),1776=>array(-71.42107,42.383367),1778=>array(-71.381186,42.343687),1801=>array(-71.154425,42.488659),1803=>array(-71.201713,42.503227),1810=>array(-71.161751,42.648044),1821=>array(-71.251725,42.54933),1824=>array(-71.355182,42.59079),1826=>array(-71.30068,42.679723),1827=>array(-71.500517,42.676078),1830=>array(-71.053436,42.796313),1832=>array(-71.132859,42.791114),1833=>array(-70.982034,42.727885),1834=>array(-71.015935,42.7539),1835=>array(-71.094242,42.751157),1840=>array(-71.160403,42.706763),1841=>array(-71.164873,42.712015),1843=>array(-71.160383,42.689974),1844=>array(-71.178588,42.742751),1845=>array(-71.091334,42.673909),1850=>array(-71.303309,42.656045),1851=>array(-71.33533,42.627812),1852=>array(-71.295785,42.631849),1854=>array(-71.348229,42.649481),1860=>array(-71.011997,42.838603),1862=>array(-71.295592,42.578543),1863=>array(-71.38947,42.63378),1864=>array(-71.084398,42.578222),1867=>array(-71.105423,42.535183),1876=>array(-71.227571,42.611801),1879=>array(-71.42882,42.667762),1880=>array(-71.0675,42.501528),1886=>array(-71.439826,42.585295),1887=>array(-71.164516,42.564647),1890=>array(-71.144319,42.452752),1901=>array(-70.946073,42.460711),1902=>array(-70.941535,42.471039),1904=>array(-70.97393,42.492456),1905=>array(-70.975792,42.465998),1906=>array(-71.013946,42.468432),1907=>array(-70.905908,42.474287),1908=>array(-70.926041,42.428256),1913=>array(-70.955837,42.851284),1915=>array(-70.866996,42.570269),1921=>array(-71.01833,42.683108),1922=>array(-70.914241,42.757313),1923=>array(-70.950516,42.574174),1929=>array(-70.776592,42.634421),1930=>array(-70.681824,42.61991),1937=>array(-70.984051,42.585723),1938=>array(-70.842664,42.68386),1940=>array(-71.038574,42.534118),1944=>array(-70.767154,42.576636),1945=>array(-70.859126,42.501835),1949=>array(-71.010316,42.606666),1950=>array(-70.891095,42.812358),1951=>array(-70.850211,42.773351),1952=>array(-70.841476,42.844793),1960=>array(-70.969734,42.534202),1966=>array(-70.620242,42.640741),1969=>array(-70.891222,42.720877),1970=>array(-70.870859,42.524435),1982=>array(-70.85723,42.626223),1983=>array(-70.94344,42.641379),1984=>array(-70.883406,42.600595),1985=>array(-70.964411,42.799516),2019=>array(-71.47449,42.076682),2021=>array(-71.125385,42.175737),2025=>array(-70.814436,42.236423),2026=>array(-71.179462,42.246872),2030=>array(-71.288033,42.235239),2032=>array(-71.216187,42.156882),2035=>array(-71.245802,42.061338),2038=>array(-71.410571,42.084858),2043=>array(-70.88127,42.216098),2045=>array(-70.923919,42.292253),2047=>array(-70.68586,42.133734),2048=>array(-71.2173,42.0173),2050=>array(-70.710331,42.115139),2052=>array(-71.305307,42.184599),2053=>array(-71.432781,42.155816),2054=>array(-71.362811,42.172551),2056=>array(-71.32936,42.116245),2061=>array(-70.818844,42.164569),2062=>array(-71.195955,42.18736),2066=>array(-70.758184,42.202273),2067=>array(-71.181771,42.107782),2071=>array(-71.273589,42.103425),2072=>array(-71.10365,42.119006),2081=>array(-71.270378,42.146227),2090=>array(-71.216769,42.219645),2093=>array(-71.356858,42.052671),2108=>array(-71.064848,42.357767),2109=>array(-71.050633,42.367223),2110=>array(-71.047846,42.361962),2111=>array(-71.059062,42.350518),2113=>array(-71.055236,42.365335),2114=>array(-71.068646,42.363175),2115=>array(-71.104176,42.336342),2116=>array(-71.076397,42.350579),2118=>array(-71.069805,42.33786),2119=>array(-71.085021,42.324026),2120=>array(-71.096545,42.332091),2121=>array(-71.085897,42.306267),2122=>array(-71.042158,42.291413),2124=>array(-71.070571,42.285805),2125=>array(-71.055896,42.315748),2126=>array(-71.09679,42.274016),2127=>array(-71.039093,42.334992),2128=>array(-71.006975,42.361129),2129=>array(-71.061487,42.379657),2130=>array(-71.113835,42.309174),2131=>array(-71.126228,42.284333),2132=>array(-71.162017,42.280455),2134=>array(-71.128608,42.358016),2135=>array(-71.153964,42.349688),2136=>array(-71.12922,42.255083),2138=>array(-71.135152,42.379637),2139=>array(-71.103353,42.362986),2140=>array(-71.133996,42.392157),2141=>array(-71.08256,42.3703),2142=>array(-71.081994,42.361471),2143=>array(-71.096552,42.380985),2144=>array(-71.12255,42.399655),2145=>array(-71.08991,42.391577),2148=>array(-71.057694,42.43014),2149=>array(-71.054649,42.405938),2150=>array(-71.031348,42.396824),2151=>array(-71.001257,42.418294),2152=>array(-70.974807,42.373055),2155=>array(-71.107673,42.42384),2163=>array(-71.12285,42.366168),2169=>array(-71.002279,42.248386),2170=>array(-71.015573,42.266412),2171=>array(-71.020475,42.292142),2176=>array(-71.059019,42.455723),2180=>array(-71.097665,42.474208),2184=>array(-71.002168,42.205416),2186=>array(-71.082651,42.241589),2188=>array(-70.957749,42.204578),2189=>array(-70.931021,42.208704),2190=>array(-70.952363,42.166731),2191=>array(-70.942033,42.243453),2199=>array(-71.082039,42.347463),2203=>array(-71.058775,42.360598),2210=>array(-71.039562,42.347792),2215=>array(-71.102934,42.347593),2301=>array(-71.042304,42.078371),2302=>array(-70.998293,42.088123),2322=>array(-71.05393,42.1324),2324=>array(-70.978778,41.972387),2330=>array(-70.744138,41.878046),2332=>array(-70.706115,42.044373),2333=>array(-70.940459,42.037278),2338=>array(-70.863334,42.003513),2339=>array(-70.85631,42.122956),2341=>array(-70.867161,42.050335),2343=>array(-71.003737,42.148913),2346=>array(-70.869267,41.878004),2347=>array(-70.95704,41.834474),2351=>array(-70.957216,42.119964),2356=>array(-71.12497,42.060485),2357=>array(-71.081416,42.055136),2359=>array(-70.805713,42.067804),2360=>array(-70.631381,41.883359),2364=>array(-70.741942,41.987196),2366=>array(-70.656046,41.85057),2367=>array(-70.802753,41.9591),2368=>array(-71.051567,42.176446),2370=>array(-70.910615,42.130399),2375=>array(-71.076928,42.003041),2379=>array(-71.026717,42.021617),2382=>array(-70.93939,42.078974),2420=>array(-71.215464,42.457055),2421=>array(-71.239573,42.438547),2445=>array(-71.135045,42.325483),2446=>array(-71.122248,42.343503),2451=>array(-71.255708,42.397823),2452=>array(-71.218443,42.392073),2453=>array(-71.240513,42.369542),2457=>array(-71.274242,42.299388),2458=>array(-71.187882,42.35341),2459=>array(-71.192017,42.314779),2460=>array(-71.20849,42.351824),2461=>array(-71.206508,42.317362),2462=>array(-71.2559,42.328708),2464=>array(-71.218882,42.312975),2465=>array(-71.22633,42.348912),2466=>array(-71.248617,42.344457),2467=>array(-71.15306,42.314608),2468=>array(-71.229553,42.328553),2472=>array(-71.177925,42.369451),2474=>array(-71.15637,42.420949),2476=>array(-71.17567,42.415637),2478=>array(-71.180284,42.395317),2481=>array(-71.275531,42.311927),2482=>array(-71.298122,42.293137),2492=>array(-71.244543,42.276029),2493=>array(-71.303433,42.360502),2494=>array(-71.232706,42.299405),2532=>array(-70.597596,41.751767),2534=>array(-70.620356,41.667824),2535=>array(-70.763059,41.334413),2536=>array(-70.567877,41.596976),2537=>array(-70.435818,41.728423),2538=>array(-70.648923,41.77636),2539=>array(-70.522091,41.37766),2540=>array(-70.628285,41.57419),2542=>array(-70.54552,41.707839),2543=>array(-70.766911,41.478974),2553=>array(-70.620758,41.712516),2554=>array(-70.092826,41.291167),2556=>array(-70.624515,41.639445),2557=>array(-70.574093,41.441299),2558=>array(-70.653513,41.745017),2559=>array(-70.616283,41.690243),2561=>array(-70.532595,41.769348),2562=>array(-70.526717,41.787209),2563=>array(-70.476549,41.728137),2564=>array(-69.986367,41.270628),2568=>array(-70.61592,41.458594),2571=>array(-70.695991,41.761187),2575=>array(-70.656934,41.400252),2576=>array(-70.762948,41.772221),2584=>array(-70.007142,41.258688),2601=>array(-70.298442,41.657863),2630=>array(-70.303537,41.704506),2631=>array(-70.068779,41.747016),2632=>array(-70.346876,41.659095),2633=>array(-69.972128,41.689729),2635=>array(-70.438206,41.622905),2637=>array(-70.270929,41.705725),2638=>array(-70.197411,41.730204),2639=>array(-70.135645,41.666904),2641=>array(-70.153472,41.751246),2642=>array(-69.977436,41.841331),2643=>array(-69.937327,41.797777),2644=>array(-70.510786,41.683488),2645=>array(-70.058071,41.70584),2646=>array(-70.071449,41.670596),2647=>array(-70.308397,41.631396),2648=>array(-70.41537,41.670946),2649=>array(-70.489313,41.617239),2650=>array(-69.963804,41.701807),2651=>array(-70.003492,41.874985),2652=>array(-70.094989,42.049537),2653=>array(-69.973549,41.768988),2655=>array(-70.392536,41.630252),2657=>array(-70.200407,42.059829),2659=>array(-70.023531,41.681439),2660=>array(-70.15856,41.7077),2663=>array(-70.01218,41.894444),2664=>array(-70.195648,41.674727),2666=>array(-70.045721,41.990779),2667=>array(-70.023356,41.921997),2668=>array(-70.362696,41.710853),2669=>array(-69.989702,41.666646),2670=>array(-70.170678,41.660113),2671=>array(-70.113401,41.670836),2672=>array(-70.314073,41.635544),2673=>array(-70.247476,41.655182),2675=>array(-70.231801,41.704155),2702=>array(-71.059047,41.785113),2703=>array(-71.294503,41.931653),2713=>array(-70.902217,41.441295),2715=>array(-71.157549,41.815051),2717=>array(-70.972874,41.760108),2718=>array(-71.01169,41.862486),2719=>array(-70.87114,41.632443),2720=>array(-71.120746,41.726343),2721=>array(-71.148281,41.675125),2723=>array(-71.129726,41.692705),2724=>array(-71.1775,41.683936),2725=>array(-71.185458,41.722721),2726=>array(-71.144592,41.7597),2738=>array(-70.752225,41.704138),2739=>array(-70.814531,41.665794),2740=>array(-70.938265,41.637485),2743=>array(-70.901151,41.718217),2744=>array(-70.913632,41.606252),2745=>array(-70.950546,41.700737),2746=>array(-70.941208,41.661694),2747=>array(-71.015965,41.667013),2748=>array(-70.971135,41.553574),2760=>array(-71.335208,41.972493),2762=>array(-71.336602,42.0128),2763=>array(-71.308178,41.966696),2764=>array(-71.153598,41.851929),2766=>array(-71.179067,41.957441),2767=>array(-71.048499,41.940996),2769=>array(-71.244503,41.846963),2770=>array(-70.838449,41.759846),2771=>array(-71.320428,41.837751),2777=>array(-71.214202,41.758175),2779=>array(-71.077615,41.838061),2780=>array(-71.118346,41.909112),2790=>array(-71.082371,41.599176),2791=>array(-71.078091,41.528538),2802=>array(-71.456233,41.95213),2804=>array(-71.770314,41.433934),2806=>array(-71.319732,41.734753),2807=>array(-71.577096,41.17684),2808=>array(-71.749674,41.408251),2809=>array(-71.273331,41.67573),2812=>array(-71.652334,41.478948),2813=>array(-71.669861,41.394479),2814=>array(-71.700554,41.895932),2815=>array(-71.647954,41.77463),2816=>array(-71.619116,41.692046),2817=>array(-71.678369,41.637104),2818=>array(-71.485719,41.642919),2822=>array(-71.626993,41.57021),2825=>array(-71.726833,41.782067),2826=>array(-71.653144,41.982746),2827=>array(-71.739118,41.698748),2828=>array(-71.564311,41.880083),2830=>array(-71.654226,41.97498),2831=>array(-71.620289,41.774762),2832=>array(-71.72962,41.514716),2833=>array(-71.772112,41.483583),2835=>array(-71.378366,41.510088),2836=>array(-71.620332,41.454574),2837=>array(-71.167247,41.518769),2838=>array(-71.476373,41.965249),2839=>array(-71.641513,41.940757),2840=>array(-71.322375,41.478216),2841=>array(-71.332175,41.511864),2842=>array(-71.281685,41.518611),2852=>array(-71.459825,41.588552),2857=>array(-71.633605,41.822761),2858=>array(-71.653424,41.965375),2859=>array(-71.757323,41.959069),2860=>array(-71.388673,41.870378),2861=>array(-71.353131,41.878603),2863=>array(-71.393481,41.890064),2864=>array(-71.420477,41.967599),2865=>array(-71.44834,41.913145),2871=>array(-71.261269,41.587259),2872=>array(-71.321497,41.597011),2873=>array(-71.780524,41.533065),2874=>array(-71.481857,41.508687),2875=>array(-71.638865,41.456486),2876=>array(-71.58549,41.994278),2878=>array(-71.180471,41.610137),2879=>array(-71.534272,41.424013),2881=>array(-71.524717,41.478083),2882=>array(-71.473206,41.41711),2885=>array(-71.258373,41.724959),2886=>array(-71.455568,41.703849),2888=>array(-71.406118,41.747671),2889=>array(-71.376927,41.700591),2891=>array(-71.789666,41.361831),2892=>array(-71.592808,41.489847),2893=>array(-71.518688,41.679006),2894=>array(-71.703237,41.44447),2895=>array(-71.499949,42.001706),2896=>array(-71.544069,41.975186),2898=>array(-71.672436,41.516047),2903=>array(-71.409088,41.81823),2904=>array(-71.436309,41.858331),2905=>array(-71.396103,41.784725),2906=>array(-71.390408,41.840169),2907=>array(-71.42463,41.798593),2908=>array(-71.436794,41.839825),2909=>array(-71.453869,41.821521),2910=>array(-71.435594,41.774999),2911=>array(-71.472812,41.854888),2912=>array(-71.402239,41.825593),2914=>array(-71.366169,41.814295),2915=>array(-71.354839,41.772847),2916=>array(-71.352424,41.842653),2917=>array(-71.523305,41.905774),2919=>array(-71.519879,41.82744),2920=>array(-71.465508,41.767344),2921=>array(-71.517296,41.766854),3031=>array(-71.600503,42.874864),3032=>array(-71.363424,42.997261),3033=>array(-71.67583,42.749989),3034=>array(-71.319997,43.061446),3036=>array(-71.255213,42.984657),3037=>array(-71.248197,43.141274),3038=>array(-71.276763,42.892761),3042=>array(-71.078737,43.048512),3043=>array(-71.817788,42.997),3044=>array(-71.119714,42.999856),3045=>array(-71.563462,43.021515),3046=>array(-71.60748,43.112454),3047=>array(-71.879424,42.93874),3048=>array(-71.76206,42.742343),3049=>array(-71.585401,42.749626),3051=>array(-71.409494,42.760508),3052=>array(-71.468297,42.846073),3053=>array(-71.387919,42.86967),3054=>array(-71.520956,42.853756),3055=>array(-71.673354,42.818645),3057=>array(-71.694199,42.908885),3060=>array(-71.458792,42.741295),3062=>array(-71.495387,42.723884),3063=>array(-71.51793,42.782146),3064=>array(-71.474918,42.779378),3070=>array(-71.677524,42.981207),3071=>array(-71.874434,42.746257),3076=>array(-71.337073,42.730992),3077=>array(-71.205107,43.038038),3079=>array(-71.22172,42.788275),3082=>array(-71.771414,42.904156),3084=>array(-71.875294,42.826895),3086=>array(-71.759816,42.832063),3087=>array(-71.302688,42.811092),3101=>array(-71.466111,42.989027),3102=>array(-71.491119,43.011915),3103=>array(-71.446547,42.950538),3104=>array(-71.439782,43.009552),3106=>array(-71.446878,43.082584),3109=>array(-71.40035,42.963734),3110=>array(-71.536871,42.935584),3215=>array(-71.447774,43.942621),3216=>array(-71.79794,43.451175),3217=>array(-71.642508,43.726075),3218=>array(-71.277262,43.338034),3220=>array(-71.482372,43.474596),3221=>array(-71.960169,43.258003),3222=>array(-71.789139,43.642709),3223=>array(-71.68547,43.855414),3224=>array(-71.55802,43.36249),3225=>array(-71.239034,43.363332),3226=>array(-71.515467,43.710672),3227=>array(-71.48108,43.841356),3229=>array(-71.697915,43.203876),3230=>array(-71.890242,43.50865),3231=>array(-71.762339,43.473341),3233=>array(-71.931188,43.424042),3234=>array(-71.348563,43.204812),3235=>array(-71.674267,43.449136),3237=>array(-71.387249,43.423067),3238=>array(-71.911271,43.984428),3240=>array(-71.962546,43.576693),3241=>array(-71.817394,43.751504),3242=>array(-71.831189,43.169421),3243=>array(-71.768677,43.528694),3244=>array(-71.91694,43.128103),3245=>array(-71.594625,43.745844),3246=>array(-71.481025,43.576423),3249=>array(-71.367281,43.522384),3251=>array(-71.494074,44.100673),3253=>array(-71.498585,43.631211),3254=>array(-71.369179,43.717721),3255=>array(-72.024551,43.314026),3256=>array(-71.632625,43.623326),3257=>array(-71.990609,43.417721),3258=>array(-71.408835,43.265259),3259=>array(-71.395018,43.875712),3260=>array(-71.921638,43.344231),3261=>array(-71.215974,43.210589),3262=>array(-71.714447,43.999889),3263=>array(-71.309368,43.288501),3264=>array(-71.702722,43.738799),3266=>array(-71.884746,43.782889),3268=>array(-71.769947,43.388528),3269=>array(-71.601607,43.524186),3273=>array(-71.926953,43.301982),3275=>array(-71.416755,43.159633),3276=>array(-71.575998,43.431031),3278=>array(-71.835468,43.309037),3279=>array(-71.878102,43.952771),3280=>array(-72.087057,43.178127),3281=>array(-71.703612,43.078061),3282=>array(-71.923719,43.858722),3284=>array(-72.027553,43.470501),3285=>array(-71.635802,43.94787),3287=>array(-71.922637,43.443115),3290=>array(-71.131859,43.129847),3291=>array(-71.142619,43.179131),3293=>array(-71.679913,43.97062),3301=>array(-71.553012,43.23227),3303=>array(-71.665421,43.311685),3304=>array(-71.537242,43.133177),3307=>array(-71.446658,43.333988),3431=>array(-72.294803,42.965044),3440=>array(-71.988755,43.052669),3441=>array(-72.446994,42.780669),3442=>array(-71.903693,43.020281),3443=>array(-72.456114,42.875727),3444=>array(-72.069849,42.889279),3445=>array(-72.214374,43.020616),3446=>array(-72.29636,42.858271),3447=>array(-72.153174,42.753868),3448=>array(-72.274498,43.052622),3449=>array(-71.997821,42.977339),3450=>array(-72.068558,42.948318),3451=>array(-72.504822,42.809298),3452=>array(-72.059901,42.829254),3455=>array(-72.172904,42.901769),3456=>array(-72.208769,43.138544),3457=>array(-72.121568,42.999759),3458=>array(-71.940102,42.868369),3461=>array(-72.013247,42.756663),3462=>array(-72.388934,42.889215),3464=>array(-72.124299,43.088157),3465=>array(-72.18894,42.828785),3466=>array(-72.502966,42.890263),3467=>array(-72.430856,42.968075),3470=>array(-72.354694,42.771336),3561=>array(-71.795119,44.343352),3570=>array(-71.155466,44.504596),3574=>array(-71.609203,44.260435),3575=>array(-71.402889,44.313744),3576=>array(-71.385112,44.912445),3579=>array(-71.025563,44.964771),3580=>array(-71.693299,44.163382),3581=>array(-71.152149,44.289781),3582=>array(-71.441428,44.562046),3583=>array(-71.464694,44.396741),3584=>array(-71.545865,44.483853),3585=>array(-71.877173,44.222416),3586=>array(-71.80024,44.21841),3588=>array(-71.211846,44.62304),3590=>array(-71.47672,44.750929),3592=>array(-71.260979,45.116271),3593=>array(-71.299151,44.302174),3595=>array(-71.497302,44.305324),3597=>array(-71.382495,44.744505),3598=>array(-71.628699,44.378898),3601=>array(-72.288446,43.236967),3602=>array(-72.347568,43.140832),3603=>array(-72.383931,43.246634),3604=>array(-72.376864,43.127333),3605=>array(-72.184869,43.236564),3607=>array(-72.268353,43.19651),3608=>array(-72.395926,43.076505),3609=>array(-72.446391,43.143926),3740=>array(-71.978799,44.184322),3741=>array(-72.008828,43.674942),3743=>array(-72.326929,43.360725),3745=>array(-72.33415,43.476455),3746=>array(-72.257151,43.494376),3748=>array(-72.131929,43.589031),3750=>array(-72.195047,43.708188),3751=>array(-72.092311,43.449753),3752=>array(-72.100485,43.272295),3753=>array(-72.149093,43.51659),3754=>array(-72.13839,43.377461),3755=>array(-72.139134,43.740983),3765=>array(-72.050203,44.035227),3766=>array(-72.235746,43.633301),3768=>array(-72.094012,43.816372),3770=>array(-72.258815,43.5313),3771=>array(-71.980649,44.296664),3773=>array(-72.197494,43.370546),3774=>array(-71.985475,44.099753),3777=>array(-72.061138,43.886181),3779=>array(-72.001418,43.961593),3780=>array(-71.988957,44.046846),3781=>array(-72.299358,43.560058),3782=>array(-72.093129,43.390088),3784=>array(-72.306405,43.638168),3785=>array(-71.9122,44.043516),3801=>array(-70.805443,43.074812),3809=>array(-71.199131,43.457846),3810=>array(-71.293868,43.513645),3811=>array(-71.16632,42.839223),3812=>array(-71.297237,44.08113),3813=>array(-71.060853,44.127388),3814=>array(-71.181505,43.770937),3816=>array(-71.269001,43.68651),3817=>array(-71.229402,43.88717),3818=>array(-71.27532,43.959534),3819=>array(-71.120184,42.927911),3820=>array(-70.887661,43.190665),3823=>array(-70.941453,43.174607),3824=>array(-70.91842,43.117346),3825=>array(-71.038979,43.215569),3826=>array(-71.130675,42.890002),3827=>array(-70.99557,42.903739),3830=>array(-70.9945,43.613563),3832=>array(-71.04752,43.90696),3833=>array(-70.987522,42.978415),3835=>array(-71.083259,43.37256),3836=>array(-71.075122,43.842055),3837=>array(-71.336087,43.422251),3838=>array(-71.225448,44.112336),3839=>array(-70.991203,43.262994),3840=>array(-70.845622,43.039732),3841=>array(-71.183034,42.881445),3842=>array(-70.836728,42.939601),3844=>array(-70.886242,42.924811),3845=>array(-71.120516,44.095422),3846=>array(-71.155786,44.187473),3847=>array(-71.124033,44.071875),3848=>array(-71.073595,42.913731),3849=>array(-71.129871,43.902455),3850=>array(-71.297603,43.690636),3851=>array(-71.025435,43.437254),3852=>array(-70.98604,43.495013),3853=>array(-71.283253,43.642126),3854=>array(-70.718856,43.06028),3855=>array(-71.152216,43.463672),3856=>array(-70.967954,43.038509),3857=>array(-70.951365,43.071424),3858=>array(-71.045915,42.870369),3860=>array(-71.120959,44.040239),3861=>array(-71.006511,43.118537),3862=>array(-70.830109,42.978317),3864=>array(-71.100411,43.688305),3865=>array(-71.094993,42.840703),3867=>array(-70.988238,43.303528),3868=>array(-70.940177,43.324241),3869=>array(-70.843112,43.219845),3870=>array(-70.75833,43.008649),3871=>array(-70.777362,42.980948),3872=>array(-71.043233,43.570559),3873=>array(-71.183605,42.934018),3874=>array(-70.860823,42.883123),3875=>array(-71.189275,43.895078),3878=>array(-70.887944,43.253476),3882=>array(-71.04191,43.746733),3883=>array(-71.320336,43.808537),3884=>array(-71.168991,43.275599),3885=>array(-70.902586,43.014997),3886=>array(-71.296068,43.864038),3887=>array(-71.068085,43.499637),3890=>array(-71.201489,43.800602),3894=>array(-71.177139,43.603773),3901=>array(-70.842077,43.299332),3902=>array(-70.628806,43.214916),3903=>array(-70.774383,43.146552),3904=>array(-70.728595,43.108051),3905=>array(-70.686846,43.086194),3906=>array(-70.778745,43.35111),3907=>array(-70.611275,43.255858),3908=>array(-70.752426,43.230492),3909=>array(-70.679004,43.16646),3910=>array(-70.603455,43.185309),3911=>array(-70.626355,43.142223),4001=>array(-70.923659,43.51984),4002=>array(-70.661906,43.489069),4003=>array(-69.956899,43.727261),4005=>array(-70.485368,43.492125),4006=>array(-70.34457,43.444292),4008=>array(-69.867048,44.034239),4009=>array(-70.728424,44.046241),4010=>array(-70.918584,43.930799),4011=>array(-69.973386,43.896431),4015=>array(-70.521109,43.976287),4017=>array(-70.088396,43.738955),4019=>array(-70.102838,43.686216),4020=>array(-70.808862,43.767186),4021=>array(-70.266527,43.792289),4022=>array(-70.814547,43.99463),4024=>array(-70.685245,43.83632),4027=>array(-70.912785,43.399909),4029=>array(-70.689564,43.902532),4030=>array(-70.696275,43.589062),4032=>array(-70.091699,43.843503),4037=>array(-70.946608,44.094355),4038=>array(-70.46378,43.703617),4039=>array(-70.367027,43.904551),4040=>array(-70.820154,44.143452),4041=>array(-70.831569,43.848913),4042=>array(-70.614369,43.631019),4043=>array(-70.576994,43.393277),4046=>array(-70.474113,43.42948),4047=>array(-70.899154,43.732787),4048=>array(-70.781883,43.688481),4049=>array(-70.70298,43.745004),4050=>array(-70.153919,43.685939),4051=>array(-70.885803,44.192471),4055=>array(-70.639298,43.975769),4056=>array(-70.877492,43.659808),4057=>array(-70.698919,44.101552),4061=>array(-70.741783,43.635495),4062=>array(-70.405329,43.794689),4063=>array(-70.394191,43.499153),4064=>array(-70.38825,43.525044),4066=>array(-69.965439,43.769148),4068=>array(-70.947045,43.838843),4069=>array(-70.182018,43.903914),4071=>array(-70.450242,43.928049),4072=>array(-70.466341,43.550411),4073=>array(-70.747751,43.418644),4074=>array(-70.366191,43.589627),4076=>array(-70.832796,43.554017),4079=>array(-69.97153,43.790591),4083=>array(-70.814398,43.464121),4084=>array(-70.56668,43.762147),4085=>array(-70.616514,43.77332),4086=>array(-69.955624,43.964977),4087=>array(-70.744025,43.569932),4088=>array(-70.722362,44.202833),4090=>array(-70.645586,43.331432),4091=>array(-70.744187,43.839352),4092=>array(-70.352614,43.707947),4093=>array(-70.538831,43.636387),4095=>array(-70.906834,43.628909),4096=>array(-70.159447,43.787819),4097=>array(-70.234109,43.850998),4101=>array(-70.257949,43.662607),4102=>array(-70.304301,43.657977),4103=>array(-70.288071,43.69413),4105=>array(-70.277172,43.740479),4106=>array(-70.285989,43.631402),4107=>array(-70.236476,43.587173),4108=>array(-70.186052,43.660255),4109=>array(-70.171426,43.637528),4110=>array(-70.180065,43.746027),4210=>array(-70.249649,44.084537),4216=>array(-70.855362,44.708613),4217=>array(-70.815239,44.3801),4219=>array(-70.55811,44.400755),4220=>array(-70.351732,44.343734),4221=>array(-70.300563,44.462329),4222=>array(-70.126598,43.964603),4224=>array(-70.415749,44.559953),4226=>array(-70.676912,44.597872),4227=>array(-70.293139,44.568123),4228=>array(-70.11525,44.433489),4231=>array(-70.875532,44.263039),4234=>array(-70.191893,44.623831),4236=>array(-70.145088,44.189754),4237=>array(-70.734687,44.494585),4238=>array(-70.388878,44.209257),4239=>array(-70.202187,44.516897),4240=>array(-70.172185,44.089594),4250=>array(-70.12747,44.01052),4252=>array(-70.058799,44.036688),4253=>array(-70.21556,44.404127),4254=>array(-70.137715,44.445003),4255=>array(-70.66983,44.344761),4256=>array(-70.40468,44.104897),4257=>array(-70.495771,44.553364),4258=>array(-70.336334,44.13794),4259=>array(-70.014723,44.233505),4260=>array(-70.296011,43.957508),4261=>array(-70.961471,44.503368),4263=>array(-70.133074,44.295351),4265=>array(-70.042845,44.279255),4267=>array(-70.792354,44.206591),4268=>array(-70.610021,44.225867),4270=>array(-70.527478,44.117335),4271=>array(-70.49819,44.263611),4274=>array(-70.393563,44.048106),4275=>array(-70.646426,44.702191),4276=>array(-70.625313,44.559954),4280=>array(-70.059358,44.119863),4281=>array(-70.490816,44.248001),4282=>array(-70.24798,44.265107),4284=>array(-70.06123,44.362503),4285=>array(-70.448975,44.697513),4286=>array(-70.865079,44.401438),4287=>array(-69.974982,44.065403),4289=>array(-70.522647,44.319278),4290=>array(-70.430225,44.473718),4292=>array(-70.449596,44.385909),4294=>array(-70.275434,44.637914),4330=>array(-69.747639,44.351875),4342=>array(-69.737021,44.086084),4343=>array(-69.891409,44.32879),4344=>array(-69.827805,44.260548),4345=>array(-69.793915,44.195062),4346=>array(-69.751356,44.236607),4347=>array(-69.81804,44.287241),4348=>array(-69.499152,44.210864),4349=>array(-70.067034,44.434007),4350=>array(-69.9345,44.172144),4351=>array(-69.862257,44.342538),4352=>array(-69.96045,44.466488),4353=>array(-69.619628,44.198048),4354=>array(-69.43063,44.396114),4355=>array(-69.945747,44.381571),4357=>array(-69.829607,44.116833),4358=>array(-69.535271,44.414473),4359=>array(-69.762624,44.177786),4360=>array(-69.999631,44.55484),4363=>array(-69.573032,44.316673),4364=>array(-69.963093,44.309991),4401=>array(-68.850405,44.848517),4406=>array(-69.596917,45.2293),4408=>array(-68.302785,44.893162),4410=>array(-68.906681,45.08826),4411=>array(-68.58047,44.869056),4412=>array(-68.735075,44.784691),4413=>array(-67.764628,45.561415),4414=>array(-69.11457,45.442861),4415=>array(-69.057877,45.400376),4416=>array(-68.749742,44.623798),4417=>array(-68.341886,45.231514),4418=>array(-68.461406,45.088416),4419=>array(-69.003117,44.800454),4421=>array(-68.814192,44.409668),4422=>array(-69.031437,45.077653),4424=>array(-67.876199,45.680311),4426=>array(-69.189134,45.213059),4427=>array(-69.010879,44.980538),4428=>array(-68.553983,44.805781),4429=>array(-68.61623,44.720612),4430=>array(-68.575197,45.636841),4431=>array(-68.668816,44.557581),4434=>array(-69.132895,44.785632),4435=>array(-69.124994,44.963218),4438=>array(-68.928337,44.598953),4441=>array(-69.623233,45.702416),4442=>array(-69.727274,45.497827),4443=>array(-69.353525,45.228047),4444=>array(-68.949961,44.728984),4448=>array(-68.71106,45.296196),4449=>array(-68.888485,44.992639),4450=>array(-68.92799,44.916048),4451=>array(-68.222173,45.60701),4453=>array(-68.760531,45.16225),4454=>array(-67.561059,45.552117),4455=>array(-68.259756,45.299494),4456=>array(-68.996713,44.876869),4457=>array(-68.479867,45.413429),4459=>array(-68.339985,45.588735),4460=>array(-68.539963,45.711395),4461=>array(-68.582438,44.954787),4462=>array(-69.012445,45.972769),4463=>array(-68.90254,45.28233),4464=>array(-69.276365,45.41704),4468=>array(-68.733419,45.023431),4469=>array(-68.668316,44.901059),4471=>array(-67.861428,45.90829),4472=>array(-68.670122,44.576095),4473=>array(-68.738649,44.881679),4474=>array(-68.770343,44.706955),4475=>array(-68.589614,45.183587),4476=>array(-68.706001,44.482702),4478=>array(-69.815675,45.86523),4479=>array(-69.321792,45.14118),4481=>array(-69.092775,45.245979),4485=>array(-69.624361,45.358461),4487=>array(-68.104471,45.387737),4488=>array(-69.104698,44.875433),4489=>array(-68.690173,44.910384),4490=>array(-67.867623,45.436636),4491=>array(-67.473356,45.572693),4492=>array(-67.681322,45.367045),4493=>array(-68.524576,45.236824),4495=>array(-68.333804,45.454119),4496=>array(-68.90889,44.650384),4497=>array(-68.060944,45.75461),4530=>array(-69.826702,43.88824),4535=>array(-69.629175,44.098471),4537=>array(-69.618394,43.875516),4538=>array(-69.627611,43.851505),4539=>array(-69.500783,43.974967),4541=>array(-69.476881,43.894242),4543=>array(-69.497588,44.022865),4544=>array(-69.582479,43.84456),4547=>array(-69.33495,43.97986),4548=>array(-69.738561,43.833447),4551=>array(-69.430661,43.975714),4553=>array(-69.567522,44.052277),4554=>array(-69.512332,43.864966),4555=>array(-69.482767,44.101202),4556=>array(-69.623536,43.972254),4558=>array(-69.514471,43.885128),4562=>array(-69.819176,43.770817),4563=>array(-69.258706,44.013924),4564=>array(-69.457458,43.93185),4568=>array(-69.558472,43.878003),4570=>array(-69.630765,43.808546),4571=>array(-69.67417,43.896656),4572=>array(-69.38335,44.122083),4573=>array(-69.55233,43.951357),4574=>array(-69.391524,44.260639),4575=>array(-69.662658,43.852011),4576=>array(-69.662868,43.813345),4578=>array(-69.692754,43.982445),4579=>array(-69.769351,43.959656),4605=>array(-68.391841,44.672809),4606=>array(-67.712364,44.540726),4607=>array(-68.087772,44.467314),4609=>array(-68.263808,44.39747),4611=>array(-67.612596,44.466957),4612=>array(-68.414514,44.23153),4613=>array(-68.027288,44.371929),4614=>array(-68.569297,44.40218),4616=>array(-68.540355,44.261324),4617=>array(-68.76099,44.351627),4619=>array(-67.239189,45.150327),4622=>array(-67.966952,44.75066),4623=>array(-67.733658,44.744467),4624=>array(-67.985876,44.423951),4625=>array(-68.261711,44.259793),4626=>array(-67.219358,44.665569),4627=>array(-68.607845,44.23701),4628=>array(-67.281078,44.873113),4629=>array(-68.506597,44.421885),4630=>array(-67.477913,44.855066),4631=>array(-67.008913,44.910958),4634=>array(-68.222036,44.650904),4635=>array(-68.351482,44.172234),4637=>array(-67.81603,45.196253),4640=>array(-68.285916,44.524175),4642=>array(-68.809947,44.330584),4643=>array(-67.818538,44.538027),4644=>array(-68.252076,44.413835),4645=>array(-68.620985,44.064664),4646=>array(-68.224954,44.245566),4648=>array(-67.59633,44.665425),4649=>array(-67.48983,44.54711),4650=>array(-68.713763,44.287636),4652=>array(-67.062328,44.819713),4653=>array(-68.334648,44.209467),4654=>array(-67.539894,44.757153),4655=>array(-67.377551,44.653005),4657=>array(-67.415773,44.970309),4658=>array(-67.878004,44.50791),4660=>array(-68.346104,44.338276),4662=>array(-68.292452,44.300959),4664=>array(-68.127353,44.543335),4666=>array(-67.223672,44.980584),4667=>array(-67.103562,44.985316),4668=>array(-67.585966,45.212926),4669=>array(-68.015641,44.408677),4671=>array(-67.152172,45.067375),4673=>array(-68.679144,44.314352),4674=>array(-68.458828,44.274254),4675=>array(-68.251148,44.301347),4676=>array(-68.634365,44.34688),4677=>array(-68.181506,44.476822),4679=>array(-68.325159,44.273005),4680=>array(-67.946457,44.501482),4681=>array(-68.645327,44.150464),4683=>array(-68.787827,44.245205),4684=>array(-68.50319,44.467361),4685=>array(-68.465212,44.151687),4686=>array(-67.694027,44.996537),4691=>array(-67.255047,44.760322),4693=>array(-68.093624,44.376493),4694=>array(-67.477541,45.115083),4730=>array(-67.861028,46.191043),4732=>array(-68.939198,46.327493),4733=>array(-68.404152,45.757478),4734=>array(-67.956337,46.468001),4735=>array(-67.866788,46.416386),4736=>array(-68.026095,46.909532),4739=>array(-68.672927,46.995906),4740=>array(-67.847623,46.633304),4741=>array(-69.222921,47.453712),4742=>array(-67.859197,46.776241),4743=>array(-68.614333,47.200266),4745=>array(-68.388783,47.282101),4746=>array(-68.136142,47.256665),4747=>array(-68.233771,46.004972),4750=>array(-67.857723,46.955064),4756=>array(-68.303525,47.328079),4757=>array(-68.168635,46.667614),4758=>array(-67.853225,46.559272),4760=>array(-67.954874,46.339341),4761=>array(-67.975284,46.117254),4762=>array(-68.124731,46.958248),4763=>array(-68.114066,46.074387),4764=>array(-68.585323,46.398929),4765=>array(-68.591119,46.158786),4766=>array(-68.21578,46.892463),4768=>array(-68.891724,46.863157),4769=>array(-67.993016,46.688484),4772=>array(-68.311449,47.230084),4773=>array(-68.22314,47.267509),4774=>array(-69.1545,47.07704),4776=>array(-68.324753,45.871695),4777=>array(-68.501076,45.842521),4779=>array(-68.331472,47.114457),4780=>array(-68.285281,46.239244),4781=>array(-68.613495,47.150199),4783=>array(-68.17505,47.040124),4785=>array(-67.99435,47.111951),4786=>array(-68.192051,46.794921),4787=>array(-67.972825,46.534693),4841=>array(-69.133822,44.133536),4843=>array(-69.064039,44.238406),4847=>array(-69.189267,44.240818),4848=>array(-68.91525,44.29888),4849=>array(-69.025998,44.316106),4851=>array(-68.86868,43.87711),4852=>array(-69.309772,43.766543),4853=>array(-68.867587,44.136963),4854=>array(-69.079854,44.075525),4855=>array(-69.263526,43.935858),4856=>array(-69.121696,44.180452),4858=>array(-69.156345,44.047854),4859=>array(-69.144356,43.999115),4860=>array(-69.21605,43.979596),4861=>array(-69.171387,44.107601),4862=>array(-69.277723,44.262706),4863=>array(-68.853259,44.068908),4864=>array(-69.243193,44.128546),4901=>array(-69.575174,44.540353),4910=>array(-69.445253,44.508045),4911=>array(-69.972548,44.769927),4912=>array(-69.689878,44.980705),4915=>array(-69.037571,44.463502),4917=>array(-69.839488,44.487708),4918=>array(-69.866232,44.51573),4920=>array(-69.854458,45.142341),4921=>array(-69.136548,44.560894),4922=>array(-69.384813,44.688545),4923=>array(-69.445746,45.029009),4924=>array(-69.546315,44.782241),4925=>array(-69.903397,45.212372),4926=>array(-69.513908,44.480122),4927=>array(-69.531675,44.659788),4928=>array(-69.258217,44.943693),4929=>array(-69.302176,44.772109),4930=>array(-69.31797,45.027572),4932=>array(-69.143702,44.69757),4933=>array(-69.231348,44.816495),4936=>array(-70.624426,45.421946),4937=>array(-69.661276,44.651653),4938=>array(-70.103104,44.661856),4939=>array(-69.158771,45.077258),4940=>array(-70.083293,44.623994),4941=>array(-69.285662,44.46719),4942=>array(-69.586446,45.077022),4943=>array(-69.5205,44.879823),4944=>array(-69.646718,44.692647),4945=>array(-70.266346,45.869719),4947=>array(-70.269486,45.049549),4949=>array(-69.333664,44.37103),4950=>array(-69.799713,44.826354),4951=>array(-69.07076,44.607516),4952=>array(-69.154791,44.412796),4953=>array(-69.236698,44.8603),4955=>array(-69.993337,44.647207),4956=>array(-70.10984,44.807906),4957=>array(-69.843372,44.702067),4958=>array(-69.918836,44.899067),4961=>array(-70.144293,45.137779),4962=>array(-69.625946,44.489077),4963=>array(-69.887309,44.589007),4964=>array(-70.774098,44.866916),4965=>array(-69.368356,44.843151),4966=>array(-70.427311,44.814699),4967=>array(-69.43367,44.769841),4969=>array(-69.236275,44.785285),4970=>array(-70.61795,45.008278),4971=>array(-69.391278,44.92968),4973=>array(-69.19393,44.362192),4974=>array(-68.927435,44.471036),4975=>array(-69.588334,44.625354),4976=>array(-69.66769,44.78928),4978=>array(-69.800169,44.642012),4979=>array(-69.807536,44.939541),4981=>array(-68.839047,44.514122),4982=>array(-70.430575,45.097984),4983=>array(-70.368401,44.979981),4984=>array(-70.271152,44.698619),4985=>array(-69.931095,45.369441),4986=>array(-69.211292,44.54946),4987=>array(-69.251844,44.674148),4988=>array(-69.362441,44.570148),4989=>array(-69.649508,44.42798),4992=>array(-70.162677,44.663657),5001=>array(-72.380193,43.672188),5031=>array(-72.589826,43.699932),5032=>array(-72.65774,43.801566),5033=>array(-72.158312,44.01218),5034=>array(-72.643241,43.5745),5035=>array(-72.6864,43.61167),5036=>array(-72.58709,44.023896),5037=>array(-72.493459,43.457745),5038=>array(-72.459992,43.993916),5039=>array(-72.31308,44.063296),5040=>array(-72.198724,44.06988),5041=>array(-72.538902,43.955546),5042=>array(-72.096756,44.222165),5043=>array(-72.204673,43.805098),5045=>array(-72.180296,43.917846),5046=>array(-72.257516,44.232453),5048=>array(-72.427711,43.580615),5050=>array(-72.064006,44.266812),5051=>array(-72.121743,44.104485),5052=>array(-72.359713,43.596988),5053=>array(-72.489225,43.719447),5055=>array(-72.323984,43.777628),5056=>array(-72.704232,43.50671),5058=>array(-72.272289,43.881263),5059=>array(-72.427734,43.637817),5060=>array(-72.708604,43.967072),5061=>array(-72.570184,43.916763),5062=>array(-72.599969,43.496493),5065=>array(-72.423363,43.782477),5067=>array(-72.518063,43.677373),5068=>array(-72.547496,43.780961),5069=>array(-72.131204,44.204072),5070=>array(-72.344406,43.851588),5071=>array(-72.546332,43.561557),5072=>array(-72.372069,43.898928),5075=>array(-72.288607,43.847073),5076=>array(-72.230959,44.141854),5077=>array(-72.459306,43.908796),5079=>array(-72.326539,43.956765),5081=>array(-72.065864,44.122968),5083=>array(-72.268095,43.918897),5084=>array(-72.451442,43.729848),5086=>array(-72.300719,44.108969),5089=>array(-72.442313,43.495591),5091=>array(-72.577119,43.634612),5101=>array(-72.493221,43.182144),5141=>array(-72.569224,43.151168),5142=>array(-72.580475,43.397517),5143=>array(-72.640348,43.27763),5146=>array(-72.633999,43.184967),5148=>array(-72.791008,43.231362),5149=>array(-72.712123,43.380553),5150=>array(-72.53079,43.334434),5151=>array(-72.496973,43.395317),5152=>array(-72.939013,43.233332),5153=>array(-72.642552,43.418436),5154=>array(-72.546165,43.135197),5155=>array(-72.915891,43.092921),5156=>array(-72.461623,43.310627),5158=>array(-72.469725,43.084054),5161=>array(-72.802903,43.321441),5201=>array(-73.129196,42.869481),5250=>array(-73.173044,43.103754),5251=>array(-73.063631,43.264183),5252=>array(-73.068759,43.081011),5253=>array(-73.002022,43.245763),5254=>array(-73.060906,43.153807),5255=>array(-73.0222,43.137364),5257=>array(-73.260755,42.958719),5260=>array(-73.265621,42.808836),5261=>array(-73.195152,42.782513),5262=>array(-73.07526,42.973748),5301=>array(-72.655573,42.842769),5340=>array(-72.972359,43.168974),5341=>array(-72.79786,42.964292),5342=>array(-72.794821,42.777498),5343=>array(-72.82026,43.103091),5345=>array(-72.684024,42.987719),5346=>array(-72.536522,43.037688),5350=>array(-72.97264,42.790943),5352=>array(-73.076527,42.808039),5353=>array(-72.682189,43.071031),5354=>array(-72.522086,42.764133),5355=>array(-72.81353,43.020138),5356=>array(-72.864581,42.975529),5358=>array(-72.705469,42.773345),5359=>array(-72.715939,43.153015),5360=>array(-72.946971,43.000119),5361=>array(-72.879131,42.780694),5362=>array(-72.660004,42.935303),5363=>array(-72.893126,42.882781),5401=>array(-73.209998,44.476621),5403=>array(-73.173468,44.444866),5404=>array(-73.184854,44.495588),5405=>array(-73.195609,44.473733),5408=>array(-73.249611,44.511852),5439=>array(-73.164415,44.494539),5440=>array(-73.291974,44.957882),5441=>array(-72.720038,44.805565),5442=>array(-72.671334,44.757187),5443=>array(-73.03993,44.139443),5444=>array(-72.896957,44.649728),5445=>array(-73.220978,44.309955),5446=>array(-73.182904,44.541385),5447=>array(-72.701892,44.932454),5448=>array(-72.900865,44.750291),5450=>array(-72.795246,44.894578),5452=>array(-73.050085,44.538872),5454=>array(-73.028878,44.710289),5455=>array(-72.967393,44.801687),5456=>array(-73.264596,44.221416),5457=>array(-72.917923,44.957693),5458=>array(-73.307486,44.717847),5459=>array(-73.005367,44.95006),5461=>array(-73.087324,44.332786),5462=>array(-72.952108,44.312539),5463=>array(-73.3492,44.871324),5464=>array(-72.818997,44.646262),5465=>array(-72.959411,44.464905),5468=>array(-73.144488,44.657371),5471=>array(-72.577366,44.827981),5472=>array(-73.155209,44.102761),5473=>array(-73.194663,44.241936),5474=>array(-73.297992,44.787732),5476=>array(-72.643138,44.955228),5477=>array(-72.962422,44.416769),5478=>array(-73.081499,44.809326),5481=>array(-73.205391,44.772921),5482=>array(-73.211006,44.380662),5483=>array(-72.963135,44.889901),5485=>array(-72.970903,44.900339),5486=>array(-73.30774,44.642247),5487=>array(-72.990128,44.228435),5488=>array(-73.125393,44.921329),5489=>array(-72.901614,44.570896),5491=>array(-73.310796,44.111961),5492=>array(-72.761719,44.737614),5494=>array(-73.003642,44.607422),5495=>array(-73.096245,44.429068),5602=>array(-72.609475,44.274953),5640=>array(-72.499842,44.34188),5641=>array(-72.472163,44.188841),5647=>array(-72.282372,44.4027),5648=>array(-72.492386,44.382753),5649=>array(-72.347187,44.166651),5650=>array(-72.436355,44.380397),5651=>array(-72.489262,44.282307),5652=>array(-72.611082,44.723235),5653=>array(-72.47256,44.714847),5654=>array(-72.475659,44.140286),5655=>array(-72.567051,44.624817),5656=>array(-72.68884,44.648124),5657=>array(-72.52672,44.535509),5658=>array(-72.35483,44.364724),5660=>array(-72.734479,44.253995),5661=>array(-72.620196,44.53267),5663=>array(-72.691275,44.147613),5664=>array(-72.653138,44.167173),5667=>array(-72.38887,44.269042),5669=>array(-72.729887,44.064618),5672=>array(-72.713006,44.491975),5673=>array(-72.840849,44.199044),5674=>array(-72.874028,44.112526),5675=>array(-72.422633,44.076165),5676=>array(-72.827823,44.298566),5677=>array(-72.708265,44.409206),5678=>array(-72.477807,44.157597),5679=>array(-72.531907,44.108943),5680=>array(-72.471939,44.540596),5681=>array(-72.407139,44.453217),5682=>array(-72.565453,44.401783),5701=>array(-72.910205,43.624577),5730=>array(-72.788657,43.437589),5732=>array(-73.210774,43.643813),5733=>array(-73.090333,43.810619),5734=>array(-73.331937,43.981724),5735=>array(-73.167738,43.635671),5736=>array(-73.008456,43.633591),5737=>array(-72.906187,43.773353),5738=>array(-72.860737,43.528587),5739=>array(-73.000196,43.342621),5740=>array(-73.105275,43.971751),5742=>array(-72.910801,43.419653),5743=>array(-73.304926,43.67733),5744=>array(-73.080457,43.694013),5747=>array(-72.841314,44.005291),5748=>array(-72.921796,43.90548),5751=>array(-72.78441,43.657584),5753=>array(-73.178514,43.989489),5757=>array(-73.123641,43.480102),5758=>array(-72.757786,43.450789),5759=>array(-72.964768,43.532157),5760=>array(-73.289701,43.800615),5761=>array(-73.151758,43.360927),5762=>array(-72.836936,43.80448),5763=>array(-72.995211,43.730216),5764=>array(-73.189191,43.53994),5765=>array(-73.034649,43.651666),5766=>array(-72.996753,43.984944),5767=>array(-72.83185,43.871952),5769=>array(-73.119822,43.932071),5770=>array(-73.32449,43.881955),5772=>array(-72.760914,43.750797),5773=>array(-72.986994,43.420232),5774=>array(-73.191086,43.442986),5775=>array(-73.228386,43.365956),5776=>array(-73.197361,43.252732),5777=>array(-73.048764,43.556446),5778=>array(-73.212537,43.876421),5819=>array(-71.983075,44.404737),5820=>array(-72.375155,44.763601),5821=>array(-72.114854,44.311345),5822=>array(-72.142891,44.75272),5824=>array(-71.842937,44.442519),5825=>array(-72.249316,44.860534),5826=>array(-72.402091,44.647727),5827=>array(-72.362504,44.676898),5828=>array(-72.124822,44.437504),5829=>array(-72.068265,44.96721),5830=>array(-71.985854,44.97322),5832=>array(-71.917703,44.578024),5833=>array(-71.959562,44.842317),5836=>array(-72.264672,44.515314),5837=>array(-71.805063,44.662982),5839=>array(-72.20228,44.673667),5841=>array(-72.288602,44.60767),5842=>array(-72.231568,44.558929),5843=>array(-72.348111,44.515785),5845=>array(-72.290572,44.800772),5846=>array(-71.862687,44.800887),5847=>array(-72.458451,44.793437),5850=>array(-72.014699,44.541247),5851=>array(-72.08059,44.557132),5853=>array(-71.93934,44.888401),5855=>array(-72.191141,44.928285),5857=>array(-72.3127,44.928911),5858=>array(-71.816917,44.558787),5859=>array(-72.443035,44.966671),5860=>array(-72.103996,44.80266),5862=>array(-72.217809,44.319675),5866=>array(-72.110075,44.641631),5867=>array(-72.035973,44.665071),5868=>array(-72.377864,44.902167),5871=>array(-71.936955,44.689305),5872=>array(-72.048033,44.868527),5873=>array(-72.195302,44.424553),5874=>array(-72.484844,44.883431),5875=>array(-72.24709,44.709712),5901=>array(-71.660073,44.939704),5902=>array(-71.487927,45.009587),5903=>array(-71.588008,44.935092),5904=>array(-71.70654,44.416217),5905=>array(-71.679421,44.702005),5906=>array(-71.705947,44.470995),5907=>array(-71.818279,44.912613),6001=>array(-72.852046,41.787159),6002=>array(-72.740951,41.84493),6010=>array(-72.940749,41.681578),6013=>array(-72.957561,41.757517),6016=>array(-72.547432,41.901899),6018=>array(-73.309616,42.024629),6019=>array(-72.902765,41.857508),6020=>array(-72.928835,41.834605),6021=>array(-73.104821,42.017229),6022=>array(-72.927326,41.865433),6023=>array(-72.720095,41.61259),6024=>array(-73.274264,42.012137),6026=>array(-72.745378,41.929719),6027=>array(-72.915699,42.00493),6029=>array(-72.444294,41.915167),6031=>array(-73.316785,41.955257),6032=>array(-72.830309,41.725223),6033=>array(-72.53893,41.707461),6035=>array(-72.803846,41.960682),6037=>array(-72.778459,41.605477),6039=>array(-73.448303,41.949929),6040=>array(-72.525608,41.761415),6042=>array(-72.520987,41.802778),6043=>array(-72.437576,41.764588),6051=>array(-72.769832,41.665141),6052=>array(-72.803107,41.655568),6053=>array(-72.79194,41.690145),6057=>array(-72.99868,41.841041),6058=>array(-73.178464,41.969912),6059=>array(-72.94195,41.95718),6060=>array(-72.847465,42.009151),6061=>array(-72.96684,41.8756),6062=>array(-72.859729,41.673639),6063=>array(-72.971286,41.925197),6065=>array(-73.007693,41.974623),6066=>array(-72.459123,41.837523),6067=>array(-72.661779,41.656624),6068=>array(-73.422227,42.007238),6069=>array(-73.449213,41.860761),6070=>array(-72.80894,41.874256),6071=>array(-72.45363,41.992781),6073=>array(-72.55504,41.664442),6074=>array(-72.577836,41.83809),6076=>array(-72.263453,41.984442),6078=>array(-72.65146,41.992731),6081=>array(-72.772551,41.905187),6082=>array(-72.555553,41.983993),6084=>array(-72.359068,41.882488),6085=>array(-72.889415,41.748955),6088=>array(-72.585048,41.912186),6089=>array(-72.821964,41.837488),6090=>array(-72.863185,41.946484),6091=>array(-72.976917,42.024228),6092=>array(-72.860524,41.873452),6093=>array(-72.717371,42.01321),6095=>array(-72.675082,41.871037),6096=>array(-72.659703,41.92763),6098=>array(-73.086362,41.956185),6103=>array(-72.674257,41.767208),6105=>array(-72.705032,41.77468),6106=>array(-72.696006,41.748587),6107=>array(-72.758098,41.752304),6108=>array(-72.623945,41.780375),6109=>array(-72.669301,41.702484),6110=>array(-72.733602,41.732684),6111=>array(-72.730838,41.686993),6112=>array(-72.695823,41.793336),6114=>array(-72.670695,41.740854),6117=>array(-72.763564,41.78516),6118=>array(-72.609686,41.748702),6119=>array(-72.727208,41.763421),6120=>array(-72.664356,41.789073),6160=>array(-72.691126,41.766596),6226=>array(-72.208549,41.708238),6231=>array(-72.367207,41.633242),6232=>array(-72.374658,41.732982),6234=>array(-71.953266,41.793889),6235=>array(-72.12954,41.79089),6237=>array(-72.305414,41.694527),6238=>array(-72.344021,41.780099),6239=>array(-71.854535,41.79404),6241=>array(-71.847371,41.853901),6242=>array(-72.093305,41.895596),6243=>array(-71.805029,41.84487),6247=>array(-72.075026,41.767801),6248=>array(-72.409107,41.688578),6249=>array(-72.24009,41.632955),6250=>array(-72.198446,41.772955),6254=>array(-72.142609,41.621212),6255=>array(-71.901952,41.991087),6256=>array(-72.157361,41.732151),6259=>array(-71.987646,41.871502),6260=>array(-71.870452,41.908027),6262=>array(-71.948384,42.019311),6263=>array(-71.899848,41.835236),6264=>array(-72.100366,41.69421),6266=>array(-72.172813,41.673661),6268=>array(-72.245399,41.801119),6269=>array(-72.293122,41.804401),6277=>array(-71.84392,41.958388),6278=>array(-72.171427,41.897123),6279=>array(-72.251848,41.897267),6280=>array(-72.130094,41.690986),6281=>array(-72.014137,41.973476),6282=>array(-72.0842,41.944128),6320=>array(-72.102451,41.34785),6330=>array(-72.077527,41.63557),6331=>array(-72.003414,41.695706),6332=>array(-71.902335,41.731216),6333=>array(-72.232102,41.388969),6334=>array(-72.173849,41.544925),6335=>array(-72.058533,41.434707),6336=>array(-72.195867,41.580577),6339=>array(-71.990545,41.441939),6340=>array(-72.04178,41.357477),6350=>array(-72.068444,41.648507),6351=>array(-71.948385,41.589788),6353=>array(-72.149606,41.464427),6354=>array(-71.855134,41.708858),6355=>array(-71.976371,41.366899),6357=>array(-72.220077,41.324532),6359=>array(-71.87237,41.471184),6360=>array(-72.089488,41.54786),6365=>array(-72.006597,41.518652),6370=>array(-72.186089,41.468318),6371=>array(-72.323754,41.362386),6373=>array(-71.797689,41.681949),6374=>array(-71.910931,41.681878),6375=>array(-72.123236,41.406338),6376=>array(-72.25395,41.29406),6377=>array(-71.819313,41.730545),6378=>array(-71.908408,41.383211),6379=>array(-71.853195,41.363472),6380=>array(-72.051631,41.563417),6382=>array(-72.122235,41.467256),6384=>array(-71.831228,41.579192),6385=>array(-72.156576,41.36173),6387=>array(-71.913021,41.741171),6389=>array(-72.129139,41.564159),6390=>array(-71.968993,41.273576),6401=>array(-73.069825,41.344249),6403=>array(-73.051925,41.443685),6405=>array(-72.793548,41.285007),6409=>array(-72.420167,41.351081),6410=>array(-72.903617,41.511827),6412=>array(-72.484735,41.409683),6413=>array(-72.529125,41.29561),6414=>array(-72.552319,41.572231),6415=>array(-72.348073,41.551099),6416=>array(-72.661604,41.616551),6417=>array(-72.477442,41.367819),6418=>array(-73.08257,41.326171),6419=>array(-72.576659,41.380739),6420=>array(-72.25838,41.489351),6422=>array(-72.684525,41.468922),6423=>array(-72.389223,41.457501),6424=>array(-72.502329,41.560603),6426=>array(-72.397624,41.351587),6437=>array(-72.696816,41.331777),6438=>array(-72.504397,41.455264),6441=>array(-72.580378,41.471081),6442=>array(-72.434679,41.341858),6443=>array(-72.625456,41.346749),6444=>array(-72.93327,41.562682),6447=>array(-72.454002,41.636439),6450=>array(-72.775686,41.535812),6451=>array(-72.823409,41.541906),6455=>array(-72.717844,41.514163),6456=>array(-72.553751,41.51669),6457=>array(-72.657719,41.549534),6460=>array(-73.050812,41.214266),6461=>array(-73.075393,41.239863),6467=>array(-72.899757,41.567845),6468=>array(-73.222828,41.339236),6469=>array(-72.444812,41.510405),6470=>array(-73.317663,41.395083),6471=>array(-72.781,41.332109),6472=>array(-72.775194,41.382766),6473=>array(-72.856347,41.381327),6475=>array(-72.382734,41.299897),6477=>array(-73.024637,41.284951),6478=>array(-73.147999,41.444001),6479=>array(-72.911875,41.574754),6480=>array(-72.589071,41.598834),6481=>array(-72.698236,41.536519),6482=>array(-73.242514,41.408157),6483=>array(-73.083529,41.385132),6484=>array(-73.139041,41.304515),6488=>array(-73.230081,41.476862),6489=>array(-72.869567,41.614398),6492=>array(-72.805511,41.461989),6498=>array(-72.478017,41.303695),6510=>array(-72.926004,41.306521),6511=>array(-72.927295,41.317046),6512=>array(-72.875249,41.278274),6513=>array(-72.870791,41.316686),6514=>array(-72.943431,41.375791),6515=>array(-72.97084,41.328039),6516=>array(-72.964967,41.272573),6517=>array(-72.907174,41.349206),6518=>array(-72.912031,41.430806),6519=>array(-72.932028,41.293934),6524=>array(-72.994187,41.422964),6525=>array(-73.003892,41.363538),6604=>array(-73.208027,41.18292),6605=>array(-73.217672,41.162092),6606=>array(-73.206673,41.21211),6607=>array(-73.168038,41.170744),6608=>array(-73.181251,41.186475),6610=>array(-73.164603,41.209283),6611=>array(-73.213691,41.267861),6612=>array(-73.300479,41.264945),6614=>array(-73.129767,41.232717),6615=>array(-73.13216,41.171614),6702=>array(-73.045886,41.556461),6704=>array(-73.03539,41.588692),6705=>array(-72.992727,41.547103),6706=>array(-73.02358,41.532778),6708=>array(-73.068653,41.550872),6710=>array(-73.045817,41.569145),6712=>array(-72.975635,41.499248),6716=>array(-72.969624,41.596305),6750=>array(-73.268144,41.723731),6751=>array(-73.211411,41.635768),6752=>array(-73.361093,41.520294),6754=>array(-73.362981,41.775432),6755=>array(-73.479354,41.650654),6756=>array(-73.234002,41.849537),6757=>array(-73.457817,41.741417),6758=>array(-73.246125,41.676116),6759=>array(-73.212028,41.75364),6762=>array(-73.121576,41.530545),6763=>array(-73.21,41.694322),6770=>array(-73.053383,41.488428),6776=>array(-73.422832,41.60132),6777=>array(-73.33441,41.691303),6778=>array(-73.111909,41.71349),6779=>array(-73.08208,41.594462),6782=>array(-73.042744,41.651536),6783=>array(-73.296011,41.555498),6784=>array(-73.492529,41.577251),6785=>array(-73.464792,41.695051),6786=>array(-73.018048,41.672734),6787=>array(-73.085047,41.67108),6790=>array(-73.13152,41.834255),6791=>array(-73.060443,41.761345),6793=>array(-73.2889,41.633703),6794=>array(-73.323557,41.649454),6795=>array(-73.126107,41.62223),6796=>array(-73.342081,41.866022),6798=>array(-73.206096,41.561632),6801=>array(-73.389503,41.369778),6804=>array(-73.393667,41.469885),6807=>array(-73.592029,41.056732),6810=>array(-73.457611,41.374284),6811=>array(-73.478364,41.422586),6812=>array(-73.48762,41.482081),6820=>array(-73.48008,41.076202),6824=>array(-73.280818,41.173039),6825=>array(-73.243254,41.196583),6830=>array(-73.624339,41.037605),6831=>array(-73.658838,41.088724),6840=>array(-73.501184,41.161054),6850=>array(-73.447459,41.126683),6851=>array(-73.401526,41.138233),6853=>array(-73.438006,41.0661),6854=>array(-73.426615,41.08391),6855=>array(-73.395757,41.084489),6856=>array(-73.42086,41.111223),6870=>array(-73.570619,41.022718),6877=>array(-73.501019,41.306249),6878=>array(-73.583719,41.030093),6880=>array(-73.347921,41.133235),6883=>array(-73.366757,41.228103),6890=>array(-73.287843,41.148535),6896=>array(-73.392584,41.305415),6897=>array(-73.437607,41.206532),6901=>array(-73.538141,41.053607),6902=>array(-73.544337,41.059353),6903=>array(-73.571142,41.136018),6905=>array(-73.542669,41.088293),6906=>array(-73.522621,41.071023),6907=>array(-73.520517,41.100918),7001=>array(-74.271506,40.582316),7002=>array(-74.110228,40.662411),7003=>array(-74.187155,40.809128),7004=>array(-74.304593,40.882508),7005=>array(-74.417304,40.932771),7006=>array(-74.282865,40.851187),7008=>array(-74.227457,40.58379),7009=>array(-74.229791,40.858023),7010=>array(-73.987834,40.822081),7011=>array(-74.144073,40.878256),7012=>array(-74.160266,40.848398),7013=>array(-74.173062,40.869405),7014=>array(-74.135424,40.831352),7016=>array(-74.30483,40.656391),7017=>array(-74.207161,40.772089),7018=>array(-74.218015,40.755889),7020=>array(-73.974237,40.8238),7021=>array(-74.276197,40.828127),7022=>array(-74.003061,40.821054),7023=>array(-74.385676,40.6417),7024=>array(-73.971007,40.85064),7026=>array(-74.10825,40.879797),7027=>array(-74.323137,40.651249),7028=>array(-74.204569,40.804798),7029=>array(-74.154913,40.743595),7030=>array(-74.032021,40.745268),7031=>array(-74.12622,40.786256),7032=>array(-74.120875,40.75372),7033=>array(-74.289341,40.67742),7034=>array(-74.380104,40.87948),7035=>array(-74.308334,40.927501),7036=>array(-74.237823,40.62523),7039=>array(-74.3291,40.785828),7040=>array(-74.268919,40.730785),7041=>array(-74.301546,40.722448),7042=>array(-74.219011,40.813487),7043=>array(-74.200502,40.844837),7044=>array(-74.242877,40.834007),7045=>array(-74.368846,40.912095),7046=>array(-74.440329,40.889726),7047=>array(-74.02496,40.794175),7050=>array(-74.235692,40.76804),7052=>array(-74.265059,40.785753),7054=>array(-74.403515,40.854906),7055=>array(-74.12694,40.856413),7057=>array(-74.106323,40.853084),7058=>array(-74.341776,40.872514),7059=>array(-74.519044,40.634588),7060=>array(-74.422042,40.616667),7062=>array(-74.401184,40.632358),7063=>array(-74.444522,40.605118),7064=>array(-74.24564,40.57331),7065=>array(-74.280531,40.607152),7066=>array(-74.315442,40.62062),7067=>array(-74.31131,40.589252),7068=>array(-74.310168,40.819861),7069=>array(-74.436233,40.642845),7070=>array(-74.106041,40.820314),7071=>array(-74.11325,40.798004),7072=>array(-74.062338,40.826424),7073=>array(-74.085024,40.817097),7074=>array(-74.055268,40.838127),7075=>array(-74.087068,40.850183),7076=>array(-74.372905,40.633026),7077=>array(-74.25306,40.554147),7078=>array(-74.334237,40.742346),7079=>array(-74.261512,40.748811),7080=>array(-74.4148,40.574413),7081=>array(-74.33452,40.697899),7082=>array(-74.342511,40.926913),7083=>array(-74.269078,40.695266),7086=>array(-74.020791,40.767828),7087=>array(-74.032326,40.767374),7088=>array(-74.286158,40.717934),7090=>array(-74.343447,40.651644),7092=>array(-74.360292,40.680722),7093=>array(-74.011357,40.788079),7094=>array(-74.067649,40.781958),7095=>array(-74.286949,40.552844),7102=>array(-74.173605,40.735659),7103=>array(-74.195573,40.738731),7104=>array(-74.16838,40.76791),7105=>array(-74.138636,40.723066),7106=>array(-74.230329,40.741798),7107=>array(-74.186559,40.762918),7108=>array(-74.200211,40.723122),7109=>array(-74.16185,40.795515),7110=>array(-74.156079,40.820568),7111=>array(-74.232517,40.72386),7112=>array(-74.209645,40.709368),7114=>array(-74.170093,40.697362),7201=>array(-74.165414,40.688972),7202=>array(-74.216848,40.652415),7203=>array(-74.260158,40.652211),7204=>array(-74.266706,40.665265),7205=>array(-74.2288,40.695889),7206=>array(-74.183811,40.651654),7208=>array(-74.226408,40.67383),7302=>array(-74.046469,40.719389),7304=>array(-74.072593,40.716495),7305=>array(-74.082273,40.697302),7306=>array(-74.071875,40.734924),7307=>array(-74.056865,40.750877),7310=>array(-74.036881,40.730126),7311=>array(-74.032724,40.720216),7401=>array(-74.133826,41.032669),7403=>array(-74.332852,41.02092),7405=>array(-74.380839,40.98467),7407=>array(-74.119514,40.904526),7410=>array(-74.117504,40.935833),7416=>array(-74.599735,41.112558),7417=>array(-74.205652,41.007529),7418=>array(-74.486047,41.242167),7419=>array(-74.568485,41.153685),7420=>array(-74.302086,41.032305),7421=>array(-74.352494,41.174004),7422=>array(-74.439868,41.184034),7423=>array(-74.096574,40.999485),7424=>array(-74.205834,40.882454),7430=>array(-74.185895,41.083159),7432=>array(-74.141262,40.995809),7435=>array(-74.449126,41.035529),7436=>array(-74.243842,41.02998),7438=>array(-74.518867,41.028134),7439=>array(-74.600766,41.079609),7440=>array(-74.29304,40.946468),7442=>array(-74.285455,41.003095),7444=>array(-74.306967,40.967407),7446=>array(-74.145931,41.059136),7450=>array(-74.113506,40.981591),7452=>array(-74.125202,40.959471),7456=>array(-74.27317,41.102332),7457=>array(-74.315648,40.995495),7458=>array(-74.096511,41.046652),7460=>array(-74.495093,41.111812),7461=>array(-74.610416,41.246268),7462=>array(-74.495576,41.198457),7463=>array(-74.125919,41.013615),7465=>array(-74.332764,41.054855),7470=>array(-74.245077,40.945855),7480=>array(-74.37639,41.088259),7481=>array(-74.168849,40.999093),7495=>array(-74.164353,41.103887),7501=>array(-74.170965,40.911998),7502=>array(-74.194088,40.918574),7503=>array(-74.154121,40.897548),7504=>array(-74.141615,40.912548),7505=>array(-74.171635,40.916335),7506=>array(-74.158561,40.956957),7508=>array(-74.183638,40.955074),7512=>array(-74.219779,40.903415),7513=>array(-74.148686,40.906182),7514=>array(-74.143838,40.926992),7522=>array(-74.179096,40.924959),7524=>array(-74.15687,40.931711),7601=>array(-74.045698,40.889398),7603=>array(-74.029735,40.874287),7604=>array(-74.075182,40.862751),7605=>array(-73.988471,40.863391),7606=>array(-74.048473,40.858477),7607=>array(-74.063457,40.902885),7608=>array(-74.060355,40.852999),7620=>array(-73.91715,40.968149),7621=>array(-73.998001,40.922334),7624=>array(-73.960315,40.97289),7626=>array(-73.958581,40.939786),7627=>array(-73.956563,40.954576),7628=>array(-73.992428,40.945239),7630=>array(-74.023248,40.97499),7631=>array(-73.972515,40.891197),7632=>array(-73.942047,40.889682),7640=>array(-73.980202,40.991681),7641=>array(-73.997437,40.961713),7642=>array(-74.045119,41.007127),7643=>array(-74.036164,40.844332),7644=>array(-74.0825,40.877915),7645=>array(-74.047298,41.054594),7646=>array(-74.019453,40.934161),7647=>array(-73.942772,41.006364),7648=>array(-73.950917,40.992252),7649=>array(-74.032858,40.956651),7650=>array(-73.997061,40.847017),7652=>array(-74.070989,40.947309),7656=>array(-74.043561,41.0363),7657=>array(-74.015134,40.832337),7660=>array(-74.019926,40.854705),7661=>array(-74.039611,40.927354),7662=>array(-74.082895,40.910694),7663=>array(-74.101061,40.902976),7666=>array(-74.011478,40.890317),7670=>array(-73.950521,40.918309),7675=>array(-74.001778,41.003506),7676=>array(-74.064693,40.988306),7677=>array(-74.061061,41.025977),7701=>array(-74.078076,40.361667),7702=>array(-74.059667,40.326064),7703=>array(-74.039773,40.315784),7704=>array(-74.038775,40.36194),7711=>array(-74.008008,40.238531),7712=>array(-74.053712,40.249708),7716=>array(-74.032978,40.401088),7717=>array(-74.015105,40.191418),7718=>array(-74.085373,40.420384),7719=>array(-74.073226,40.168908),7720=>array(-74.012056,40.201604),7721=>array(-74.234672,40.436522),7722=>array(-74.171589,40.285889),7723=>array(-73.997458,40.249701),7724=>array(-74.074178,40.298625),7726=>array(-74.346564,40.282353),7727=>array(-74.149231,40.204403),7728=>array(-74.285785,40.225793),7730=>array(-74.176063,40.425495),7731=>array(-74.204208,40.149318),7732=>array(-73.990424,40.430468),7733=>array(-74.173849,40.374964),7734=>array(-74.13681,40.444151),7735=>array(-74.172274,40.450109),7737=>array(-74.065759,40.412373),7738=>array(-74.127066,40.337907),7739=>array(-74.034535,40.336952),7740=>array(-73.989899,40.295372),7746=>array(-74.248318,40.317727),7747=>array(-74.253906,40.415326),7748=>array(-74.115274,40.3963),7750=>array(-73.985608,40.335895),7751=>array(-74.26296,40.361882),7753=>array(-74.081834,40.216763),7755=>array(-74.022877,40.263635),7756=>array(-74.006944,40.21182),7757=>array(-74.015897,40.316313),7758=>array(-74.103295,40.430684),7760=>array(-74.002368,40.369551),7762=>array(-74.033876,40.152911),7764=>array(-74.020019,40.287904),7801=>array(-74.553551,40.918693),7803=>array(-74.60078,40.878175),7820=>array(-74.811976,40.930738),7821=>array(-74.754393,40.965937),7822=>array(-74.708642,41.139513),7823=>array(-75.039497,40.829451),7825=>array(-74.97571,40.971252),7826=>array(-74.778167,41.193195),7827=>array(-74.730427,41.280864),7828=>array(-74.750312,40.883935),7830=>array(-74.794021,40.719283),7832=>array(-75.053728,40.962126),7833=>array(-75.0693,40.892562),7834=>array(-74.490462,40.887246),7836=>array(-74.710722,40.843103),7838=>array(-74.911639,40.887907),7840=>array(-74.835763,40.85373),7842=>array(-74.512172,40.942121),7843=>array(-74.659474,40.939241),7846=>array(-74.877068,40.96594),7847=>array(-74.623879,40.889346),7848=>array(-74.687004,41.103892),7849=>array(-74.608296,40.970527),7850=>array(-74.662035,40.906858),7851=>array(-74.846827,41.231436),7852=>array(-74.668029,40.883268),7853=>array(-74.789238,40.780755),7856=>array(-74.626675,40.915783),7857=>array(-74.700322,40.896755),7860=>array(-74.819113,41.056547),7863=>array(-74.957898,40.808136),7865=>array(-74.898346,40.793808),7866=>array(-74.48899,40.954922),7869=>array(-74.57833,40.841691),7870=>array(-74.819651,40.80398),7871=>array(-74.62788,41.052354),7874=>array(-74.73579,40.923063),7876=>array(-74.656097,40.854699),7878=>array(-74.473755,40.873007),7880=>array(-74.888891,40.871452),7881=>array(-74.89404,41.118632),7882=>array(-75.013787,40.75264),7885=>array(-74.599911,40.910506),7901=>array(-74.366372,40.714923),7920=>array(-74.564115,40.678994),7921=>array(-74.678657,40.656019),7922=>array(-74.425027,40.676393),7924=>array(-74.592571,40.730387),7926=>array(-74.570122,40.801262),7927=>array(-74.45429,40.821862),7928=>array(-74.412612,40.725986),7930=>array(-74.683945,40.781196),7931=>array(-74.616525,40.681427),7932=>array(-74.392943,40.777242),7933=>array(-74.462129,40.698318),7934=>array(-74.675589,40.722624),7935=>array(-74.445887,40.736004),7936=>array(-74.363742,40.818553),7939=>array(-74.553908,40.667382),7940=>array(-74.427358,40.760545),7945=>array(-74.599501,40.781948),7946=>array(-74.508538,40.677709),7950=>array(-74.482314,40.846026),7960=>array(-74.500025,40.784201),7961=>array(-74.432741,40.78062),7970=>array(-74.572814,40.807897),7974=>array(-74.403867,40.69691),7976=>array(-74.479344,40.72806),7977=>array(-74.670075,40.705188),7979=>array(-74.724987,40.702981),7980=>array(-74.488915,40.680423),7981=>array(-74.422469,40.820387),8001=>array(-75.346384,39.54788),8002=>array(-75.027557,39.931978),8003=>array(-74.972036,39.882703),8004=>array(-74.870626,39.764747),8005=>array(-74.312588,39.767727),8006=>array(-74.106157,39.752759),8007=>array(-75.053823,39.865825),8008=>array(-74.298174,39.542599),8009=>array(-74.93286,39.760656),8010=>array(-74.918438,40.053356),8011=>array(-74.713117,39.972764),8012=>array(-75.056068,39.783815),8014=>array(-75.349521,39.817352),8015=>array(-74.545375,39.932089),8016=>array(-74.824196,40.069522),8019=>array(-74.534219,39.777292),8020=>array(-75.22414,39.791562),8021=>array(-75.000151,39.806194),8022=>array(-74.705741,40.06759),8023=>array(-75.496274,39.686699),8026=>array(-74.967175,39.832872),8027=>array(-75.29028,39.833175),8028=>array(-75.121415,39.695863),8029=>array(-75.067211,39.840937),8030=>array(-75.118078,39.888896),8031=>array(-75.09467,39.866356),8033=>array(-75.036651,39.892421),8034=>array(-75.000166,39.906532),8035=>array(-75.065918,39.879127),8036=>array(-74.832209,39.970569),8037=>array(-74.765284,39.640371),8038=>array(-75.490291,39.470004),8039=>array(-75.27737,39.685628),8041=>array(-74.678698,40.039074),8042=>array(-74.662278,40.015387),8043=>array(-74.953498,39.848539),8045=>array(-75.029746,39.867114),8046=>array(-74.886984,40.02795),8048=>array(-74.802478,39.958855),8049=>array(-75.038544,39.85439),8050=>array(-74.231291,39.713641),8051=>array(-75.175825,39.786549),8052=>array(-74.994896,39.952381),8053=>array(-74.90081,39.856677),8054=>array(-74.900247,39.948992),8055=>array(-74.821488,39.862559),8056=>array(-75.255275,39.783669),8057=>array(-74.941308,39.979658),8059=>array(-75.092268,39.884418),8060=>array(-74.790088,40.007737),8061=>array(-75.205363,39.798865),8062=>array(-75.21924,39.716068),8063=>array(-75.185621,39.867297),8064=>array(-74.640754,39.962782),8065=>array(-75.035273,40.002615),8066=>array(-75.228389,39.834329),8067=>array(-75.411655,39.739885),8068=>array(-74.665755,39.961426),8069=>array(-75.44518,39.699258),8070=>array(-75.512237,39.619113),8071=>array(-75.133534,39.731894),8072=>array(-75.418704,39.544308),8073=>array(-74.866779,40.009542),8074=>array(-75.16344,39.716166),8075=>array(-74.948936,40.029586),8077=>array(-74.991632,40.000162),8078=>array(-75.074803,39.851738),8079=>array(-75.431684,39.542408),8080=>array(-75.11721,39.758292),8081=>array(-74.976771,39.733564),8083=>array(-75.028593,39.841266),8084=>array(-75.015458,39.828957),8085=>array(-75.32406,39.761129),8086=>array(-75.198687,39.854682),8087=>array(-74.380612,39.596035),8088=>array(-74.693412,39.851467),8089=>array(-74.826622,39.7178),8090=>array(-75.150692,39.799077),8091=>array(-74.924178,39.807116),8092=>array(-74.281121,39.651575),8093=>array(-75.137452,39.864643),8094=>array(-74.959292,39.650587),8095=>array(-74.861065,39.64818),8096=>array(-75.126663,39.826854),8097=>array(-75.150617,39.813376),8098=>array(-75.329849,39.639535),8102=>array(-75.120999,39.952558),8103=>array(-75.113921,39.935834),8104=>array(-75.113179,39.916435),8105=>array(-75.091486,39.951825),8106=>array(-75.073329,39.890992),8107=>array(-75.083563,39.907845),8108=>array(-75.060862,39.914668),8109=>array(-75.050129,39.951291),8110=>array(-75.057876,39.971893),8201=>array(-74.493025,39.423563),8202=>array(-74.731415,39.095265),8203=>array(-74.392933,39.425627),8204=>array(-74.920979,38.971087),8205=>array(-74.452637,39.482),8210=>array(-74.834282,39.121668),8212=>array(-74.953895,38.933446),8215=>array(-74.563656,39.586506),8217=>array(-74.719915,39.574192),8221=>array(-74.571049,39.343718),8223=>array(-74.655703,39.27875),8224=>array(-74.467363,39.601878),8225=>array(-74.530934,39.362667),8226=>array(-74.604605,39.263596),8230=>array(-74.718691,39.209253),8232=>array(-74.515196,39.387525),8234=>array(-74.620728,39.388393),8240=>array(-74.533973,39.488059),8241=>array(-74.476981,39.534381),8242=>array(-74.888905,39.018576),8243=>array(-74.696319,39.151013),8244=>array(-74.588458,39.318968),8246=>array(-74.765806,39.180965),8247=>array(-74.783628,39.052267),8248=>array(-74.657187,39.195657),8251=>array(-74.929514,39.027715),8260=>array(-74.837454,38.994915),8270=>array(-74.785925,39.271519),8302=>array(-75.260646,39.438613),8310=>array(-74.896623,39.531345),8311=>array(-75.204035,39.327866),8312=>array(-75.077505,39.663756),8314=>array(-74.940368,39.221854),8316=>array(-74.949689,39.269532),8317=>array(-74.829634,39.400688),8318=>array(-75.177717,39.557728),8319=>array(-74.810816,39.370409),8320=>array(-75.1606,39.38508),8321=>array(-75.143169,39.223596),8322=>array(-75.048907,39.610619),8323=>array(-75.367551,39.396273),8324=>array(-74.996612,39.214626),8326=>array(-74.928273,39.537672),8327=>array(-74.962801,39.251549),8328=>array(-75.058737,39.578361),8329=>array(-75.007658,39.275985),8330=>array(-74.737379,39.481949),8332=>array(-75.023374,39.377041),8340=>array(-74.876499,39.437245),8341=>array(-74.95302,39.525424),8343=>array(-75.167607,39.636316),8344=>array(-74.986037,39.561745),8345=>array(-75.165509,39.277032),8346=>array(-74.854042,39.564995),8348=>array(-74.971365,39.309933),8349=>array(-75.071307,39.273865),8350=>array(-74.88202,39.487876),8352=>array(-75.12798,39.475732),8353=>array(-75.29252,39.462259),8360=>array(-75.008665,39.495524),8361=>array(-74.958827,39.449369),8401=>array(-74.451082,39.377297),8402=>array(-74.504473,39.326385),8403=>array(-74.543485,39.318681),8406=>array(-74.480862,39.34156),8501=>array(-74.561983,40.161709),8502=>array(-74.653244,40.448217),8505=>array(-74.733455,40.103026),8510=>array(-74.41708,40.191636),8511=>array(-74.557037,40.042379),8512=>array(-74.525526,40.324357),8514=>array(-74.491787,40.134327),8515=>array(-74.653491,40.120242),8518=>array(-74.802088,40.115428),8520=>array(-74.530078,40.255265),8525=>array(-74.779412,40.397648),8527=>array(-74.357579,40.108585),8528=>array(-74.618926,40.387098),8530=>array(-74.908492,40.370685),8533=>array(-74.500141,40.071031),8534=>array(-74.792789,40.329422),8535=>array(-74.432096,40.244304),8536=>array(-74.581039,40.332286),8540=>array(-74.655321,40.36301),8542=>array(-74.660366,40.352913),8550=>array(-74.614673,40.280155),8551=>array(-74.844836,40.44118),8553=>array(-74.638922,40.400347),8554=>array(-74.777844,40.117217),8555=>array(-74.470792,40.218286),8558=>array(-74.703455,40.413812),8559=>array(-74.979065,40.429224),8560=>array(-74.857279,40.31573),8561=>array(-74.578389,40.249939),8562=>array(-74.591878,40.061957),8608=>array(-74.76777,40.219297),8609=>array(-74.740906,40.225747),8610=>array(-74.716603,40.191174),8611=>array(-74.740319,40.183615),8618=>array(-74.789973,40.249347),8619=>array(-74.696408,40.242301),8620=>array(-74.651278,40.170048),8628=>array(-74.827047,40.264418),8629=>array(-74.731201,40.220669),8638=>array(-74.763385,40.254018),8640=>array(-74.591269,40.004416),8641=>array(-74.590178,40.020284),8648=>array(-74.717976,40.284308),8690=>array(-74.660279,40.224505),8691=>array(-74.594069,40.208885),8701=>array(-74.200383,40.077041),8720=>array(-74.09805,40.135366),8721=>array(-74.152844,39.902752),8722=>array(-74.202189,39.928405),8723=>array(-74.1116,40.038584),8724=>array(-74.11085,40.086235),8730=>array(-74.062755,40.105062),8731=>array(-74.263027,39.86585),8732=>array(-74.143814,39.941792),8733=>array(-74.320809,40.023795),8734=>array(-74.172064,39.862755),8735=>array(-74.070619,39.982051),8736=>array(-74.053257,40.120018),8738=>array(-74.05904,40.022724),8740=>array(-74.132429,39.92767),8741=>array(-74.166931,39.937116),8742=>array(-74.059125,40.080784),8750=>array(-74.041715,40.132812),8751=>array(-74.08815,39.951907),8752=>array(-74.093433,39.8425),8753=>array(-74.160429,39.979031),8755=>array(-74.221884,40.00844),8757=>array(-74.251072,39.942397),8758=>array(-74.223349,39.790361),8759=>array(-74.351495,39.975912),8801=>array(-74.886324,40.622794),8802=>array(-75.017983,40.671028),8804=>array(-75.095715,40.646655),8805=>array(-74.537507,40.573874),8807=>array(-74.619323,40.592247),8808=>array(-75.049029,40.73213),8809=>array(-74.934206,40.651832),8810=>array(-74.491018,40.368288),8812=>array(-74.478793,40.598731),8816=>array(-74.416287,40.429119),8817=>array(-74.393104,40.514658),8820=>array(-74.36575,40.576806),8821=>array(-74.685662,40.520045),8822=>array(-74.865273,40.525122),8823=>array(-74.569007,40.43999),8824=>array(-74.553237,40.422086),8825=>array(-75.02717,40.514186),8826=>array(-74.896762,40.719257),8827=>array(-74.968085,40.668619),8828=>array(-74.423066,40.378025),8829=>array(-74.890548,40.669591),8830=>array(-74.31488,40.569551),8831=>array(-74.428801,40.319474),8832=>array(-74.306784,40.517202),8833=>array(-74.816261,40.645542),8835=>array(-74.589273,40.541269),8836=>array(-74.55732,40.596376),8837=>array(-74.344075,40.513105),8840=>array(-74.358981,40.543139),8844=>array(-74.670505,40.497692),8846=>array(-74.498259,40.574627),8848=>array(-75.096659,40.594266),8850=>array(-74.439078,40.447921),8852=>array(-74.549623,40.388277),8853=>array(-74.742314,40.529933),8854=>array(-74.460817,40.54564),8857=>array(-74.330397,40.392789),8858=>array(-74.737037,40.682576),8859=>array(-74.302768,40.458848),8861=>array(-74.272943,40.520494),8863=>array(-74.31623,40.527688),8865=>array(-75.147074,40.708223),8867=>array(-74.966157,40.574254),8869=>array(-74.646514,40.572127),8872=>array(-74.356884,40.444335),8873=>array(-74.532009,40.496619),8876=>array(-74.685411,40.589554),8879=>array(-74.2779,40.465802),8880=>array(-74.527455,40.553947),8882=>array(-74.378459,40.445652),8884=>array(-74.390089,40.395687),8886=>array(-75.101127,40.687502),8887=>array(-74.796339,40.522219),8889=>array(-74.754216,40.609021),8890=>array(-74.575423,40.539039),8901=>array(-74.44246,40.483638),8902=>array(-74.484377,40.43919),8904=>array(-74.427911,40.500795),10001=>array(-73.997281,40.750672),10002=>array(-73.986258,40.715762),10003=>array(-73.989181,40.731829),10004=>array(-74.018244,40.68863),10005=>array(-74.008768,40.705974),10006=>array(-74.012954,40.709614),10007=>array(-74.007806,40.713864),10009=>array(-73.978636,40.726408),10010=>array(-73.982232,40.739045),10011=>array(-74.000594,40.742002),10012=>array(-73.998078,40.725581),10013=>array(-74.004928,40.720107),10014=>array(-74.007033,40.733698),10016=>array(-73.978294,40.74522),10017=>array(-73.972417,40.752347),10018=>array(-73.993127,40.755329),10019=>array(-73.987067,40.765793),10020=>array(-73.978833,40.758236),10021=>array(-73.95863,40.769159),10022=>array(-73.967817,40.758555),10023=>array(-73.982607,40.775921),10024=>array(-73.974414,40.798452),10025=>array(-73.966623,40.798601),10026=>array(-73.952681,40.80238),10027=>array(-73.953224,40.811819),10028=>array(-73.953493,40.776426),10029=>array(-73.943876,40.791698),10030=>array(-73.942856,40.818267),10031=>array(-73.950056,40.825294),10032=>array(-73.942846,40.838824),10033=>array(-73.933863,40.850538),10034=>array(-73.924415,40.86723),10035=>array(-73.929731,40.795652),10036=>array(-73.989909,40.75928),10037=>array(-73.937285,40.812984),10038=>array(-74.002532,40.70932),10039=>array(-73.936069,40.830856),10040=>array(-73.93052,40.858298),10044=>array(-73.949933,40.76205),10065=>array(-73.963013,40.764584),10069=>array(-73.990528,40.775978),10075=>array(-73.956208,40.773357),10103=>array(-73.97767,40.76078),10110=>array(-73.982256,40.754499),10111=>array(-73.977596,40.759114),10112=>array(-73.979668,40.759167),10115=>array(-73.963744,40.810852),10119=>array(-73.992979,40.75031),10128=>array(-73.949942,40.78143),10152=>array(-73.972031,40.758404),10153=>array(-73.972439,40.763622),10154=>array(-73.972487,40.757779),10162=>array(-73.949942,40.769298),10165=>array(-73.978722,40.752131),10167=>array(-73.974771,40.754648),10168=>array(-73.977103,40.751448),10169=>array(-73.976098,40.754391),10170=>array(-73.975877,40.752625),10171=>array(-73.973858,40.755899),10172=>array(-73.974315,40.755273),10173=>array(-73.979364,40.754131),10174=>array(-73.975003,40.751441),10177=>array(-73.975934,40.755139),10199=>array(-73.997229,40.751393),10271=>array(-74.010541,40.708236),10278=>array(-74.003778,40.715182),10279=>array(-74.008669,40.712626),10280=>array(-74.016808,40.708778),10282=>array(-74.015375,40.716651),10301=>array(-74.094407,40.627456),10302=>array(-74.137776,40.630688),10303=>array(-74.17413,40.629885),10304=>array(-74.092859,40.607994),10305=>array(-74.074866,40.596691),10306=>array(-74.12595,40.571768),10307=>array(-74.237137,40.508321),10308=>array(-74.147646,40.551884),10309=>array(-74.220971,40.531515),10310=>array(-74.116148,40.632648),10311=>array(-74.179503,40.605241),10312=>array(-74.180914,40.545394),10314=>array(-74.165748,40.599263),10451=>array(-73.925084,40.820479),10452=>array(-73.92343,40.83739),10453=>array(-73.912332,40.852779),10454=>array(-73.91659,40.805518),10455=>array(-73.908592,40.81471),10456=>array(-73.90812,40.829881),10457=>array(-73.898678,40.84715),10458=>array(-73.888145,40.862545),10459=>array(-73.892971,40.825875),10460=>array(-73.879569,40.841764),10461=>array(-73.840554,40.847434),10462=>array(-73.860389,40.84328),10463=>array(-73.90654,40.880678),10464=>array(-73.79992,40.867787),10465=>array(-73.825602,40.823277),10466=>array(-73.846239,40.890964),10467=>array(-73.865696,40.869953),10468=>array(-73.899944,40.868966),10469=>array(-73.848218,40.86857),10470=>array(-73.87266,40.889527),10471=>array(-73.90331,40.898814),10472=>array(-73.869359,40.829556),10473=>array(-73.858474,40.81869),10474=>array(-73.884412,40.810614),10475=>array(-73.823817,40.875259),10501=>array(-73.75849,41.295608),10502=>array(-73.841433,41.011602),10503=>array(-73.87531,41.026556),10504=>array(-73.707521,41.128468),10505=>array(-73.745449,41.34209),10506=>array(-73.638479,41.190889),10507=>array(-73.686047,41.227896),10509=>array(-73.59434,41.410855),10510=>array(-73.834891,41.138997),10511=>array(-73.943192,41.265428),10512=>array(-73.714235,41.444202),10514=>array(-73.768948,41.17233),10516=>array(-73.875003,41.4621),10517=>array(-73.861993,41.298243),10518=>array(-73.588251,41.26616),10519=>array(-73.652662,41.352346),10520=>array(-73.867787,41.226478),10522=>array(-73.863746,41.01031),10523=>array(-73.819457,41.059341),10524=>array(-73.926122,41.375242),10526=>array(-73.670532,41.291114),10527=>array(-73.769878,41.321183),10528=>array(-73.725777,40.974752),10530=>array(-73.81281,41.023712),10532=>array(-73.800327,41.099278),10533=>array(-73.854864,41.036927),10535=>array(-73.793919,41.335169),10536=>array(-73.688694,41.269098),10537=>array(-73.882349,41.33974),10538=>array(-73.755906,40.938637),10541=>array(-73.754447,41.378544),10543=>array(-73.73604,40.952693),10545=>array(-73.83545,41.178591),10546=>array(-73.800418,41.197237),10547=>array(-73.846039,41.313334),10548=>array(-73.932977,41.245696),10549=>array(-73.723465,41.200584),10550=>array(-73.835253,40.905448),10552=>array(-73.826115,40.92446),10553=>array(-73.821652,40.908584),10560=>array(-73.597609,41.340527),10562=>array(-73.825254,41.19448),10566=>array(-73.917823,41.28947),10567=>array(-73.89703,41.289545),10570=>array(-73.78667,41.130067),10573=>array(-73.677404,41.015857),10576=>array(-73.572332,41.221577),10577=>array(-73.711743,41.038271),10578=>array(-73.678991,41.320276),10579=>array(-73.83866,41.394225),10580=>array(-73.69332,40.978942),10583=>array(-73.789204,40.988682),10588=>array(-73.820007,41.336623),10589=>array(-73.702858,41.328436),10590=>array(-73.539322,41.255441),10591=>array(-73.841014,41.090097),10594=>array(-73.774292,41.113425),10595=>array(-73.782645,41.085897),10596=>array(-73.959177,41.256258),10597=>array(-73.596568,41.293021),10598=>array(-73.792203,41.288223),10601=>array(-73.765071,41.032932),10603=>array(-73.779287,41.0544),10604=>array(-73.74338,41.062079),10605=>array(-73.745125,41.010525),10606=>array(-73.775846,41.020572),10607=>array(-73.811368,41.039089),10701=>array(-73.880471,40.94542),10703=>array(-73.880302,40.959829),10704=>array(-73.862651,40.919729),10705=>array(-73.889928,40.919705),10706=>array(-73.867552,40.989821),10707=>array(-73.822732,40.960533),10708=>array(-73.829922,40.938267),10709=>array(-73.808184,40.954635),10710=>array(-73.846339,40.967157),10801=>array(-73.784858,40.91757),10803=>array(-73.807138,40.900458),10804=>array(-73.788051,40.946841),10805=>array(-73.779258,40.897721),10901=>array(-74.104976,41.140772),10910=>array(-74.137958,41.28157),10911=>array(-74.008159,41.319158),10913=>array(-73.954975,41.068258),10914=>array(-74.200026,41.417717),10915=>array(-74.359321,41.545359),10916=>array(-74.250674,41.442463),10917=>array(-74.117641,41.319525),10918=>array(-74.262177,41.344192),10919=>array(-74.387618,41.525959),10920=>array(-73.937748,41.156213),10921=>array(-74.363412,41.332062),10922=>array(-73.996452,41.33276),10923=>array(-74.000621,41.202564),10924=>array(-74.352471,41.381005),10925=>array(-74.314759,41.198181),10926=>array(-74.122701,41.301401),10927=>array(-73.967562,41.191052),10928=>array(-73.998495,41.34897),10930=>array(-74.113297,41.361676),10931=>array(-74.162522,41.148792),10932=>array(-74.464285,41.48216),10933=>array(-74.512968,41.367984),10940=>array(-74.478741,41.446544),10941=>array(-74.344437,41.487318),10950=>array(-74.201961,41.317089),10952=>array(-74.07854,41.111118),10953=>array(-74.077432,41.404964),10954=>array(-74.012296,41.099029),10956=>array(-73.993416,41.157191),10958=>array(-74.432479,41.371913),10960=>array(-73.924648,41.092068),10962=>array(-73.958585,41.050066),10963=>array(-74.543423,41.463529),10964=>array(-73.914304,41.016204),10965=>array(-74.007832,41.061561),10968=>array(-73.921633,41.036334),10969=>array(-74.487978,41.294796),10970=>array(-74.099794,41.179603),10973=>array(-74.480462,41.380516),10974=>array(-74.178013,41.168058),10975=>array(-74.172263,41.267079),10976=>array(-73.928488,41.02296),10977=>array(-74.048158,41.11892),10979=>array(-74.314921,41.18283),10980=>array(-74.050013,41.238902),10983=>array(-73.947703,41.031088),10984=>array(-74.022265,41.202903),10985=>array(-74.373188,41.583519),10986=>array(-73.99871,41.285235),10987=>array(-74.23735,41.186928),10988=>array(-74.548556,41.302081),10989=>array(-73.938031,41.122955),10990=>array(-74.364011,41.267448),10992=>array(-74.164346,41.426161),10993=>array(-73.973842,41.209896),10994=>array(-73.972649,41.098072),10996=>array(-73.972175,41.3937),10998=>array(-74.541192,41.324048),11001=>array(-73.704949,40.723317),11003=>array(-73.706166,40.699176),11004=>array(-73.711469,40.746198),11005=>array(-73.714178,40.756578),11010=>array(-73.675018,40.700587),11020=>array(-73.714819,40.771442),11021=>array(-73.731488,40.784319),11023=>array(-73.733702,40.7987),11024=>array(-73.741414,40.81609),11030=>array(-73.688549,40.793409),11040=>array(-73.680292,40.745347),11042=>array(-73.697224,40.758538),11050=>array(-73.693128,40.839895),11096=>array(-73.75699,40.621346),11101=>array(-73.939736,40.74713),11102=>array(-73.926295,40.772884),11103=>array(-73.913447,40.762574),11104=>array(-73.920214,40.744617),11105=>array(-73.906769,40.778877),11106=>array(-73.931528,40.762211),11109=>array(-73.956928,40.745115),11201=>array(-73.989693,40.693682),11203=>array(-73.934371,40.649591),11204=>array(-73.984826,40.618779),11205=>array(-73.966301,40.694698),11206=>array(-73.942358,40.701954),11207=>array(-73.894209,40.670747),11208=>array(-73.871371,40.669689),11209=>array(-74.030323,40.621982),11210=>array(-73.946324,40.628147),11211=>array(-73.953098,40.712597),11212=>array(-73.913029,40.662936),11213=>array(-73.936336,40.671078),11214=>array(-73.99609,40.599148),11215=>array(-73.98674,40.662688),11216=>array(-73.949316,40.680768),11217=>array(-73.978099,40.682306),11218=>array(-73.976043,40.643476),11219=>array(-73.996669,40.632667),11220=>array(-74.016863,40.641221),11221=>array(-73.927879,40.69134),11222=>array(-73.947605,40.72779),11223=>array(-73.973428,40.597139),11224=>array(-73.988706,40.577372),11225=>array(-73.954219,40.663046),11226=>array(-73.956649,40.646448),11228=>array(-74.013047,40.616695),11229=>array(-73.944493,40.601293),11230=>array(-73.965105,40.622164),11231=>array(-74.005154,40.677916),11232=>array(-74.007331,40.656527),11233=>array(-73.919936,40.678308),11234=>array(-73.911721,40.60508),11235=>array(-73.949096,40.583949),11236=>array(-73.900664,40.639413),11237=>array(-73.921139,40.70416),11238=>array(-73.963804,40.679171),11239=>array(-73.879477,40.647735),11351=>array(-73.825301,40.780747),11354=>array(-73.827403,40.768208),11355=>array(-73.821031,40.751475),11356=>array(-73.841279,40.78485),11357=>array(-73.810862,40.786394),11358=>array(-73.796371,40.760471),11359=>array(-73.776867,40.791786),11360=>array(-73.781206,40.780294),11361=>array(-73.772775,40.764191),11362=>array(-73.737845,40.756574),11363=>array(-73.746526,40.772616),11364=>array(-73.760607,40.745296),11365=>array(-73.79449,40.739634),11366=>array(-73.785019,40.728152),11367=>array(-73.82703,40.730145),11368=>array(-73.85278,40.749407),11369=>array(-73.872443,40.763336),11370=>array(-73.893243,40.76537),11371=>array(-73.873399,40.773836),11372=>array(-73.883638,40.75169),11373=>array(-73.878508,40.738825),11374=>array(-73.861509,40.726388),11375=>array(-73.846151,40.720936),11377=>array(-73.905181,40.744788),11378=>array(-73.909639,40.724744),11379=>array(-73.879601,40.716748),11385=>array(-73.889433,40.700671),11411=>array(-73.736218,40.694021),11412=>array(-73.758986,40.698095),11413=>array(-73.752568,40.671659),11414=>array(-73.844804,40.657604),11415=>array(-73.828212,40.707917),11416=>array(-73.849548,40.684654),11417=>array(-73.844443,40.676446),11418=>array(-73.835971,40.700272),11419=>array(-73.822918,40.688673),11420=>array(-73.817733,40.673584),11421=>array(-73.858626,40.694062),11422=>array(-73.736012,40.66006),11423=>array(-73.768471,40.715606),11424=>array(-73.827263,40.714304),11425=>array(-74.023937,40.607754),11426=>array(-73.722376,40.736459),11427=>array(-73.745676,40.730887),11428=>array(-73.742245,40.721016),11429=>array(-73.738665,40.70977),11430=>array(-73.78563,40.647126),11432=>array(-73.793071,40.715359),11433=>array(-73.786893,40.698162),11434=>array(-73.776425,40.676808),11435=>array(-73.809605,40.701265),11436=>array(-73.796617,40.67582),11451=>array(-73.795972,40.701282),11501=>array(-73.63891,40.746283),11507=>array(-73.65226,40.770847),11509=>array(-73.728528,40.587963),11510=>array(-73.607709,40.650127),11514=>array(-73.612476,40.749891),11516=>array(-73.726685,40.625787),11518=>array(-73.666807,40.637472),11520=>array(-73.582951,40.649401),11530=>array(-73.637009,40.726854),11542=>array(-73.628622,40.872605),11545=>array(-73.589365,40.826321),11547=>array(-73.642687,40.83367),11548=>array(-73.627405,40.812868),11549=>array(-73.602746,40.71724),11550=>array(-73.621108,40.701475),11552=>array(-73.652416,40.692979),11553=>array(-73.591622,40.70643),11554=>array(-73.558861,40.720115),11556=>array(-73.583807,40.719683),11557=>array(-73.691976,40.637176),11558=>array(-73.649046,40.605357),11559=>array(-73.716208,40.60548),11560=>array(-73.588724,40.880757),11561=>array(-73.648178,40.589081),11563=>array(-73.673728,40.657253),11565=>array(-73.671666,40.675061),11566=>array(-73.553779,40.663239),11568=>array(-73.596505,40.786964),11569=>array(-73.582305,40.589786),11570=>array(-73.638409,40.666066),11572=>array(-73.636624,40.631772),11575=>array(-73.584877,40.680422),11576=>array(-73.647467,40.799414),11577=>array(-73.638866,40.783266),11579=>array(-73.644006,40.844016),11580=>array(-73.702154,40.6749),11581=>array(-73.715325,40.651028),11590=>array(-73.574338,40.755182),11596=>array(-73.642308,40.759667),11598=>array(-73.712336,40.630919),11691=>array(-73.761651,40.601278),11692=>array(-73.792896,40.594095),11693=>array(-73.809749,40.590692),11694=>array(-73.844762,40.57827),11697=>array(-73.920688,40.555681),11701=>array(-73.410099,40.681433),11702=>array(-73.262413,40.650581),11703=>array(-73.325925,40.73267),11704=>array(-73.358203,40.717504),11705=>array(-73.055841,40.743277),11706=>array(-73.252183,40.722537),11709=>array(-73.559505,40.906478),11710=>array(-73.533514,40.671803),11713=>array(-72.943291,40.776152),11714=>array(-73.486081,40.742553),11715=>array(-73.034877,40.751006),11716=>array(-73.134857,40.776697),11717=>array(-73.252208,40.783765),11718=>array(-73.268488,40.723177),11719=>array(-72.912104,40.782153),11720=>array(-73.082097,40.870291),11721=>array(-73.372447,40.900759),11722=>array(-73.194927,40.783033),11724=>array(-73.456383,40.864224),11725=>array(-73.280788,40.840482),11726=>array(-73.395729,40.678789),11727=>array(-73.004014,40.882073),11729=>array(-73.321445,40.762698),11730=>array(-73.169818,40.716886),11731=>array(-73.316948,40.862648),11732=>array(-73.536901,40.844736),11733=>array(-73.112784,40.940247),11735=>array(-73.432789,40.732747),11738=>array(-73.038221,40.83819),11739=>array(-73.159874,40.729371),11740=>array(-73.361292,40.865401),11741=>array(-73.07033,40.794828),11742=>array(-73.041426,40.810011),11743=>array(-73.423641,40.883386),11746=>array(-73.362276,40.814268),11747=>array(-73.407298,40.788528),11749=>array(-73.170891,40.806738),11751=>array(-73.213924,40.730486),11752=>array(-73.174012,40.757114),11753=>array(-73.539911,40.789722),11754=>array(-73.24988,40.885566),11755=>array(-73.116818,40.857797),11756=>array(-73.516333,40.724567),11757=>array(-73.373328,40.68901),11758=>array(-73.458448,40.668934),11762=>array(-73.446664,40.682744),11763=>array(-72.984928,40.826881),11764=>array(-72.979047,40.938993),11765=>array(-73.558941,40.882186),11766=>array(-73.018666,40.939219),11767=>array(-73.145216,40.842949),11768=>array(-73.339309,40.923631),11769=>array(-73.129837,40.736277),11770=>array(-73.156596,40.645842),11771=>array(-73.52502,40.872799),11772=>array(-72.987407,40.76178),11776=>array(-73.046399,40.913615),11777=>array(-73.066659,40.956068),11778=>array(-72.937087,40.948048),11779=>array(-73.116108,40.812431),11780=>array(-73.174729,40.909287),11782=>array(-73.08167,40.738088),11783=>array(-73.490014,40.677612),11784=>array(-73.041215,40.868923),11786=>array(-72.886658,40.950485),11787=>array(-73.21126,40.852924),11788=>array(-73.213084,40.818075),11789=>array(-72.971008,40.962028),11790=>array(-73.127374,40.905957),11791=>array(-73.505922,40.828288),11792=>array(-72.825588,40.954997),11793=>array(-73.514561,40.650294),11794=>array(-73.124864,40.913317),11795=>array(-73.296337,40.709005),11796=>array(-73.099701,40.731277),11797=>array(-73.472077,40.820348),11798=>array(-73.378743,40.752599),11801=>array(-73.524452,40.762304),11803=>array(-73.473035,40.7817),11804=>array(-73.457384,40.75901),11901=>array(-72.647924,40.925735),11930=>array(-72.098043,40.989573),11931=>array(-72.613346,40.933503),11932=>array(-72.306647,40.934344),11933=>array(-72.767557,40.941096),11934=>array(-72.794297,40.798359),11935=>array(-72.486958,41.021223),11937=>array(-72.165487,41.011627),11939=>array(-72.31535,41.123116),11940=>array(-72.752231,40.812662),11941=>array(-72.729761,40.83016),11942=>array(-72.582227,40.850777),11944=>array(-72.371541,41.10403),11946=>array(-72.521704,40.87027),11947=>array(-72.571053,40.950659),11948=>array(-72.553554,40.963769),11949=>array(-72.80456,40.866411),11950=>array(-72.84701,40.808032),11951=>array(-72.830344,40.763164),11952=>array(-72.547599,41.001648),11953=>array(-72.951773,40.893272),11954=>array(-71.946386,41.047565),11955=>array(-72.816096,40.809125),11956=>array(-72.462175,40.969049),11957=>array(-72.148968,41.192201),11958=>array(-72.464419,41.039067),11959=>array(-72.601345,40.822586),11960=>array(-72.706062,40.810615),11961=>array(-72.888349,40.905139),11962=>array(-72.268719,40.930895),11963=>array(-72.320196,40.993886),11964=>array(-72.316976,41.055701),11965=>array(-72.2884,41.096081),11967=>array(-72.875477,40.794778),11968=>array(-72.415663,40.905926),11970=>array(-72.577539,40.938952),11971=>array(-72.430926,41.064037),11972=>array(-72.702923,40.848016),11973=>array(-72.882123,40.867173),11975=>array(-72.244466,40.941107),11976=>array(-72.350704,40.922393),11977=>array(-72.678983,40.827467),11978=>array(-72.649008,40.826323),11980=>array(-72.92376,40.831652),12007=>array(-73.927143,42.455665),12008=>array(-73.906535,42.853488),12009=>array(-74.035542,42.697566),12010=>array(-74.173332,42.937626),12015=>array(-73.824837,42.294886),12017=>array(-73.455928,42.321148),12018=>array(-73.52077,42.628833),12019=>array(-73.881808,42.934351),12020=>array(-73.868123,43.001589),12022=>array(-73.333838,42.656947),12023=>array(-74.183022,42.598558),12024=>array(-73.533278,42.476788),12025=>array(-74.138092,43.083346),12027=>array(-73.907815,42.935415),12028=>array(-73.442269,42.934442),12029=>array(-73.424965,42.415956),12031=>array(-74.45161,42.766037),12032=>array(-74.52507,43.124008),12033=>array(-73.705499,42.543138),12035=>array(-74.357711,42.730668),12036=>array(-74.673053,42.541514),12037=>array(-73.567126,42.344725),12040=>array(-73.350721,42.63735),12041=>array(-73.95266,42.577943),12042=>array(-73.938206,42.416518),12043=>array(-74.530506,42.69397),12045=>array(-73.800532,42.482555),12046=>array(-73.923521,42.509465),12047=>array(-73.726219,42.784054),12051=>array(-73.842543,42.345525),12052=>array(-73.478427,42.75447),12053=>array(-74.190866,42.757543),12054=>array(-73.864416,42.608547),12056=>array(-74.09515,42.764785),12057=>array(-73.346287,42.968892),12058=>array(-73.918376,42.345129),12059=>array(-74.060894,42.619229),12060=>array(-73.505286,42.410399),12061=>array(-73.659578,42.594948),12062=>array(-73.504976,42.538976),12063=>array(-73.638051,42.568163),12064=>array(-74.655719,42.614166),12065=>array(-73.785597,42.852284),12066=>array(-74.384535,42.800729),12067=>array(-73.920294,42.557461),12068=>array(-74.401834,42.956072),12069=>array(-74.27964,42.946168),12070=>array(-74.263032,42.986058),12071=>array(-74.422657,42.552669),12072=>array(-74.356741,42.884893),12074=>array(-74.030006,43.054217),12075=>array(-73.633627,42.299922),12076=>array(-74.395734,42.410272),12077=>array(-73.777695,42.588163),12078=>array(-74.339632,43.134351),12083=>array(-74.026509,42.424859),12084=>array(-73.899429,42.704563),12085=>array(-73.963261,42.703313),12086=>array(-74.086332,43.009005),12087=>array(-73.892894,42.43225),12089=>array(-73.312773,42.867481),12090=>array(-73.351525,42.876802),12092=>array(-74.378715,42.696079),12093=>array(-74.628095,42.497796),12094=>array(-73.489795,42.899423),12095=>array(-74.403815,43.024817),12106=>array(-73.710951,42.389554),12108=>array(-74.451487,43.573248),12110=>array(-73.775205,42.75091),12115=>array(-73.576704,42.477297),12116=>array(-74.911164,42.538795),12117=>array(-74.261094,43.169293),12118=>array(-73.708337,42.913382),12120=>array(-74.148844,42.449724),12121=>array(-73.607392,42.839897),12122=>array(-74.32586,42.542052),12123=>array(-73.605908,42.52681),12124=>array(-73.797581,42.453111),12125=>array(-73.399844,42.484748),12130=>array(-73.65938,42.442223),12131=>array(-74.464577,42.457514),12132=>array(-73.630029,42.470522),12134=>array(-74.228535,43.266222),12136=>array(-73.559506,42.434836),12137=>array(-74.133057,42.860351),12138=>array(-73.370413,42.748844),12139=>array(-74.579588,43.500184),12140=>array(-73.540064,42.696684),12143=>array(-73.855238,42.489818),12144=>array(-73.717842,42.627836),12147=>array(-74.15884,42.518611),12148=>array(-73.848164,42.827793),12149=>array(-74.563445,42.616653),12150=>array(-74.052686,42.880521),12151=>array(-73.787225,42.922697),12153=>array(-73.473341,42.629923),12154=>array(-73.605775,42.93746),12155=>array(-74.827655,42.596357),12156=>array(-73.747254,42.483504),12157=>array(-74.286077,42.669798),12158=>array(-73.822124,42.542092),12159=>array(-73.885894,42.651428),12160=>array(-74.383153,42.761621),12161=>array(-73.854863,42.534769),12164=>array(-74.358706,43.587995),12165=>array(-73.510986,42.305721),12166=>array(-74.445493,42.833604),12167=>array(-74.578036,42.424942),12168=>array(-73.380714,42.560862),12169=>array(-73.448036,42.592887),12170=>array(-73.667271,43.001956),12172=>array(-73.739212,42.288764),12173=>array(-73.75966,42.380013),12174=>array(-73.728436,42.353449),12175=>array(-74.556231,42.544713),12176=>array(-73.980862,42.382017),12177=>array(-74.287066,42.951223),12180=>array(-73.599536,42.748588),12182=>array(-73.630864,42.799699),12183=>array(-73.692595,42.74787),12184=>array(-73.653177,42.420039),12185=>array(-73.554112,42.862521),12186=>array(-73.977188,42.633164),12187=>array(-74.463554,42.61884),12188=>array(-73.695521,42.821229),12189=>array(-73.717521,42.736341),12190=>array(-74.28541,43.475631),12192=>array(-73.827676,42.409031),12193=>array(-74.043268,42.52276),12194=>array(-74.44763,42.528439),12195=>array(-73.475088,42.482789),12196=>array(-73.613946,42.631786),12197=>array(-74.724749,42.609999),12198=>array(-73.633574,42.672768),12202=>array(-73.763248,42.633752),12203=>array(-73.845869,42.678763),12204=>array(-73.733797,42.691525),12205=>array(-73.82924,42.718785),12206=>array(-73.782731,42.674514),12207=>array(-73.746424,42.6575),12208=>array(-73.809978,42.653031),12209=>array(-73.790469,42.638686),12210=>array(-73.756386,42.659616),12211=>array(-73.763706,42.703095),12222=>array(-73.82323,42.685261),12302=>array(-73.982505,42.878182),12303=>array(-73.926481,42.753534),12304=>array(-73.898297,42.77469),12305=>array(-73.950254,42.811977),12306=>array(-74.044234,42.805431),12307=>array(-73.932822,42.804981),12308=>array(-73.91967,42.82098),12309=>array(-73.86496,42.799829),12401=>array(-74.010273,41.987541),12404=>array(-74.236062,41.818967),12405=>array(-74.085995,42.317909),12406=>array(-74.524094,42.079945),12407=>array(-74.358151,42.317636),12409=>array(-74.182346,42.039946),12410=>array(-74.424733,42.066098),12411=>array(-74.044802,41.876019),12412=>array(-74.279585,42.012729),12413=>array(-74.02216,42.313984),12414=>array(-73.913867,42.232022),12416=>array(-74.280684,42.103216),12417=>array(-73.990723,41.906422),12418=>array(-74.161681,42.358759),12419=>array(-74.102007,41.860252),12420=>array(-74.371763,41.67228),12421=>array(-74.546139,42.250044),12422=>array(-74.213288,42.391829),12423=>array(-74.109746,42.379218),12424=>array(-74.115156,42.24827),12427=>array(-74.136697,42.134193),12428=>array(-74.447304,41.742833),12429=>array(-73.985378,41.833329),12430=>array(-74.49916,42.200758),12431=>array(-74.023533,42.362023),12432=>array(-73.944531,42.04442),12433=>array(-74.156458,42.000525),12434=>array(-74.502385,42.36364),12435=>array(-74.513284,41.730835),12436=>array(-74.077813,42.195759),12438=>array(-74.601076,42.205044),12439=>array(-74.210391,42.277818),12440=>array(-74.172876,41.781151),12441=>array(-74.509215,42.134422),12442=>array(-74.222976,42.182011),12443=>array(-74.084925,41.934991),12444=>array(-74.29752,42.264233),12446=>array(-74.326443,41.809054),12448=>array(-74.15797,42.090011),12449=>array(-73.993705,41.992355),12450=>array(-74.24428,42.133247),12451=>array(-73.948176,42.304893),12452=>array(-74.364938,42.252385),12453=>array(-73.936281,42.093389),12454=>array(-74.149495,42.286951),12455=>array(-74.659523,42.14071),12456=>array(-73.998278,42.032997),12457=>array(-74.252501,42.044072),12458=>array(-74.43208,41.822918),12459=>array(-74.678893,42.240382),12460=>array(-74.14759,42.415615),12461=>array(-74.267998,41.904961),12463=>array(-74.020774,42.205593),12464=>array(-74.359949,42.027684),12465=>array(-74.460016,42.157153),12466=>array(-73.979025,41.904345),12468=>array(-74.427185,42.304177),12469=>array(-74.238585,42.447741),12470=>array(-74.095475,42.300387),12471=>array(-74.041344,41.843871),12472=>array(-74.079545,41.84709),12473=>array(-74.041007,42.258166),12474=>array(-74.583034,42.323807),12475=>array(-74.015432,42.015237),12477=>array(-73.990006,42.091943),12480=>array(-74.391252,42.135377),12481=>array(-74.228435,41.987348),12482=>array(-73.955446,42.268143),12483=>array(-74.422001,41.672384),12484=>array(-74.176532,41.861843),12485=>array(-74.144197,42.204998),12486=>array(-74.063984,41.832417),12487=>array(-73.998795,41.869399),12489=>array(-74.358293,41.750485),12490=>array(-73.925237,42.122227),12491=>array(-74.141441,41.965186),12492=>array(-74.335763,42.184926),12493=>array(-73.974095,41.785589),12494=>array(-74.292894,41.956599),12495=>array(-74.24068,42.084923),12496=>array(-74.269692,42.337294),12498=>array(-74.109455,42.046044),12501=>array(-73.573604,41.863492),12502=>array(-73.664724,42.086568),12503=>array(-73.580146,42.035959),12504=>array(-73.912425,42.034803),12507=>array(-73.918958,42.008182),12508=>array(-73.953632,41.495996),12512=>array(-73.968402,41.548499),12513=>array(-73.720481,42.219307),12514=>array(-73.764441,41.877418),12515=>array(-74.06484,41.684774),12516=>array(-73.563583,42.106275),12517=>array(-73.507454,42.114296),12518=>array(-74.043064,41.416157),12520=>array(-73.996195,41.428017),12521=>array(-73.650487,42.171335),12522=>array(-73.599402,41.715067),12523=>array(-73.759502,42.086878),12524=>array(-73.890419,41.529535),12525=>array(-74.188198,41.691551),12526=>array(-73.858769,42.122234),12527=>array(-73.93567,41.519426),12528=>array(-74.009482,41.722054),12529=>array(-73.542728,42.19874),12530=>array(-73.687763,42.207467),12531=>array(-73.671671,41.540555),12533=>array(-73.787605,41.561643),12534=>array(-73.752256,42.217345),12538=>array(-73.893141,41.792345),12540=>array(-73.724891,41.671202),12542=>array(-74.015014,41.613876),12543=>array(-74.173101,41.49554),12545=>array(-73.669343,41.782912),12546=>array(-73.523357,41.948),12547=>array(-73.986567,41.660687),12548=>array(-74.101802,41.657701),12549=>array(-74.259365,41.528031),12550=>array(-74.057223,41.539574),12553=>array(-74.074901,41.455714),12561=>array(-74.096058,41.759307),12563=>array(-73.587226,41.499189),12564=>array(-73.582587,41.582617),12565=>array(-73.647638,42.247128),12566=>array(-74.319661,41.633519),12567=>array(-73.642221,41.986196),12569=>array(-73.79284,41.734557),12570=>array(-73.675662,41.626321),12571=>array(-73.809608,42.002775),12572=>array(-73.863664,41.924885),12574=>array(-73.945658,41.917688),12575=>array(-74.178871,41.466705),12577=>array(-74.122142,41.42404),12578=>array(-73.795859,41.809125),12580=>array(-73.871534,41.863649),12581=>array(-73.700652,41.901879),12582=>array(-73.738443,41.544293),12583=>array(-73.868652,42.063367),12585=>array(-73.69151,41.726404),12586=>array(-74.170102,41.562764),12589=>array(-74.158771,41.623791),12590=>array(-73.886853,41.592556),12592=>array(-73.578624,41.802074),12594=>array(-73.557677,41.684401),12601=>array(-73.911521,41.701908),12603=>array(-73.864484,41.675868),12604=>array(-73.89226,41.688266),12701=>array(-74.700396,41.650261),12719=>array(-74.904285,41.49825),12720=>array(-74.907849,41.645848),12721=>array(-74.422422,41.581723),12722=>array(-74.374304,41.590634),12723=>array(-74.987694,41.7531),12724=>array(-74.958711,41.837621),12725=>array(-74.5697,41.983131),12726=>array(-75.017203,41.708209),12729=>array(-74.623499,41.475792),12732=>array(-74.874588,41.551929),12733=>array(-74.617933,41.724769),12734=>array(-74.75046,41.734585),12736=>array(-75.021754,41.852843),12737=>array(-74.798632,41.501481),12738=>array(-74.58612,41.676179),12740=>array(-74.433956,41.938918),12741=>array(-75.077725,41.839141),12742=>array(-74.723518,41.724328),12743=>array(-74.831043,41.548639),12745=>array(-75.024648,41.783433),12746=>array(-74.656826,41.442383),12747=>array(-74.692894,41.750928),12748=>array(-74.922609,41.774642),12749=>array(-74.841166,41.695254),12750=>array(-74.967508,41.729237),12751=>array(-74.664427,41.695871),12752=>array(-74.99419,41.680039),12754=>array(-74.736412,41.799066),12758=>array(-74.739118,41.940283),12759=>array(-74.658853,41.78173),12760=>array(-75.107835,41.90393),12762=>array(-74.792204,41.664364),12763=>array(-74.522774,41.676348),12764=>array(-74.995556,41.591553),12765=>array(-74.621157,41.852332),12766=>array(-74.978854,41.815208),12767=>array(-74.994415,41.838093),12768=>array(-74.730022,41.864443),12769=>array(-74.46728,41.657943),12770=>array(-74.843115,41.449112),12771=>array(-74.624279,41.37438),12775=>array(-74.592331,41.615654),12776=>array(-74.958681,41.963382),12777=>array(-74.709618,41.561802),12778=>array(-74.81755,41.642678),12779=>array(-74.632195,41.702466),12780=>array(-74.727343,41.440142),12781=>array(-74.466384,41.619677),12783=>array(-74.833724,41.738633),12784=>array(-74.63824,41.669877),12785=>array(-74.561271,41.532391),12786=>array(-74.857203,41.63863),12787=>array(-74.845023,41.795396),12788=>array(-74.589314,41.787539),12789=>array(-74.571025,41.704127),12790=>array(-74.517603,41.592121),12791=>array(-74.89287,41.817275),12792=>array(-74.95982,41.51392),12801=>array(-73.645286,43.31116),12803=>array(-73.629363,43.290078),12804=>array(-73.685911,43.340954),12808=>array(-73.715618,43.760148),12809=>array(-73.454506,43.237078),12810=>array(-73.985941,43.491968),12811=>array(-74.028328,43.605465),12812=>array(-74.389767,43.875794),12814=>array(-73.636202,43.624539),12815=>array(-73.667874,43.695952),12816=>array(-73.382032,43.044236),12817=>array(-73.823628,43.639585),12819=>array(-73.468547,43.59087),12821=>array(-73.415995,43.453564),12822=>array(-73.922216,43.228513),12823=>array(-73.409117,43.179961),12824=>array(-73.727177,43.524757),12827=>array(-73.529859,43.460929),12828=>array(-73.558355,43.254993),12831=>array(-73.691811,43.195329),12832=>array(-73.330271,43.358467),12833=>array(-73.840896,43.15),12834=>array(-73.500556,43.094213),12835=>array(-74.006336,43.332745),12836=>array(-73.605592,43.71234),12837=>array(-73.255601,43.476445),12838=>array(-73.404949,43.329069),12839=>array(-73.553953,43.354486),12841=>array(-73.533429,43.605595),12842=>array(-74.367058,43.738345),12843=>array(-73.972748,43.565104),12844=>array(-73.621194,43.489396),12845=>array(-73.71274,43.424048),12846=>array(-73.789719,43.345954),12847=>array(-74.609231,44.008384),12849=>array(-73.29832,43.449567),12850=>array(-73.981441,43.102616),12851=>array(-74.034467,43.841891),12852=>array(-74.163697,43.936189),12853=>array(-74.065037,43.657786),12855=>array(-73.758053,44.02701),12856=>array(-74.142961,43.66594),12857=>array(-73.89062,43.819563),12858=>array(-73.67578,43.908933),12859=>array(-73.920872,43.171875),12860=>array(-73.843348,43.757003),12861=>array(-73.417527,43.746887),12862=>array(-73.910321,43.685403),12863=>array(-73.931904,43.060377),12864=>array(-74.305442,43.72731),12865=>array(-73.347451,43.214159),12866=>array(-73.740236,43.073715),12870=>array(-73.761222,43.830056),12871=>array(-73.612965,43.088569),12872=>array(-73.734418,43.874656),12873=>array(-73.311646,43.117451),12874=>array(-73.549746,43.69056),12878=>array(-74.02745,43.415025),12883=>array(-73.552805,43.836623),12884=>array(-73.591291,43.088396),12885=>array(-73.806561,43.523052),12886=>array(-73.93466,43.682704),12887=>array(-73.365798,43.53676),12901=>array(-73.471148,44.704021),12903=>array(-73.445883,44.680303),12910=>array(-73.636413,44.855031),12911=>array(-73.460805,44.52144),12912=>array(-73.772496,44.48095),12913=>array(-74.002212,44.430097),12914=>array(-74.602942,44.927419),12916=>array(-74.515665,44.834052),12917=>array(-74.178909,44.927638),12918=>array(-73.676657,44.700736),12919=>array(-73.447082,44.964535),12920=>array(-74.066012,44.882768),12921=>array(-73.438073,44.891337),12922=>array(-74.702114,44.286614),12923=>array(-73.939425,44.960311),12924=>array(-73.580617,44.481354),12926=>array(-74.328997,44.950817),12927=>array(-74.809703,44.207326),12928=>array(-73.583301,43.963848),12929=>array(-73.719234,44.720027),12930=>array(-74.543229,44.720458),12932=>array(-73.6102,44.21488),12933=>array(-73.845341,44.890994),12934=>array(-73.873753,44.875311),12935=>array(-73.796933,44.844657),12936=>array(-73.40145,44.285062),12937=>array(-74.478455,44.960847),12939=>array(-74.160828,44.432955),12941=>array(-73.705667,44.348458),12942=>array(-73.827579,44.232563),12943=>array(-73.883516,44.122758),12944=>array(-73.514751,44.442367),12945=>array(-74.24044,44.309091),12946=>array(-74.04628,44.206113),12950=>array(-73.581246,44.318369),12952=>array(-73.905659,44.708318),12953=>array(-74.260113,44.745188),12955=>array(-73.970421,44.80665),12956=>array(-73.481333,44.097612),12957=>array(-74.574604,44.848323),12958=>array(-73.572178,44.960855),12959=>array(-73.719912,44.952351),12960=>array(-73.572348,44.015756),12961=>array(-73.549539,44.057111),12962=>array(-73.605439,44.701391),12964=>array(-73.626721,44.125919),12965=>array(-74.685289,44.703456),12966=>array(-74.418686,44.798893),12967=>array(-74.657566,44.774921),12969=>array(-74.098205,44.710879),12970=>array(-74.307514,44.478136),12972=>array(-73.569296,44.554081),12973=>array(-74.594706,44.287677),12974=>array(-73.464831,44.060141),12975=>array(-73.430536,44.529091),12976=>array(-74.213593,44.520475),12977=>array(-74.072971,44.277015),12978=>array(-73.808712,44.61636),12979=>array(-73.373373,44.991653),12980=>array(-74.524079,44.563851),12981=>array(-73.84585,44.627097),12983=>array(-74.171593,44.28642),12985=>array(-73.738967,44.560709),12986=>array(-74.480931,44.226011),12987=>array(-73.75346,44.320841),12989=>array(-74.06977,44.520107),12992=>array(-73.517698,44.817451),12993=>array(-73.476221,44.211345),12996=>array(-73.448053,44.355279),12997=>array(-73.892043,44.372798),12998=>array(-73.576545,44.0778),13020=>array(-76.074504,42.816424),13021=>array(-76.558539,42.922279),13024=>array(-76.574232,42.934596),13026=>array(-76.652266,42.744043),13027=>array(-76.364345,43.166437),13028=>array(-75.926835,43.301187),13029=>array(-76.151343,43.225942),13030=>array(-75.962695,43.152233),13031=>array(-76.310286,43.044464),13032=>array(-75.76605,43.081629),13033=>array(-76.562626,43.188494),13034=>array(-76.711189,42.961986),13035=>array(-75.830147,42.940856),13036=>array(-76.166775,43.309256),13037=>array(-75.855983,43.062303),13039=>array(-76.056249,43.172142),13040=>array(-75.930761,42.559649),13041=>array(-76.192302,43.192089),13042=>array(-75.85258,43.26045),13044=>array(-75.996241,43.291249),13045=>array(-76.202102,42.573807),13051=>array(-75.908639,42.876725),13052=>array(-75.865194,42.71231),13053=>array(-76.267919,42.479574),13054=>array(-75.666823,43.169352),13057=>array(-76.037919,43.101955),13060=>array(-76.411872,43.022862),13061=>array(-75.762082,42.871851),13062=>array(-76.384376,42.484095),13063=>array(-75.977961,42.847849),13064=>array(-76.711915,43.328996),13066=>array(-76.000667,43.032475),13068=>array(-76.359199,42.492431),13069=>array(-76.380658,43.329278),13071=>array(-76.542586,42.675103),13072=>array(-75.763989,42.76221),13073=>array(-76.387923,42.58367),13074=>array(-76.549843,43.310917),13076=>array(-76.149319,43.353717),13077=>array(-76.211042,42.727973),13078=>array(-76.061077,42.958484),13080=>array(-76.485258,43.09321),13081=>array(-76.627152,42.673617),13082=>array(-75.959888,43.10273),13083=>array(-75.978676,43.645972),13084=>array(-76.124474,42.880541),13087=>array(-76.15405,42.708597),13088=>array(-76.189457,43.112421),13090=>array(-76.212402,43.153084),13092=>array(-76.419295,42.654563),13101=>array(-76.056007,42.589125),13102=>array(-76.292002,42.550304),13103=>array(-76.109544,43.32576),13104=>array(-75.948439,42.96303),13108=>array(-76.331113,42.964845),13110=>array(-76.280364,42.895398),13111=>array(-76.614264,43.258488),13112=>array(-76.417239,43.106266),13113=>array(-76.538623,43.16265),13114=>array(-76.244786,43.465706),13115=>array(-76.478779,43.398646),13116=>array(-76.007947,43.074797),13117=>array(-76.707508,43.009299),13118=>array(-76.387278,42.755585),13120=>array(-76.175146,42.93317),13122=>array(-75.856505,42.841182),13123=>array(-75.769068,43.233564),13124=>array(-75.823604,42.661074),13126=>array(-76.457454,43.438798),13131=>array(-76.091802,43.423243),13132=>array(-76.251046,43.271927),13134=>array(-75.684678,42.967368),13135=>array(-76.314375,43.253687),13136=>array(-75.844788,42.614098),13138=>array(-76.014634,42.899087),13140=>array(-76.650274,43.060381),13141=>array(-76.185697,42.752495),13142=>array(-76.137872,43.554899),13143=>array(-76.714793,43.235788),13144=>array(-75.977023,43.568747),13145=>array(-76.119141,43.650319),13146=>array(-76.750191,43.085645),13147=>array(-76.569608,42.775406),13148=>array(-76.783434,42.914872),13152=>array(-76.37262,42.890839),13153=>array(-76.453627,42.996557),13155=>array(-75.776726,42.674546),13156=>array(-76.661304,43.325994),13157=>array(-75.721431,43.206652),13158=>array(-75.951068,42.696935),13159=>array(-76.111769,42.802768),13160=>array(-76.648904,42.827598),13162=>array(-75.714741,43.185045),13163=>array(-75.710522,43.079679),13164=>array(-76.312578,43.096891),13165=>array(-76.883297,42.916639),13166=>array(-76.55682,43.071922),13167=>array(-76.06026,43.326421),13202=>array(-76.150639,43.043781),13203=>array(-76.134924,43.061111),13204=>array(-76.177473,43.050817),13205=>array(-76.14203,43.005276),13206=>array(-76.10582,43.073466),13207=>array(-76.163401,43.012868),13208=>array(-76.145229,43.078768),13209=>array(-76.224251,43.068502),13210=>array(-76.127021,43.031189),13211=>array(-76.119484,43.103572),13212=>array(-76.130154,43.129697),13214=>array(-76.075591,43.038709),13215=>array(-76.223386,42.980793),13219=>array(-76.224195,43.041266),13224=>array(-76.1029,43.037163),13290=>array(-76.173017,43.069136),13301=>array(-75.218175,43.41605),13302=>array(-75.965068,43.49811),13303=>array(-75.468212,43.367414),13304=>array(-75.160287,43.24388),13305=>array(-75.421171,43.892289),13308=>array(-75.657668,43.251266),13309=>array(-75.355443,43.452005),13310=>array(-75.571545,42.88962),13312=>array(-75.194701,43.697077),13313=>array(-75.272902,42.880221),13314=>array(-75.319104,42.816533),13315=>array(-75.143611,42.744144),13316=>array(-75.73974,43.418917),13317=>array(-74.590835,42.854095),13318=>array(-75.261538,42.920182),13319=>array(-75.266925,43.026436),13320=>array(-74.740798,42.777805),13321=>array(-75.370635,43.087779),13322=>array(-75.201657,42.954345),13323=>array(-75.379366,43.039976),13324=>array(-74.966657,43.325878),13325=>array(-75.527092,43.582829),13326=>array(-74.895371,42.722511),13327=>array(-75.262309,43.972929),13328=>array(-75.429027,42.985096),13329=>array(-74.70351,43.110979),13331=>array(-74.880884,43.866311),13332=>array(-75.581764,42.764187),13333=>array(-74.818644,42.836995),13334=>array(-75.656427,42.827039),13335=>array(-75.248224,42.70226),13337=>array(-74.999545,42.757804),13338=>array(-74.982347,43.510379),13339=>array(-74.65866,42.936896),13340=>array(-75.12857,43.061642),13341=>array(-75.396891,43.036086),13342=>array(-75.195234,42.654143),13343=>array(-75.3115,43.751239),13345=>array(-75.321254,43.687108),13346=>array(-75.542907,42.818504),13348=>array(-75.066926,42.709982),13350=>array(-75.000618,43.06116),13352=>array(-75.116208,43.313337),13353=>array(-74.694618,43.447326),13354=>array(-75.268497,43.265093),13355=>array(-75.430434,42.809841),13357=>array(-75.081183,42.970962),13360=>array(-74.714836,43.72179),13361=>array(-74.86756,42.904352),13362=>array(-75.522003,42.982178),13363=>array(-75.513109,43.324528),13364=>array(-75.261071,42.804977),13365=>array(-74.853291,43.125689),13367=>array(-75.532709,43.757731),13368=>array(-75.286787,43.638483),13402=>array(-75.500514,42.892391),13403=>array(-75.267645,43.164533),13404=>array(-75.471758,43.736385),13406=>array(-74.924889,43.134514),13407=>array(-74.95059,42.968799),13408=>array(-75.676749,42.922949),13409=>array(-75.595139,42.976461),13410=>array(-74.61252,42.931174),13411=>array(-75.306457,42.633789),13413=>array(-75.27942,43.060356),13415=>array(-75.198473,42.596489),13416=>array(-74.970566,43.18739),13417=>array(-75.293793,43.100965),13418=>array(-75.38046,42.845704),13420=>array(-74.984147,43.717768),13421=>array(-75.660092,43.061915),13424=>array(-75.365215,43.152368),13425=>array(-75.48706,42.964793),13428=>array(-74.546238,42.915071),13431=>array(-75.073328,43.209082),13433=>array(-75.242417,43.589518),13435=>array(-75.150772,43.304981),13436=>array(-74.666226,43.811023),13437=>array(-75.803859,43.580307),13438=>array(-75.159613,43.354138),13439=>array(-74.995275,42.857316),13440=>array(-75.461779,43.215771),13441=>array(-75.408248,43.226377),13450=>array(-74.810298,42.701925),13452=>array(-74.63047,43.043056),13454=>array(-74.7577,43.219835),13456=>array(-75.255495,43.000029),13459=>array(-74.588674,42.775005),13460=>array(-75.442842,42.687037),13461=>array(-75.599126,43.070467),13464=>array(-75.615788,42.687973),13468=>array(-74.851925,42.848254),13469=>array(-75.302367,43.214828),13470=>array(-74.610052,43.209651),13471=>array(-75.577397,43.357597),13472=>array(-75.067836,43.697411),13473=>array(-75.446375,43.642941),13475=>array(-74.830529,42.893741),13476=>array(-75.509514,43.087503),13477=>array(-75.512948,43.032894),13478=>array(-75.581897,43.144012),13480=>array(-75.363163,42.917856),13483=>array(-75.826061,43.397335),13484=>array(-75.65919,42.866325),13485=>array(-75.315224,42.787528),13486=>array(-75.344599,43.345147),13488=>array(-74.750589,42.688638),13489=>array(-75.552463,43.460774),13490=>array(-75.426511,43.11008),13491=>array(-75.168133,42.864135),13492=>array(-75.33768,43.114604),13493=>array(-75.897509,43.432843),13494=>array(-75.141288,43.532529),13495=>array(-75.277497,43.11089),13501=>array(-75.225833,43.081283),13502=>array(-75.154707,43.141264),13601=>array(-75.906501,43.968892),13602=>array(-75.778311,44.066533),13603=>array(-75.793813,44.035974),13605=>array(-76.050285,43.807294),13606=>array(-76.014721,43.872567),13607=>array(-75.935736,44.298512),13608=>array(-75.61534,44.254686),13612=>array(-75.76937,43.985237),13613=>array(-74.750443,44.870613),13614=>array(-75.691167,44.530892),13615=>array(-75.988503,44.029103),13616=>array(-75.857573,44.030078),13617=>array(-75.142767,44.580531),13618=>array(-76.290981,44.114766),13619=>array(-75.600977,43.978952),13620=>array(-75.448325,43.908782),13621=>array(-75.080272,44.833691),13622=>array(-76.109305,44.099234),13623=>array(-75.752462,44.449786),13624=>array(-76.093055,44.20948),13625=>array(-74.928377,44.538101),13626=>array(-75.734774,43.830086),13628=>array(-75.682394,44.030542),13630=>array(-75.311532,44.498619),13633=>array(-75.455993,44.49743),13634=>array(-76.073698,44.01129),13635=>array(-75.280789,44.286726),13636=>array(-76.116547,43.743435),13637=>array(-75.818322,44.106202),13638=>array(-75.741697,44.019072),13639=>array(-75.150529,44.263676),13640=>array(-76.028103,44.303561),13641=>array(-76.003351,44.273801),13642=>array(-75.455879,44.335388),13643=>array(-75.717094,44.031812),13646=>array(-75.674193,44.446084),13647=>array(-74.98058,44.605875),13648=>array(-75.318,44.150217),13650=>array(-76.216091,43.81131),13651=>array(-76.176962,43.866156),13652=>array(-75.186773,44.432661),13654=>array(-75.436848,44.577112),13655=>array(-74.650084,44.982056),13656=>array(-75.955486,44.192235),13658=>array(-75.279399,44.743083),13659=>array(-75.86338,43.738005),13660=>array(-75.160958,44.773868),13661=>array(-76.098396,43.70962),13662=>array(-74.884038,44.932334),13664=>array(-75.64546,44.584013),13665=>array(-75.434366,44.04846),13666=>array(-74.926076,44.218485),13667=>array(-74.960097,44.837267),13668=>array(-74.986314,44.754954),13669=>array(-75.482342,44.672777),13670=>array(-75.116735,44.167379),13672=>array(-74.660706,44.470543),13673=>array(-75.717782,44.164271),13674=>array(-76.04818,43.738561),13675=>array(-75.846286,44.281718),13676=>array(-74.926222,44.65496),13677=>array(-75.179673,44.512429),13678=>array(-74.992918,44.813766),13679=>array(-75.770605,44.319891),13680=>array(-75.323398,44.595988),13681=>array(-75.373133,44.428046),13682=>array(-75.90189,43.843311),13684=>array(-75.013141,44.356596),13685=>array(-76.085519,43.925467),13687=>array(-74.836656,44.432964),13690=>array(-74.991203,44.108365),13691=>array(-75.773875,44.22722),13692=>array(-76.026292,44.288793),13693=>array(-76.246105,43.985747),13694=>array(-75.146018,44.857601),13695=>array(-74.922258,44.102929),13696=>array(-74.888042,44.694736),13697=>array(-74.810347,44.754714),13730=>array(-75.53272,42.223238),13731=>array(-74.78737,42.128419),13732=>array(-76.167535,42.049447),13733=>array(-75.479481,42.301754),13734=>array(-76.409653,42.069955),13736=>array(-76.202038,42.324084),13739=>array(-74.789149,42.349124),13740=>array(-74.756993,42.273814),13743=>array(-76.338222,42.211894),13744=>array(-75.907999,42.243494),13746=>array(-75.884667,42.268926),13748=>array(-75.822521,42.042579),13750=>array(-74.857921,42.471014),13751=>array(-74.902857,42.454193),13752=>array(-74.897015,42.190557),13753=>array(-74.926915,42.30696),13754=>array(-75.447962,42.088482),13755=>array(-74.966906,42.055244),13756=>array(-75.10067,42.004099),13757=>array(-74.891229,42.410607),13760=>array(-76.084713,42.133387),13774=>array(-75.149396,41.960129),13775=>array(-75.134017,42.32791),13776=>array(-75.332049,42.470351),13777=>array(-75.989587,42.258166),13778=>array(-75.759496,42.359219),13780=>array(-75.476583,42.422485),13782=>array(-74.991294,42.169631),13783=>array(-75.266006,41.993662),13784=>array(-76.221343,42.426878),13786=>array(-74.693941,42.44098),13787=>array(-75.671984,42.212533),13788=>array(-74.665791,42.339032),13790=>array(-76.001942,42.165361),13794=>array(-76.013719,42.393236),13795=>array(-75.778938,42.056638),13796=>array(-75.132129,42.557188),13797=>array(-76.040401,42.333665),13801=>array(-75.77697,42.505085),13802=>array(-76.041266,42.242134),13803=>array(-76.067124,42.456883),13804=>array(-75.38422,42.225702),13806=>array(-74.957114,42.375535),13807=>array(-74.988235,42.607461),13808=>array(-75.262202,42.525233),13809=>array(-75.395542,42.403813),13810=>array(-75.108363,42.606817),13811=>array(-76.164054,42.234926),13812=>array(-76.354752,42.03006),13813=>array(-75.551337,42.163706),13815=>array(-75.530855,42.547866),13820=>array(-75.036905,42.483431),13825=>array(-75.204553,42.435577),13826=>array(-75.638796,42.09982),13827=>array(-76.249166,42.117827),13830=>array(-75.627625,42.435584),13832=>array(-75.672216,42.65813),13833=>array(-75.768632,42.198205),13834=>array(-74.965895,42.530981),13835=>array(-76.178996,42.383214),13838=>array(-75.388127,42.285099),13839=>array(-75.252051,42.262039),13841=>array(-75.842161,42.40699),13842=>array(-74.723609,42.3767),13843=>array(-75.38141,42.506711),13844=>array(-75.668317,42.608179),13845=>array(-76.354924,42.053431),13846=>array(-75.054746,42.363723),13847=>array(-75.292138,42.180595),13849=>array(-75.309317,42.350096),13850=>array(-76.017594,42.049395),13856=>array(-75.183316,42.171041),13859=>array(-75.245254,42.372485),13860=>array(-74.941986,42.44796),13861=>array(-75.151092,42.50854),13862=>array(-75.931008,42.330958),13863=>array(-75.898915,42.455495),13864=>array(-76.388622,42.271668),13865=>array(-75.615617,42.032061),13901=>array(-75.876065,42.183181),13902=>array(-75.968883,42.088824),13903=>array(-75.889073,42.041886),13904=>array(-75.820206,42.134123),13905=>array(-75.943434,42.170436),14001=>array(-78.510856,43.036593),14004=>array(-78.503687,42.891371),14005=>array(-78.250065,42.920586),14006=>array(-79.021745,42.63313),14008=>array(-78.623166,43.312726),14009=>array(-78.39752,42.593267),14011=>array(-78.299709,42.830674),14012=>array(-78.532622,43.332173),14013=>array(-78.397746,43.08629),14020=>array(-78.213412,42.99619),14024=>array(-78.245468,42.581363),14025=>array(-78.726936,42.622156),14026=>array(-78.687987,42.942313),14028=>array(-78.717617,43.31804),14030=>array(-78.507624,42.564386),14031=>array(-78.614262,42.983128),14032=>array(-78.630773,43.046729),14033=>array(-78.692124,42.654382),14034=>array(-78.871196,42.49574),14035=>array(-78.848389,42.490778),14036=>array(-78.389527,42.973851),14037=>array(-78.453328,42.802789),14039=>array(-78.173096,42.85148),14040=>array(-78.376631,42.890873),14041=>array(-78.971581,42.398835),14042=>array(-78.488807,42.475564),14043=>array(-78.703411,42.90197),14047=>array(-78.986623,42.687361),14048=>array(-79.317005,42.484359),14051=>array(-78.699413,43.042842),14052=>array(-78.584397,42.772537),14054=>array(-78.126802,42.919587),14055=>array(-78.600126,42.562879),14057=>array(-78.874782,42.646574),14058=>array(-78.168857,43.102049),14059=>array(-78.634046,42.833552),14060=>array(-78.296467,42.450155),14061=>array(-79.079302,42.593878),14062=>array(-79.143107,42.438404),14063=>array(-79.331104,42.408411),14065=>array(-78.312811,42.484905),14066=>array(-78.185536,42.629054),14067=>array(-78.568403,43.213204),14068=>array(-78.756619,43.027329),14069=>array(-78.642926,42.615223),14070=>array(-78.917725,42.419658),14072=>array(-78.962657,43.017901),14075=>array(-78.833315,42.713252),14080=>array(-78.548318,42.648332),14081=>array(-79.067832,42.563205),14082=>array(-78.384873,42.657556),14085=>array(-78.91865,42.721647),14086=>array(-78.629256,42.909063),14091=>array(-78.893008,42.538233),14092=>array(-78.993074,43.17322),14094=>array(-78.702073,43.157693),14098=>array(-78.380616,43.334373),14101=>array(-78.538203,42.392651),14102=>array(-78.557725,42.837026),14103=>array(-78.37677,43.211161),14105=>array(-78.483902,43.199163),14108=>array(-78.72695,43.263343),14109=>array(-79.03416,43.13795),14111=>array(-78.904703,42.580261),14112=>array(-78.939953,42.697963),14113=>array(-78.339931,42.671576),14120=>array(-78.842654,43.079317),14125=>array(-78.274609,43.084919),14126=>array(-78.728636,43.335882),14127=>array(-78.739697,42.752803),14129=>array(-79.017384,42.481182),14130=>array(-78.147652,42.555981),14131=>array(-78.899823,43.238603),14132=>array(-78.877732,43.14933),14134=>array(-78.523996,42.527675),14135=>array(-79.240898,42.487694),14136=>array(-79.174812,42.517346),14138=>array(-79.036656,42.379512),14139=>array(-78.541402,42.718405),14141=>array(-78.712076,42.524967),14143=>array(-78.063986,42.971918),14145=>array(-78.434328,42.729606),14150=>array(-78.878256,42.998084),14167=>array(-78.324679,42.750032),14168=>array(-78.990541,42.520385),14169=>array(-78.523697,42.766145),14170=>array(-78.674307,42.700245),14171=>array(-78.649832,42.424674),14172=>array(-78.812943,43.272672),14173=>array(-78.473102,42.525971),14174=>array(-78.998325,43.249139),14201=>array(-78.886424,42.89606),14202=>array(-78.877482,42.881482),14203=>array(-78.869813,42.869213),14204=>array(-78.861327,42.882135),14206=>array(-78.810472,42.880078),14207=>array(-78.898883,42.951932),14208=>array(-78.853098,42.91589),14209=>array(-78.86602,42.913943),14210=>array(-78.828739,42.862658),14211=>array(-78.819956,42.90629),14212=>array(-78.820121,42.894207),14213=>array(-78.892406,42.918097),14214=>array(-78.840658,42.939648),14215=>array(-78.810669,42.935317),14216=>array(-78.861119,42.949615),14217=>array(-78.876868,42.971869),14218=>array(-78.830952,42.819372),14219=>array(-78.826472,42.788705),14220=>array(-78.822076,42.845738),14221=>array(-78.722871,42.984522),14222=>array(-78.876943,42.919916),14223=>array(-78.846201,42.973452),14224=>array(-78.747935,42.837826),14225=>array(-78.752459,42.928824),14226=>array(-78.796455,42.971014),14227=>array(-78.730563,42.886909),14228=>array(-78.777335,43.044371),14261=>array(-78.791517,43.007631),14301=>array(-79.040407,43.095821),14302=>array(-79.049193,43.093896),14303=>array(-79.038403,43.084976),14304=>array(-78.951983,43.099407),14305=>array(-79.023242,43.122828),14411=>array(-78.216477,43.235972),14414=>array(-77.743757,42.890961),14415=>array(-77.017084,42.755495),14416=>array(-77.980122,43.082686),14418=>array(-77.216428,42.60443),14420=>array(-77.934564,43.211739),14422=>array(-78.066965,43.084761),14423=>array(-77.821103,42.933948),14424=>array(-77.303277,42.856695),14425=>array(-77.33802,42.991514),14427=>array(-78.053905,42.621589),14428=>array(-77.853568,43.080517),14432=>array(-77.143523,42.957391),14433=>array(-76.877598,43.082126),14435=>array(-77.663312,42.712552),14437=>array(-77.736663,42.57474),14441=>array(-76.957603,42.68461),14445=>array(-77.490301,43.11306),14450=>array(-77.421023,43.092647),14454=>array(-77.774638,42.797774),14456=>array(-76.998972,42.847695),14462=>array(-77.751115,42.686534),14464=>array(-77.932164,43.327044),14466=>array(-77.581042,42.776517),14467=>array(-77.612005,43.036432),14468=>array(-77.802049,43.293956),14469=>array(-77.471014,42.877919),14470=>array(-78.057685,43.205212),14471=>array(-77.492189,42.753761),14472=>array(-77.575134,42.966819),14475=>array(-77.498297,42.937819),14476=>array(-78.0428,43.329379),14477=>array(-78.140393,43.333129),14478=>array(-77.126322,42.577823),14479=>array(-78.313775,43.236262),14480=>array(-77.710359,42.838492),14481=>array(-77.921452,42.761795),14482=>array(-77.971534,42.978904),14485=>array(-77.601026,42.882635),14486=>array(-77.921587,42.89428),14487=>array(-77.636006,42.811758),14489=>array(-76.994347,43.088381),14502=>array(-77.335402,43.096474),14504=>array(-77.231501,42.968981),14505=>array(-77.168961,43.159419),14506=>array(-77.516652,43.005513),14507=>array(-77.254886,42.684916),14510=>array(-77.869009,42.68301),14511=>array(-77.89179,42.999374),14512=>array(-77.39977,42.645241),14513=>array(-77.092116,43.086309),14514=>array(-77.81493,43.109961),14516=>array(-76.919338,43.201328),14517=>array(-77.895852,42.592426),14519=>array(-77.314631,43.233972),14521=>array(-76.805003,42.676642),14522=>array(-77.221976,43.061905),14525=>array(-78.013331,42.877514),14526=>array(-77.444396,43.151464),14527=>array(-77.066309,42.665508),14529=>array(-77.6381,42.539976),14530=>array(-77.998746,42.73991),14532=>array(-77.032088,42.964101),14533=>array(-77.888759,42.83881),14534=>array(-77.521042,43.05689),14536=>array(-78.083671,42.543975),14537=>array(-77.163201,43.035808),14539=>array(-77.874751,42.834499),14541=>array(-76.848849,42.757557),14542=>array(-76.860121,43.147329),14543=>array(-77.678319,42.98368),14544=>array(-77.243735,42.756251),14545=>array(-77.701007,42.664857),14546=>array(-77.780006,43.032675),14548=>array(-77.24387,42.976072),14549=>array(-78.017273,42.700031),14550=>array(-78.093487,42.679902),14551=>array(-77.049402,43.218114),14555=>array(-76.97574,43.260787),14559=>array(-77.819055,43.189993),14560=>array(-77.565904,42.683429),14561=>array(-77.131778,42.820432),14564=>array(-77.43436,42.986699),14568=>array(-77.281449,43.160609),14569=>array(-78.168593,42.734693),14571=>array(-78.251742,43.341652),14572=>array(-77.562598,42.564925),14580=>array(-77.444534,43.217283),14585=>array(-77.553145,42.906261),14586=>array(-77.689956,43.041661),14588=>array(-76.870803,42.680987),14589=>array(-77.174261,43.249424),14590=>array(-76.826243,43.242547),14591=>array(-78.107466,42.832057),14592=>array(-77.895893,42.872237),14604=>array(-77.604741,43.156212),14605=>array(-77.602642,43.168428),14606=>array(-77.697914,43.170996),14607=>array(-77.586436,43.150787),14608=>array(-77.623336,43.15389),14609=>array(-77.554873,43.177093),14610=>array(-77.545602,43.142643),14611=>array(-77.646987,43.148316),14612=>array(-77.676706,43.26633),14613=>array(-77.640175,43.182171),14614=>array(-77.615355,43.157442),14615=>array(-77.654726,43.201252),14616=>array(-77.657664,43.234623),14617=>array(-77.593527,43.225497),14618=>array(-77.553942,43.113525),14619=>array(-77.649477,43.136456),14620=>array(-77.605805,43.128291),14621=>array(-77.603649,43.189939),14622=>array(-77.552402,43.215741),14623=>array(-77.641867,43.087333),14624=>array(-77.731354,43.128271),14625=>array(-77.505521,43.150039),14626=>array(-77.710806,43.216527),14627=>array(-77.629144,43.128664),14701=>array(-79.25671,42.08016),14706=>array(-78.533146,42.113246),14707=>array(-78.060511,42.077338),14708=>array(-78.063617,42.019219),14709=>array(-77.982064,42.356494),14710=>array(-79.419847,42.08777),14711=>array(-78.119435,42.326725),14712=>array(-79.361923,42.183745),14714=>array(-78.233633,42.296728),14715=>array(-78.144755,42.076532),14716=>array(-79.445044,42.390637),14717=>array(-78.179701,42.361647),14718=>array(-79.287617,42.345814),14719=>array(-78.875953,42.341958),14720=>array(-79.281179,42.108592),14721=>array(-78.26652,42.013888),14722=>array(-79.468361,42.209489),14723=>array(-79.157231,42.317704),14724=>array(-79.66983,42.046328),14726=>array(-79.020279,42.253585),14727=>array(-78.297252,42.206974),14728=>array(-79.423176,42.263333),14729=>array(-78.743584,42.408377),14731=>array(-78.655503,42.307351),14732=>array(-79.116414,42.231862),14733=>array(-79.172199,42.160122),14735=>array(-78.096169,42.45269),14736=>array(-79.746108,42.140845),14737=>array(-78.428611,42.32905),14738=>array(-79.084541,42.055006),14739=>array(-78.146295,42.192604),14740=>array(-79.181435,42.223203),14741=>array(-78.611624,42.219966),14742=>array(-79.306839,42.120123),14743=>array(-78.394917,42.207941),14744=>array(-78.206654,42.4281),14747=>array(-79.094518,42.153715),14748=>array(-78.643061,42.157106),14750=>array(-79.329244,42.079766),14752=>array(-79.319857,42.351728),14753=>array(-78.664372,42.036032),14754=>array(-78.201569,42.021908),14755=>array(-78.804596,42.233756),14756=>array(-79.421274,42.198039),14757=>array(-79.504709,42.237679),14760=>array(-78.418429,42.077027),14767=>array(-79.514135,42.057352),14769=>array(-79.472317,42.367931),14770=>array(-78.300296,42.037929),14772=>array(-78.952618,42.15747),14774=>array(-78.149093,42.088367),14775=>array(-79.699933,42.228753),14777=>array(-78.273772,42.38608),14778=>array(-78.483239,42.077584),14779=>array(-78.777986,42.08123),14781=>array(-79.601288,42.161603),14782=>array(-79.263865,42.265508),14783=>array(-78.887355,42.082135),14784=>array(-79.385369,42.311143),14787=>array(-79.571405,42.311648),14788=>array(-78.380108,42.061991),14801=>array(-77.292968,42.104056),14802=>array(-77.789297,42.253375),14803=>array(-77.745296,42.273416),14804=>array(-77.847936,42.317259),14805=>array(-76.720073,42.351406),14806=>array(-77.772537,42.171541),14807=>array(-77.711334,42.420987),14808=>array(-77.46686,42.559639),14809=>array(-77.448755,42.424318),14810=>array(-77.343373,42.349744),14812=>array(-77.005249,42.300727),14813=>array(-77.995104,42.252647),14814=>array(-76.958827,42.154488),14815=>array(-77.086684,42.374323),14816=>array(-76.732083,42.197873),14817=>array(-76.334979,42.357575),14818=>array(-76.818927,42.454933),14819=>array(-77.441939,42.224194),14820=>array(-77.3599,42.19328),14821=>array(-77.219254,42.241574),14822=>array(-77.851457,42.424481),14823=>array(-77.558954,42.249138),14824=>array(-76.699531,42.259793),14825=>array(-76.618187,42.056296),14826=>array(-77.497778,42.491464),14827=>array(-77.142885,42.180651),14830=>array(-77.031973,42.128119),14836=>array(-77.878193,42.542918),14837=>array(-77.026107,42.490667),14838=>array(-76.662322,42.188143),14839=>array(-77.640967,42.119444),14840=>array(-77.194254,42.440793),14841=>array(-76.840915,42.525338),14842=>array(-76.981134,42.600505),14843=>array(-77.646339,42.320079),14845=>array(-76.834161,42.215912),14846=>array(-78.001564,42.53209),14847=>array(-76.734212,42.608582),14850=>array(-76.497024,42.432194),14853=>array(-76.477551,42.449002),14854=>array(-76.614769,42.505802),14855=>array(-77.497396,42.1457),14856=>array(-77.366506,42.376717),14858=>array(-77.135009,42.029557),14859=>array(-76.538139,42.114838),14860=>array(-76.831428,42.59192),14861=>array(-76.686236,42.088212),14864=>array(-76.840921,42.275415),14865=>array(-76.833977,42.348192),14867=>array(-76.618094,42.34315),14869=>array(-76.768968,42.360831),14870=>array(-77.127624,42.160378),14871=>array(-76.911418,42.039625),14872=>array(-76.874902,42.243653),14873=>array(-77.296985,42.522288),14874=>array(-77.17549,42.530172),14877=>array(-77.680307,42.05779),14878=>array(-76.943405,42.450262),14879=>array(-77.187158,42.321946),14880=>array(-77.969226,42.177487),14881=>array(-76.358994,42.399901),14882=>array(-76.553256,42.580097),14883=>array(-76.472102,42.243022),14884=>array(-77.893852,42.479522),14885=>array(-77.570328,42.046486),14886=>array(-76.68498,42.505751),14889=>array(-76.578897,42.234171),14891=>array(-76.946182,42.377014),14892=>array(-76.529114,42.046025),14893=>array(-77.107721,42.467714),14894=>array(-76.777092,42.019064),14895=>array(-77.940922,42.08144),14897=>array(-77.792682,42.020669),14898=>array(-77.4295,42.053364),14901=>array(-76.746938,42.087649),14903=>array(-76.871851,42.131632),14904=>array(-76.800695,42.069149),14905=>array(-76.843282,42.087725),15001=>array(-80.322877,40.595263),15003=>array(-80.216424,40.60364),15004=>array(-80.381297,40.345102),15005=>array(-80.186188,40.642533),15006=>array(-79.876889,40.63359),15007=>array(-79.931679,40.652233),15009=>array(-80.365122,40.697918),15010=>array(-80.351497,40.770882),15012=>array(-79.812961,40.155434),15014=>array(-79.740428,40.608072),15015=>array(-80.081101,40.637248),15017=>array(-80.128217,40.339614),15018=>array(-79.797067,40.265885),15019=>array(-80.328574,40.406974),15020=>array(-79.950296,40.233411),15021=>array(-80.441527,40.388565),15022=>array(-79.939333,40.124908),15024=>array(-79.847315,40.58497),15025=>array(-79.92325,40.297614),15026=>array(-80.353946,40.504991),15027=>array(-80.240199,40.66635),15028=>array(-79.78956,40.311313),15030=>array(-79.782503,40.591655),15031=>array(-80.161128,40.348228),15033=>array(-79.864709,40.179104),15034=>array(-79.890602,40.350816),15035=>array(-79.807401,40.384822),15037=>array(-79.85277,40.257714),15038=>array(-79.925568,40.250809),15042=>array(-80.204823,40.690315),15043=>array(-80.487856,40.551695),15044=>array(-79.947904,40.637986),15045=>array(-79.885985,40.325814),15046=>array(-80.227975,40.557753),15047=>array(-79.808154,40.318926),15049=>array(-79.805574,40.556113),15050=>array(-80.434517,40.563665),15051=>array(-79.866913,40.562602),15052=>array(-80.430767,40.658561),15053=>array(-80.359879,40.381001),15054=>array(-80.407683,40.362377),15055=>array(-80.123516,40.306293),15056=>array(-80.216015,40.56389),15057=>array(-80.243904,40.358656),15059=>array(-80.485549,40.677919),15060=>array(-80.292127,40.366849),15061=>array(-80.319701,40.659904),15062=>array(-79.878186,40.148786),15063=>array(-79.922476,40.191166),15064=>array(-80.149928,40.356339),15065=>array(-79.725372,40.64406),15066=>array(-80.256143,40.747074),15067=>array(-79.96248,40.207243),15068=>array(-79.726079,40.557925),15071=>array(-80.187802,40.412098),15072=>array(-79.85633,40.139245),15074=>array(-80.208354,40.734016),15075=>array(-79.826914,40.586037),15076=>array(-79.834668,40.607346),15077=>array(-80.415781,40.624986),15078=>array(-80.384977,40.355915),15081=>array(-80.236071,40.574948),15082=>array(-80.212916,40.377841),15083=>array(-79.785752,40.263984),15084=>array(-79.803264,40.62859),15085=>array(-79.72226,40.385736),15086=>array(-80.106364,40.674953),15087=>array(-79.853422,40.189522),15088=>array(-79.89618,40.272147),15089=>array(-79.748788,40.225327),15090=>array(-80.067535,40.625887),15101=>array(-79.955241,40.580328),15102=>array(-80.036546,40.321349),15104=>array(-79.862605,40.403883),15106=>array(-80.114205,40.410123),15108=>array(-80.201802,40.500472),15110=>array(-79.850162,40.373461),15112=>array(-79.837706,40.404483),15116=>array(-79.932225,40.526079),15120=>array(-79.907511,40.395872),15122=>array(-79.898389,40.362505),15126=>array(-80.284452,40.462422),15129=>array(-79.996036,40.293248),15131=>array(-79.796072,40.338789),15132=>array(-79.842782,40.339767),15133=>array(-79.864408,40.326376),15135=>array(-79.812893,40.310836),15136=>array(-80.103905,40.465188),15137=>array(-79.808765,40.375736),15139=>array(-79.83621,40.521697),15140=>array(-79.776344,40.407779),15142=>array(-80.118682,40.382059),15143=>array(-80.146809,40.568133),15144=>array(-79.777952,40.548049),15145=>array(-79.824085,40.415277),15146=>array(-79.761358,40.426328),15147=>array(-79.83077,40.497284),15148=>array(-79.79511,40.393449),15201=>array(-79.950968,40.47441),15202=>array(-80.06783,40.505165),15203=>array(-79.97563,40.426225),15204=>array(-80.06063,40.456867),15205=>array(-80.099059,40.43809),15206=>array(-79.913156,40.472272),15207=>array(-79.928872,40.403793),15208=>array(-79.899498,40.453191),15209=>array(-79.970593,40.499771),15210=>array(-79.984725,40.406634),15211=>array(-80.015528,40.43038),15212=>array(-79.990054,40.456939),15213=>array(-79.955247,40.444043),15214=>array(-80.013953,40.486557),15215=>array(-79.91322,40.503693),15216=>array(-80.034851,40.402628),15217=>array(-79.920089,40.430821),15218=>array(-79.889803,40.42361),15219=>array(-79.982794,40.442229),15220=>array(-80.04773,40.419504),15221=>array(-79.86427,40.435791),15222=>array(-79.993462,40.447679),15223=>array(-79.952226,40.505181),15224=>array(-79.944805,40.464234),15225=>array(-80.113842,40.506673),15226=>array(-80.013955,40.395075),15227=>array(-79.970572,40.375703),15228=>array(-80.044135,40.370668),15229=>array(-80.037048,40.520343),15232=>array(-79.931939,40.452517),15233=>array(-80.034917,40.460862),15234=>array(-80.017803,40.368133),15235=>array(-79.82242,40.459801),15236=>array(-79.975481,40.347406),15237=>array(-80.043513,40.549607),15238=>array(-79.879444,40.537201),15239=>array(-79.738073,40.483674),15241=>array(-80.081267,40.333539),15243=>array(-80.072372,40.375511),15260=>array(-79.953256,40.443915),15290=>array(-80.019294,40.457329),15301=>array(-80.253464,40.153494),15310=>array(-80.482197,39.792724),15311=>array(-80.183933,40.045914),15312=>array(-80.440702,40.251528),15313=>array(-80.023705,40.06796),15314=>array(-80.016809,40.146306),15315=>array(-79.982684,39.758289),15316=>array(-80.252412,39.724269),15317=>array(-80.175055,40.277948),15320=>array(-79.990265,39.876232),15321=>array(-80.187945,40.323357),15322=>array(-80.053364,39.981643),15323=>array(-80.405659,40.112251),15324=>array(-80.065715,40.100777),15325=>array(-79.963374,39.949429),15327=>array(-79.960854,39.744871),15329=>array(-80.279927,40.027715),15330=>array(-80.089973,40.179368),15331=>array(-80.022571,40.10535),15332=>array(-79.993501,40.240185),15333=>array(-80.01321,40.030787),15334=>array(-79.967895,39.808312),15337=>array(-80.378188,39.952162),15338=>array(-79.991515,39.784864),15340=>array(-80.317491,40.283226),15341=>array(-80.343863,39.8242),15342=>array(-80.221186,40.244231),15344=>array(-80.061424,39.915747),15345=>array(-80.105047,40.022623),15346=>array(-80.075344,39.935438),15347=>array(-80.221104,40.220317),15348=>array(-79.995437,39.986895),15349=>array(-80.093949,39.762442),15350=>array(-80.200808,40.293306),15351=>array(-79.924327,39.884463),15352=>array(-80.382774,39.752215),15353=>array(-80.310954,39.962124),15357=>array(-79.980409,39.941608),15358=>array(-80.003007,40.055388),15359=>array(-80.275766,39.876488),15360=>array(-80.082379,40.084912),15361=>array(-80.258411,40.329012),15362=>array(-80.213926,39.772465),15363=>array(-80.19805,40.251799),15364=>array(-80.304781,39.946322),15366=>array(-79.973027,40.159548),15367=>array(-80.058058,40.265968),15368=>array(-79.989284,40.013872),15370=>array(-80.171197,39.880615),15376=>array(-80.478959,40.1089),15377=>array(-80.449057,39.988469),15378=>array(-80.275081,40.278384),15379=>array(-80.425176,40.243194),15380=>array(-80.467119,39.867562),15401=>array(-79.745662,39.899926),15410=>array(-79.902122,39.911612),15411=>array(-79.346892,39.74858),15412=>array(-79.859227,40.088771),15413=>array(-79.871134,39.985307),15417=>array(-79.918268,40.008601),15419=>array(-79.894985,40.046955),15420=>array(-79.865229,39.960141),15421=>array(-79.597198,39.845848),15422=>array(-79.811587,39.981184),15423=>array(-79.932521,40.089905),15424=>array(-79.35935,39.819528),15425=>array(-79.54791,40.029511),15427=>array(-79.974807,40.069947),15428=>array(-79.682026,40.084267),15429=>array(-79.9381,40.003649),15430=>array(-79.654282,40.03935),15431=>array(-79.596338,39.949851),15432=>array(-79.860274,40.114094),15433=>array(-79.948732,39.982683),15434=>array(-79.887389,40.081867),15435=>array(-79.85027,39.943714),15436=>array(-79.724778,39.817812),15437=>array(-79.612135,39.780204),15438=>array(-79.85777,40.073207),15440=>array(-79.616939,39.735268),15442=>array(-79.839819,40.020301),15443=>array(-79.880747,39.919668),15444=>array(-79.908804,40.011976),15445=>array(-79.667827,39.876092),15446=>array(-79.402992,40.030982),15447=>array(-79.936893,39.943822),15448=>array(-79.732512,40.135979),15449=>array(-79.783355,39.964329),15450=>array(-79.974194,40.001137),15451=>array(-79.836057,39.737132),15454=>array(-79.871733,39.863151),15455=>array(-79.642276,40.0033),15456=>array(-79.652007,39.926407),15458=>array(-79.851171,39.890125),15459=>array(-79.466755,39.767136),15460=>array(-79.907168,39.807966),15461=>array(-79.900068,39.842683),15462=>array(-79.378703,40.064295),15463=>array(-79.899834,39.965563),15464=>array(-79.436202,39.930138),15466=>array(-79.890057,40.075047),15467=>array(-79.925752,39.784842),15468=>array(-79.832679,39.950182),15469=>array(-79.418394,40.009819),15470=>array(-79.532018,39.867154),15472=>array(-79.716851,39.919373),15473=>array(-79.790742,40.043825),15474=>array(-79.891941,39.752149),15475=>array(-79.877545,39.951649),15476=>array(-79.920611,39.86973),15477=>array(-79.863966,40.078203),15478=>array(-79.804657,39.787462),15479=>array(-79.707539,40.151237),15480=>array(-79.773861,39.985198),15482=>array(-79.766067,40.061488),15483=>array(-79.850922,40.08302),15484=>array(-79.783677,39.892689),15486=>array(-79.711164,40.025886),15489=>array(-79.696055,39.966381),15490=>array(-79.454496,40.072382),15492=>array(-79.764298,40.118305),15501=>array(-79.12982,40.039742),15502=>array(-79.241687,40.041717),15510=>array(-79.039908,39.967492),15520=>array(-79.060539,40.106367),15521=>array(-78.638662,40.207596),15522=>array(-78.548385,39.941725),15530=>array(-78.924027,39.940809),15531=>array(-79.082097,40.183936),15532=>array(-79.060801,39.762035),15533=>array(-78.224303,39.992892),15534=>array(-78.69128,39.899323),15535=>array(-78.443779,39.821115),15536=>array(-78.203555,39.954555),15537=>array(-78.366843,40.000385),15538=>array(-78.834458,39.863715),15539=>array(-78.59138,40.128409),15540=>array(-79.239272,39.797439),15541=>array(-78.971391,40.043876),15542=>array(-79.071544,39.875694),15544=>array(-79.093436,40.135638),15545=>array(-78.75251,39.802265),15546=>array(-79.047988,40.136624),15547=>array(-79.071708,40.162146),15550=>array(-78.649618,39.978253),15551=>array(-79.283167,39.868549),15552=>array(-78.99101,39.79277),15554=>array(-78.621785,40.122918),15555=>array(-79.082247,40.092408),15557=>array(-79.218371,39.927663),15558=>array(-79.110357,39.74842),15559=>array(-78.691065,40.060248),15560=>array(-78.907139,40.016558),15561=>array(-79.087672,40.095599),15562=>array(-79.134556,39.739533),15563=>array(-78.92892,40.097575),15564=>array(-78.837774,39.729993),15601=>array(-79.535741,40.315028),15610=>array(-79.417201,40.146956),15611=>array(-79.65264,40.306516),15612=>array(-79.599717,40.137347),15613=>array(-79.569029,40.553591),15615=>array(-79.734156,40.365308),15616=>array(-79.553298,40.222755),15617=>array(-79.655373,40.268182),15618=>array(-79.439869,40.571026),15620=>array(-79.338689,40.323545),15621=>array(-79.483456,40.213857),15622=>array(-79.329115,40.049534),15623=>array(-79.620342,40.367199),15624=>array(-79.4702,40.36486),15625=>array(-79.679749,40.269506),15626=>array(-79.576158,40.406993),15627=>array(-79.300048,40.351006),15628=>array(-79.373415,40.100489),15629=>array(-79.562908,40.597437),15631=>array(-79.585356,40.087482),15632=>array(-79.600116,40.439145),15633=>array(-79.523907,40.357319),15634=>array(-79.604923,40.323945),15635=>array(-79.501557,40.347904),15636=>array(-79.657084,40.36547),15637=>array(-79.711818,40.264955),15638=>array(-79.398961,40.264322),15639=>array(-79.593806,40.203514),15640=>array(-79.729265,40.224626),15641=>array(-79.589207,40.631589),15642=>array(-79.723736,40.318382),15644=>array(-79.611245,40.347383),15646=>array(-79.326493,40.082173),15647=>array(-79.729198,40.342501),15650=>array(-79.392907,40.277177),15655=>array(-79.160179,40.190161),15656=>array(-79.629005,40.656904),15658=>array(-79.226466,40.248486),15660=>array(-79.77439,40.244601),15661=>array(-79.360131,40.322166),15662=>array(-79.478335,40.334318),15663=>array(-79.679271,40.251846),15665=>array(-79.660846,40.339497),15666=>array(-79.509814,40.161024),15668=>array(-79.670009,40.460564),15670=>array(-79.436918,40.4056),15671=>array(-79.3218,40.356289),15672=>array(-79.621588,40.243792),15673=>array(-79.556616,40.593808),15675=>array(-79.637074,40.335305),15676=>array(-79.465715,40.240835),15677=>array(-79.23731,40.143126),15678=>array(-79.726231,40.287221),15679=>array(-79.653825,40.175948),15680=>array(-79.499279,40.520777),15681=>array(-79.439346,40.500308),15683=>array(-79.608307,40.107213),15684=>array(-79.520663,40.460696),15686=>array(-79.431311,40.623446),15687=>array(-79.316448,40.136223),15688=>array(-79.584793,40.168606),15689=>array(-79.49144,40.221425),15690=>array(-79.549422,40.64135),15691=>array(-79.686141,40.295377),15692=>array(-79.678914,40.331755),15693=>array(-79.407701,40.253148),15695=>array(-79.693244,40.197278),15696=>array(-79.366167,40.280112),15697=>array(-79.579932,40.241129),15698=>array(-79.688567,40.214346),15701=>array(-79.150041,40.628381),15710=>array(-78.871669,40.642728),15711=>array(-78.95562,41.018425),15712=>array(-78.847887,40.790456),15713=>array(-79.26168,40.569757),15714=>array(-78.825059,40.651306),15715=>array(-78.87743,40.970724),15716=>array(-79.186897,40.465148),15717=>array(-79.243322,40.457271),15721=>array(-78.792568,40.816322),15722=>array(-78.723896,40.595253),15723=>array(-79.158676,40.698747),15724=>array(-78.813634,40.735096),15725=>array(-79.348779,40.518948),15727=>array(-79.309754,40.558009),15728=>array(-78.97178,40.675665),15729=>array(-78.915125,40.706445),15730=>array(-79.094938,41.057594),15731=>array(-79.17641,40.503767),15732=>array(-79.211872,40.727686),15733=>array(-78.959295,40.988862),15734=>array(-79.001265,40.724797),15736=>array(-79.366445,40.70125),15737=>array(-78.759013,40.601258),15738=>array(-78.785122,40.691553),15739=>array(-79.168735,40.674249),15741=>array(-78.891033,40.802488),15742=>array(-78.864006,40.816978),15744=>array(-79.084009,40.922559),15745=>array(-78.915191,40.623001),15746=>array(-78.889294,40.758509),15747=>array(-79.145875,40.775788),15748=>array(-79.08415,40.523638),15750=>array(-79.180918,40.48478),15752=>array(-79.283249,40.540593),15753=>array(-78.653877,40.795648),15754=>array(-79.151524,40.556656),15756=>array(-79.296945,40.565527),15757=>array(-78.739058,40.891237),15759=>array(-79.031699,40.773017),15760=>array(-78.800199,40.648324),15761=>array(-78.889807,40.632245),15762=>array(-78.829301,40.594306),15764=>array(-79.02871,40.992622),15765=>array(-78.991085,40.597935),15767=>array(-78.968171,40.962153),15770=>array(-79.136717,41.008788),15771=>array(-78.989145,40.831556),15772=>array(-78.898714,40.870214),15773=>array(-78.735444,40.626766),15774=>array(-79.323835,40.65469),15775=>array(-78.788141,40.632482),15776=>array(-79.111592,41.010988),15777=>array(-78.965439,40.69376),15778=>array(-79.195246,40.969117),15779=>array(-79.219703,40.385675),15780=>array(-79.070466,40.912437),15781=>array(-78.986853,40.963797),15783=>array(-79.349659,40.60731),15784=>array(-79.141266,41.024426),15801=>array(-78.722433,41.125057),15821=>array(-78.368514,41.350958),15823=>array(-78.710427,41.258613),15824=>array(-78.841186,41.250833),15825=>array(-79.034401,41.174947),15827=>array(-78.521654,41.319159),15828=>array(-79.115706,41.384837),15829=>array(-79.202144,41.169298),15832=>array(-78.187384,41.349495),15834=>array(-78.322815,41.500749),15840=>array(-78.822649,41.171972),15841=>array(-78.529883,41.262939),15845=>array(-78.689455,41.494238),15846=>array(-78.572392,41.319687),15847=>array(-79.032482,41.090187),15848=>array(-78.730381,41.028097),15849=>array(-78.582254,41.164492),15851=>array(-78.910417,41.102906),15853=>array(-78.791631,41.392343),15856=>array(-78.613385,41.082255),15857=>array(-78.519875,41.455283),15860=>array(-79.018668,41.333594),15861=>array(-78.069054,41.30853),15863=>array(-78.839736,41.014385),15864=>array(-79.197538,41.10358),15865=>array(-78.828292,41.044954),15866=>array(-78.791035,41.023892),15868=>array(-78.327211,41.301774),15870=>array(-78.567901,41.594121),15901=>array(-78.914292,40.328742),15902=>array(-78.879287,40.323205),15904=>array(-78.840989,40.311595),15905=>array(-78.969902,40.290673),15906=>array(-78.955677,40.379677),15909=>array(-78.869741,40.409742),15920=>array(-79.047534,40.4745),15921=>array(-78.70086,40.317338),15922=>array(-78.876676,40.517598),15923=>array(-79.158504,40.35522),15924=>array(-78.762858,40.103423),15925=>array(-78.640702,40.408519),15926=>array(-78.823632,40.053269),15927=>array(-78.778646,40.539999),15928=>array(-78.918459,40.239529),15929=>array(-79.008637,40.468246),15930=>array(-78.71902,40.294969),15931=>array(-78.758964,40.506489),15934=>array(-78.803986,40.279061),15935=>array(-78.965027,40.208131),15936=>array(-78.892595,40.16091),15937=>array(-78.984732,40.205329),15938=>array(-78.611126,40.418854),15940=>array(-78.625208,40.517034),15942=>array(-78.811023,40.398324),15943=>array(-78.839052,40.474268),15944=>array(-79.079159,40.363888),15945=>array(-78.867092,40.358484),15946=>array(-78.637116,40.370295),15948=>array(-78.76464,40.489957),15949=>array(-79.120654,40.396682),15951=>array(-78.7707,40.333148),15952=>array(-78.776141,40.303506),15953=>array(-78.885159,40.208513),15954=>array(-78.998119,40.424054),15955=>array(-78.697386,40.322865),15956=>array(-78.795942,40.350555),15957=>array(-78.902282,40.557624),15958=>array(-78.730422,40.387524),15960=>array(-78.884169,40.497161),15961=>array(-78.941795,40.471096),15962=>array(-78.715039,40.38818),15963=>array(-78.759251,40.227773),16001=>array(-79.945191,40.910025),16002=>array(-79.855361,40.815135),16020=>array(-79.898582,41.115334),16022=>array(-79.733691,41.05414),16023=>array(-79.750313,40.785483),16024=>array(-80.038538,40.742716),16025=>array(-79.75338,40.942432),16027=>array(-80.019183,40.820154),16028=>array(-79.635554,40.951317),16029=>array(-79.846169,40.879153),16030=>array(-79.796967,41.136395),16033=>array(-80.051087,40.783878),16034=>array(-79.733208,40.861209),16035=>array(-80.014526,41.108993),16036=>array(-79.666595,41.134894),16037=>array(-80.133751,40.842611),16038=>array(-79.953343,41.164483),16040=>array(-79.8402,41.094245),16041=>array(-79.714928,41.005338),16045=>array(-79.916718,40.852774),16046=>array(-80.023915,40.702755),16048=>array(-79.818427,41.053202),16049=>array(-79.671823,41.094067),16050=>array(-79.761561,41.043999),16051=>array(-80.138143,40.944894),16052=>array(-80.061572,40.899377),16053=>array(-79.983142,40.811869),16054=>array(-79.663009,41.153536),16055=>array(-79.747709,40.717488),16056=>array(-79.841706,40.724934),16057=>array(-80.0603,41.034074),16059=>array(-79.927088,40.707082),16061=>array(-79.88474,41.005109),16063=>array(-80.1229,40.762315),16066=>array(-80.105642,40.709967),16101=>array(-80.290037,40.983989),16102=>array(-80.424431,40.960367),16105=>array(-80.340317,41.057381),16110=>array(-80.380762,41.505249),16111=>array(-80.282617,41.520379),16112=>array(-80.498397,40.960467),16113=>array(-80.424148,41.280826),16114=>array(-80.183931,41.402848),16115=>array(-80.460695,40.796605),16116=>array(-80.449625,41.044162),16117=>array(-80.256197,40.871839),16120=>array(-80.478966,40.885089),16121=>array(-80.497194,41.211214),16123=>array(-80.196513,40.821932),16124=>array(-80.276062,41.33617),16125=>array(-80.372825,41.406356),16127=>array(-80.072998,41.173009),16130=>array(-80.222949,41.444632),16131=>array(-80.37823,41.550522),16132=>array(-80.500832,41.004767),16133=>array(-80.114451,41.267791),16134=>array(-80.478857,41.524926),16136=>array(-80.323707,40.834939),16137=>array(-80.238644,41.231618),16140=>array(-80.51403,41.095323),16141=>array(-80.398468,40.868089),16142=>array(-80.333181,41.145414),16143=>array(-80.452682,41.105824),16145=>array(-80.078627,41.380196),16146=>array(-80.499672,41.234113),16148=>array(-80.417588,41.228484),16150=>array(-80.45325,41.285145),16151=>array(-80.206786,41.4439),16153=>array(-80.086586,41.32224),16154=>array(-80.420117,41.325901),16155=>array(-80.510731,41.067732),16156=>array(-80.216432,41.088767),16157=>array(-80.333383,40.888212),16159=>array(-80.475263,41.153413),16160=>array(-80.356894,40.930558),16161=>array(-80.495844,41.19709),16201=>array(-79.469413,40.805185),16210=>array(-79.510523,40.895902),16211=>array(-79.202555,40.794443),16212=>array(-79.583624,40.755157),16213=>array(-79.557671,41.125669),16214=>array(-79.357224,41.202672),16217=>array(-79.17368,41.331192),16218=>array(-79.590649,40.933435),16222=>array(-79.257028,40.873676),16223=>array(-79.363954,40.975988),16224=>array(-79.29486,41.06508),16226=>array(-79.486425,40.711646),16228=>array(-79.535765,40.760813),16229=>array(-79.642747,40.717124),16230=>array(-79.283324,41.020475),16232=>array(-79.551242,41.213586),16233=>array(-79.271067,41.36124),16235=>array(-79.352329,41.322665),16236=>array(-79.522661,40.787838),16238=>array(-79.520848,40.787837),16239=>array(-79.137779,41.496972),16240=>array(-79.225,41.036013),16242=>array(-79.365745,41.009881),16244=>array(-79.276658,40.792176),16245=>array(-79.298366,41.00672),16246=>array(-79.182154,40.79172),16248=>array(-79.502977,41.034002),16249=>array(-79.312139,40.761947),16250=>array(-79.232968,40.768512),16253=>array(-79.342756,40.951168),16254=>array(-79.461458,41.253345),16255=>array(-79.466757,41.128813),16256=>array(-79.134458,40.855267),16258=>array(-79.278339,41.236936),16259=>array(-79.451859,40.925711),16260=>array(-79.230763,41.396463),16262=>array(-79.652206,40.839032),16263=>array(-79.336609,40.801717),16301=>array(-79.623854,41.454216),16311=>array(-80.042383,41.462166),16312=>array(-79.303214,41.932135),16313=>array(-79.122409,41.733693),16314=>array(-80.077072,41.520676),16316=>array(-80.303633,41.601773),16317=>array(-79.853702,41.532556),16319=>array(-79.623458,41.324204),16321=>array(-79.399591,41.57106),16322=>array(-79.373564,41.598847),16323=>array(-79.828317,41.41192),16326=>array(-79.43174,41.376158),16327=>array(-79.959566,41.637082),16328=>array(-79.72554,41.653227),16329=>array(-79.258874,41.798643),16331=>array(-79.558676,41.293731),16332=>array(-79.369545,41.356717),16333=>array(-78.91677,41.697329),16334=>array(-79.449351,41.290554),16335=>array(-80.155868,41.631017),16340=>array(-79.417669,41.802378),16341=>array(-79.549355,41.56608),16342=>array(-79.941497,41.321887),16343=>array(-79.752655,41.42603),16344=>array(-79.684546,41.470393),16345=>array(-79.082916,41.944404),16346=>array(-79.67197,41.378502),16347=>array(-79.069365,41.659517),16350=>array(-79.334446,41.956937),16351=>array(-79.370344,41.675353),16352=>array(-79.038364,41.767268),16353=>array(-79.373001,41.49572),16354=>array(-79.706464,41.613725),16360=>array(-79.890935,41.684105),16361=>array(-79.345873,41.383889),16362=>array(-79.965179,41.450497),16364=>array(-79.527344,41.351411),16365=>array(-79.157385,41.840224),16370=>array(-79.460024,41.574811),16371=>array(-79.326122,41.869947),16372=>array(-79.872877,41.200166),16373=>array(-79.698409,41.208469),16374=>array(-79.815085,41.263498),16401=>array(-80.40516,41.878476),16402=>array(-79.469799,41.961028),16403=>array(-80.014121,41.792998),16404=>array(-79.789388,41.727006),16405=>array(-79.535939,41.946543),16406=>array(-80.36214,41.749512),16407=>array(-79.664251,41.922164),16410=>array(-80.308509,41.922751),16411=>array(-80.447072,41.977956),16412=>array(-80.170371,41.88493),16415=>array(-80.23032,42.03752),16416=>array(-79.472696,41.825729),16417=>array(-80.313819,41.971411),16420=>array(-79.547259,41.6963),16421=>array(-79.931855,42.171262),16422=>array(-80.310175,41.667558),16423=>array(-80.339572,42.020652),16424=>array(-80.438957,41.661408),16426=>array(-80.14208,41.979331),16427=>array(-79.967907,41.877373),16428=>array(-79.831488,42.171464),16433=>array(-80.142804,41.735686),16434=>array(-79.668625,41.796904),16435=>array(-80.385386,41.817035),16436=>array(-79.510451,41.83892),16438=>array(-79.845314,41.892299),16440=>array(-80.126018,41.782549),16441=>array(-79.983551,41.95849),16442=>array(-79.825705,42.038485),16443=>array(-80.484235,41.939645),16444=>array(-80.120436,41.871286),16501=>array(-80.088919,42.121293),16502=>array(-80.101358,42.110702),16503=>array(-80.061565,42.126936),16504=>array(-80.049031,42.109074),16505=>array(-80.138303,42.131338),16506=>array(-80.151707,42.062345),16507=>array(-80.084294,42.136958),16508=>array(-80.09403,42.096812),16509=>array(-80.038075,42.060034),16510=>array(-79.954574,42.108738),16511=>array(-79.99017,42.166262),16546=>array(-80.053445,42.104924),16563=>array(-79.986486,42.117333),16601=>array(-78.370416,40.555264),16602=>array(-78.373901,40.512604),16611=>array(-78.115671,40.579959),16613=>array(-78.537565,40.548031),16616=>array(-78.440079,40.767547),16617=>array(-78.322365,40.60747),16619=>array(-78.445778,40.659513),16620=>array(-78.351837,40.840687),16621=>array(-78.125214,40.232247),16622=>array(-78.066403,40.32864),16623=>array(-78.052188,40.271681),16624=>array(-78.600475,40.570425),16625=>array(-78.50498,40.274926),16627=>array(-78.497822,40.757881),16630=>array(-78.576441,40.456176),16631=>array(-78.345602,40.272766),16633=>array(-78.234926,40.157386),16634=>array(-78.173077,40.210954),16635=>array(-78.499413,40.410853),16636=>array(-78.501203,40.600318),16637=>array(-78.467242,40.341102),16638=>array(-78.203622,40.336605),16639=>array(-78.448137,40.695498),16640=>array(-78.576281,40.707479),16641=>array(-78.484985,40.489794),16645=>array(-78.498965,40.799362),16646=>array(-78.727262,40.689332),16647=>array(-78.103813,40.400575),16648=>array(-78.331,40.434448),16650=>array(-78.288103,40.120958),16651=>array(-78.38098,40.851288),16652=>array(-77.950096,40.516022),16655=>array(-78.503123,40.227556),16656=>array(-78.556084,40.807205),16657=>array(-78.180282,40.324864),16659=>array(-78.38973,40.161554),16661=>array(-78.460928,40.831088),16662=>array(-78.29545,40.312725),16664=>array(-78.423648,40.180753),16665=>array(-78.434236,40.388705),16666=>array(-78.32731,40.8858),16667=>array(-78.531657,40.178297),16668=>array(-78.619468,40.655088),16669=>array(-77.906687,40.655953),16670=>array(-78.507952,40.262378),16671=>array(-78.398242,40.787552),16672=>array(-78.241163,40.172252),16673=>array(-78.391483,40.312437),16674=>array(-78.088273,40.189417),16677=>array(-78.243597,40.811839),16678=>array(-78.238232,40.222577),16679=>array(-78.194649,40.15537),16680=>array(-78.377591,40.743203),16682=>array(-78.457822,40.266061),16683=>array(-78.084079,40.64873),16685=>array(-78.082637,40.287492),16686=>array(-78.251286,40.668341),16689=>array(-78.12899,40.129985),16691=>array(-78.145934,40.077493),16692=>array(-78.710802,40.750827),16693=>array(-78.211876,40.475774),16694=>array(-78.148799,40.155301),16695=>array(-78.336765,40.203025),16699=>array(-78.560505,40.447211),16701=>array(-78.750614,41.918457),16720=>array(-78.017545,41.603964),16724=>array(-78.369239,41.731993),16725=>array(-78.655324,41.908177),16726=>array(-78.572463,41.81459),16727=>array(-78.53004,41.981005),16728=>array(-78.924183,41.565765),16729=>array(-78.477022,41.96255),16730=>array(-78.422813,41.817813),16731=>array(-78.360377,41.95138),16732=>array(-78.617264,41.857255),16733=>array(-78.582749,41.69551),16734=>array(-78.840217,41.617607),16735=>array(-78.813409,41.636098),16738=>array(-78.719738,41.809793),16740=>array(-78.681499,41.740956),16743=>array(-78.232975,41.767638),16744=>array(-78.567081,41.867085),16745=>array(-78.480505,41.922273),16746=>array(-78.122491,41.793875),16748=>array(-78.144487,41.947228),16749=>array(-78.443291,41.77955),16750=>array(-78.291593,41.888978),16801=>array(-77.841359,40.77893),16802=>array(-77.860639,40.802605),16803=>array(-77.899616,40.80168),16820=>array(-77.392432,40.895701),16821=>array(-78.2009,40.964394),16822=>array(-77.69703,41.1483),16823=>array(-77.772647,40.939052),16825=>array(-78.316466,40.98677),16826=>array(-77.58041,41.053921),16827=>array(-77.767837,40.767497),16828=>array(-77.680555,40.81211),16829=>array(-77.893573,41.08164),16830=>array(-78.428601,41.078863),16832=>array(-77.478044,40.840309),16833=>array(-78.576575,40.944306),16834=>array(-78.087077,41.051824),16835=>array(-77.877404,40.90743),16836=>array(-78.27354,41.159719),16837=>array(-78.474451,40.94544),16838=>array(-78.636587,40.991458),16839=>array(-78.110537,41.003854),16840=>array(-78.203082,40.924257),16841=>array(-77.698187,41.044614),16843=>array(-78.465645,41.002756),16844=>array(-77.932075,40.909068),16845=>array(-78.01843,41.121953),16847=>array(-78.165435,40.999329),16848=>array(-77.535879,41.010623),16849=>array(-78.114665,40.961737),16851=>array(-77.787183,40.821867),16852=>array(-77.518663,40.937031),16853=>array(-77.787059,40.939209),16854=>array(-77.4731,40.898021),16855=>array(-78.375664,40.996457),16858=>array(-78.202871,40.99849),16859=>array(-78.023238,41.040743),16860=>array(-78.179793,40.937935),16861=>array(-78.520556,40.859321),16863=>array(-78.474641,40.90785),16865=>array(-77.995913,40.712045),16866=>array(-78.181338,40.829329),16868=>array(-77.880499,40.731973),16870=>array(-78.063337,40.801698),16871=>array(-78.025727,41.186615),16872=>array(-77.358425,40.967475),16874=>array(-77.976008,40.984823),16875=>array(-77.587318,40.840788),16876=>array(-78.287646,40.965638),16877=>array(-78.060782,40.738693),16878=>array(-78.323571,40.948941),16879=>array(-78.150238,40.969884),16881=>array(-78.320258,41.026792),16882=>array(-77.323471,40.912451),16901=>array(-77.337283,41.721291),16911=>array(-77.127371,41.65604),16912=>array(-77.043261,41.678438),16914=>array(-76.783666,41.854216),16915=>array(-77.971204,41.775304),16917=>array(-77.056756,41.721702),16920=>array(-77.280838,41.973608),16921=>array(-77.556256,41.724126),16922=>array(-77.702302,41.666212),16923=>array(-77.870544,41.950572),16925=>array(-76.783646,41.948502),16926=>array(-76.701713,41.727085),16927=>array(-77.658709,41.958712),16928=>array(-77.434495,41.95334),16929=>array(-77.133505,41.96101),16930=>array(-77.138826,41.583782),16932=>array(-76.939295,41.77862),16933=>array(-77.062502,41.819424),16935=>array(-77.304722,41.877494),16936=>array(-76.967113,41.951125),16937=>array(-77.710941,41.967896),16938=>array(-77.36773,41.581131),16939=>array(-77.028939,41.662022),16940=>array(-77.23825,41.985396),16941=>array(-77.758044,41.988299),16942=>array(-77.352245,41.962524),16943=>array(-77.612813,41.830161),16946=>array(-77.137752,41.908746),16947=>array(-76.804051,41.759502),16948=>array(-77.759215,41.854715),16950=>array(-77.531951,41.899908),17002=>array(-77.848424,40.50247),17003=>array(-76.569599,40.362358),17004=>array(-77.72953,40.601458),17005=>array(-76.8097,40.602849),17006=>array(-77.546042,40.286783),17007=>array(-77.118771,40.125794),17009=>array(-77.565287,40.636112),17010=>array(-76.582841,40.277992),17011=>array(-76.928846,40.23483),17013=>array(-77.197284,40.242686),17015=>array(-77.229536,40.177826),17016=>array(-76.402287,40.277475),17017=>array(-76.882189,40.637788),17018=>array(-76.826124,40.422061),17019=>array(-77.022059,40.094023),17020=>array(-77.041503,40.414171),17021=>array(-77.668192,40.330526),17022=>array(-76.60892,40.167052),17023=>array(-76.816261,40.584266),17024=>array(-77.306813,40.406931),17025=>array(-76.974481,40.294093),17026=>array(-76.431397,40.458441),17027=>array(-76.995529,40.155886),17028=>array(-76.659197,40.39646),17029=>array(-77.616997,40.558017),17030=>array(-76.725609,40.609235),17032=>array(-76.832842,40.489927),17033=>array(-76.637562,40.271823),17034=>array(-76.785532,40.20861),17035=>array(-77.581315,40.403786),17036=>array(-76.713129,40.268941),17037=>array(-77.42167,40.434053),17038=>array(-76.555856,40.46788),17039=>array(-76.240707,40.292709),17040=>array(-77.304095,40.322798),17041=>array(-76.539605,40.216634),17042=>array(-76.424823,40.294817),17043=>array(-76.900145,40.247578),17044=>array(-77.594258,40.577237),17045=>array(-77.000928,40.597093),17046=>array(-76.429627,40.381858),17047=>array(-77.428302,40.376547),17048=>array(-76.761348,40.576792),17049=>array(-77.256087,40.653038),17050=>array(-77.026578,40.247992),17051=>array(-77.775772,40.459518),17052=>array(-77.986345,40.276913),17053=>array(-77.026474,40.32504),17055=>array(-77.004599,40.182917),17056=>array(-77.35426,40.537288),17057=>array(-76.724573,40.193562),17058=>array(-77.552442,40.505427),17059=>array(-77.391092,40.589702),17060=>array(-77.893956,40.469261),17061=>array(-76.909363,40.566373),17062=>array(-77.187476,40.546912),17063=>array(-77.484947,40.761026),17064=>array(-76.476111,40.242231),17065=>array(-77.189025,40.110206),17066=>array(-77.869187,40.352823),17067=>array(-76.315043,40.39037),17068=>array(-77.178369,40.410416),17069=>array(-76.970039,40.453987),17070=>array(-76.865678,40.202401),17071=>array(-77.601934,40.298415),17072=>array(-77.081728,40.233731),17073=>array(-76.255161,40.302838),17074=>array(-77.148585,40.478901),17075=>array(-77.834155,40.394279),17076=>array(-77.311762,40.616186),17077=>array(-76.535937,40.403009),17078=>array(-76.58108,40.287452),17080=>array(-76.8031,40.640678),17081=>array(-77.283453,40.20102),17082=>array(-77.435532,40.499479),17083=>array(-76.437595,40.277602),17084=>array(-77.626648,40.675513),17086=>array(-77.122007,40.690624),17087=>array(-76.280818,40.435744),17088=>array(-76.294224,40.300678),17090=>array(-77.181043,40.318207),17093=>array(-76.930571,40.307209),17094=>array(-77.19828,40.581169),17097=>array(-76.677428,40.580098),17098=>array(-76.632327,40.588957),17099=>array(-77.576438,40.632242),17101=>array(-76.894376,40.258655),17102=>array(-76.905279,40.27037),17103=>array(-76.866332,40.275965),17104=>array(-76.862114,40.25492),17109=>array(-76.824317,40.289955),17110=>array(-76.886436,40.315813),17111=>array(-76.787143,40.267715),17112=>array(-76.776511,40.373101),17113=>array(-76.827994,40.225984),17120=>array(-76.882805,40.265186),17201=>array(-77.656165,39.961056),17202=>array(-77.609075,39.875125),17210=>array(-77.658449,40.206345),17211=>array(-78.400966,39.754149),17212=>array(-78.065972,39.811597),17213=>array(-77.771225,40.244192),17214=>array(-77.47132,39.748111),17215=>array(-77.892945,40.078237),17217=>array(-77.721567,40.238625),17219=>array(-77.687584,40.241188),17220=>array(-77.738724,40.191054),17221=>array(-77.816484,40.068125),17222=>array(-77.49398,39.896382),17223=>array(-77.942752,40.0865),17224=>array(-77.897478,39.967941),17225=>array(-77.762866,39.78356),17228=>array(-78.093362,39.9871),17229=>array(-78.010139,40.084004),17233=>array(-77.98716,39.975605),17235=>array(-77.698053,39.857193),17236=>array(-77.946919,39.797518),17237=>array(-77.541756,39.838637),17238=>array(-78.13094,39.85811),17239=>array(-77.836771,40.131795),17240=>array(-77.579686,40.150871),17241=>array(-77.408448,40.176528),17243=>array(-77.819941,40.277527),17244=>array(-77.658616,40.086764),17246=>array(-77.660811,40.054394),17247=>array(-77.579352,39.798776),17249=>array(-77.899459,40.241379),17250=>array(-77.524295,39.737141),17251=>array(-77.685552,40.131802),17252=>array(-77.822252,39.913018),17253=>array(-78.006905,40.213308),17254=>array(-77.590358,39.970229),17255=>array(-77.862516,40.16124),17256=>array(-77.677308,39.782914),17257=>array(-77.493064,40.046821),17260=>array(-77.893701,40.296045),17261=>array(-77.508159,39.860912),17262=>array(-77.740213,40.144998),17263=>array(-77.717855,39.727222),17264=>array(-77.993741,40.179925),17265=>array(-77.781355,40.027318),17266=>array(-77.412929,40.0886),17267=>array(-78.239657,39.807955),17268=>array(-77.575618,39.774872),17270=>array(-77.797808,39.85473),17271=>array(-77.803092,40.097754),17272=>array(-77.621818,39.769525),17301=>array(-76.978971,39.89524),17302=>array(-76.413678,39.81729),17304=>array(-77.232739,39.977245),17306=>array(-77.249398,39.980581),17307=>array(-77.326817,39.947765),17309=>array(-76.450129,39.871334),17311=>array(-76.842472,39.816546),17313=>array(-76.659451,39.883976),17314=>array(-76.326301,39.755506),17315=>array(-76.864066,40.026601),17316=>array(-77.007961,39.965465),17317=>array(-76.523182,39.970713),17318=>array(-76.723016,40.022258),17319=>array(-76.79394,40.160522),17320=>array(-77.387563,39.768626),17321=>array(-76.442912,39.751261),17322=>array(-76.532733,39.855909),17324=>array(-77.234957,40.031811),17325=>array(-77.227635,39.826254),17327=>array(-76.753258,39.779507),17329=>array(-76.851125,39.761844),17331=>array(-76.977984,39.78969),17339=>array(-76.885292,40.134731),17340=>array(-77.116784,39.755229),17343=>array(-77.334798,39.869254),17344=>array(-77.019219,39.805688),17345=>array(-76.747503,40.078089),17347=>array(-76.688196,40.057701),17349=>array(-76.647408,39.744992),17350=>array(-77.079399,39.890088),17352=>array(-76.499847,39.761201),17353=>array(-77.371845,39.88318),17355=>array(-76.696019,39.759868),17356=>array(-76.582259,39.896585),17360=>array(-76.75039,39.854372),17361=>array(-76.677039,39.765522),17362=>array(-76.868704,39.847679),17363=>array(-76.586385,39.768623),17364=>array(-76.899328,39.929394),17365=>array(-76.937975,40.056062),17366=>array(-76.556703,39.93279),17368=>array(-76.518703,39.983858),17370=>array(-76.778402,40.12144),17371=>array(-76.787965,39.902712),17372=>array(-77.106153,40.001467),17401=>array(-76.733457,39.959462),17402=>array(-76.658667,39.958485),17403=>array(-76.712794,39.923228),17404=>array(-76.773549,40.002607),17406=>array(-76.640469,40.014651),17407=>array(-76.712102,39.883773),17408=>array(-76.7996,39.929011),17501=>array(-76.203959,40.156599),17502=>array(-76.660147,40.100904),17505=>array(-76.192436,40.063501),17507=>array(-76.016233,40.198042),17508=>array(-76.218766,40.124758),17509=>array(-76.036499,39.912055),17512=>array(-76.486282,40.040169),17516=>array(-76.371356,39.941461),17517=>array(-76.132881,40.244751),17518=>array(-76.253014,39.80893),17519=>array(-76.023423,40.141438),17520=>array(-76.349193,40.097518),17522=>array(-76.16914,40.171484),17527=>array(-75.991296,40.008881),17529=>array(-76.097142,40.041933),17532=>array(-76.288008,39.858156),17535=>array(-76.022866,39.982036),17536=>array(-76.073774,39.848034),17538=>array(-76.414548,40.082629),17540=>array(-76.189894,40.097543),17543=>array(-76.29538,40.181032),17545=>array(-76.43437,40.178669),17547=>array(-76.586368,40.068478),17550=>array(-76.583396,40.07589),17551=>array(-76.371419,39.982202),17552=>array(-76.510775,40.107241),17554=>array(-76.424173,40.040303),17555=>array(-75.959407,40.122346),17557=>array(-76.072742,40.09985),17560=>array(-76.227681,39.912675),17562=>array(-76.092067,39.970438),17563=>array(-76.193306,39.760748),17565=>array(-76.331027,39.897702),17566=>array(-76.147513,39.867186),17569=>array(-76.096577,40.271433),17570=>array(-76.568851,40.129942),17572=>array(-76.120065,39.975006),17576=>array(-76.19676,40.037195),17578=>array(-76.159806,40.226099),17579=>array(-76.180752,39.960406),17581=>array(-76.048702,40.160264),17582=>array(-76.469176,39.99314),17584=>array(-76.259814,39.95454),17601=>array(-76.314914,40.074241),17602=>array(-76.246351,40.014623),17603=>array(-76.330432,40.030839),17606=>array(-76.303907,40.11167),17701=>array(-76.857256,41.345045),17702=>array(-77.077271,41.183488),17721=>array(-77.318405,41.183625),17723=>array(-77.471376,41.435023),17724=>array(-76.805113,41.642528),17727=>array(-77.496451,41.510688),17728=>array(-77.078567,41.334774),17729=>array(-77.736116,41.511224),17730=>array(-76.87841,41.110449),17731=>array(-76.57867,41.429408),17737=>array(-76.68578,41.299271),17739=>array(-77.401189,41.397216),17740=>array(-77.267758,41.25063),17742=>array(-76.60227,41.238532),17744=>array(-77.153274,41.24097),17745=>array(-77.4649,41.277795),17747=>array(-77.331759,41.032578),17748=>array(-77.352941,41.150402),17749=>array(-76.818889,41.072241),17750=>array(-77.482253,41.057866),17751=>array(-77.544826,41.153567),17752=>array(-76.930251,41.180139),17754=>array(-76.889212,41.311612),17756=>array(-76.739806,41.208004),17758=>array(-76.535617,41.360197),17760=>array(-77.658475,41.41326),17762=>array(-76.700158,41.28423),17763=>array(-76.97618,41.507375),17764=>array(-77.813637,41.33475),17765=>array(-76.973451,41.565735),17767=>array(-77.463161,41.083874),17768=>array(-76.755985,41.558836),17771=>array(-77.035738,41.437306),17772=>array(-76.713033,41.125057),17774=>array(-76.533013,41.281191),17776=>array(-77.294106,41.415059),17777=>array(-76.821696,41.106517),17778=>array(-77.980212,41.28782),17779=>array(-77.376887,41.20732),17801=>array(-76.755008,40.834724),17810=>array(-77.031372,41.11136),17812=>array(-77.22791,40.740534),17813=>array(-77.172083,40.780401),17814=>array(-76.363142,41.273237),17815=>array(-76.420092,41.020038),17820=>array(-76.403739,40.895639),17821=>array(-76.643864,40.989183),17822=>array(-76.605142,40.968016),17823=>array(-76.776193,40.745495),17824=>array(-76.505353,40.85231),17827=>array(-76.968032,40.75286),17829=>array(-77.155804,40.900549),17830=>array(-76.80517,40.686064),17832=>array(-76.45902,40.805945),17834=>array(-76.466875,40.78021),17835=>array(-77.204312,40.878987),17836=>array(-76.606462,40.714342),17837=>array(-76.94515,40.974977),17840=>array(-76.43312,40.772092),17841=>array(-77.352556,40.724869),17842=>array(-77.040151,40.80295),17844=>array(-77.085405,40.973978),17845=>array(-77.21157,40.88437),17846=>array(-76.517122,41.141745),17847=>array(-76.811029,41.007983),17850=>array(-76.857448,40.965596),17851=>array(-76.4343,40.803118),17853=>array(-77.0067,40.694729),17855=>array(-76.966684,40.890386),17856=>array(-76.947382,41.06535),17857=>array(-76.772972,40.932136),17859=>array(-76.398094,41.116964),17860=>array(-76.611035,40.866964),17861=>array(-77.082304,40.773224),17862=>array(-77.056395,40.860506),17864=>array(-76.905819,40.704727),17865=>array(-76.786769,40.99018),17866=>array(-76.532457,40.80651),17867=>array(-76.688597,40.714115),17868=>array(-76.633968,40.957721),17870=>array(-76.888636,40.817323),17872=>array(-76.697714,40.753396),17876=>array(-76.826665,40.859744),17878=>array(-76.323488,41.176018),17880=>array(-77.121755,40.892209),17881=>array(-76.670014,40.782906),17884=>array(-76.669463,41.055983),17885=>array(-77.314016,40.866349),17886=>array(-76.875204,41.016709),17887=>array(-76.935982,41.12922),17888=>array(-76.378479,40.806775),17889=>array(-76.921646,40.877442),17901=>array(-76.277542,40.683828),17920=>array(-76.326917,40.819666),17921=>array(-76.360586,40.751575),17922=>array(-76.110646,40.582492),17923=>array(-76.319934,40.632591),17925=>array(-76.067802,40.753377),17929=>array(-76.194039,40.630703),17930=>array(-76.115313,40.708664),17931=>array(-76.214575,40.786491),17933=>array(-76.243195,40.604485),17934=>array(-76.211333,40.796439),17935=>array(-76.279682,40.79614),17936=>array(-76.33993,40.750116),17938=>array(-76.516266,40.651576),17941=>array(-76.609184,40.685722),17943=>array(-76.38781,40.75666),17944=>array(-76.279256,40.67254),17945=>array(-76.377026,40.785436),17946=>array(-76.256372,40.810364),17948=>array(-76.117468,40.845385),17949=>array(-76.242345,40.793926),17951=>array(-76.245246,40.678556),17952=>array(-76.058552,40.755438),17953=>array(-76.120218,40.751902),17954=>array(-76.259688,40.69042),17957=>array(-76.518212,40.591824),17959=>array(-76.149951,40.732069),17960=>array(-75.947044,40.697241),17961=>array(-76.060946,40.649698),17963=>array(-76.382017,40.561577),17964=>array(-76.502961,40.714366),17965=>array(-76.165281,40.698615),17967=>array(-76.216264,40.856256),17968=>array(-76.6123,40.638679),17970=>array(-76.191949,40.720206),17972=>array(-76.205601,40.592057),17974=>array(-76.236267,40.6957),17976=>array(-76.210606,40.819867),17978=>array(-76.614963,40.625448),17979=>array(-76.199716,40.561567),17980=>array(-76.644717,40.518647),17981=>array(-76.390115,40.634301),17982=>array(-76.021309,40.785932),17983=>array(-76.547166,40.642622),17985=>array(-76.216648,40.912303),18011=>array(-75.646324,40.477974),18013=>array(-75.177272,40.84876),18014=>array(-75.409221,40.764431),18015=>array(-75.367239,40.585869),18016=>array(-75.392847,40.63213),18017=>array(-75.387361,40.659981),18018=>array(-75.395584,40.627594),18020=>array(-75.321188,40.670951),18030=>array(-75.664107,40.802138),18031=>array(-75.648674,40.552084),18032=>array(-75.467873,40.656434),18034=>array(-75.415278,40.546353),18035=>array(-75.539119,40.745426),18036=>array(-75.38594,40.509151),18037=>array(-75.546121,40.681817),18038=>array(-75.486087,40.794881),18040=>array(-75.225665,40.746007),18041=>array(-75.509926,40.42046),18042=>array(-75.223124,40.654176),18045=>array(-75.272796,40.69345),18046=>array(-75.560346,40.548009),18049=>array(-75.48929,40.515732),18051=>array(-75.667054,40.595644),18052=>array(-75.504255,40.657428),18053=>array(-75.704117,40.71923),18054=>array(-75.438736,40.352369),18055=>array(-75.304385,40.591504),18056=>array(-75.550389,40.450942),18058=>array(-75.493409,40.889647),18059=>array(-75.543081,40.723506),18062=>array(-75.58518,40.503935),18063=>array(-75.167286,40.782592),18064=>array(-75.315959,40.757009),18066=>array(-75.7401,40.664462),18067=>array(-75.474675,40.715038),18068=>array(-75.520041,40.484829),18069=>array(-75.615125,40.625289),18070=>array(-75.535617,40.434866),18071=>array(-75.555193,40.834245),18072=>array(-75.259135,40.84414),18073=>array(-75.47443,40.386499),18074=>array(-75.515686,40.316737),18076=>array(-75.48079,40.374803),18077=>array(-75.237114,40.570065),18078=>array(-75.620717,40.673304),18079=>array(-75.658519,40.743873),18080=>array(-75.635308,40.735856),18081=>array(-75.281409,40.563893),18083=>array(-75.267086,40.754952),18085=>array(-75.254887,40.741232),18086=>array(-75.54793,40.736807),18087=>array(-75.594101,40.553537),18088=>array(-75.557509,40.765692),18091=>array(-75.319795,40.831388),18092=>array(-75.51314,40.469697),18101=>array(-75.469236,40.602658),18102=>array(-75.476275,40.608473),18103=>array(-75.488926,40.570308),18104=>array(-75.546853,40.611658),18105=>array(-75.493938,40.601416),18106=>array(-75.560284,40.568227),18109=>array(-75.439893,40.636938),18195=>array(-75.624789,40.584272),18201=>array(-75.957126,40.947134),18202=>array(-76.045987,40.954433),18210=>array(-75.576536,41.004434),18211=>array(-75.830406,40.74408),18212=>array(-75.709569,40.775254),18214=>array(-76.083954,40.800261),18216=>array(-75.892858,40.941496),18218=>array(-75.916102,40.81974),18219=>array(-76.057456,40.990787),18220=>array(-76.060382,40.840529),18221=>array(-75.917333,41.001778),18222=>array(-76.000073,41.03619),18223=>array(-75.950287,40.982353),18224=>array(-75.873263,41.026275),18225=>array(-75.971311,40.981311),18229=>array(-75.673699,40.931148),18230=>array(-75.934528,40.921083),18231=>array(-76.007984,40.904304),18232=>array(-75.884824,40.832974),18234=>array(-75.96435,40.992594),18235=>array(-75.69786,40.829796),18237=>array(-75.978492,40.884881),18239=>array(-75.988272,40.989337),18240=>array(-75.872265,40.864677),18241=>array(-76.130802,40.951524),18242=>array(-76.124322,40.911388),18244=>array(-75.670561,40.822445),18245=>array(-76.033518,40.853214),18246=>array(-76.195185,40.957215),18248=>array(-76.091979,40.902147),18249=>array(-76.116117,40.987794),18250=>array(-75.846201,40.824963),18251=>array(-76.077381,41.008051),18252=>array(-75.973775,40.766755),18254=>array(-75.965651,40.915913),18255=>array(-75.829695,40.933327),18256=>array(-76.146755,40.940886),18301=>array(-75.175581,41.042703),18302=>array(-75.1128,41.11215),18321=>array(-75.28331,41.02575),18322=>array(-75.393353,40.918535),18323=>array(-75.273469,41.196579),18324=>array(-75.000689,41.158143),18325=>array(-75.225146,41.204887),18326=>array(-75.253037,41.16722),18327=>array(-75.133837,40.967874),18328=>array(-74.971008,41.226643),18330=>array(-75.449217,40.968776),18331=>array(-75.443831,40.909936),18332=>array(-75.261302,41.094938),18333=>array(-75.490084,40.906085),18334=>array(-75.431784,41.054954),18335=>array(-75.103933,41.068101),18336=>array(-74.74279,41.374719),18337=>array(-74.871787,41.32911),18340=>array(-74.765303,41.417841),18342=>array(-75.273444,41.170609),18343=>array(-75.110092,40.898529),18344=>array(-75.343042,41.122996),18346=>array(-75.421179,41.142797),18347=>array(-75.560205,41.138865),18349=>array(-75.367074,41.101274),18350=>array(-75.466143,41.123825),18351=>array(-75.099334,40.92272),18352=>array(-75.356087,41.006831),18353=>array(-75.358074,40.895293),18354=>array(-75.322095,40.922603),18355=>array(-75.358803,41.076972),18356=>array(-75.118103,41.011079),18357=>array(-75.216499,41.232813),18360=>array(-75.28797,40.967389),18370=>array(-75.339537,41.092408),18371=>array(-75.041444,41.157318),18372=>array(-75.33635,41.044022),18403=>array(-75.535045,41.509701),18405=>array(-75.10424,41.599551),18407=>array(-75.528121,41.59336),18411=>array(-75.744541,41.454492),18413=>array(-75.589335,41.648124),18414=>array(-75.741072,41.541069),18415=>array(-75.124268,41.74353),18417=>array(-75.201095,41.809764),18419=>array(-75.792369,41.585933),18420=>array(-75.710133,41.602006),18421=>array(-75.492886,41.66421),18424=>array(-75.524965,41.230478),18425=>array(-75.042345,41.437562),18426=>array(-75.239061,41.325507),18427=>array(-75.406897,41.404977),18428=>array(-75.11806,41.404302),18430=>array(-75.472457,41.756459),18431=>array(-75.257698,41.61651),18433=>array(-75.58133,41.573307),18434=>array(-75.542128,41.4536),18435=>array(-74.983238,41.455609),18436=>array(-75.39345,41.442799),18437=>array(-75.316504,41.871969),18438=>array(-75.256488,41.439159),18439=>array(-75.348966,41.825503),18441=>array(-75.61395,41.656056),18443=>array(-75.102094,41.662927),18444=>array(-75.55277,41.329074),18445=>array(-75.359358,41.297916),18446=>array(-75.759149,41.656159),18447=>array(-75.607166,41.513448),18451=>array(-75.217955,41.396998),18452=>array(-75.590282,41.483628),18453=>array(-75.370789,41.758495),18454=>array(-75.426144,41.827285),18455=>array(-75.359193,41.893001),18456=>array(-75.340433,41.612796),18457=>array(-75.049165,41.472094),18458=>array(-74.919561,41.395965),18459=>array(-75.428839,41.504102),18460=>array(-75.313104,41.249931),18461=>array(-75.327674,41.929003),18462=>array(-75.409089,41.914344),18463=>array(-75.396934,41.357556),18464=>array(-75.17695,41.403012),18465=>array(-75.516842,41.831306),18466=>array(-75.394233,41.196442),18469=>array(-75.130492,41.703684),18470=>array(-75.535512,41.724676),18471=>array(-75.69118,41.529093),18472=>array(-75.396687,41.58341),18473=>array(-75.217206,41.522142),18503=>array(-75.667469,41.411106),18504=>array(-75.699867,41.425521),18505=>array(-75.651527,41.386202),18507=>array(-75.681823,41.359038),18508=>array(-75.657937,41.454947),18509=>array(-75.642906,41.430836),18510=>array(-75.636613,41.407379),18512=>array(-75.601898,41.42632),18517=>array(-75.713641,41.39464),18518=>array(-75.739559,41.375054),18519=>array(-75.630719,41.461938),18602=>array(-75.750771,41.183232),18603=>array(-76.258139,41.082104),18610=>array(-75.549147,41.069335),18612=>array(-75.98638,41.346088),18614=>array(-76.496996,41.524947),18615=>array(-75.857203,41.461702),18616=>array(-76.635657,41.504887),18617=>array(-76.080726,41.169676),18618=>array(-76.041417,41.365093),18619=>array(-76.717816,41.461696),18621=>array(-76.098546,41.248601),18622=>array(-76.273515,41.201232),18623=>array(-76.151984,41.664801),18624=>array(-75.64717,41.060643),18625=>array(-75.848822,41.513387),18626=>array(-76.523881,41.398268),18628=>array(-76.313808,41.430143),18629=>array(-76.141339,41.517603),18630=>array(-76.023636,41.662144),18631=>array(-76.304374,41.029907),18632=>array(-76.377495,41.45936),18634=>array(-76.022619,41.185512),18635=>array(-76.201347,41.02924),18636=>array(-76.113651,41.39141),18640=>array(-75.738725,41.29823),18641=>array(-75.722968,41.342515),18642=>array(-75.773181,41.356348),18643=>array(-75.840422,41.370822),18644=>array(-75.882405,41.327911),18651=>array(-75.959845,41.25404),18653=>array(-75.824277,41.393759),18655=>array(-76.203214,41.187724),18656=>array(-76.18484,41.333037),18657=>array(-75.959481,41.522511),18660=>array(-76.062014,41.097733),18661=>array(-75.74087,41.07643),18701=>array(-75.885029,41.243648),18702=>array(-75.757447,41.230482),18704=>array(-75.914636,41.262553),18705=>array(-75.842735,41.271834),18706=>array(-75.914623,41.203365),18707=>array(-75.933499,41.13575),18708=>array(-75.963463,41.295848),18709=>array(-75.896388,41.285469),18801=>array(-75.939711,41.826389),18810=>array(-76.50713,41.933295),18812=>array(-75.964742,41.973201),18814=>array(-76.607272,41.784063),18816=>array(-75.915633,41.757157),18817=>array(-76.631611,41.872722),18818=>array(-76.044011,41.911258),18821=>array(-75.722798,41.98991),18822=>array(-75.794089,41.970165),18823=>array(-75.690089,41.77831),18824=>array(-75.787183,41.697366),18825=>array(-75.607728,41.807883),18826=>array(-75.748893,41.745746),18828=>array(-76.096165,41.806724),18829=>array(-76.173504,41.837702),18830=>array(-76.11444,41.959087),18831=>array(-76.598118,41.894223),18832=>array(-76.568614,41.678555),18833=>array(-76.483621,41.597169),18834=>array(-75.720933,41.830968),18837=>array(-76.302838,41.915054),18840=>array(-76.534965,41.971552),18842=>array(-75.623434,41.749695),18843=>array(-75.899586,41.794457),18844=>array(-75.905239,41.69097),18845=>array(-76.182163,41.787369),18846=>array(-76.229986,41.621411),18847=>array(-75.579031,41.92882),18848=>array(-76.454741,41.751057),18850=>array(-76.462384,41.854257),18851=>array(-76.176463,41.933902),18853=>array(-76.276925,41.721414),18854=>array(-76.355747,41.790684),18901=>array(-75.147144,40.306267),18902=>array(-75.09568,40.352134),18912=>array(-75.056407,40.323952),18913=>array(-75.06001,40.37939),18914=>array(-75.209814,40.288824),18915=>array(-75.256828,40.272097),18917=>array(-75.205949,40.376919),18920=>array(-75.084034,40.497718),18923=>array(-75.173921,40.359341),18925=>array(-75.058039,40.288811),18929=>array(-75.080152,40.255513),18930=>array(-75.218673,40.521074),18932=>array(-75.254708,40.293616),18935=>array(-75.403473,40.437016),18936=>array(-75.230959,40.22405),18938=>array(-74.998049,40.351048),18940=>array(-74.937775,40.261315),18942=>array(-75.160467,40.471159),18944=>array(-75.234442,40.389293),18947=>array(-75.117839,40.422899),18950=>array(-75.074432,40.445221),18951=>array(-75.348942,40.452359),18954=>array(-74.993015,40.22547),18955=>array(-75.313694,40.47664),18960=>array(-75.325845,40.366237),18962=>array(-75.271138,40.346684),18964=>array(-75.337889,40.30347),18966=>array(-75.009898,40.188468),18969=>array(-75.368422,40.326304),18970=>array(-75.38117,40.412007),18972=>array(-75.124666,40.52732),18974=>array(-75.072803,40.217062),18976=>array(-75.143441,40.248905),18977=>array(-74.882113,40.286862),18980=>array(-75.017182,40.269965),19001=>array(-75.125442,40.125912),19002=>array(-75.206777,40.186587),19003=>array(-75.298929,40.001553),19004=>array(-75.231508,40.009753),19006=>array(-75.033899,40.150436),19007=>array(-74.85765,40.113179),19008=>array(-75.360258,39.972605),19009=>array(-75.064242,40.137805),19010=>array(-75.329727,40.023624),19012=>array(-75.10588,40.059767),19013=>array(-75.378097,39.848163),19014=>array(-75.432958,39.864907),19015=>array(-75.392945,39.868633),19017=>array(-75.460142,39.892229),19018=>array(-75.298595,39.923075),19020=>array(-74.938934,40.100591),19021=>array(-74.892183,40.089651),19022=>array(-75.337022,39.86144),19023=>array(-75.267387,39.91714),19025=>array(-75.161987,40.146444),19026=>array(-75.304042,39.950318),19027=>array(-75.124431,40.073118),19029=>array(-75.292496,39.868345),19030=>array(-74.837263,40.180468),19031=>array(-75.217005,40.109155),19032=>array(-75.278777,39.891296),19033=>array(-75.328434,39.890882),19034=>array(-75.204847,40.134266),19035=>array(-75.277642,40.051349),19036=>array(-75.293355,39.903578),19038=>array(-75.171761,40.100418),19040=>array(-75.105595,40.176879),19041=>array(-75.315837,40.007406),19043=>array(-75.30885,39.900283),19044=>array(-75.152867,40.186067),19046=>array(-75.105519,40.101404),19047=>array(-74.912096,40.179971),19050=>array(-75.263665,39.937537),19053=>array(-74.974991,40.153681),19054=>array(-74.818822,40.173024),19055=>array(-74.839218,40.150307),19056=>array(-74.885815,40.149339),19057=>array(-74.85404,40.140815),19060=>array(-75.493692,39.849999),19061=>array(-75.435069,39.82883),19063=>array(-75.416182,39.92046),19064=>array(-75.340813,39.933156),19066=>array(-75.249064,40.002583),19067=>array(-74.81844,40.206218),19070=>array(-75.324733,39.906248),19072=>array(-75.257741,40.023891),19073=>array(-75.435416,39.979412),19074=>array(-75.295756,39.88599),19075=>array(-75.185031,40.11388),19076=>array(-75.30737,39.886097),19078=>array(-75.322125,39.874378),19079=>array(-75.266592,39.898951),19081=>array(-75.347159,39.898048),19082=>array(-75.270393,39.960411),19083=>array(-75.312066,39.977025),19085=>array(-75.349913,40.036973),19086=>array(-75.370032,39.890631),19087=>array(-75.402461,40.061872),19090=>array(-75.124753,40.157452),19094=>array(-75.346642,39.874881),19095=>array(-75.151408,40.086002),19096=>array(-75.274178,39.997882),19102=>array(-75.165586,39.952783),19103=>array(-75.174298,39.952896),19104=>array(-75.199069,39.958719),19106=>array(-75.142789,39.948629),19107=>array(-75.158654,39.951735),19109=>array(-75.163654,39.949652),19111=>array(-75.080176,40.060612),19112=>array(-75.169141,39.889877),19113=>array(-75.247123,39.870698),19114=>array(-75.000264,40.069361),19115=>array(-75.042868,40.090698),19116=>array(-75.013276,40.115569),19118=>array(-75.212415,40.072443),19119=>array(-75.191112,40.053348),19120=>array(-75.119198,40.034147),19121=>array(-75.17912,39.98198),19122=>array(-75.145899,39.977746),19123=>array(-75.145526,39.964441),19124=>array(-75.092814,40.017119),19125=>array(-75.125105,39.976249),19126=>array(-75.13756,40.05539),19127=>array(-75.227549,40.028146),19128=>array(-75.227934,40.048483),19129=>array(-75.185402,40.013014),19130=>array(-75.176073,39.967935),19131=>array(-75.217795,39.990184),19132=>array(-75.170855,39.996262),19133=>array(-75.141671,39.993092),19134=>array(-75.109091,39.989604),19135=>array(-75.048534,40.02211),19136=>array(-75.018555,40.039406),19137=>array(-75.072044,39.993169),19138=>array(-75.159048,40.056002),19139=>array(-75.229334,39.961352),19140=>array(-75.145495,40.012177),19141=>array(-75.145697,40.037574),19142=>array(-75.233277,39.921746),19143=>array(-75.225905,39.942579),19144=>array(-75.174075,40.033858),19145=>array(-75.198265,39.909857),19146=>array(-75.184146,39.939496),19147=>array(-75.152489,39.935327),19148=>array(-75.151475,39.911612),19149=>array(-75.065768,40.037722),19150=>array(-75.171824,40.072496),19151=>array(-75.257036,39.97957),19152=>array(-75.046985,40.060946),19153=>array(-75.229648,39.893446),19154=>array(-74.983219,40.096485),19301=>array(-75.480341,40.040279),19310=>array(-75.972836,39.93506),19311=>array(-75.771347,39.821095),19312=>array(-75.454948,40.031291),19316=>array(-75.833825,40.054082),19317=>array(-75.599381,39.8608),19319=>array(-75.520943,39.924558),19320=>array(-75.832374,39.962514),19330=>array(-75.914423,39.871898),19333=>array(-75.423597,40.041872),19335=>array(-75.721218,40.022618),19341=>array(-75.640626,40.039941),19342=>array(-75.496932,39.906048),19343=>array(-75.754835,40.100822),19344=>array(-75.881815,40.083633),19345=>array(-75.565339,40.029437),19348=>array(-75.712913,39.87028),19350=>array(-75.796677,39.760017),19352=>array(-75.889657,39.775919),19355=>array(-75.531359,40.046834),19358=>array(-75.8055,39.965269),19362=>array(-76.070383,39.750743),19363=>array(-75.969405,39.790137),19365=>array(-75.925129,39.966371),19367=>array(-75.884023,39.962992),19372=>array(-75.758457,39.998397),19373=>array(-75.532483,39.901816),19374=>array(-75.759748,39.824747),19375=>array(-75.740472,39.900459),19380=>array(-75.604383,39.989503),19382=>array(-75.613444,39.92767),19383=>array(-75.601627,39.951594),19390=>array(-75.842359,39.836097),19401=>array(-75.331629,40.13018),19403=>array(-75.378372,40.149717),19405=>array(-75.341022,40.103552),19406=>array(-75.382861,40.095288),19422=>array(-75.279393,40.15681),19425=>array(-75.651066,40.101778),19426=>array(-75.437052,40.191299),19428=>array(-75.300461,40.080337),19435=>array(-75.569174,40.327484),19436=>array(-75.246987,40.201504),19437=>array(-75.258603,40.182431),19438=>array(-75.390968,40.268928),19440=>array(-75.29093,40.286592),19442=>array(-75.583145,40.129517),19444=>array(-75.253168,40.087755),19446=>array(-75.303178,40.232824),19453=>array(-75.497917,40.140568),19454=>array(-75.243047,40.223335),19456=>array(-75.461771,40.133903),19457=>array(-75.590117,40.206378),19460=>array(-75.530448,40.126827),19462=>array(-75.281862,40.115287),19464=>array(-75.615861,40.258928),19465=>array(-75.684443,40.190531),19468=>array(-75.532067,40.207638),19472=>array(-75.573783,40.336934),19473=>array(-75.481495,40.256574),19474=>array(-75.404036,40.223528),19475=>array(-75.6,40.172197),19477=>array(-75.231457,40.183315),19492=>array(-75.491912,40.28546),19501=>array(-76.066211,40.244212),19503=>array(-75.571502,40.406369),19504=>array(-75.588554,40.416219),19505=>array(-75.622653,40.379238),19506=>array(-76.127974,40.452953),19507=>array(-76.27118,40.504847),19508=>array(-75.83393,40.263155),19510=>array(-75.877656,40.447528),19511=>array(-75.742724,40.48422),19512=>array(-75.680555,40.348327),19518=>array(-75.752511,40.270211),19519=>array(-75.735108,40.320657),19520=>array(-75.793465,40.16351),19522=>array(-75.820496,40.447368),19523=>array(-75.850448,40.201036),19525=>array(-75.585013,40.305649),19526=>array(-75.996509,40.54724),19529=>array(-75.864614,40.631309),19530=>array(-75.781445,40.53907),19533=>array(-75.992623,40.425103),19534=>array(-75.874898,40.573419),19535=>array(-75.804035,40.339979),19536=>array(-75.758948,40.480578),19538=>array(-75.702562,40.547528),19539=>array(-75.68354,40.496322),19540=>array(-75.966664,40.236271),19541=>array(-76.030287,40.486032),19542=>array(-75.767196,40.261203),19543=>array(-75.901026,40.177062),19544=>array(-76.296566,40.416876),19545=>array(-75.624078,40.341513),19547=>array(-75.768603,40.380048),19549=>array(-76.020034,40.584518),19550=>array(-76.249432,40.454939),19551=>array(-76.1374,40.361),19554=>array(-76.103746,40.512925),19555=>array(-75.953919,40.494382),19559=>array(-76.182401,40.495223),19560=>array(-75.893801,40.406182),19562=>array(-75.702653,40.505379),19564=>array(-75.87831,40.518731),19565=>array(-76.08788,40.342381),19567=>array(-76.209785,40.388389),19601=>array(-75.940014,40.355294),19602=>array(-75.914976,40.32874),19604=>array(-75.910242,40.356825),19605=>array(-75.943197,40.39791),19606=>array(-75.858157,40.338614),19607=>array(-75.944791,40.291483),19608=>array(-76.034772,40.310798),19609=>array(-75.997285,40.328313),19610=>array(-75.974839,40.341402),19611=>array(-75.942981,40.324708),19701=>array(-75.700909,39.583153),19702=>array(-75.729724,39.6182),19703=>array(-75.453853,39.801513),19706=>array(-75.596104,39.573236),19707=>array(-75.68364,39.785685),19709=>array(-75.675004,39.494582),19710=>array(-75.588092,39.795167),19711=>array(-75.741073,39.713598),19713=>array(-75.712298,39.670784),19716=>array(-75.758391,39.68956),19717=>array(-75.752273,39.678464),19720=>array(-75.604852,39.646922),19730=>array(-75.646933,39.463828),19731=>array(-75.587574,39.523585),19732=>array(-75.570042,39.783897),19733=>array(-75.651088,39.555826),19734=>array(-75.653322,39.381644),19735=>array(-75.599718,39.803172),19736=>array(-75.674753,39.804939),19801=>array(-75.540718,39.727781),19802=>array(-75.529302,39.756764),19803=>array(-75.542415,39.800665),19804=>array(-75.617677,39.716862),19805=>array(-75.593842,39.743799),19806=>array(-75.564142,39.763305),19807=>array(-75.614358,39.79865),19808=>array(-75.667057,39.737615),19809=>array(-75.500953,39.757786),19810=>array(-75.5064,39.81878),19901=>array(-75.473517,39.181546),19902=>array(-75.481823,39.125261),19904=>array(-75.587529,39.171293),19930=>array(-75.061096,38.551362),19931=>array(-75.623043,38.573968),19933=>array(-75.619702,38.728637),19934=>array(-75.628778,39.082694),19936=>array(-75.584133,39.219138),19938=>array(-75.705055,39.260654),19939=>array(-75.212753,38.565774),19940=>array(-75.564931,38.477562),19941=>array(-75.426062,38.793658),19943=>array(-75.606986,39.004436),19944=>array(-75.058146,38.478535),19945=>array(-75.228872,38.505064),19946=>array(-75.4496,39.034804),19947=>array(-75.398201,38.66649),19950=>array(-75.596743,38.818451),19951=>array(-75.256875,38.691757),19952=>array(-75.628425,38.921424),19953=>array(-75.694133,39.152487),19954=>array(-75.520457,38.89701),19955=>array(-75.668556,39.225855),19956=>array(-75.538143,38.547724),19958=>array(-75.167184,38.729767),19960=>array(-75.408716,38.850913),19962=>array(-75.488122,39.068862),19963=>array(-75.362567,38.943253),19964=>array(-75.7205,39.089325),19966=>array(-75.277196,38.579422),19967=>array(-75.122502,38.53869),19968=>array(-75.28688,38.773918),19970=>array(-75.097137,38.559302),19971=>array(-75.086681,38.686005),19973=>array(-75.615899,38.638896),19975=>array(-75.165154,38.468423),19977=>array(-75.546122,39.298946),19979=>array(-75.572566,39.048818),20001=>array(-77.017739,38.910353),20002=>array(-76.983607,38.905026),20003=>array(-76.990935,38.881904),20004=>array(-77.028635,38.894888),20005=>array(-77.031578,38.904674),20006=>array(-77.041468,38.898613),20007=>array(-77.079313,38.914337),20008=>array(-77.059981,38.936238),20009=>array(-77.037381,38.919144),20010=>array(-77.030312,38.933366),20011=>array(-77.022991,38.952514),20012=>array(-77.032609,38.976873),20015=>array(-77.058323,38.966889),20016=>array(-77.091159,38.937093),20017=>array(-76.992126,38.938188),20018=>array(-76.974446,38.926576),20019=>array(-76.943575,38.891412),20020=>array(-76.978933,38.860413),20024=>array(-77.025323,38.87601),20032=>array(-77.006591,38.833719),20036=>array(-77.041569,38.907017),20037=>array(-77.055446,38.898918),20045=>array(-77.030798,38.896731),20052=>array(-77.046981,38.900126),20053=>array(-77.011231,38.884108),20057=>array(-77.075774,38.909123),20064=>array(-76.999168,38.936353),20105=>array(-77.602742,38.953126),20106=>array(-78.002506,38.693414),20109=>array(-77.531024,38.793641),20110=>array(-77.484727,38.747561),20111=>array(-77.427873,38.748968),20112=>array(-77.432845,38.661923),20115=>array(-77.911841,38.809947),20117=>array(-77.733937,38.998822),20118=>array(-77.737005,38.968339),20119=>array(-77.622006,38.61038),20120=>array(-77.476371,38.856401),20121=>array(-77.463237,38.811059),20124=>array(-77.391333,38.781332),20129=>array(-77.601254,39.172018),20130=>array(-77.949319,39.036981),20132=>array(-77.719389,39.166243),20135=>array(-77.864902,39.094939),20136=>array(-77.554552,38.738325),20137=>array(-77.722463,38.806731),20139=>array(-77.697216,38.658385),20141=>array(-77.790704,39.11239),20143=>array(-77.564143,38.859556),20144=>array(-77.946943,38.92299),20147=>array(-77.47813,39.041947),20148=>array(-77.522341,38.995234),20151=>array(-77.445141,38.896524),20152=>array(-77.502426,38.919145),20155=>array(-77.617789,38.810114),20158=>array(-77.657989,39.139658),20164=>array(-77.395067,39.013299),20165=>array(-77.392694,39.05794),20166=>array(-77.455909,38.98651),20169=>array(-77.645449,38.879166),20170=>array(-77.380901,38.980039),20171=>array(-77.396479,38.924038),20175=>array(-77.604118,39.065167),20176=>array(-77.544111,39.184706),20180=>array(-77.637938,39.268574),20181=>array(-77.56961,38.689126),20184=>array(-77.883754,39.000671),20186=>array(-77.851394,38.698163),20187=>array(-77.748045,38.722872),20190=>array(-77.339298,38.959322),20191=>array(-77.351702,38.934645),20194=>array(-77.340775,38.981059),20197=>array(-77.627818,39.195454),20198=>array(-77.744761,38.88411),20202=>array(-77.02101,38.887071),20204=>array(-77.014429,38.885559),20228=>array(-77.03024,38.886413),20230=>array(-77.032798,38.893794),20240=>array(-77.042605,38.894456),20245=>array(-77.04446,38.89334),20260=>array(-77.024998,38.88367),20307=>array(-77.031354,38.974772),20317=>array(-77.014277,38.934852),20319=>array(-77.017003,38.864838),20373=>array(-77.007865,38.858625),20390=>array(-76.993695,38.879019),20405=>array(-77.042588,38.896377),20418=>array(-77.047764,38.8928),20427=>array(-77.047573,38.902083),20506=>array(-77.038702,38.89703),20510=>array(-77.00689,38.89278),20520=>array(-77.048407,38.894759),20535=>array(-77.024844,38.894467),20540=>array(-77.004713,38.887929),20551=>array(-77.0458,38.892802),20553=>array(-77.022968,38.886946),20560=>array(-77.026003,38.888232),20565=>array(-77.019211,38.89063),20566=>array(-77.055064,38.895579),20593=>array(-77.01016,38.866759),20601=>array(-76.851612,38.613372),20602=>array(-76.894551,38.583394),20603=>array(-76.976583,38.63039),20606=>array(-76.737309,38.263046),20607=>array(-77.018549,38.672666),20608=>array(-76.700998,38.582405),20609=>array(-76.767723,38.270007),20611=>array(-76.978244,38.455014),20612=>array(-76.67721,38.50506),20613=>array(-76.805307,38.671222),20615=>array(-76.548347,38.416231),20616=>array(-77.09748,38.663663),20617=>array(-76.858802,38.548459),20618=>array(-76.786972,38.285216),20619=>array(-76.527888,38.292364),20620=>array(-76.528928,38.233919),20621=>array(-76.800492,38.325866),20622=>array(-76.874412,38.418591),20623=>array(-76.842233,38.741337),20624=>array(-76.733442,38.338026),20625=>array(-76.84727,38.262223),20626=>array(-76.769482,38.229649),20628=>array(-76.338415,38.153439),20629=>array(-76.450404,38.336582),20630=>array(-76.475774,38.164277),20632=>array(-76.957993,38.432799),20634=>array(-76.506885,38.269412),20636=>array(-76.567187,38.352141),20637=>array(-76.755948,38.525108),20639=>array(-76.609784,38.607278),20640=>array(-77.2137,38.525435),20645=>array(-76.914752,38.2945),20646=>array(-77.002986,38.523258),20650=>array(-76.633157,38.268654),20653=>array(-76.432886,38.23631),20657=>array(-76.442883,38.379757),20658=>array(-77.160419,38.560582),20659=>array(-76.732449,38.418673),20660=>array(-76.706614,38.370232),20662=>array(-77.20534,38.428471),20664=>array(-76.925395,38.354485),20667=>array(-76.440438,38.219073),20670=>array(-76.415708,38.285279),20674=>array(-76.503548,38.134797),20675=>array(-77.022463,38.580932),20676=>array(-76.541273,38.493224),20677=>array(-77.034991,38.499329),20678=>array(-76.60135,38.52282),20680=>array(-76.377931,38.112015),20684=>array(-76.409959,38.14229),20685=>array(-76.526706,38.434862),20686=>array(-76.429504,38.178213),20687=>array(-76.340757,38.064296),20688=>array(-76.464183,38.327135),20689=>array(-76.579405,38.662952),20690=>array(-76.533469,38.157447),20692=>array(-76.502084,38.181015),20693=>array(-77.089581,38.457068),20695=>array(-76.970784,38.591492),20701=>array(-76.785436,39.125563),20705=>array(-76.900362,39.049423),20706=>array(-76.851091,38.96588),20707=>array(-76.882766,39.099378),20708=>array(-76.825784,39.057365),20710=>array(-76.92591,38.942368),20711=>array(-76.645108,38.801058),20712=>array(-76.964578,38.942361),20714=>array(-76.552748,38.723689),20715=>array(-76.741331,38.989393),20716=>array(-76.715028,38.926428),20720=>array(-76.785824,38.98278),20721=>array(-76.785129,38.915222),20722=>array(-76.9506,38.934558),20723=>array(-76.867942,39.137569),20724=>array(-76.804005,39.101075),20732=>array(-76.542568,38.655142),20733=>array(-76.532229,38.805653),20735=>array(-76.905165,38.750234),20736=>array(-76.627765,38.689075),20737=>array(-76.913538,38.964265),20740=>array(-76.931652,39.002866),20742=>array(-76.94569,38.989629),20743=>array(-76.893317,38.88423),20744=>array(-76.983786,38.758348),20745=>array(-76.995859,38.806809),20746=>array(-76.918265,38.836403),20747=>array(-76.883307,38.854996),20748=>array(-76.933436,38.814902),20751=>array(-76.561199,38.794437),20754=>array(-76.646639,38.73071),20755=>array(-76.747196,39.107783),20758=>array(-76.593145,38.73337),20759=>array(-76.931202,39.153988),20762=>array(-76.869158,38.809803),20763=>array(-76.820472,39.135205),20764=>array(-76.506137,38.834356),20765=>array(-76.544916,38.84189),20769=>array(-76.81866,38.996697),20770=>array(-76.879165,39.002985),20772=>array(-76.766978,38.78028),20774=>array(-76.774153,38.874543),20776=>array(-76.572429,38.872408),20777=>array(-76.968988,39.17502),20778=>array(-76.572609,38.828682),20779=>array(-76.572586,38.764781),20781=>array(-76.946296,38.95286),20782=>array(-76.966259,38.965814),20783=>array(-76.970698,38.999757),20784=>array(-76.89172,38.950547),20785=>array(-76.881948,38.918291),20794=>array(-76.794631,39.151138),20812=>array(-77.143881,38.967041),20814=>array(-77.10149,39.004989),20815=>array(-77.079288,38.983386),20816=>array(-77.120006,38.95695),20817=>array(-77.151871,38.997229),20818=>array(-77.162143,38.973938),20832=>array(-77.070708,39.15063),20833=>array(-77.05467,39.207175),20837=>array(-77.407115,39.116506),20838=>array(-77.390831,39.218101),20839=>array(-77.434971,39.188307),20841=>array(-77.327521,39.191853),20842=>array(-77.415265,39.199879),20850=>array(-77.182197,39.09139),20851=>array(-77.121858,39.079082),20852=>array(-77.12204,39.051928),20853=>array(-77.094562,39.101713),20854=>array(-77.222312,39.032995),20855=>array(-77.132021,39.137633),20860=>array(-77.025412,39.142366),20861=>array(-76.999591,39.149747),20862=>array(-77.018806,39.18123),20866=>array(-76.933852,39.109331),20868=>array(-76.969321,39.126395),20871=>array(-77.282547,39.261341),20872=>array(-77.216125,39.294465),20874=>array(-77.298548,39.130031),20876=>array(-77.237152,39.208384),20877=>array(-77.185238,39.139703),20878=>array(-77.25161,39.115209),20879=>array(-77.175386,39.168041),20880=>array(-77.173557,39.139726),20882=>array(-77.151071,39.239122),20886=>array(-77.207136,39.187415),20895=>array(-77.077539,39.02703),20896=>array(-77.092454,39.035382),20899=>array(-77.216228,39.143736),20901=>array(-77.008021,39.020266),20902=>array(-77.039264,39.045249),20903=>array(-76.984677,39.022179),20904=>array(-76.980935,39.066605),20905=>array(-76.988478,39.109645),20906=>array(-77.057159,39.087321),20910=>array(-77.036607,39.002883),20912=>array(-77.00113,38.981596),21001=>array(-76.202092,39.503048),21005=>array(-76.14452,39.488112),21009=>array(-76.2952,39.466888),21010=>array(-76.292629,39.390932),21012=>array(-76.496133,39.046835),21013=>array(-76.490788,39.511502),21014=>array(-76.352157,39.536084),21015=>array(-76.292469,39.544175),21017=>array(-76.23441,39.474778),21028=>array(-76.249469,39.565977),21029=>array(-76.959448,39.213616),21030=>array(-76.670695,39.490779),21031=>array(-76.65801,39.487208),21032=>array(-76.604145,39.028343),21034=>array(-76.223028,39.640719),21035=>array(-76.626588,38.9383),21036=>array(-76.999238,39.233122),21037=>array(-76.543507,38.919135),21040=>array(-76.289966,39.4365),21042=>array(-76.894602,39.277181),21043=>array(-76.800106,39.26058),21044=>array(-76.87911,39.205869),21045=>array(-76.828234,39.206042),21046=>array(-76.842028,39.173116),21047=>array(-76.438784,39.521387),21048=>array(-76.915068,39.488167),21050=>array(-76.392164,39.585343),21051=>array(-76.455841,39.472691),21052=>array(-76.447118,39.205885),21053=>array(-76.715068,39.695532),21054=>array(-76.68598,39.041032),21056=>array(-76.428558,39.072941),21057=>array(-76.512474,39.448749),21060=>array(-76.580873,39.169791),21061=>array(-76.629444,39.161942),21071=>array(-76.810954,39.481656),21074=>array(-76.839847,39.621612),21075=>array(-76.750444,39.203363),21076=>array(-76.716355,39.168512),21077=>array(-76.697686,39.156134),21078=>array(-76.141217,39.559237),21082=>array(-76.473523,39.478136),21084=>array(-76.466441,39.613561),21085=>array(-76.35701,39.445889),21087=>array(-76.41324,39.449314),21090=>array(-76.672517,39.208481),21093=>array(-76.640811,39.439448),21102=>array(-76.850538,39.682834),21104=>array(-76.912757,39.346904),21105=>array(-76.651296,39.713941),21108=>array(-76.621098,39.091266),21111=>array(-76.589692,39.575537),21113=>array(-76.716577,39.053573),21114=>array(-76.684221,39.009642),21117=>array(-76.777976,39.427563),21120=>array(-76.674854,39.646204),21122=>array(-76.4953,39.121745),21128=>array(-76.44746,39.409428),21130=>array(-76.194185,39.477306),21131=>array(-76.58987,39.503655),21132=>array(-76.440369,39.694705),21133=>array(-76.815284,39.373505),21136=>array(-76.794244,39.483767),21140=>array(-76.583949,38.950564),21144=>array(-76.677268,39.120912),21146=>array(-76.558698,39.079136),21152=>array(-76.679892,39.541052),21153=>array(-76.700918,39.418385),21154=>array(-76.360475,39.657449),21155=>array(-76.806079,39.573619),21156=>array(-76.396486,39.437208),21157=>array(-76.983558,39.548569),21158=>array(-77.035092,39.653737),21160=>array(-76.306537,39.700255),21161=>array(-76.56506,39.659903),21162=>array(-76.405583,39.3901),21163=>array(-76.848255,39.337532),21201=>array(-76.622228,39.294794),21202=>array(-76.607016,39.296526),21204=>array(-76.632295,39.402268),21205=>array(-76.564465,39.302295),21206=>array(-76.538877,39.338428),21207=>array(-76.719484,39.324167),21208=>array(-76.731109,39.385362),21209=>array(-76.670003,39.373191),21210=>array(-76.632685,39.359156),21211=>array(-76.639408,39.329817),21212=>array(-76.614898,39.368561),21213=>array(-76.577841,39.314942),21214=>array(-76.564402,39.351797),21215=>array(-76.683566,39.345241),21216=>array(-76.671717,39.310595),21217=>array(-76.639154,39.308473),21218=>array(-76.601451,39.330107),21219=>array(-76.443305,39.227459),21220=>array(-76.390009,39.347315),21221=>array(-76.43477,39.289205),21222=>array(-76.492566,39.26484),21223=>array(-76.653992,39.282778),21224=>array(-76.542833,39.27486),21225=>array(-76.615735,39.226117),21226=>array(-76.562926,39.208888),21227=>array(-76.67945,39.23997),21228=>array(-76.747741,39.272857),21229=>array(-76.691405,39.284272),21230=>array(-76.623807,39.266128),21231=>array(-76.591953,39.2872),21234=>array(-76.534228,39.393417),21236=>array(-76.48355,39.388421),21237=>array(-76.495402,39.341874),21239=>array(-76.589171,39.367099),21240=>array(-76.671519,39.173866),21244=>array(-76.776703,39.334941),21250=>array(-76.711179,39.255611),21251=>array(-76.581242,39.344713),21252=>array(-76.607803,39.393786),21286=>array(-76.573235,39.411836),21401=>array(-76.5528,38.98775),21402=>array(-76.472326,38.98765),21403=>array(-76.489628,38.942123),21405=>array(-76.557721,39.027584),21409=>array(-76.442533,39.018435),21502=>array(-78.755141,39.643695),21520=>array(-79.301479,39.624738),21521=>array(-79.041477,39.551371),21522=>array(-79.227754,39.610245),21523=>array(-79.079493,39.481678),21524=>array(-78.801406,39.707625),21529=>array(-78.767171,39.703942),21530=>array(-78.546123,39.67964),21531=>array(-79.428015,39.643087),21532=>array(-78.983757,39.647813),21536=>array(-79.165566,39.65696),21538=>array(-79.224443,39.409819),21539=>array(-78.969715,39.561281),21540=>array(-79.062465,39.478161),21541=>array(-79.380288,39.541999),21542=>array(-78.949988,39.596073),21543=>array(-78.960651,39.656452),21545=>array(-78.854521,39.704066),21550=>array(-79.39234,39.388807),21555=>array(-78.562474,39.575827),21557=>array(-78.92279,39.536233),21561=>array(-79.194401,39.491571),21562=>array(-79.040639,39.514119),21601=>array(-76.082437,38.793812),21607=>array(-75.854207,39.132717),21610=>array(-76.072577,39.367085),21612=>array(-76.275426,38.751513),21613=>array(-76.078875,38.502789),21617=>array(-76.044514,39.049403),21619=>array(-76.277789,38.943608),21620=>array(-76.097907,39.200187),21622=>array(-76.159253,38.414465),21623=>array(-75.966748,39.124035),21624=>array(-76.269891,38.844673),21625=>array(-75.996027,38.873205),21626=>array(-76.098361,38.341359),21627=>array(-76.046342,38.233029),21628=>array(-75.921896,39.232791),21629=>array(-75.824999,38.858889),21631=>array(-75.938981,38.582391),21632=>array(-75.772428,38.731398),21634=>array(-76.199153,38.292164),21635=>array(-75.846612,39.334792),21636=>array(-75.802806,39.025292),21638=>array(-76.207604,38.940201),21639=>array(-75.782373,38.958616),21640=>array(-75.820948,39.068141),21641=>array(-75.940168,38.917924),21643=>array(-75.869896,38.645582),21644=>array(-75.873521,39.112428),21645=>array(-75.956142,39.315859),21647=>array(-76.283079,38.812385),21648=>array(-76.23933,38.485356),21649=>array(-75.769331,39.13409),21650=>array(-75.81387,39.316259),21651=>array(-75.850227,39.255497),21652=>array(-76.274135,38.703188),21653=>array(-76.179733,38.750464),21654=>array(-76.127833,38.688756),21655=>array(-75.912768,38.744968),21657=>array(-75.986922,38.969939),21658=>array(-76.140688,38.955536),21659=>array(-75.77556,38.583928),21660=>array(-75.889093,38.956135),21661=>array(-76.219487,39.096119),21662=>array(-76.209515,38.713549),21663=>array(-76.229131,38.788962),21664=>array(-75.944694,38.607081),21665=>array(-76.332597,38.7518),21666=>array(-76.337531,38.939333),21667=>array(-76.042108,39.350621),21668=>array(-75.853,39.191191),21669=>array(-76.285161,38.460081),21671=>array(-76.335128,38.695574),21672=>array(-76.052704,38.271699),21673=>array(-76.043478,38.642513),21675=>array(-76.0896,38.288979),21676=>array(-76.353189,38.773206),21677=>array(-76.173233,38.472684),21678=>array(-76.1123,39.313279),21679=>array(-76.091617,38.913777),21701=>array(-77.33294,39.44355),21702=>array(-77.455987,39.479827),21703=>array(-77.473482,39.367031),21704=>array(-77.375659,39.354763),21705=>array(-77.410008,39.40886),21710=>array(-77.448302,39.297082),21711=>array(-78.019569,39.668396),21713=>array(-77.675498,39.529573),21714=>array(-77.504419,39.419295),21716=>array(-77.620019,39.314453),21717=>array(-77.435959,39.336876),21718=>array(-77.627767,39.393346),21719=>array(-77.494228,39.707956),21722=>array(-77.920752,39.662213),21723=>array(-77.002556,39.329124),21727=>array(-77.329234,39.688635),21733=>array(-77.758485,39.549302),21734=>array(-77.707835,39.607817),21737=>array(-77.026665,39.249219),21738=>array(-77.026706,39.279844),21740=>array(-77.743611,39.631916),21742=>array(-77.652688,39.678217),21746=>array(-77.711467,39.565064),21750=>array(-78.212939,39.685043),21754=>array(-77.316215,39.332124),21755=>array(-77.568128,39.359655),21756=>array(-77.70403,39.462722),21757=>array(-77.268169,39.591574),21758=>array(-77.656816,39.353204),21762=>array(-77.247089,39.48083),21766=>array(-78.38789,39.670471),21767=>array(-77.747473,39.697132),21769=>array(-77.568912,39.442447),21770=>array(-77.256234,39.350196),21771=>array(-77.163984,39.394652),21773=>array(-77.551713,39.542575),21774=>array(-77.268422,39.407766),21776=>array(-77.099688,39.517975),21777=>array(-77.519376,39.27131),21778=>array(-77.334303,39.615898),21779=>array(-77.651631,39.426808),21780=>array(-77.465582,39.677417),21781=>array(-77.759648,39.571073),21782=>array(-77.762346,39.456811),21783=>array(-77.553549,39.651829),21784=>array(-76.973736,39.401084),21787=>array(-77.172591,39.67763),21788=>array(-77.413861,39.589979),21790=>array(-77.484901,39.260865),21791=>array(-77.188143,39.533255),21793=>array(-77.346614,39.491577),21794=>array(-76.966129,39.298422),21795=>array(-77.823698,39.580608),21797=>array(-77.071411,39.328183),21798=>array(-77.302603,39.536511),21801=>array(-75.639577,38.3823),21802=>array(-75.582696,38.344771),21804=>array(-75.532106,38.314082),21810=>array(-75.711993,38.300747),21811=>array(-75.216741,38.318877),21813=>array(-75.155464,38.424217),21814=>array(-75.897056,38.295829),21817=>array(-75.836073,37.981029),21821=>array(-75.91666,38.164595),21822=>array(-75.636782,38.279782),21824=>array(-76.036546,37.980774),21826=>array(-75.626502,38.316891),21829=>array(-75.371456,38.097659),21830=>array(-75.737946,38.402166),21835=>array(-75.948459,38.531887),21837=>array(-75.766315,38.454572),21838=>array(-75.73792,38.017906),21840=>array(-75.900009,38.248736),21841=>array(-75.295806,38.246944),21842=>array(-75.12888,38.350536),21849=>array(-75.46181,38.377261),21850=>array(-75.397078,38.361731),21851=>array(-75.542418,38.079871),21853=>array(-75.720881,38.203521),21856=>array(-75.794885,38.330729),21861=>array(-75.72734,38.536443),21862=>array(-75.227184,38.398091),21863=>array(-75.399041,38.187913),21864=>array(-75.405558,38.031539),21865=>array(-75.841179,38.287338),21866=>array(-76.021365,37.967128),21867=>array(-75.793678,38.109665),21869=>array(-75.896268,38.438227),21871=>array(-75.735688,38.093785),21872=>array(-75.299133,38.415162),21874=>array(-75.351965,38.391283),21875=>array(-75.544695,38.439999),21890=>array(-75.704343,38.157317),21901=>array(-75.958955,39.585407),21902=>array(-76.063147,39.551971),21903=>array(-76.039062,39.573438),21904=>array(-76.079163,39.623317),21911=>array(-76.035968,39.694668),21912=>array(-75.818633,39.419399),21913=>array(-75.867973,39.404601),21914=>array(-75.978975,39.572896),21915=>array(-75.848164,39.496143),21916=>array(-75.861559,39.641278),21917=>array(-76.097397,39.671632),21918=>array(-76.175874,39.67819),21919=>array(-75.933623,39.416838),21920=>array(-75.828324,39.657497),21921=>array(-75.859891,39.627145),21930=>array(-75.887995,39.375659),22003=>array(-77.215318,38.829817),22015=>array(-77.278973,38.787814),22025=>array(-77.346866,38.592418),22026=>array(-77.296099,38.56085),22027=>array(-77.223065,38.894844),22030=>array(-77.340466,38.837138),22031=>array(-77.258547,38.859531),22032=>array(-77.290301,38.819046),22033=>array(-77.384701,38.875215),22035=>array(-77.357416,38.854496),22039=>array(-77.313969,38.75607),22041=>array(-77.143197,38.844726),22042=>array(-77.197125,38.865024),22043=>array(-77.195909,38.900852),22044=>array(-77.154372,38.862044),22046=>array(-77.180975,38.886334),22060=>array(-77.153084,38.69344),22066=>array(-77.302566,39.012049),22079=>array(-77.209739,38.674606),22101=>array(-77.164899,38.940236),22102=>array(-77.229152,38.949956),22124=>array(-77.332554,38.892997),22125=>array(-77.262219,38.6819),22134=>array(-77.385028,38.521753),22150=>array(-77.186523,38.772863),22151=>array(-77.207804,38.804093),22152=>array(-77.232029,38.774493),22153=>array(-77.23564,38.744969),22172=>array(-77.371479,38.564727),22180=>array(-77.256133,38.895439),22181=>array(-77.293388,38.906651),22182=>array(-77.273172,38.937476),22185=>array(-77.303992,38.874582),22191=>array(-77.262938,38.622914),22192=>array(-77.314673,38.683699),22193=>array(-77.348631,38.643671),22201=>array(-77.09525,38.886566),22202=>array(-77.051484,38.856835),22203=>array(-77.11734,38.873692),22204=>array(-77.098984,38.860785),22205=>array(-77.139524,38.883513),22206=>array(-77.089408,38.843917),22207=>array(-77.124238,38.906665),22209=>array(-77.075463,38.895023),22211=>array(-77.070768,38.880097),22213=>array(-77.162457,38.895203),22214=>array(-77.073946,38.868808),22301=>array(-77.059645,38.819853),22302=>array(-77.083132,38.827888),22303=>array(-77.078837,38.79438),22304=>array(-77.112126,38.81314),22305=>array(-77.06214,38.836508),22306=>array(-77.097783,38.755748),22307=>array(-77.057273,38.771982),22308=>array(-77.058089,38.732729),22309=>array(-77.106668,38.720527),22310=>array(-77.122817,38.784071),22311=>array(-77.125432,38.833608),22312=>array(-77.154271,38.815789),22314=>array(-77.056439,38.80686),22315=>array(-77.151192,38.758337),22401=>array(-77.486658,38.299272),22405=>array(-77.403848,38.313488),22406=>array(-77.544009,38.399244),22407=>array(-77.575684,38.283474),22408=>array(-77.444023,38.21894),22427=>array(-77.271122,38.093146),22432=>array(-76.342347,37.869524),22433=>array(-77.859386,38.367057),22435=>array(-76.5678,37.971751),22436=>array(-77.117264,38.084227),22437=>array(-76.79989,37.780878),22438=>array(-76.980741,38.041022),22443=>array(-76.986786,38.169503),22448=>array(-77.028442,38.336332),22454=>array(-76.833638,37.844086),22460=>array(-76.615132,37.868544),22469=>array(-76.650166,38.081058),22473=>array(-76.420749,37.887476),22476=>array(-77.072949,38.051047),22480=>array(-76.412535,37.662728),22482=>array(-76.346113,37.735631),22485=>array(-77.162702,38.277179),22488=>array(-76.587936,38.049195),22503=>array(-76.513471,37.750398),22504=>array(-76.720678,37.768927),22508=>array(-77.798472,38.313187),22509=>array(-77.079949,38.120518),22511=>array(-76.504028,37.991033),22514=>array(-77.327972,38.005845),22520=>array(-76.806212,38.122285),22529=>array(-76.684016,38.004462),22530=>array(-76.293047,37.897826),22534=>array(-77.672859,38.077579),22535=>array(-77.162837,38.148454),22538=>array(-77.258893,38.204245),22539=>array(-76.286041,37.860634),22542=>array(-77.880863,38.293517),22546=>array(-77.448666,37.942668),22548=>array(-76.704785,37.815803),22551=>array(-77.700023,38.169838),22553=>array(-77.647788,38.272028),22554=>array(-77.376646,38.426764),22556=>array(-77.510944,38.472053),22560=>array(-76.9612,37.916112),22567=>array(-77.928353,38.229702),22572=>array(-76.771068,37.965301),22576=>array(-76.442195,37.679576),22578=>array(-76.356208,37.636761),22579=>array(-76.314938,37.795598),22580=>array(-77.445683,38.109182),22601=>array(-78.173406,39.174468),22602=>array(-78.284807,39.144249),22603=>array(-78.206659,39.277686),22610=>array(-78.279142,38.824656),22611=>array(-77.984613,39.168882),22620=>array(-78.032277,39.068189),22623=>array(-78.140663,38.848927),22624=>array(-78.091841,39.269784),22625=>array(-78.310739,39.372811),22627=>array(-78.144226,38.757455),22630=>array(-78.174878,38.93021),22637=>array(-78.352993,39.256651),22639=>array(-78.019064,38.813779),22640=>array(-78.142119,38.812015),22641=>array(-78.374963,39.085146),22642=>array(-78.011905,38.947146),22643=>array(-77.983339,38.885568),22644=>array(-78.486478,38.949772),22645=>array(-78.27547,39.021862),22646=>array(-78.050929,39.072518),22650=>array(-78.364632,38.765084),22652=>array(-78.429396,38.839587),22654=>array(-78.573422,38.987823),22655=>array(-78.209123,39.067742),22656=>array(-78.089345,39.219255),22657=>array(-78.376112,39.002622),22660=>array(-78.431429,38.944061),22663=>array(-78.110604,39.05474),22664=>array(-78.532453,38.888919),22701=>array(-77.996261,38.438777),22709=>array(-78.213737,38.328731),22711=>array(-78.274975,38.467169),22712=>array(-77.757247,38.564008),22713=>array(-78.118816,38.560716),22714=>array(-77.895419,38.519671),22715=>array(-78.185599,38.410696),22716=>array(-78.104019,38.629259),22718=>array(-77.82746,38.477181),22719=>array(-78.281252,38.534889),22720=>array(-77.641881,38.475948),22722=>array(-78.227068,38.466262),22723=>array(-78.380361,38.334605),22724=>array(-77.893981,38.614645),22726=>array(-77.82066,38.402458),22727=>array(-78.295292,38.407594),22728=>array(-77.675263,38.59662),22729=>array(-78.017758,38.374194),22730=>array(-78.158613,38.375209),22731=>array(-78.257331,38.336564),22732=>array(-78.189884,38.31463),22733=>array(-78.045724,38.333588),22734=>array(-77.794564,38.526185),22735=>array(-78.174258,38.476865),22736=>array(-77.704567,38.398165),22737=>array(-78.015056,38.580508),22738=>array(-78.280931,38.293931),22740=>array(-78.286953,38.64569),22741=>array(-77.868642,38.428949),22742=>array(-77.715072,38.466332),22743=>array(-78.38097,38.539312),22747=>array(-78.165674,38.709056),22749=>array(-78.180235,38.619655),22801=>array(-78.875125,38.403645),22802=>array(-78.863045,38.494488),22807=>array(-78.86787,38.43397),22810=>array(-78.796534,38.827091),22811=>array(-78.991643,38.811609),22812=>array(-79.027107,38.37825),22815=>array(-78.841209,38.712509),22820=>array(-79.019048,38.704836),22821=>array(-79.129968,38.475937),22824=>array(-78.631822,38.836074),22827=>array(-78.596414,38.410719),22830=>array(-78.972242,38.659814),22831=>array(-79.076132,38.576395),22832=>array(-78.759702,38.454916),22834=>array(-78.860046,38.559256),22835=>array(-78.453418,38.670893),22840=>array(-78.716762,38.421369),22841=>array(-78.892489,38.341793),22842=>array(-78.699661,38.778048),22843=>array(-79.147387,38.373406),22844=>array(-78.661655,38.655857),22845=>array(-78.816413,38.786329),22846=>array(-78.790693,38.378772),22847=>array(-78.717385,38.730637),22849=>array(-78.621982,38.525686),22850=>array(-78.924344,38.559677),22851=>array(-78.512907,38.563053),22853=>array(-78.75832,38.650252),22901=>array(-78.556765,38.087663),22902=>array(-78.522359,37.910371),22903=>array(-78.596294,38.006654),22904=>array(-78.524436,38.034803),22911=>array(-78.410109,38.097076),22920=>array(-78.805298,37.96898),22922=>array(-78.921765,37.693701),22923=>array(-78.318434,38.188326),22931=>array(-78.727551,37.898938),22932=>array(-78.696458,38.147507),22935=>array(-78.562701,38.253925),22936=>array(-78.499128,38.159998),22937=>array(-78.613986,37.798273),22938=>array(-78.794527,37.865862),22939=>array(-78.974107,38.105772),22940=>array(-78.556161,38.159742),22942=>array(-78.202164,38.101601),22943=>array(-78.774051,38.035826),22946=>array(-78.571382,37.858585),22947=>array(-78.327642,38.045602),22948=>array(-78.129177,38.363407),22949=>array(-78.879393,37.790016),22952=>array(-78.962741,37.963562),22958=>array(-78.898664,37.899997),22959=>array(-78.656536,37.937226),22960=>array(-78.073339,38.218996),22963=>array(-78.305094,37.848121),22964=>array(-78.97765,37.709424),22967=>array(-79.014082,37.797305),22968=>array(-78.400888,38.240602),22969=>array(-78.693382,37.797482),22971=>array(-78.793177,37.745121),22972=>array(-78.230285,38.215776),22973=>array(-78.479006,38.335921),22974=>array(-78.284439,37.972639),22976=>array(-79.056728,37.81279),22980=>array(-78.880549,38.099858),22989=>array(-78.132082,38.288675),23002=>array(-77.967875,37.35106),23004=>array(-78.399222,37.688882),23005=>array(-77.48187,37.759696),23009=>array(-77.181166,37.820938),23011=>array(-76.810563,37.478311),23015=>array(-77.626447,37.929599),23021=>array(-76.373522,37.389948),23022=>array(-78.263155,37.731004),23023=>array(-76.96245,37.782325),23024=>array(-77.779274,37.927752),23025=>array(-76.36344,37.41483),23027=>array(-78.132234,37.645338),23030=>array(-77.054808,37.34649),23032=>array(-76.668109,37.650965),23035=>array(-76.388232,37.491911),23038=>array(-78.149405,37.752969),23039=>array(-77.812465,37.656565),23040=>array(-78.245636,37.504061),23043=>array(-76.350255,37.563338),23045=>array(-76.268808,37.425348),23047=>array(-77.473917,37.843384),23050=>array(-76.437118,37.498909),23055=>array(-78.221898,37.770451),23056=>array(-76.362611,37.35648),23059=>array(-77.574006,37.702234),23060=>array(-77.537787,37.656174),23061=>array(-76.538653,37.428452),23062=>array(-76.501938,37.257069),23063=>array(-78.00613,37.712553),23064=>array(-76.299432,37.495789),23065=>array(-77.932428,37.805959),23066=>array(-76.283582,37.49706),23068=>array(-76.334658,37.501303),23069=>array(-77.322377,37.771537),23070=>array(-76.388985,37.552199),23071=>array(-76.448576,37.54543),23072=>array(-76.448456,37.292181),23075=>array(-77.31314,37.557876),23076=>array(-76.306854,37.47752),23079=>array(-76.671343,37.730568),23083=>array(-78.120611,37.310449),23084=>array(-78.115077,37.88499),23085=>array(-76.831539,37.713508),23086=>array(-77.055096,37.667222),23089=>array(-76.90468,37.461143),23091=>array(-76.799654,37.655786),23092=>array(-76.513826,37.605859),23093=>array(-78.042113,38.005893),23102=>array(-77.832239,37.706554),23103=>array(-77.72364,37.648034),23106=>array(-77.201511,37.716107),23108=>array(-76.740172,37.646765),23109=>array(-76.332,37.431431),23110=>array(-76.771108,37.58282),23111=>array(-77.24293,37.613502),23112=>array(-77.662862,37.433405),23113=>array(-77.679628,37.538846),23114=>array(-77.659771,37.482226),23115=>array(-76.914535,37.810985),23116=>array(-77.336603,37.675824),23117=>array(-77.874114,37.977478),23119=>array(-76.277178,37.448174),23120=>array(-77.781314,37.422105),23123=>array(-78.301142,37.651834),23124=>array(-77.04218,37.54686),23125=>array(-76.286254,37.324979),23126=>array(-77.144316,37.923461),23128=>array(-76.430688,37.437355),23129=>array(-77.77042,37.68163),23130=>array(-76.259439,37.387286),23138=>array(-76.303706,37.343148),23139=>array(-77.937577,37.545674),23140=>array(-77.038311,37.435013),23141=>array(-77.156144,37.52869),23146=>array(-77.704529,37.73149),23148=>array(-77.05464,37.846428),23149=>array(-76.609283,37.575671),23150=>array(-77.252612,37.501136),23153=>array(-77.947259,37.770805),23156=>array(-76.706618,37.521141),23160=>array(-77.845916,37.628163),23161=>array(-76.935072,37.715866),23163=>array(-76.309595,37.357691),23168=>array(-76.824294,37.395389),23169=>array(-76.458004,37.600481),23173=>array(-77.536969,37.577676),23175=>array(-76.625872,37.654885),23176=>array(-76.414601,37.576384),23177=>array(-77.01447,37.751618),23180=>array(-76.618655,37.701404),23181=>array(-76.888708,37.597555),23185=>array(-76.717042,37.233458),23187=>array(-76.720941,37.268856),23188=>array(-76.769554,37.348905),23192=>array(-77.680814,37.820363),23219=>array(-77.435528,37.539769),23220=>array(-77.460606,37.549349),23221=>array(-77.493558,37.553306),23222=>array(-77.418907,37.582968),23223=>array(-77.378183,37.558305),23224=>array(-77.466135,37.497492),23225=>array(-77.512937,37.518624),23226=>array(-77.523347,37.579912),23227=>array(-77.438188,37.611292),23228=>array(-77.492834,37.626617),23229=>array(-77.574165,37.586772),23230=>array(-77.489411,37.586479),23231=>array(-77.315342,37.441123),23233=>array(-77.624235,37.646431),23234=>array(-77.47066,37.451423),23235=>array(-77.564758,37.51457),23236=>array(-77.585285,37.47581),23237=>array(-77.449054,37.400878),23238=>array(-77.647849,37.59552),23250=>array(-77.320899,37.504783),23294=>array(-77.541852,37.629925),23301=>array(-75.633464,37.681259),23302=>array(-75.520915,37.86567),23303=>array(-75.504972,37.911355),23304=>array(-76.572107,36.996135),23306=>array(-75.872258,37.561215),23307=>array(-75.87135,37.432053),23308=>array(-75.653786,37.836799),23310=>array(-75.963657,37.258993),23313=>array(-75.942244,37.197586),23314=>array(-76.524465,36.958955),23315=>array(-76.840511,36.73739),23316=>array(-75.992901,37.303098),23320=>array(-76.217637,36.751734),23321=>array(-76.420759,36.800209),23322=>array(-76.227045,36.618747),23323=>array(-76.379928,36.696963),23324=>array(-76.273447,36.799721),23325=>array(-76.238429,36.814548),23336=>array(-75.334522,37.954605),23337=>array(-75.486165,37.930674),23347=>array(-75.970712,37.338648),23350=>array(-75.862763,37.512896),23354=>array(-75.908828,37.463334),23356=>array(-75.382404,37.99079),23357=>array(-75.676028,37.755646),23358=>array(-75.862671,37.656619),23359=>array(-75.587982,37.884947),23389=>array(-75.834778,37.660513),23395=>array(-75.461008,37.975963),23398=>array(-75.944072,37.516128),23401=>array(-75.779396,37.627492),23405=>array(-75.922216,37.411565),23407=>array(-75.578774,37.840957),23408=>array(-75.843474,37.452913),23409=>array(-75.662907,37.887621),23410=>array(-75.736904,37.63784),23413=>array(-75.857763,37.472853),23414=>array(-75.579897,37.806814),23415=>array(-75.534703,37.969553),23416=>array(-75.563351,37.933768),23417=>array(-75.783815,37.759052),23418=>array(-75.687163,37.666867),23420=>array(-75.81508,37.584466),23421=>array(-75.611647,37.764621),23422=>array(-75.822735,37.635389),23423=>array(-75.71431,37.525301),23426=>array(-75.689541,37.924102),23427=>array(-75.720538,37.938929),23430=>array(-76.655932,37.001261),23432=>array(-76.553889,36.876314),23433=>array(-76.462863,36.918069),23434=>array(-76.592105,36.703003),23435=>array(-76.484849,36.841457),23436=>array(-76.505145,36.8946),23437=>array(-76.803197,36.627115),23438=>array(-76.696875,36.581413),23440=>array(-75.984124,37.829055),23441=>array(-75.699685,37.710268),23442=>array(-75.575437,37.904756),23451=>array(-76.007229,36.867408),23452=>array(-76.092807,36.845756),23453=>array(-76.071791,36.783651),23454=>array(-76.030783,36.818048),23455=>array(-76.146573,36.891804),23456=>array(-76.035478,36.736543),23457=>array(-76.024143,36.612748),23459=>array(-76.018732,36.924797),23460=>array(-76.028412,36.807977),23461=>array(-75.96325,36.775402),23462=>array(-76.150514,36.837313),23464=>array(-76.18768,36.797023),23480=>array(-75.690711,37.618711),23486=>array(-75.813877,37.51317),23487=>array(-76.725048,36.847368),23488=>array(-75.598466,37.947497),23502=>array(-76.204908,36.860941),23503=>array(-76.266481,36.949097),23504=>array(-76.265612,36.857302),23505=>array(-76.288896,36.913604),23507=>array(-76.303218,36.864564),23508=>array(-76.31027,36.884888),23509=>array(-76.263969,36.882397),23510=>array(-76.291682,36.852122),23511=>array(-76.325805,36.912232),23513=>array(-76.238602,36.889916),23517=>array(-76.29257,36.869679),23518=>array(-76.215375,36.916118),23523=>array(-76.272082,36.832389),23551=>array(-76.288625,36.924048),23601=>array(-76.476632,37.038016),23602=>array(-76.517947,37.113416),23603=>array(-76.564535,37.191057),23604=>array(-76.574793,37.105026),23605=>array(-76.43625,37.018444),23606=>array(-76.519902,37.06435),23607=>array(-76.424372,36.971747),23608=>array(-76.543036,37.147813),23651=>array(-76.304306,37.007817),23661=>array(-76.386177,37.009301),23662=>array(-76.353027,37.133319),23663=>array(-76.314908,37.032442),23664=>array(-76.289825,37.078374),23665=>array(-76.365498,37.084498),23666=>array(-76.406646,37.058141),23669=>array(-76.342873,37.050277),23690=>array(-76.517104,37.222401),23691=>array(-76.549423,37.255252),23692=>array(-76.463582,37.192438),23693=>array(-76.447129,37.123066),23696=>array(-76.42108,37.191585),23701=>array(-76.371059,36.812899),23702=>array(-76.329619,36.798933),23703=>array(-76.373292,36.893339),23704=>array(-76.310161,36.824187),23707=>array(-76.339628,36.842301),23708=>array(-76.305158,36.849529),23709=>array(-76.305458,36.812752),23801=>array(-77.335396,37.235551),23803=>array(-77.497484,37.209159),23805=>array(-77.403475,37.138544),23806=>array(-77.418238,37.238611),23821=>array(-77.911996,36.883676),23824=>array(-77.97218,37.085581),23827=>array(-77.196878,36.612313),23828=>array(-77.278414,36.581562),23829=>array(-77.217351,36.73267),23830=>array(-77.395057,37.016961),23831=>array(-77.450566,37.346253),23832=>array(-77.592091,37.387859),23833=>array(-77.673402,37.207737),23834=>array(-77.404112,37.290584),23836=>array(-77.346743,37.345226),23837=>array(-77.084152,36.749583),23838=>array(-77.633166,37.31921),23839=>array(-76.920618,37.079815),23840=>array(-77.666008,37.065325),23841=>array(-77.543937,37.048042),23842=>array(-77.221949,37.131685),23843=>array(-77.822071,36.846159),23844=>array(-77.326525,36.680032),23845=>array(-77.977561,36.578823),23846=>array(-76.83402,37.066603),23847=>array(-77.550253,36.670258),23850=>array(-77.765253,37.220515),23851=>array(-76.95065,36.655976),23856=>array(-77.702347,36.784009),23857=>array(-77.883799,36.584651),23860=>array(-77.225393,37.272031),23866=>array(-76.862401,36.923676),23867=>array(-77.481624,36.816602),23868=>array(-77.817381,36.722009),23872=>array(-77.718798,36.987994),23874=>array(-77.085713,36.608956),23875=>array(-77.26741,37.219762),23876=>array(-77.83361,36.955753),23878=>array(-77.025551,36.825024),23879=>array(-77.596924,36.592362),23881=>array(-76.978431,37.179903),23882=>array(-77.421687,36.926173),23883=>array(-76.735795,37.13613),23884=>array(-77.279442,36.917234),23885=>array(-77.572659,37.190287),23887=>array(-77.816917,36.573362),23888=>array(-76.975005,36.949634),23889=>array(-77.745861,36.900108),23890=>array(-77.118319,37.009176),23891=>array(-77.212429,37.050821),23893=>array(-77.920776,36.644073),23894=>array(-77.820822,37.122207),23897=>array(-77.283462,36.829095),23898=>array(-76.861405,36.834376),23899=>array(-76.965858,37.233638),23901=>array(-78.421147,37.321096),23909=>array(-78.396639,37.300584),23915=>array(-78.287525,36.693867),23917=>array(-78.344856,36.625554),23919=>array(-78.132614,36.594671),23920=>array(-77.975253,36.724517),23921=>array(-78.623542,37.586332),23922=>array(-78.216409,37.185508),23923=>array(-78.649776,37.087129),23924=>array(-78.428438,36.807989),23927=>array(-78.564584,36.587497),23930=>array(-78.099611,37.171003),23934=>array(-78.626705,37.177152),23936=>array(-78.476759,37.534064),23937=>array(-78.512503,36.945141),23938=>array(-77.992026,36.905314),23942=>array(-78.289196,37.134366),23943=>array(-78.453666,37.245545),23944=>array(-78.138337,36.915054),23947=>array(-78.444709,37.031092),23950=>array(-78.075746,36.658969),23952=>array(-78.291851,36.92994),23954=>array(-78.378902,37.104953),23958=>array(-78.659633,37.264893),23959=>array(-78.794749,37.105192),23960=>array(-78.560952,37.31367),23962=>array(-78.73934,37.00466),23963=>array(-78.798347,37.201059),23964=>array(-78.627089,36.772427),23966=>array(-78.270718,37.293852),23967=>array(-78.636592,36.913121),23968=>array(-78.528509,36.725263),23970=>array(-78.190761,36.750501),23974=>array(-78.255276,36.970455),23976=>array(-78.585307,36.844428),24011=>array(-79.94149,37.27085),24012=>array(-79.900364,37.308387),24013=>array(-79.923095,37.266503),24014=>array(-79.914401,37.221656),24015=>array(-79.98133,37.25676),24016=>array(-79.954687,37.273437),24017=>array(-79.990966,37.297647),24018=>array(-80.041192,37.212776),24019=>array(-79.95358,37.346523),24020=>array(-79.944179,37.358216),24053=>array(-80.534079,36.607233),24054=>array(-79.704095,36.673945),24055=>array(-79.997554,36.756169),24058=>array(-80.622252,37.176663),24059=>array(-80.130437,37.163765),24060=>array(-80.421951,37.256076),24064=>array(-79.770367,37.37602),24065=>array(-79.997517,37.117253),24066=>array(-79.681003,37.537053),24067=>array(-80.060926,37.031669),24069=>array(-79.640539,36.577818),24070=>array(-80.225842,37.356219),24072=>array(-80.242363,37.041976),24073=>array(-80.424902,37.13245),24076=>array(-80.421039,36.605192),24077=>array(-79.904022,37.366211),24078=>array(-79.900228,36.720605),24079=>array(-80.160939,37.056632),24082=>array(-80.112085,36.621469),24083=>array(-79.920188,37.405171),24084=>array(-80.845746,37.12795),24085=>array(-79.821548,37.679371),24086=>array(-80.632246,37.27558),24087=>array(-80.256774,37.214011),24088=>array(-80.077927,36.887904),24089=>array(-79.971555,36.708518),24090=>array(-79.886553,37.521699),24091=>array(-80.329625,36.920279),24092=>array(-79.757851,37.012031),24093=>array(-80.868752,37.385177),24095=>array(-79.737268,37.22321),24101=>array(-79.798982,37.172272),24102=>array(-79.998307,36.837285),24104=>array(-79.489959,37.133049),24105=>array(-80.603685,36.911559),24112=>array(-79.849362,36.721554),24120=>array(-80.413917,36.691636),24121=>array(-79.647209,37.168883),24122=>array(-79.69213,37.426197),24124=>array(-80.854494,37.311202),24127=>array(-80.231734,37.473129),24128=>array(-80.482544,37.339994),24130=>array(-80.002393,37.609758),24131=>array(-80.232729,37.57031),24132=>array(-80.659249,37.203787),24133=>array(-80.134421,36.669705),24134=>array(-80.777559,37.247923),24136=>array(-80.601589,37.331845),24137=>array(-79.653317,36.927763),24138=>array(-80.306411,37.042837),24139=>array(-79.481073,37.013166),24141=>array(-80.568655,37.096142),24142=>array(-80.550906,37.137882),24147=>array(-80.823621,37.401494),24148=>array(-79.877967,36.579801),24149=>array(-80.429177,37.021646),24150=>array(-80.602628,37.406601),24151=>array(-79.8652,36.954022),24153=>array(-80.114711,37.30244),24161=>array(-79.529113,36.978085),24162=>array(-80.249698,37.129445),24165=>array(-80.051921,36.584884),24167=>array(-80.724536,37.255259),24168=>array(-79.946456,36.734753),24171=>array(-80.239037,36.671941),24174=>array(-79.673095,37.351716),24175=>array(-79.939737,37.427955),24176=>array(-79.691834,37.005934),24179=>array(-79.810524,37.295038),24184=>array(-79.779648,37.0903),24185=>array(-80.269238,36.811592),24201=>array(-82.17005,36.610715),24202=>array(-82.212219,36.65631),24210=>array(-82.027987,36.768883),24211=>array(-81.95507,36.654088),24216=>array(-82.799411,36.948295),24217=>array(-82.178539,37.084846),24219=>array(-82.758491,36.849443),24220=>array(-82.244318,37.143884),24221=>array(-82.999148,36.625334),24224=>array(-82.271754,36.861431),24225=>array(-82.142704,36.99191),24226=>array(-82.320373,37.140423),24228=>array(-82.456473,37.167087),24230=>array(-82.453973,36.956554),24236=>array(-81.74648,36.652534),24237=>array(-82.261943,37.036159),24239=>array(-82.148525,37.117682),24243=>array(-82.926022,36.773101),24244=>array(-82.782264,36.723769),24245=>array(-82.512802,36.838011),24246=>array(-82.745551,36.865811),24248=>array(-83.514584,36.625358),24250=>array(-82.596526,36.756733),24251=>array(-82.606159,36.655848),24256=>array(-82.286792,37.21631),24258=>array(-82.422038,36.645372),24260=>array(-82.014818,37.030725),24263=>array(-83.147399,36.668226),24265=>array(-82.945802,36.831887),24266=>array(-82.120986,36.858753),24269=>array(-82.380683,37.072765),24270=>array(-82.250652,36.72964),24271=>array(-82.41642,36.749134),24272=>array(-82.314775,37.013892),24273=>array(-82.661557,36.964719),24277=>array(-83.03843,36.744789),24279=>array(-82.627486,37.077709),24280=>array(-81.923315,36.956077),24281=>array(-83.340226,36.637323),24282=>array(-83.054647,36.818659),24283=>array(-82.34933,36.945645),24290=>array(-82.56794,36.612701),24292=>array(-81.578136,36.617691),24293=>array(-82.550699,37.004098),24301=>array(-80.810743,37.06771),24311=>array(-81.422017,36.87419),24312=>array(-80.887055,36.832976),24313=>array(-80.820003,36.909891),24314=>array(-81.228407,37.147842),24315=>array(-81.074077,37.130839),24316=>array(-81.668988,36.955705),24317=>array(-80.671347,36.601166),24318=>array(-81.387124,36.995958),24319=>array(-81.654976,36.745188),24322=>array(-81.113703,36.798845),24323=>array(-81.185373,36.866475),24324=>array(-80.776884,36.974312),24325=>array(-80.591555,36.801832),24326=>array(-81.202199,36.729845),24328=>array(-80.700836,36.645356),24330=>array(-81.020688,36.725798),24333=>array(-80.934776,36.639975),24340=>array(-81.767899,36.753256),24343=>array(-80.690913,36.770411),24347=>array(-80.652471,36.960871),24348=>array(-81.199058,36.641574),24350=>array(-80.994235,36.813309),24351=>array(-80.765127,36.579431),24352=>array(-80.531193,36.709011),24354=>array(-81.53971,36.829354),24360=>array(-80.896896,36.932895),24361=>array(-81.845258,36.767265),24363=>array(-81.405157,36.61664),24366=>array(-81.118583,37.259482),24368=>array(-81.302492,36.888029),24370=>array(-81.689777,36.911469),24374=>array(-81.210166,36.792191),24375=>array(-81.387771,36.768931),24377=>array(-81.574148,37.000304),24378=>array(-81.443367,36.686691),24380=>array(-80.508764,36.859701),24381=>array(-80.840655,36.729989),24382=>array(-81.101367,36.960016),24401=>array(-79.085514,38.134404),24411=>array(-79.311238,38.105128),24412=>array(-79.815938,38.053837),24413=>array(-79.598066,38.54351),24415=>array(-79.317053,37.925),24416=>array(-79.360864,37.722497),24421=>array(-79.245218,38.244788),24422=>array(-79.758834,37.830403),24426=>array(-80.084876,37.763523),24430=>array(-79.355774,38.086984),24431=>array(-78.842838,38.170011),24432=>array(-79.443356,38.148002),24433=>array(-79.424235,38.423418),24435=>array(-79.301938,37.87264),24437=>array(-78.935476,38.220807),24439=>array(-79.489306,37.993806),24440=>array(-79.165436,37.99925),24441=>array(-78.824873,38.226067),24442=>array(-79.384583,38.372539),24445=>array(-79.891931,37.942225),24448=>array(-79.788524,37.79711),24450=>array(-79.526578,37.778993),24457=>array(-79.941307,37.764571),24458=>array(-79.527755,38.316163),24459=>array(-79.29232,38.020842),24460=>array(-79.656459,38.01988),24464=>array(-79.093913,37.874933),24465=>array(-79.647758,38.384565),24467=>array(-78.971321,38.254985),24471=>array(-78.78418,38.31321),24472=>array(-79.208109,37.941329),24473=>array(-79.415376,37.934734),24474=>array(-79.84553,37.805612),24476=>array(-79.227293,37.974534),24477=>array(-79.042239,38.004877),24479=>array(-79.239044,38.163944),24482=>array(-78.996676,38.205935),24483=>array(-79.230553,37.812333),24484=>array(-79.784108,38.160557),24485=>array(-79.333024,38.267603),24486=>array(-78.924533,38.296885),24487=>array(-79.583031,38.193369),24501=>array(-79.141653,37.359607),24502=>array(-79.221579,37.360401),24503=>array(-79.249736,37.454015),24504=>array(-79.048192,37.365249),24517=>array(-79.237168,37.147576),24520=>array(-79.032394,36.592461),24521=>array(-79.100875,37.632622),24522=>array(-78.778792,37.376805),24523=>array(-79.523894,37.344789),24526=>array(-79.406786,37.543655),24527=>array(-79.341721,36.736768),24528=>array(-78.876229,37.079686),24529=>array(-78.646754,36.626619),24530=>array(-79.619231,36.806773),24531=>array(-79.453378,36.842264),24534=>array(-78.770507,36.867403),24536=>array(-79.326532,37.495689),24538=>array(-78.962285,37.345256),24539=>array(-78.914535,36.854591),24540=>array(-79.426751,36.634506),24541=>array(-79.5151,36.588822),24549=>array(-79.505199,36.713997),24550=>array(-79.246429,37.239462),24551=>array(-79.324396,37.356335),24553=>array(-78.812796,37.54843),24554=>array(-79.069868,37.134836),24555=>array(-79.484088,37.669829),24556=>array(-79.398561,37.374818),24557=>array(-79.306424,36.969859),24558=>array(-78.953963,36.774341),24562=>array(-78.627533,37.694481),24563=>array(-79.279115,37.0625),24565=>array(-79.200674,36.848582),24566=>array(-79.252639,36.731828),24569=>array(-79.125819,37.042584),24570=>array(-79.424457,37.34646),24571=>array(-79.372748,37.132961),24572=>array(-79.095098,37.464935),24574=>array(-79.253367,37.57615),24577=>array(-78.982643,36.937349),24578=>array(-79.562257,37.659883),24579=>array(-79.502698,37.585803),24580=>array(-78.673121,36.579054),24581=>array(-78.805801,37.655293),24586=>array(-79.276609,36.607044),24588=>array(-79.096232,37.262151),24589=>array(-78.758047,36.760808),24590=>array(-78.490289,37.796421),24592=>array(-78.965555,36.675795),24593=>array(-78.902729,37.32249),24594=>array(-79.178528,36.646843),24595=>array(-79.082106,37.559759),24597=>array(-79.109496,36.782508),24598=>array(-78.788004,36.60467),24599=>array(-78.723891,37.62356),24601=>array(-81.649243,37.193732),24602=>array(-81.65851,37.183213),24603=>array(-82.197201,37.353341),24604=>array(-81.538085,37.211983),24605=>array(-81.371368,37.253367),24606=>array(-81.392098,37.282935),24607=>array(-82.262524,37.293533),24609=>array(-81.808041,37.009747),24612=>array(-81.838141,37.09335),24613=>array(-81.336881,37.265157),24614=>array(-82.071085,37.298652),24620=>array(-82.011712,37.431325),24622=>array(-81.789498,37.214782),24628=>array(-82.222958,37.282358),24630=>array(-81.465545,37.178327),24631=>array(-81.990489,37.217306),24634=>array(-81.887992,37.276808),24635=>array(-81.362984,37.312452),24637=>array(-81.713894,37.061082),24639=>array(-81.888205,37.160378),24641=>array(-81.802451,37.111816),24646=>array(-82.024538,37.143396),24649=>array(-81.899934,37.062876),24651=>array(-81.503095,37.075529),24656=>array(-82.124994,37.175055),24657=>array(-81.854783,37.225846),24701=>array(-81.204941,37.305951),24712=>array(-81.01501,37.463059),24714=>array(-81.18918,37.47811),24715=>array(-81.324613,37.340389),24716=>array(-81.371928,37.480093),24719=>array(-81.326725,37.487167),24724=>array(-81.299757,37.330881),24726=>array(-81.352074,37.514751),24729=>array(-81.25746,37.453953),24731=>array(-81.151064,37.397966),24733=>array(-81.205194,37.450768),24736=>array(-81.277515,37.444268),24737=>array(-81.250681,37.352758),24738=>array(-81.3097,37.302041),24740=>array(-81.004649,37.373761),24747=>array(-81.309037,37.381781),24801=>array(-81.576989,37.448883),24808=>array(-81.422403,37.330026),24811=>array(-81.771063,37.399018),24813=>array(-81.720113,37.357412),24815=>array(-81.659603,37.241667),24816=>array(-81.705939,37.461102),24817=>array(-81.804746,37.352309),24818=>array(-81.624946,37.602702),24822=>array(-81.697225,37.647905),24823=>array(-81.751954,37.671967),24826=>array(-81.623582,37.293265),24827=>array(-81.647584,37.735449),24828=>array(-81.636642,37.498914),24830=>array(-81.50611,37.323123),24831=>array(-81.411535,37.39412),24834=>array(-81.630543,37.547724),24836=>array(-81.558641,37.3339),24839=>array(-81.738387,37.560677),24843=>array(-81.710108,37.487153),24844=>array(-81.806627,37.462452),24845=>array(-81.817841,37.517953),24846=>array(-81.91286,37.529522),24847=>array(-81.418416,37.577109),24848=>array(-81.460613,37.303989),24849=>array(-81.542718,37.665758),24850=>array(-81.845423,37.317648),24851=>array(-81.833685,37.601371),24853=>array(-81.511682,37.435447),24854=>array(-81.555949,37.753683),24857=>array(-81.660302,37.67251),24860=>array(-81.60761,37.660167),24861=>array(-81.36313,37.350951),24862=>array(-81.964573,37.469181),24866=>array(-81.580323,37.248133),24867=>array(-81.444454,37.596266),24868=>array(-81.390965,37.43885),24869=>array(-81.838125,37.562659),24870=>array(-81.510367,37.765391),24871=>array(-81.468304,37.359301),24872=>array(-81.920471,37.449363),24873=>array(-81.878193,37.366148),24874=>array(-81.525653,37.560551),24878=>array(-81.620904,37.435435),24879=>array(-81.758686,37.313896),24880=>array(-81.530536,37.651474),24881=>array(-81.684589,37.431391),24882=>array(-81.766003,37.625601),24884=>array(-81.605572,37.233269),24887=>array(-81.404173,37.373345),24888=>array(-81.483288,37.392785),24892=>array(-81.687785,37.32694),24894=>array(-81.713671,37.274965),24898=>array(-81.610269,37.593824),24901=>array(-80.451746,37.855704),24910=>array(-80.656318,37.745946),24915=>array(-79.777605,38.465669),24916=>array(-80.581103,37.828565),24918=>array(-80.742662,37.521102),24920=>array(-79.704212,38.580079),24924=>array(-80.165546,38.201776),24925=>array(-80.376437,37.714707),24927=>array(-79.957193,38.375261),24931=>array(-80.588601,37.919011),24934=>array(-79.891016,38.333579),24935=>array(-80.808493,37.56653),24938=>array(-80.38719,37.893488),24941=>array(-80.346462,37.588268),24944=>array(-79.783657,38.389627),24945=>array(-80.677193,37.541978),24946=>array(-80.262312,38.18442),24951=>array(-80.643607,37.484272),24954=>array(-80.056049,38.224907),24957=>array(-80.425302,37.885119),24962=>array(-80.718342,37.662419),24963=>array(-80.758163,37.436416),24966=>array(-80.362136,38.077719),24970=>array(-80.474498,37.728085),24974=>array(-80.44932,37.64006),24976=>array(-80.511713,37.65697),24977=>array(-80.687105,37.897155),24981=>array(-80.737044,37.630403),24983=>array(-80.518586,37.57499),24984=>array(-80.40502,37.49353),24986=>array(-80.145636,37.920943),24991=>array(-80.497446,38.021608),25002=>array(-81.24173,38.135764),25003=>array(-81.784831,38.252347),25005=>array(-81.256426,38.583444),25007=>array(-81.430458,37.82484),25008=>array(-81.343967,37.947065),25009=>array(-81.684447,38.202364),25011=>array(-81.839417,38.508579),25015=>array(-81.497256,38.246135),25019=>array(-81.068876,38.371626),25021=>array(-81.680502,37.92198),25022=>array(-81.81904,37.860342),25024=>array(-81.62374,38.159091),25025=>array(-81.411336,38.314657),25028=>array(-81.725572,37.947147),25030=>array(-81.225847,38.453317),25031=>array(-81.275148,38.148617),25033=>array(-81.924382,38.612061),25035=>array(-81.521007,38.165242),25036=>array(-81.259152,38.21369),25039=>array(-81.363249,38.234955),25040=>array(-81.235109,38.126501),25043=>array(-81.006644,38.424883),25044=>array(-81.368705,37.911676),25045=>array(-81.331794,38.457263),25047=>array(-81.767625,37.920527),25048=>array(-81.437333,37.945828),25049=>array(-81.558223,38.11529),25051=>array(-81.709791,38.156947),25053=>array(-81.878882,38.036791),25054=>array(-81.488643,38.107389),25057=>array(-81.253436,38.120375),25059=>array(-81.208855,38.23494),25060=>array(-81.427325,37.94454),25061=>array(-81.436542,38.165182),25062=>array(-81.432653,37.880313),25063=>array(-80.930807,38.574617),25064=>array(-81.74846,38.377251),25067=>array(-81.442911,38.201537),25070=>array(-81.931687,38.545843),25071=>array(-81.468452,38.473561),25075=>array(-81.40517,38.059716),25076=>array(-81.931094,37.86875),25081=>array(-81.754659,38.075052),25082=>array(-82.031043,38.604207),25083=>array(-81.367758,38.069889),25085=>array(-81.205401,38.172681),25086=>array(-81.41735,38.203982),25088=>array(-81.216286,38.390103),25090=>array(-81.221003,38.155129),25093=>array(-81.669509,37.983077),25102=>array(-81.374818,38.191015),25103=>array(-81.38115,38.180779),25106=>array(-82.083966,38.788913),25107=>array(-81.621639,38.229746),25108=>array(-81.881159,37.973603),25109=>array(-81.851908,38.526763),25110=>array(-81.314979,38.21843),25111=>array(-81.128837,38.352883),25112=>array(-81.767141,38.380263),25113=>array(-81.04575,38.553543),25114=>array(-81.786334,37.987328),25115=>array(-81.182251,38.122192),25118=>array(-81.305965,38.11166),25119=>array(-81.27626,38.041387),25121=>array(-81.897277,37.916211),25123=>array(-81.900044,38.730175),25124=>array(-81.778935,38.62249),25125=>array(-81.206095,38.315316),25126=>array(-81.372605,38.203247),25130=>array(-81.752254,38.033022),25132=>array(-81.344305,38.293784),25133=>array(-81.14507,38.477099),25134=>array(-81.490597,38.162811),25136=>array(-81.327319,38.150173),25139=>array(-81.291458,38.137583),25140=>array(-81.498507,37.839918),25141=>array(-81.025297,38.626822),25142=>array(-81.729882,38.153554),25143=>array(-81.822335,38.418739),25148=>array(-81.561724,38.045592),25149=>array(-81.758598,37.944536),25152=>array(-81.248356,38.059904),25154=>array(-81.707413,38.12156),25156=>array(-81.336855,38.183259),25159=>array(-81.788635,38.523467),25160=>array(-81.272589,38.282184),25161=>array(-81.318687,38.052718),25162=>array(-81.387342,38.207558),25164=>array(-81.2078,38.498552),25165=>array(-81.649431,38.146029),25168=>array(-81.87985,38.560349),25169=>array(-81.78984,38.175825),25173=>array(-81.229776,38.091155),25174=>array(-81.410965,37.865665),25177=>array(-81.848331,38.367284),25180=>array(-81.436523,37.790226),25181=>array(-81.6412,38.04929),25183=>array(-81.801751,37.926266),25185=>array(-81.238016,38.235187),25186=>array(-81.271384,38.187353),25187=>array(-82.025382,38.72223),25193=>array(-81.507099,38.03546),25201=>array(-81.490465,38.335613),25202=>array(-81.859088,38.316375),25203=>array(-81.882308,38.015993),25204=>array(-81.61456,37.925321),25205=>array(-81.793006,38.019487),25206=>array(-81.697022,37.994524),25208=>array(-81.634038,37.849324),25209=>array(-81.519903,37.952993),25211=>array(-80.888472,38.468707),25213=>array(-81.913305,38.512666),25214=>array(-81.538235,38.187702),25234=>array(-81.138257,38.811456),25235=>array(-81.089455,38.669541),25239=>array(-81.846681,38.83866),25241=>array(-81.810031,38.787975),25243=>array(-81.479468,38.686717),25244=>array(-81.550872,38.767566),25245=>array(-81.755385,38.69742),25247=>array(-82.005535,39.006264),25248=>array(-81.619887,38.640588),25251=>array(-81.236323,38.620525),25252=>array(-81.511177,38.950961),25253=>array(-81.96149,38.921064),25259=>array(-81.251761,38.673526),25260=>array(-82.031908,39.003812),25261=>array(-81.080487,38.821662),25262=>array(-81.826041,38.907802),25264=>array(-81.893892,38.859916),25265=>array(-81.958043,38.986711),25266=>array(-81.162323,38.605981),25267=>array(-80.940896,38.833597),25268=>array(-81.076324,38.725109),25270=>array(-81.428712,38.854429),25271=>array(-81.685743,38.786153),25275=>array(-81.610584,38.921509),25276=>array(-81.328784,38.781913),25285=>array(-81.10154,38.539646),25286=>array(-81.407985,38.615199),25287=>array(-82.051426,38.954715),25301=>array(-81.630359,38.350719),25302=>array(-81.59547,38.393184),25303=>array(-81.68613,38.359561),25304=>array(-81.593204,38.306034),25305=>array(-81.612742,38.337629),25306=>array(-81.499405,38.312518),25309=>array(-81.749531,38.308648),25311=>array(-81.557024,38.366857),25312=>array(-81.659337,38.448407),25313=>array(-81.757545,38.422404),25314=>array(-81.640231,38.308045),25315=>array(-81.560333,38.222275),25320=>array(-81.63318,38.539853),25401=>array(-77.972754,39.456903),25403=>array(-78.011639,39.47485),25404=>array(-77.890325,39.483025),25405=>array(-77.961532,39.409179),25411=>array(-78.22147,39.548748),25413=>array(-78.055948,39.310588),25414=>array(-77.866234,39.242438),25419=>array(-77.895405,39.575953),25420=>array(-78.115041,39.381565),25422=>array(-78.354289,39.544988),25425=>array(-77.770147,39.307386),25427=>array(-78.085289,39.520704),25428=>array(-78.02221,39.380635),25430=>array(-77.939311,39.340972),25431=>array(-78.571804,39.487274),25432=>array(-77.78429,39.305755),25434=>array(-78.44857,39.454503),25437=>array(-78.570489,39.427797),25438=>array(-77.863135,39.318363),25442=>array(-77.83259,39.370206),25443=>array(-77.814724,39.435389),25444=>array(-78.523889,39.412854),25446=>array(-77.953418,39.241562),25501=>array(-81.969643,38.153886),25502=>array(-82.117158,38.656399),25503=>array(-82.120957,38.612591),25504=>array(-82.268103,38.377182),25505=>array(-82.031411,38.012336),25506=>array(-82.18702,38.20472),25507=>array(-82.563009,38.395279),25508=>array(-82.021985,37.964118),25510=>array(-82.082925,38.382297),25511=>array(-82.335065,38.051116),25512=>array(-82.327278,38.184728),25514=>array(-82.528669,38.10029),25515=>array(-82.14686,38.756595),25517=>array(-82.443166,38.108275),25520=>array(-82.182864,38.561148),25521=>array(-81.999378,38.219782),25523=>array(-82.049129,38.278741),25524=>array(-82.117505,38.021447),25526=>array(-81.991274,38.394397),25529=>array(-81.846879,38.152577),25530=>array(-82.576287,38.35838),25534=>array(-82.274991,38.084336),25535=>array(-82.434831,38.308576),25537=>array(-82.281971,38.533383),25540=>array(-82.156474,38.182605),25541=>array(-82.129153,38.478647),25545=>array(-82.217439,38.458992),25547=>array(-81.965478,37.916034),25550=>array(-82.071149,38.86537),25555=>array(-82.549929,38.213946),25557=>array(-82.171951,38.105832),25559=>array(-82.229426,38.325152),25560=>array(-81.897836,38.445477),25564=>array(-81.901029,38.272119),25565=>array(-81.964488,38.102343),25567=>array(-81.870029,38.21598),25570=>array(-82.425254,38.218908),25571=>array(-82.155826,38.313063),25573=>array(-81.942479,38.232038),25601=>array(-82.009289,37.862785),25606=>array(-81.819761,37.765011),25607=>array(-81.78411,37.784925),25608=>array(-81.889362,37.574102),25611=>array(-81.853229,37.69056),25617=>array(-81.77825,37.721068),25621=>array(-81.941894,37.626952),25624=>array(-81.981631,37.900678),25625=>array(-82.081279,37.819353),25628=>array(-81.862489,37.768193),25630=>array(-81.680696,37.790345),25632=>array(-81.923925,37.729913),25634=>array(-81.84059,37.735864),25635=>array(-81.885984,37.707105),25637=>array(-82.029476,37.861769),25638=>array(-81.990581,37.758844),25639=>array(-81.958345,37.881353),25644=>array(-82.030507,37.715308),25646=>array(-81.883997,37.847292),25647=>array(-81.984419,37.786805),25649=>array(-82.093093,37.875432),25650=>array(-81.819109,37.670367),25651=>array(-81.986941,37.602972),25652=>array(-82.045124,37.790733),25653=>array(-81.998297,37.828964),25654=>array(-81.874067,37.795758),25661=>array(-82.273926,37.736166),25666=>array(-82.248854,37.926751),25669=>array(-82.391502,37.932136),25670=>array(-82.158993,37.721151),25671=>array(-82.191926,37.883864),25672=>array(-82.113087,37.581336),25674=>array(-82.351577,37.868833),25676=>array(-82.194528,37.837064),25678=>array(-82.065234,37.590304),25688=>array(-82.119118,37.621295),25690=>array(-82.124445,37.68978),25692=>array(-82.109744,37.636278),25696=>array(-82.115919,37.679044),25699=>array(-82.33255,37.961653),25701=>array(-82.40525,38.365689),25702=>array(-82.314467,38.434637),25703=>array(-82.418349,38.424103),25704=>array(-82.487372,38.307571),25705=>array(-82.360178,38.404576),25801=>array(-81.265887,37.822695),25810=>array(-81.349299,37.596659),25811=>array(-81.291608,37.558776),25812=>array(-81.122676,38.181993),25813=>array(-81.10186,37.76185),25817=>array(-81.397479,37.758427),25818=>array(-81.191991,37.860275),25820=>array(-81.163015,37.51171),25823=>array(-81.208062,37.660654),25825=>array(-81.083912,37.644069),25826=>array(-81.35819,37.576034),25827=>array(-81.252549,37.739104),25831=>array(-80.930792,37.959313),25832=>array(-81.11898,37.715225),25836=>array(-81.278687,37.774944),25837=>array(-81.010679,38.052767),25839=>array(-81.386631,37.777777),25840=>array(-81.124702,38.043167),25841=>array(-81.093014,37.556241),25843=>array(-81.118224,37.610325),25844=>array(-81.385805,37.806236),25845=>array(-81.525185,37.695336),25846=>array(-81.1319,37.900972),25848=>array(-81.428283,37.718151),25849=>array(-81.279993,37.730117),25853=>array(-81.312103,37.640411),25854=>array(-80.979861,38.136747),25855=>array(-81.156453,37.93681),25857=>array(-81.281591,37.644269),25862=>array(-81.061427,38.085516),25864=>array(-81.036063,37.876046),25865=>array(-81.363019,37.711545),25868=>array(-80.966134,38.071925),25870=>array(-81.389341,37.630167),25871=>array(-81.210442,37.769825),25873=>array(-81.213823,37.750066),25875=>array(-81.460797,37.679115),25876=>array(-81.449139,37.631101),25878=>array(-81.229778,37.715436),25879=>array(-81.105957,37.983155),25880=>array(-81.207573,37.878948),25882=>array(-81.393396,37.632143),25901=>array(-81.11705,37.950702),25902=>array(-81.21743,37.569831),25904=>array(-81.283508,37.928295),25906=>array(-81.114415,37.836873),25907=>array(-81.086212,37.856017),25908=>array(-81.247167,37.67532),25911=>array(-81.16713,37.758075),25913=>array(-81.489465,37.714061),25915=>array(-81.291226,37.590135),25916=>array(-81.498056,37.675614),25917=>array(-81.21845,37.991116),25918=>array(-80.996992,37.751991),25920=>array(-81.333946,37.688993),25921=>array(-81.314129,37.672265),25922=>array(-81.105042,37.465967),25928=>array(-81.332526,37.558117),25932=>array(-81.299605,37.75226),25936=>array(-81.039103,37.923452),25938=>array(-81.046855,38.15307),25942=>array(-80.982514,38.01592),25951=>array(-80.866432,37.662049),25958=>array(-80.75001,38.022833),25962=>array(-80.808752,37.98332),25969=>array(-81.001928,37.617988),25971=>array(-80.977447,37.477422),25972=>array(-80.746123,38.035706),25976=>array(-80.845059,37.849538),25977=>array(-80.903302,37.798478),25978=>array(-80.945014,37.620672),25979=>array(-80.913482,37.510942),25981=>array(-80.711083,38.097057),25984=>array(-80.597366,38.029233),25985=>array(-80.813137,37.7806),25989=>array(-81.069851,37.680938),26003=>array(-80.645756,40.069718),26030=>array(-80.656282,40.220204),26031=>array(-80.729265,40.009395),26032=>array(-80.540472,40.192522),26033=>array(-80.578052,39.830278),26034=>array(-80.552334,40.598473),26035=>array(-80.553545,40.34493),26036=>array(-80.546742,39.983046),26037=>array(-80.584518,40.335562),26038=>array(-80.724103,39.964591),26039=>array(-80.674066,39.799369),26040=>array(-80.715944,39.988572),26041=>array(-80.705474,39.887229),26047=>array(-80.589222,40.520184),26050=>array(-80.607637,40.607741),26055=>array(-80.782572,39.7543),26056=>array(-80.577127,40.531275),26059=>array(-80.604824,40.057391),26060=>array(-80.556795,40.108313),26062=>array(-80.56068,40.426703),26070=>array(-80.585563,40.256898),26074=>array(-80.591103,40.15546),26075=>array(-80.668044,40.193433),26101=>array(-81.575872,39.240324),26104=>array(-81.480363,39.276141),26105=>array(-81.514622,39.329575),26133=>array(-81.672414,39.123282),26134=>array(-81.290434,39.368717),26136=>array(-81.140697,38.961575),26137=>array(-81.049373,38.995599),26138=>array(-81.206015,39.023425),26141=>array(-81.24588,38.933552),26142=>array(-81.44774,39.20617),26143=>array(-81.372678,39.056426),26146=>array(-81.036844,39.457065),26147=>array(-81.07539,38.904543),26148=>array(-81.182637,39.060098),26149=>array(-80.825642,39.483305),26150=>array(-81.535898,39.157283),26151=>array(-81.172577,38.879558),26152=>array(-81.195907,39.010062),26155=>array(-80.763963,39.630056),26159=>array(-80.928812,39.600493),26160=>array(-81.412057,38.981202),26161=>array(-81.254683,39.176689),26164=>array(-81.701211,39.010704),26167=>array(-80.743385,39.538939),26169=>array(-81.57159,39.072207),26170=>array(-81.171268,39.358134),26175=>array(-80.974745,39.537188),26178=>array(-81.038103,39.058252),26180=>array(-81.366571,39.19501),26181=>array(-81.666373,39.210705),26184=>array(-81.35272,39.294993),26187=>array(-81.447125,39.37325),26201=>array(-80.199199,39.003136),26202=>array(-80.639652,38.215347),26203=>array(-80.587756,38.548465),26205=>array(-80.650399,38.326803),26206=>array(-80.522355,38.43744),26208=>array(-80.505406,38.323423),26209=>array(-79.988943,38.428758),26215=>array(-80.374966,38.707125),26217=>array(-80.445436,38.614266),26218=>array(-80.266223,38.844938),26222=>array(-80.366012,38.658384),26224=>array(-80.182939,38.74031),26228=>array(-80.370949,38.754405),26230=>array(-80.175635,38.671841),26234=>array(-80.31511,38.773784),26236=>array(-80.234661,38.744665),26237=>array(-80.15068,38.845411),26238=>array(-80.173971,39.108642),26241=>array(-79.791319,38.929499),26250=>array(-79.962538,39.033465),26253=>array(-79.867783,38.781087),26254=>array(-79.662794,38.880658),26257=>array(-80.003647,38.91917),26259=>array(-79.896058,38.802897),26260=>array(-79.424054,39.08233),26261=>array(-80.544967,38.202669),26263=>array(-79.437597,38.94891),26264=>array(-79.827132,38.575718),26266=>array(-80.476414,38.411676),26267=>array(-80.091877,38.947718),26268=>array(-79.738897,38.748961),26269=>array(-79.620053,39.10561),26270=>array(-79.578017,38.863204),26271=>array(-79.558859,39.034668),26273=>array(-79.967506,38.624955),26275=>array(-79.951043,38.976177),26276=>array(-79.772894,39.025525),26278=>array(-80.030528,38.825391),26280=>array(-80.029516,38.729613),26282=>array(-80.16247,38.521675),26283=>array(-79.81258,39.062858),26285=>array(-79.937516,38.912935),26287=>array(-79.688696,39.166658),26288=>array(-80.346995,38.512693),26291=>array(-80.154407,38.394596),26292=>array(-79.533672,39.141915),26293=>array(-79.93579,38.782444),26294=>array(-80.034309,38.531451),26296=>array(-79.55356,38.76446),26298=>array(-80.253444,38.471041),26301=>array(-80.393977,39.301498),26320=>array(-80.81235,39.404013),26321=>array(-80.674599,39.046486),26323=>array(-80.29061,39.262588),26325=>array(-80.904837,39.098945),26327=>array(-80.94277,39.122886),26330=>array(-80.220851,39.285269),26335=>array(-80.68415,38.843536),26337=>array(-81.160994,39.230234),26338=>array(-80.619541,39.076885),26339=>array(-80.613994,39.422189),26342=>array(-80.85483,39.033601),26343=>array(-80.421981,38.82223),26346=>array(-81.060068,39.290022),26347=>array(-80.126099,39.256558),26348=>array(-80.545355,39.462602),26349=>array(-80.130286,39.235703),26351=>array(-80.83752,38.926223),26354=>array(-80.031779,39.34813),26361=>array(-80.317562,39.366722),26362=>array(-81.065345,39.152138),26366=>array(-80.334489,39.381255),26369=>array(-80.331754,39.333961),26372=>array(-80.346629,38.959145),26374=>array(-79.879154,39.45261),26376=>array(-80.453871,38.784372),26377=>array(-80.647037,39.496261),26378=>array(-80.437639,39.121091),26384=>array(-80.706813,38.981248),26385=>array(-80.355123,39.159428),26386=>array(-80.405822,39.395847),26404=>array(-80.306558,39.335754),26405=>array(-79.91029,39.225197),26408=>array(-80.306444,39.196594),26410=>array(-79.824426,39.40082),26411=>array(-80.71334,39.18008),26412=>array(-80.529764,38.869275),26415=>array(-80.9392,39.288302),26416=>array(-80.023946,39.157269),26419=>array(-80.68639,39.487689),26421=>array(-80.924287,39.181955),26422=>array(-80.443881,39.29449),26424=>array(-80.173598,39.266882),26425=>array(-79.757831,39.276594),26426=>array(-80.564431,39.287032),26430=>array(-80.763594,38.871117),26431=>array(-80.295345,39.399028),26435=>array(-80.092281,39.266587),26436=>array(-80.719495,39.297412),26437=>array(-80.508946,39.525977),26438=>array(-80.319108,39.346605),26440=>array(-79.918717,39.321695),26443=>array(-80.753154,39.075936),26444=>array(-79.770661,39.363716),26447=>array(-80.475009,38.908317),26448=>array(-80.493319,39.402814),26451=>array(-80.402248,39.207743),26452=>array(-80.52823,39.037122),26456=>array(-80.774045,39.262941),26501=>array(-80.036833,39.63423),26505=>array(-79.943818,39.649954),26508=>array(-79.895396,39.602633),26519=>array(-79.626971,39.569184),26520=>array(-79.823625,39.496998),26521=>array(-80.225739,39.711673),26525=>array(-79.62615,39.653857),26534=>array(-80.001649,39.648141),26537=>array(-79.71235,39.488922),26541=>array(-80.125254,39.695021),26542=>array(-79.782823,39.574706),26543=>array(-79.999923,39.664628),26547=>array(-79.813851,39.511738),26554=>array(-80.109845,39.465392),26559=>array(-80.168209,39.501274),26560=>array(-80.146984,39.541991),26562=>array(-80.46831,39.638577),26563=>array(-80.27357,39.48238),26568=>array(-80.277841,39.42489),26570=>array(-80.226841,39.633933),26571=>array(-80.261995,39.526542),26572=>array(-80.307754,39.486694),26574=>array(-80.188609,39.588393),26575=>array(-80.441399,39.677768),26576=>array(-80.256131,39.493255),26581=>array(-80.574747,39.670691),26582=>array(-80.380088,39.528793),26585=>array(-80.430619,39.619189),26586=>array(-80.101624,39.52196),26587=>array(-80.292761,39.517883),26588=>array(-80.145816,39.582098),26590=>array(-80.312306,39.669082),26591=>array(-80.296284,39.451607),26601=>array(-80.626752,38.617423),26610=>array(-80.741752,38.459204),26611=>array(-80.846298,38.846104),26615=>array(-80.711975,38.791186),26617=>array(-80.832446,38.501096),26619=>array(-80.705447,38.751669),26621=>array(-80.543406,38.713346),26623=>array(-80.871616,38.655481),26624=>array(-80.794837,38.719427),26627=>array(-80.585065,38.752473),26629=>array(-80.704268,38.56367),26631=>array(-80.537294,38.811243),26636=>array(-80.958249,38.743911),26638=>array(-81.015834,38.767524),26651=>array(-80.887236,38.332558),26656=>array(-81.16267,38.275784),26660=>array(-80.695718,38.3576),26662=>array(-80.742043,38.271473),26676=>array(-80.647768,38.160005),26678=>array(-80.909681,38.169609),26679=>array(-80.800665,38.169485),26680=>array(-80.872973,38.093333),26681=>array(-80.731681,38.233199),26684=>array(-80.845681,38.164963),26690=>array(-81.089121,38.17514),26691=>array(-80.658321,38.395337),26704=>array(-78.599287,39.291551),26705=>array(-79.584391,39.324559),26707=>array(-79.395045,39.216108),26710=>array(-78.967455,39.30169),26711=>array(-78.469379,39.28347),26714=>array(-78.655172,39.188471),26716=>array(-79.529483,39.252732),26717=>array(-79.182486,39.334176),26719=>array(-78.774805,39.482772),26720=>array(-79.329586,39.280293),26722=>array(-78.643193,39.503126),26726=>array(-78.984729,39.403781),26731=>array(-79.074567,39.168682),26739=>array(-79.255092,39.244131),26743=>array(-79.075293,39.293949),26750=>array(-79.04467,39.476642),26753=>array(-78.790215,39.562746),26755=>array(-78.724462,39.166189),26757=>array(-78.74521,39.311775),26761=>array(-78.694275,39.272821),26763=>array(-78.698319,39.472525),26764=>array(-79.553174,39.451931),26767=>array(-78.757162,39.615903),26801=>array(-78.804288,39.047799),26802=>array(-79.204429,38.626845),26804=>array(-79.564487,38.599317),26807=>array(-79.347015,38.66302),26808=>array(-78.453266,39.204897),26810=>array(-78.755302,38.993302),26812=>array(-78.878037,38.885787),26814=>array(-79.477829,38.778567),26815=>array(-79.364475,38.493516),26817=>array(-78.401808,39.373862),26818=>array(-79.016431,39.087725),26823=>array(-78.464071,39.132607),26833=>array(-79.220538,39.088928),26836=>array(-78.972336,38.999713),26845=>array(-78.963319,39.163318),26847=>array(-79.134534,38.94914),26851=>array(-78.611028,39.047101),26852=>array(-78.896354,39.246727),26855=>array(-79.269009,38.948051),26865=>array(-78.512139,39.20593),26866=>array(-79.234329,38.80061),26884=>array(-79.391676,38.906154),27006=>array(-80.440264,35.939004),27007=>array(-80.58894,36.389706),27009=>array(-80.078657,36.230931),27011=>array(-80.698472,36.216451),27012=>array(-80.379125,36.002681),27013=>array(-80.700079,35.750492),27014=>array(-80.555743,35.810044),27016=>array(-80.21985,36.446821),27017=>array(-80.756218,36.382016),27018=>array(-80.518248,36.197141),27019=>array(-80.237725,36.286886),27020=>array(-80.804054,36.102925),27021=>array(-80.339273,36.318059),27022=>array(-80.215604,36.512166),27023=>array(-80.456727,36.089764),27024=>array(-80.841179,36.519237),27025=>array(-79.969387,36.379051),27027=>array(-79.988878,36.441759),27028=>array(-80.578522,35.920228),27030=>array(-80.62925,36.490014),27040=>array(-80.393045,36.169312),27041=>array(-80.486784,36.425664),27042=>array(-80.062564,36.350453),27043=>array(-80.451911,36.337246),27045=>array(-80.29607,36.234398),27046=>array(-80.078264,36.502219),27047=>array(-80.57243,36.316943),27048=>array(-79.917678,36.482516),27050=>array(-80.406485,36.229963),27051=>array(-80.153395,36.19594),27052=>array(-80.150635,36.31883),27053=>array(-80.34785,36.474276),27054=>array(-80.597888,35.79254),27055=>array(-80.631592,36.113864),27101=>array(-80.200493,36.111102),27103=>array(-80.321496,36.05823),27104=>array(-80.321038,36.095923),27105=>array(-80.234264,36.162957),27106=>array(-80.323157,36.14391),27107=>array(-80.175491,36.013158),27109=>array(-80.27764,36.133909),27110=>array(-80.22496,36.08926),27127=>array(-80.280122,36.020077),27201=>array(-79.484834,36.034205),27203=>array(-79.786966,35.727975),27205=>array(-79.852391,35.633598),27207=>array(-79.390517,35.607613),27208=>array(-79.542928,35.56323),27209=>array(-79.753442,35.343102),27212=>array(-79.27965,36.480076),27214=>array(-79.670482,36.209415),27215=>array(-79.49161,36.029833),27217=>array(-79.380185,36.190945),27229=>array(-79.77589,35.265553),27231=>array(-79.169419,36.207715),27233=>array(-79.70551,35.892763),27235=>array(-80.012568,36.089407),27239=>array(-80.090334,35.600845),27242=>array(-79.648525,35.329799),27243=>array(-79.198148,36.066916),27244=>array(-79.488265,36.212452),27248=>array(-79.716331,35.783296),27249=>array(-79.582389,36.154141),27252=>array(-79.349758,35.566614),27253=>array(-79.347414,35.966209),27258=>array(-79.285685,36.009543),27260=>array(-79.987882,35.954467),27262=>array(-80.041638,35.962642),27263=>array(-79.937385,35.910048),27265=>array(-80.030991,36.010794),27278=>array(-79.086965,36.090303),27281=>array(-79.625115,35.187442),27282=>array(-79.929252,35.994234),27283=>array(-79.635418,35.951474),27284=>array(-80.07827,36.118637),27288=>array(-79.74946,36.497559),27291=>array(-79.168636,36.418424),27292=>array(-80.207547,35.738325),27295=>array(-80.31018,35.871767),27298=>array(-79.567545,35.885115),27299=>array(-80.386149,35.752324),27301=>array(-79.665656,36.11351),27302=>array(-79.266154,36.142031),27305=>array(-79.233755,36.526805),27306=>array(-79.980245,35.225194),27310=>array(-79.992233,36.174072),27311=>array(-79.472563,36.479651),27312=>array(-79.210066,35.755681),27313=>array(-79.758242,35.930899),27314=>array(-79.19625,36.310342),27315=>array(-79.403546,36.509968),27316=>array(-79.625793,35.697013),27317=>array(-79.802499,35.840737),27320=>array(-79.657526,36.341643),27325=>array(-79.578926,35.464346),27326=>array(-79.556413,36.461684),27330=>array(-79.194199,35.512898),27332=>array(-79.137188,35.384729),27340=>array(-79.317167,35.945873),27341=>array(-79.699421,35.524152),27343=>array(-79.091553,36.50325),27344=>array(-79.434604,35.723031),27349=>array(-79.416062,35.901313),27350=>array(-79.888213,35.808253),27355=>array(-79.574007,35.794966),27356=>array(-79.804272,35.436865),27357=>array(-79.970625,36.2666),27358=>array(-79.880061,36.228232),27360=>array(-80.100268,35.859342),27370=>array(-79.978025,35.80928),27371=>array(-79.968144,35.406855),27376=>array(-79.522126,35.243974),27377=>array(-79.608683,36.042693),27379=>array(-79.334513,36.374099),27401=>array(-79.765156,36.069144),27403=>array(-79.824383,36.065973),27405=>array(-79.735752,36.114409),27406=>array(-79.764677,36.000542),27407=>array(-79.87816,36.008599),27408=>array(-79.813712,36.103667),27409=>array(-79.93983,36.103729),27410=>array(-79.894239,36.117523),27455=>array(-79.81047,36.184081),27501=>array(-78.68457,35.484941),27502=>array(-78.915514,35.712397),27503=>array(-78.884277,36.152584),27504=>array(-78.518278,35.400309),27505=>array(-79.000039,35.423373),27507=>array(-78.569507,36.513546),27508=>array(-78.24824,35.956577),27509=>array(-78.774373,36.130409),27510=>array(-79.082604,35.915783),27511=>array(-78.788169,35.763369),27513=>array(-78.802719,35.802102),27514=>array(-79.049419,35.96674),27516=>array(-79.154855,35.906197),27517=>array(-79.023205,35.850295),27518=>array(-78.773829,35.729742),27519=>array(-78.884126,35.809584),27520=>array(-78.47621,35.617929),27521=>array(-78.655865,35.412121),27522=>array(-78.674974,36.105486),27523=>array(-78.956926,35.773618),27524=>array(-78.387595,35.394563),27525=>array(-78.45807,36.135982),27526=>array(-78.831392,35.541473),27527=>array(-78.381682,35.653972),27529=>array(-78.584906,35.655625),27530=>array(-78.062514,35.381174),27531=>array(-77.964379,35.343004),27534=>array(-77.896598,35.373342),27536=>array(-78.409125,36.326731),27537=>array(-78.397878,36.371801),27539=>array(-78.813444,35.676537),27540=>array(-78.884033,35.61561),27541=>array(-79.083217,36.264862),27542=>array(-78.136813,35.618266),27544=>array(-78.446559,36.199787),27545=>array(-78.478164,35.783689),27546=>array(-78.86598,35.382695),27549=>array(-78.232233,36.101663),27551=>array(-78.05017,36.432843),27553=>array(-78.305322,36.486561),27555=>array(-78.204133,35.562683),27556=>array(-78.314761,36.408374),27557=>array(-78.198512,35.779135),27559=>array(-79.103012,35.628239),27560=>array(-78.828272,35.858473),27562=>array(-78.990376,35.641786),27563=>array(-78.235797,36.425621),27565=>array(-78.649294,36.361663),27568=>array(-78.245099,35.510124),27569=>array(-78.182749,35.429065),27571=>array(-78.458418,35.919603),27572=>array(-78.877507,36.255158),27573=>array(-78.976099,36.396597),27574=>array(-78.864865,36.478358),27576=>array(-78.260557,35.579476),27577=>array(-78.332954,35.489722),27581=>array(-78.725986,36.204779),27582=>array(-78.576587,36.467324),27583=>array(-78.935362,36.292958),27587=>array(-78.551748,35.982413),27589=>array(-78.133484,36.322541),27591=>array(-78.388983,35.784168),27592=>array(-78.67394,35.560141),27596=>array(-78.440532,36.004817),27597=>array(-78.30268,35.841015),27601=>array(-78.634457,35.773632),27603=>array(-78.653597,35.664646),27604=>array(-78.558701,35.819972),27605=>array(-78.654596,35.790608),27606=>array(-78.715478,35.742323),27607=>array(-78.719617,35.813744),27608=>array(-78.647228,35.809046),27609=>array(-78.633643,35.843765),27610=>array(-78.546278,35.7444),27612=>array(-78.708498,35.853869),27613=>array(-78.711414,35.926102),27614=>array(-78.621619,35.94831),27615=>array(-78.635489,35.898505),27616=>array(-78.541695,35.866924),27617=>array(-78.772968,35.907871),27701=>array(-78.897944,35.99924),27703=>array(-78.806827,35.959253),27704=>array(-78.828771,36.042446),27705=>array(-78.978858,36.025937),27707=>array(-78.953317,35.954525),27709=>array(-78.832819,35.924246),27712=>array(-78.901077,36.095297),27713=>array(-78.923747,35.89504),27801=>array(-77.730779,35.913276),27803=>array(-77.856172,35.903051),27804=>array(-77.84235,35.990635),27805=>array(-77.084248,36.207741),27806=>array(-76.756067,35.304999),27807=>array(-78.095516,35.804496),27808=>array(-76.759213,35.467424),27809=>array(-77.741619,36.016777),27810=>array(-76.525506,35.531731),27812=>array(-77.369251,35.815611),27813=>array(-77.937717,35.634699),27814=>array(-76.918808,35.398663),27816=>array(-78.070319,36.108991),27817=>array(-77.069708,35.451146),27818=>array(-77.018505,36.499725),27819=>array(-77.454941,35.815994),27820=>array(-77.241567,36.421515),27821=>array(-76.874087,35.322066),27822=>array(-77.839022,35.804779),27823=>array(-77.70571,36.213482),27824=>array(-76.037172,35.513209),27825=>array(-77.174422,35.832821),27826=>array(-76.215312,35.588741),27827=>array(-77.513239,35.696636),27828=>array(-77.577213,35.585144),27829=>array(-77.626466,35.683966),27830=>array(-77.950309,35.564168),27831=>array(-77.577023,36.459608),27832=>array(-77.734725,36.521558),27834=>array(-77.380045,35.657563),27837=>array(-77.211067,35.516677),27839=>array(-77.555932,36.280743),27840=>array(-77.214599,35.982689),27841=>array(-77.276307,35.908555),27842=>array(-77.852102,36.521734),27843=>array(-77.39999,35.99556),27844=>array(-77.943156,36.249497),27845=>array(-77.43999,36.371267),27846=>array(-76.897527,35.758568),27847=>array(-77.194668,36.183169),27849=>array(-77.215025,36.077306),27850=>array(-77.880191,36.412391),27851=>array(-78.030662,35.640053),27852=>array(-77.636931,35.750459),27853=>array(-77.30421,36.51373),27855=>array(-77.069346,36.41564),27856=>array(-77.980574,36.01368),27857=>array(-77.286253,35.972793),27858=>array(-77.283895,35.531714),27860=>array(-76.676197,35.650061),27861=>array(-77.320207,35.814846),27862=>array(-77.188266,36.490195),27863=>array(-77.971726,35.488143),27864=>array(-77.651355,35.807047),27865=>array(-76.851605,35.656239),27866=>array(-77.514565,36.519869),27869=>array(-77.313433,36.267105),27870=>array(-77.715856,36.419006),27871=>array(-77.260565,35.802069),27872=>array(-77.253865,36.192755),27873=>array(-77.775232,35.653592),27874=>array(-77.408584,36.136662),27875=>array(-76.504667,35.455706),27876=>array(-77.391332,36.471995),27878=>array(-77.834929,35.866879),27879=>array(-77.279486,35.574391),27880=>array(-78.080589,35.730736),27881=>array(-77.436573,35.978414),27882=>array(-78.115598,35.941655),27883=>array(-77.803696,35.600536),27884=>array(-77.270314,35.702849),27885=>array(-76.27491,35.386195),27886=>array(-77.511658,35.904533),27888=>array(-77.71595,35.589277),27889=>array(-77.012004,35.582635),27890=>array(-77.587745,36.41418),27891=>array(-77.742789,36.097735),27892=>array(-77.052228,35.812281),27893=>array(-77.900656,35.69271),27896=>array(-77.976797,35.790772),27897=>array(-77.210701,36.324988),27909=>array(-76.26841,36.28875),27910=>array(-76.993185,36.290066),27915=>array(-75.491567,35.434104),27916=>array(-75.915131,36.322012),27917=>array(-75.997594,36.355205),27919=>array(-76.504283,36.308171),27920=>array(-75.553269,35.259492),27921=>array(-76.187929,36.352062),27922=>array(-76.84221,36.316755),27923=>array(-75.928155,36.40168),27924=>array(-76.832521,36.168447),27925=>array(-76.193837,35.856141),27926=>array(-76.604925,36.505115),27927=>array(-75.852576,36.341348),27928=>array(-76.438639,35.824423),27929=>array(-75.987038,36.435452),27932=>array(-76.607876,36.107824),27935=>array(-76.868092,36.431079),27936=>array(-75.577839,35.242195),27937=>array(-76.780733,36.504334),27938=>array(-76.716,36.384296),27939=>array(-75.843084,36.238431),27941=>array(-75.816896,36.102528),27942=>array(-76.750654,36.297368),27943=>array(-75.678903,35.224432),27944=>array(-76.421264,36.173431),27946=>array(-76.601536,36.363435),27947=>array(-75.877,36.193689),27948=>array(-75.692172,36.019229),27949=>array(-75.760527,36.108941),27950=>array(-75.996382,36.509694),27953=>array(-75.881378,35.77999),27954=>array(-75.677781,35.910154),27956=>array(-76.000725,36.401576),27957=>array(-76.759059,36.066297),27958=>array(-76.13835,36.484298),27959=>array(-75.606402,35.886943),27960=>array(-75.998527,35.073231),27962=>array(-76.744809,35.789893),27964=>array(-75.806214,36.083046),27965=>array(-75.927526,36.267692),27966=>array(-75.802261,36.149729),27967=>array(-76.904956,36.229468),27968=>array(-75.509908,35.732418),27970=>array(-76.649296,35.839106),27972=>array(-75.471224,35.55287),27973=>array(-76.055514,36.371209),27974=>array(-75.989505,36.243022),27976=>array(-76.350687,36.487866),27978=>array(-75.739872,35.727405),27979=>array(-76.560679,36.436768),27980=>array(-76.619385,36.245324),27981=>array(-75.637424,35.852855),27982=>array(-75.466252,35.565026),27983=>array(-76.917928,35.968459),27985=>array(-76.456674,36.211603),27986=>array(-76.921042,36.389887),28001=>array(-80.208179,35.338579),28006=>array(-81.092319,35.410411),28007=>array(-80.109909,35.104593),28009=>array(-80.108238,35.409174),28012=>array(-81.040035,35.208087),28016=>array(-81.283239,35.315184),28017=>array(-81.670698,35.247062),28018=>array(-81.802678,35.490775),28019=>array(-81.787707,35.276712),28020=>array(-81.641414,35.525046),28021=>array(-81.403346,35.400774),28023=>array(-80.602258,35.567714),28025=>array(-80.523467,35.382677),28027=>array(-80.6822,35.408065),28031=>array(-80.898428,35.473953),28032=>array(-81.079513,35.233033),28033=>array(-81.328253,35.41927),28034=>array(-81.178943,35.353664),28036=>array(-80.792539,35.480547),28037=>array(-81.020257,35.509034),28039=>array(-80.437427,35.678835),28040=>array(-81.758135,35.389195),28043=>array(-81.872786,35.30624),28052=>array(-81.233227,35.214656),28054=>array(-81.149075,35.262879),28056=>array(-81.125003,35.216936),28071=>array(-80.316323,35.517631),28072=>array(-80.445205,35.61407),28073=>array(-81.483781,35.198574),28075=>array(-80.639937,35.302748),28076=>array(-81.788606,35.259147),28077=>array(-81.20277,35.404802),28078=>array(-80.86402,35.405286),28079=>array(-80.600423,35.11471),28080=>array(-81.109643,35.453165),28081=>array(-80.670173,35.502816),28083=>array(-80.580668,35.489602),28086=>array(-81.378942,35.243945),28088=>array(-80.614646,35.544276),28089=>array(-81.659574,35.318233),28090=>array(-81.559555,35.454659),28091=>array(-79.933002,34.987392),28092=>array(-81.253899,35.486463),28097=>array(-80.39305,35.296715),28098=>array(-81.098623,35.271041),28101=>array(-81.077722,35.257964),28102=>array(-79.972265,34.818432),28103=>array(-80.351327,34.998925),28104=>array(-80.693292,35.060868),28105=>array(-80.713708,35.115597),28107=>array(-80.51868,35.25286),28108=>array(-80.681183,34.934781),28109=>array(-80.28853,35.496966),28110=>array(-80.524866,35.065318),28112=>array(-80.549548,34.889925),28114=>array(-81.747702,35.230441),28115=>array(-80.778871,35.58458),28117=>array(-80.898332,35.565698),28119=>array(-80.016985,34.851078),28120=>array(-81.026393,35.328651),28124=>array(-80.408792,35.399652),28125=>array(-80.698613,35.659025),28127=>array(-80.182719,35.468227),28128=>array(-80.154523,35.210696),28129=>array(-80.327162,35.231662),28133=>array(-80.265681,34.844926),28134=>array(-80.893095,35.085402),28135=>array(-80.217276,35.02976),28137=>array(-80.236391,35.563109),28138=>array(-80.43876,35.515381),28139=>array(-81.994737,35.348363),28144=>array(-80.464788,35.706685),28146=>array(-80.393298,35.619299),28147=>array(-80.562942,35.681117),28150=>array(-81.576248,35.342703),28152=>array(-81.599412,35.24272),28159=>array(-80.431873,35.694752),28160=>array(-81.922321,35.361024),28163=>array(-80.428517,35.207494),28164=>array(-81.037135,35.389444),28166=>array(-80.875531,35.682791),28167=>array(-81.966885,35.508403),28168=>array(-81.425071,35.55236),28169=>array(-81.429395,35.35847),28170=>array(-80.098787,34.998731),28173=>array(-80.731415,34.916155),28174=>array(-80.43958,34.969035),28202=>array(-80.844194,35.227271),28203=>array(-80.859107,35.208185),28204=>array(-80.827014,35.21462),28205=>array(-80.789601,35.218791),28206=>array(-80.820999,35.256127),28207=>array(-80.824585,35.194148),28208=>array(-80.907493,35.23043),28209=>array(-80.853985,35.178714),28210=>array(-80.856206,35.129916),28211=>array(-80.797285,35.166342),28212=>array(-80.744556,35.187703),28213=>array(-80.734355,35.286034),28214=>array(-80.968144,35.275252),28215=>array(-80.693471,35.244979),28216=>array(-80.887981,35.31145),28217=>array(-80.908285,35.168896),28226=>array(-80.822129,35.102697),28227=>array(-80.645488,35.189404),28244=>array(-80.843094,35.224605),28262=>array(-80.739981,35.322061),28269=>array(-80.803472,35.337313),28270=>array(-80.764415,35.112079),28273=>array(-80.946828,35.127365),28277=>array(-80.817552,35.052875),28278=>array(-81.009373,35.133403),28280=>array(-80.843091,35.226332),28282=>array(-80.845277,35.224815),28301=>array(-78.884257,35.0748),28303=>array(-78.95952,35.085957),28304=>array(-78.989604,35.025528),28305=>array(-78.907244,35.052609),28306=>array(-78.896848,34.958495),28307=>array(-78.981887,35.138559),28308=>array(-79.017082,35.171548),28310=>array(-79.037914,35.163471),28311=>array(-78.887753,35.167782),28312=>array(-78.738133,34.947752),28314=>array(-79.029891,35.052914),28315=>array(-79.432157,35.116885),28318=>array(-78.613574,35.019873),28320=>array(-78.772715,34.558122),28323=>array(-78.834901,35.314162),28325=>array(-78.104138,35.153922),28326=>array(-79.159382,35.273826),28327=>array(-79.416505,35.354586),28328=>array(-78.337924,35.003498),28330=>array(-79.82198,34.909597),28332=>array(-78.737889,34.659039),28333=>array(-78.012655,35.284311),28334=>array(-78.568104,35.272208),28337=>array(-78.56157,34.65705),28338=>array(-79.759691,35.107707),28339=>array(-78.732747,35.31054),28340=>array(-79.134422,34.471354),28341=>array(-78.174052,35.120111),28342=>array(-78.651262,35.191183),28343=>array(-79.564875,34.757362),28344=>array(-78.624483,35.1605),28345=>array(-79.670637,34.873551),28347=>array(-79.600604,35.058323),28348=>array(-78.926748,34.915262),28349=>array(-77.927065,34.981158),28350=>array(-79.314018,35.243159),28351=>array(-79.563854,34.84827),28352=>array(-79.451076,34.767332),28356=>array(-78.79104,35.235916),28357=>array(-79.082766,34.901888),28358=>array(-78.934474,34.608106),28360=>array(-79.074938,34.670334),28363=>array(-79.546024,34.957094),28364=>array(-79.323457,34.707179),28365=>array(-78.052357,35.172565),28366=>array(-78.361985,35.230268),28367=>array(-79.725159,35.172701),28369=>array(-79.029416,34.423373),28371=>array(-78.97957,34.903171),28372=>array(-79.177622,34.696873),28373=>array(-79.488461,35.091323),28374=>array(-79.462959,35.197454),28375=>array(-79.038553,34.475744),28376=>array(-79.242642,34.992407),28377=>array(-79.213242,34.826879),28379=>array(-79.778633,34.930279),28382=>array(-78.517812,34.971283),28383=>array(-79.262696,34.576974),28384=>array(-78.960927,34.79709),28385=>array(-78.491269,35.048806),28386=>array(-79.129616,34.853619),28387=>array(-79.376327,35.179464),28390=>array(-78.958164,35.218735),28391=>array(-78.698798,35.021629),28392=>array(-78.800703,34.734941),28393=>array(-78.189681,34.980876),28394=>array(-79.244848,35.218967),28395=>array(-78.740661,35.139367),28396=>array(-79.401588,34.927252),28398=>array(-78.071712,34.995035),28399=>array(-78.709012,34.784523),28401=>array(-77.963628,34.271985),28403=>array(-77.880633,34.221684),28405=>array(-77.86638,34.263182),28409=>array(-77.862676,34.154846),28411=>array(-77.79277,34.301944),28412=>array(-77.928152,34.143756),28420=>array(-78.481116,34.073706),28421=>array(-78.168375,34.505822),28422=>array(-78.173965,34.018953),28423=>array(-78.3889,34.313913),28424=>array(-78.699689,34.290291),28425=>array(-77.894389,34.562207),28428=>array(-77.909659,34.046841),28429=>array(-77.900216,34.341211),28430=>array(-78.937388,34.298389),28431=>array(-78.83842,34.314264),28432=>array(-78.758679,34.168118),28433=>array(-78.616673,34.488505),28434=>array(-78.465485,34.468325),28435=>array(-78.109108,34.40591),28436=>array(-78.267215,34.275102),28438=>array(-78.918311,34.408974),28439=>array(-79.001225,34.286894),28441=>array(-78.4318,34.804613),28442=>array(-78.600598,34.288447),28443=>array(-77.675712,34.445036),28444=>array(-78.32202,34.698827),28445=>array(-77.556317,34.483968),28447=>array(-78.263349,34.599052),28448=>array(-78.317144,34.491995),28449=>array(-77.933743,33.978811),28450=>array(-78.515299,34.32466),28451=>array(-78.089706,34.230517),28452=>array(-78.546504,33.992284),28453=>array(-78.076256,34.886439),28454=>array(-77.650871,34.678126),28455=>array(-78.631633,34.111534),28456=>array(-78.287094,34.37441),28457=>array(-77.886638,34.449598),28458=>array(-78.090782,34.814773),28460=>array(-77.418498,34.542056),28461=>array(-78.059091,33.967234),28462=>array(-78.289593,34.026571),28463=>array(-78.782385,34.104765),28464=>array(-78.01732,34.77664),28465=>array(-78.102548,33.912317),28466=>array(-77.875651,34.741253),28467=>array(-78.593713,33.919644),28468=>array(-78.519137,33.899623),28469=>array(-78.467404,33.926319),28470=>array(-78.403407,33.964096),28472=>array(-78.689949,34.298566),28478=>array(-78.040878,34.641461),28479=>array(-78.016511,34.100688),28480=>array(-77.797334,34.225734),28501=>array(-77.516659,35.242923),28504=>array(-77.634868,35.224563),28508=>array(-77.824788,35.099668),28510=>array(-76.804461,34.987612),28511=>array(-76.345763,34.901116),28512=>array(-76.793416,34.712151),28513=>array(-77.388853,35.441505),28515=>array(-76.699387,35.184068),28516=>array(-76.55048,34.903303),28518=>array(-77.747493,34.894823),28519=>array(-77.026974,35.119725),28520=>array(-76.323297,34.991933),28521=>array(-77.736618,34.817902),28523=>array(-77.286014,35.210915),28524=>array(-76.468562,34.790935),28525=>array(-77.691316,35.125496),28526=>array(-77.356588,35.270197),28527=>array(-77.030444,35.259463),28528=>array(-76.538662,34.732058),28529=>array(-76.85476,35.070527),28530=>array(-77.415297,35.374768),28531=>array(-76.55846,34.698739),28532=>array(-76.890571,34.89534),28533=>array(-76.901473,34.902869),28537=>array(-76.527113,35.232516),28538=>array(-77.565077,35.416645),28539=>array(-77.213281,34.696777),28540=>array(-77.507427,34.754586),28543=>array(-77.376708,34.734489),28544=>array(-77.308684,34.718075),28546=>array(-77.356169,34.798974),28547=>array(-77.36697,34.669025),28551=>array(-77.780856,35.321323),28552=>array(-76.546476,35.300932),28553=>array(-76.512376,34.7296),28554=>array(-77.586122,35.478481),28555=>array(-77.224973,34.871187),28556=>array(-76.625583,35.114002),28557=>array(-76.749232,34.73896),28560=>array(-76.977181,35.125849),28562=>array(-77.126893,35.081631),28570=>array(-76.857549,34.781518),28571=>array(-76.691654,35.068472),28572=>array(-77.736417,35.027895),28573=>array(-77.148842,34.98507),28574=>array(-77.589588,34.878931),28575=>array(-76.883568,34.707959),28577=>array(-76.373188,34.864837),28578=>array(-77.856972,35.196952),28579=>array(-76.510294,34.759099),28580=>array(-77.679803,35.453155),28581=>array(-76.435463,34.844375),28582=>array(-77.15438,34.751399),28583=>array(-76.740716,35.13882),28584=>array(-77.077619,34.736766),28585=>array(-77.412405,35.076923),28586=>array(-77.167497,35.313457),28587=>array(-76.661669,35.193948),28589=>array(-76.510879,34.808441),28590=>array(-77.416661,35.520683),28594=>array(-76.969688,34.689904),28601=>array(-81.326659,35.772393),28602=>array(-81.387667,35.672123),28604=>array(-81.858589,36.1777),28605=>array(-81.694929,36.129632),28606=>array(-81.322174,36.053487),28607=>array(-81.65237,36.218021),28609=>array(-81.055604,35.671692),28610=>array(-81.135305,35.730324),28611=>array(-81.735254,36.010955),28612=>array(-81.537561,35.650391),28613=>array(-81.207681,35.737687),28615=>array(-81.67036,36.462963),28616=>array(-81.920191,36.023071),28617=>array(-81.361979,36.480702),28618=>array(-81.516799,36.208178),28619=>array(-81.602494,35.758603),28621=>array(-80.914624,36.27565),28622=>array(-81.947333,36.192676),28623=>array(-80.971405,36.534328),28624=>array(-81.410206,36.127737),28625=>array(-80.890284,35.868681),28626=>array(-81.517798,36.292547),28627=>array(-81.003763,36.458749),28628=>array(-81.785107,35.726329),28629=>array(-81.365327,36.346063),28630=>array(-81.421657,35.827169),28631=>array(-81.410274,36.547594),28634=>array(-80.75696,35.972899),28635=>array(-81.126045,36.305463),28636=>array(-81.063433,35.939426),28637=>array(-81.419361,35.718005),28638=>array(-81.477938,35.845093),28640=>array(-81.402662,36.403077),28642=>array(-80.820312,36.218398),28643=>array(-81.534236,36.523609),28644=>array(-81.277976,36.426225),28645=>array(-81.547182,35.979227),28646=>array(-81.847093,36.073331),28647=>array(-81.972993,35.938084),28649=>array(-81.209458,36.333842),28650=>array(-81.150614,35.571814),28651=>array(-81.308783,36.306214),28652=>array(-81.98717,36.100032),28654=>array(-81.159284,36.058164),28655=>array(-81.741356,35.757931),28657=>array(-81.943352,36.026471),28658=>array(-81.235843,35.637619),28659=>array(-81.144782,36.214847),28660=>array(-80.856248,35.968615),28662=>array(-81.899121,36.021516),28663=>array(-81.309408,36.53203),28665=>array(-81.375474,36.209834),28666=>array(-81.470655,35.725264),28667=>array(-81.426154,35.771453),28668=>array(-80.990485,36.407054),28669=>array(-80.99309,36.223525),28670=>array(-80.914766,36.194017),28671=>array(-81.527898,35.75267),28672=>array(-81.331342,36.483565),28673=>array(-80.99489,35.619285),28675=>array(-81.137222,36.502709),28676=>array(-80.85491,36.331894),28677=>array(-80.922989,35.736732),28678=>array(-81.059596,35.822882),28679=>array(-81.82831,36.261278),28681=>array(-81.224112,35.92235),28682=>array(-80.965153,35.588255),28683=>array(-80.911085,36.390489),28684=>array(-81.608522,36.336123),28685=>array(-81.059832,36.360792),28689=>array(-80.940896,36.036555),28690=>array(-81.574229,35.732737),28692=>array(-81.808495,36.267524),28693=>array(-81.564661,36.473863),28694=>array(-81.455877,36.367456),28697=>array(-81.165721,36.134008),28698=>array(-81.736245,36.340894),28701=>array(-82.640099,35.705254),28702=>array(-83.605365,35.40639),28704=>array(-82.579542,35.457151),28705=>array(-82.156728,36.033544),28707=>array(-83.065872,35.39733),28708=>array(-82.86262,35.271316),28709=>array(-82.381416,35.771714),28711=>array(-82.293674,35.604202),28712=>array(-82.771532,35.172713),28713=>array(-83.499854,35.369463),28714=>array(-82.30398,35.889504),28715=>array(-82.711701,35.511966),28716=>array(-82.847959,35.439319),28717=>array(-83.093398,35.049341),28718=>array(-82.633547,35.161143),28719=>array(-83.334158,35.517884),28720=>array(-82.253654,35.450754),28721=>array(-82.958491,35.662677),28722=>array(-82.061012,35.208462),28723=>array(-83.026128,35.314207),28725=>array(-83.255082,35.366645),28726=>array(-82.417476,35.281157),28729=>array(-82.600376,35.320503),28730=>array(-82.37803,35.517414),28731=>array(-82.394669,35.288036),28732=>array(-82.445784,35.452565),28733=>array(-83.815701,35.429102),28734=>array(-83.412049,35.189201),28735=>array(-82.350477,35.4759),28736=>array(-83.08652,35.175631),28739=>array(-82.553068,35.260468),28740=>array(-82.272921,36.091266),28741=>array(-83.214162,35.059869),28742=>array(-82.651028,35.38269),28743=>array(-82.881144,35.800359),28745=>array(-82.972046,35.525282),28746=>array(-82.168077,35.461364),28747=>array(-82.922658,35.155183),28748=>array(-82.757716,35.649564),28749=>array(-82.098559,35.840722),28751=>array(-83.120685,35.505021),28752=>array(-82.035893,35.710565),28753=>array(-82.712731,35.86408),28754=>array(-82.515681,35.875581),28756=>array(-82.186268,35.351924),28757=>array(-82.308567,35.649746),28759=>array(-82.588562,35.381462),28761=>array(-81.91054,35.68533),28762=>array(-82.231583,35.62679),28763=>array(-83.466763,35.028551),28766=>array(-82.619825,35.251041),28768=>array(-82.707721,35.325842),28771=>array(-83.842814,35.34702),28772=>array(-82.827217,35.116966),28773=>array(-82.309708,35.265429),28774=>array(-82.995061,35.093531),28775=>array(-83.32287,35.021414),28777=>array(-82.068523,35.904438),28778=>array(-82.405196,35.629121),28779=>array(-83.211452,35.355178),28781=>array(-83.635607,35.224818),28782=>array(-82.147409,35.23396),28783=>array(-83.010412,35.262145),28785=>array(-83.139769,35.653307),28786=>array(-82.989025,35.462062),28787=>array(-82.51549,35.741288),28789=>array(-83.316777,35.407057),28790=>array(-82.514329,35.214632),28791=>array(-82.5082,35.356109),28792=>array(-82.369202,35.383322),28801=>array(-82.557917,35.594348),28803=>array(-82.523017,35.531707),28804=>array(-82.564371,35.647839),28805=>array(-82.484588,35.625161),28806=>array(-82.614729,35.571971),28901=>array(-83.810349,35.198079),28902=>array(-83.959171,35.022285),28904=>array(-83.733464,35.068396),28905=>array(-83.940087,35.163946),28906=>array(-84.138594,35.100136),28909=>array(-83.904773,35.001661),29001=>array(-80.174065,33.786644),29003=>array(-81.023815,33.241221),29006=>array(-81.551078,33.869101),29009=>array(-80.376154,34.4553),29010=>array(-80.272722,34.223328),29014=>array(-81.114513,34.523382),29015=>array(-81.330125,34.437442),29016=>array(-80.996999,34.202513),29018=>array(-80.639176,33.348797),29020=>array(-80.58159,34.316649),29030=>array(-80.647573,33.576312),29031=>array(-81.492609,34.548096),29032=>array(-80.445025,34.345114),29033=>array(-81.057439,33.953426),29036=>array(-81.339914,34.134004),29037=>array(-81.867693,34.189937),29038=>array(-80.981506,33.372643),29039=>array(-80.915021,33.42242),29040=>array(-80.440478,34.068795),29042=>array(-81.158698,33.297671),29044=>array(-80.69235,33.936526),29045=>array(-80.806315,34.185012),29046=>array(-80.153633,34.102331),29047=>array(-80.585847,33.532715),29048=>array(-80.295284,33.390561),29051=>array(-80.127828,33.861626),29052=>array(-80.741126,33.798397),29053=>array(-81.090983,33.827497),29054=>array(-81.383081,33.941953),29055=>array(-80.914866,34.574244),29056=>array(-80.005756,33.608671),29058=>array(-80.742436,34.555045),29059=>array(-80.418508,33.33003),29061=>array(-80.850604,33.897493),29062=>array(-80.605521,34.004286),29063=>array(-81.206184,34.142131),29065=>array(-81.296583,34.28514),29067=>array(-80.537094,34.544166),29069=>array(-80.094729,34.179848),29070=>array(-81.453057,33.916116),29072=>array(-81.27241,34.001778),29073=>array(-81.235774,33.892184),29074=>array(-80.81815,34.441645),29075=>array(-81.299071,34.218134),29078=>array(-80.706336,34.18515),29079=>array(-80.113717,34.286517),29080=>array(-80.085577,34.012164),29081=>array(-81.047373,33.08908),29082=>array(-80.939141,33.038215),29101=>array(-80.247858,34.460246),29102=>array(-80.188481,33.641983),29104=>array(-80.213437,34.001026),29105=>array(-81.59364,33.807397),29107=>array(-81.124331,33.529824),29108=>array(-81.627342,34.305524),29111=>array(-80.006369,33.789038),29112=>array(-81.079954,33.626435),29113=>array(-81.135334,33.432423),29114=>array(-79.93267,33.956036),29115=>array(-80.8491,33.477355),29117=>array(-80.848826,33.49826),29118=>array(-80.885684,33.56755),29122=>array(-81.328235,34.23876),29123=>array(-81.271451,33.764652),29125=>array(-80.462564,33.700612),29126=>array(-81.419482,34.328933),29127=>array(-81.512463,34.153252),29128=>array(-80.526305,34.095748),29129=>array(-81.676812,33.781876),29130=>array(-80.880412,34.331608),29133=>array(-80.803127,33.358911),29135=>array(-80.787131,33.692181),29137=>array(-81.321382,33.595632),29138=>array(-81.776152,34.042392),29142=>array(-80.524523,33.463477),29145=>array(-81.766201,34.228719),29146=>array(-81.295412,33.508249),29147=>array(-80.966483,34.091774),29148=>array(-80.337458,33.534198),29150=>array(-80.353988,33.874292),29152=>array(-80.465806,33.972299),29153=>array(-80.308378,33.959249),29154=>array(-80.440418,33.879261),29160=>array(-81.035516,33.746888),29161=>array(-79.943496,34.104703),29162=>array(-80.014019,33.885889),29163=>array(-80.439904,33.429587),29164=>array(-81.416471,33.662168),29166=>array(-81.70574,33.901804),29168=>array(-80.552297,33.849319),29169=>array(-81.097406,33.997527),29170=>array(-81.147203,33.937674),29172=>array(-81.076978,33.912417),29175=>array(-80.598356,34.443849),29178=>array(-81.604974,34.492522),29180=>array(-81.093684,34.366465),29201=>array(-81.028098,33.982484),29202=>array(-81.031009,33.993555),29203=>array(-81.042085,34.101723),29204=>array(-81.002526,34.029148),29205=>array(-80.997251,33.990057),29206=>array(-80.958995,34.026415),29207=>array(-80.845986,34.042447),29208=>array(-81.028152,33.998133),29209=>array(-80.950364,33.926751),29210=>array(-81.10658,34.046162),29212=>array(-81.198752,34.076232),29223=>array(-80.919271,34.092634),29225=>array(-81.025028,33.996177),29229=>array(-80.888209,34.139526),29301=>array(-82.010697,34.934028),29302=>array(-81.843603,34.884446),29303=>array(-81.961056,34.995782),29306=>array(-81.921576,34.892662),29307=>array(-81.831555,34.982716),29316=>array(-81.975107,35.043045),29320=>array(-81.993676,34.958401),29321=>array(-81.741065,34.714662),29322=>array(-82.132234,35.121041),29323=>array(-81.907463,35.126341),29324=>array(-81.826635,34.983686),29325=>array(-81.841751,34.47202),29329=>array(-81.835884,34.994056),29330=>array(-81.804142,35.052613),29331=>array(-81.844085,34.651836),29332=>array(-81.970367,34.27876),29333=>array(-81.910208,34.971205),29334=>array(-82.124414,34.905551),29335=>array(-81.904455,34.64669),29338=>array(-82.001598,35.135513),29340=>array(-81.585721,34.972033),29341=>array(-81.714522,35.113676),29346=>array(-81.836373,34.945078),29349=>array(-82.071005,35.06932),29351=>array(-81.808045,34.421034),29353=>array(-81.648605,34.830743),29355=>array(-81.826418,34.289571),29356=>array(-82.280831,35.142074),29360=>array(-82.050627,34.498634),29364=>array(-81.470669,34.76248),29365=>array(-82.171851,34.980988),29368=>array(-81.863411,35.081579),29369=>array(-82.019463,34.86562),29370=>array(-81.963361,34.373805),29372=>array(-81.711273,34.901747),29373=>array(-81.746754,34.924954),29374=>array(-81.853472,34.784549),29375=>array(-82.113804,34.861302),29376=>array(-81.944219,34.811382),29377=>array(-82.095061,34.930634),29378=>array(-81.968539,34.966907),29379=>array(-81.608705,34.682438),29384=>array(-82.090062,34.343368),29385=>array(-82.101417,34.972963),29388=>array(-82.044633,34.764315),29401=>array(-79.932,32.77718),29403=>array(-79.94318,32.8059),29404=>array(-80.049739,32.898999),29405=>array(-79.981994,32.856252),29406=>array(-80.035403,32.93774),29407=>array(-79.997803,32.79893),29409=>array(-79.960493,32.796088),29410=>array(-80.002751,32.932658),29412=>array(-79.947881,32.712647),29414=>array(-80.08918,32.839964),29418=>array(-80.094765,32.909648),29420=>array(-80.100722,32.931762),29423=>array(-80.071205,32.97876),29424=>array(-79.937365,32.783637),29426=>array(-80.370638,32.797192),29429=>array(-79.6582,32.970668),29431=>array(-79.881631,33.273223),29432=>array(-80.808833,33.23145),29434=>array(-79.843725,33.140888),29435=>array(-80.466445,32.972972),29436=>array(-80.18725,33.315358),29437=>array(-80.431756,33.139994),29438=>array(-80.32239,32.564708),29439=>array(-79.951857,32.654787),29440=>array(-79.32976,33.38111),29445=>array(-79.967298,32.999295),29446=>array(-80.55151,32.630668),29448=>array(-80.452695,33.258064),29449=>array(-80.287056,32.700369),29450=>array(-79.784197,33.065935),29451=>array(-79.754581,32.822611),29452=>array(-80.461468,32.677951),29453=>array(-79.642781,33.225592),29455=>array(-80.040587,32.624718),29456=>array(-80.11544,32.985877),29458=>array(-79.461488,33.093141),29461=>array(-80.006461,33.159834),29464=>array(-79.858222,32.816699),29466=>array(-79.792013,32.877758),29468=>array(-80.058167,33.421815),29469=>array(-80.05637,33.257863),29470=>array(-80.253676,32.826948),29471=>array(-80.670417,33.192675),29472=>array(-80.326823,33.044311),29474=>array(-80.523838,32.884258),29475=>array(-80.80648,32.957264),29477=>array(-80.564934,33.163135),29479=>array(-79.888317,33.379002),29481=>array(-80.800481,33.108529),29482=>array(-79.854987,32.764502),29483=>array(-80.18854,33.051384),29485=>array(-80.190585,32.948519),29487=>array(-80.183948,32.657682),29488=>array(-80.672836,32.906763),29492=>array(-79.911163,32.903802),29493=>array(-80.842844,33.034143),29501=>array(-79.82626,34.205933),29505=>array(-79.688893,34.130066),29506=>array(-79.646192,34.213891),29510=>array(-79.613121,33.454312),29511=>array(-79.122716,33.975732),29512=>array(-79.718217,34.618873),29516=>array(-79.63464,34.437454),29518=>array(-79.847975,33.788608),29519=>array(-79.35981,34.018664),29520=>array(-79.927292,34.679486),29525=>array(-79.540687,34.552581),29526=>array(-78.964476,33.853903),29527=>array(-79.145938,33.785195),29530=>array(-79.740075,33.996055),29532=>array(-79.869336,34.280331),29536=>array(-79.373048,34.419502),29540=>array(-79.846171,34.377419),29541=>array(-79.74075,34.064949),29543=>array(-79.265929,34.287604),29544=>array(-79.255583,33.926098),29545=>array(-78.966477,34.16366),29546=>array(-79.351821,33.882357),29547=>array(-79.334829,34.496287),29550=>array(-80.082806,34.399975),29554=>array(-79.381598,33.70405),29555=>array(-79.466397,33.841627),29556=>array(-79.762707,33.668097),29560=>array(-79.74458,33.830403),29563=>array(-79.208673,34.353366),29564=>array(-79.848408,33.449386),29565=>array(-79.499289,34.358052),29566=>array(-78.666957,33.873402),29567=>array(-79.429607,34.558925),29568=>array(-78.750284,33.91356),29569=>array(-78.916972,34.03684),29570=>array(-79.564322,34.667376),29571=>array(-79.425036,34.135045),29572=>array(-78.784745,33.77156),29574=>array(-79.260681,34.165504),29575=>array(-78.970339,33.629225),29576=>array(-79.056329,33.56247),29577=>array(-78.902868,33.698784),29579=>array(-78.916899,33.753215),29580=>array(-79.551975,33.653101),29581=>array(-79.113015,34.199275),29582=>array(-78.660551,33.838529),29583=>array(-79.571077,33.977851),29584=>array(-80.065768,34.583313),29585=>array(-79.135803,33.520097),29588=>array(-79.02427,33.671137),29590=>array(-79.848696,33.56892),29591=>array(-79.76229,33.937999),29592=>array(-79.478986,34.266958),29593=>array(-79.857051,34.49283),29594=>array(-79.57736,34.640233),29596=>array(-79.830739,34.744162),29601=>array(-82.402264,34.847112),29605=>array(-82.37661,34.774425),29607=>array(-82.331435,34.811726),29609=>array(-82.38817,34.912592),29611=>array(-82.458497,34.830934),29613=>array(-82.438736,34.924566),29614=>array(-82.363149,34.873771),29615=>array(-82.296139,34.856825),29617=>array(-82.468095,34.911021),29620=>array(-82.425604,34.182424),29621=>array(-82.605626,34.506502),29624=>array(-82.624115,34.435943),29625=>array(-82.763452,34.559027),29626=>array(-82.756514,34.460802),29627=>array(-82.476617,34.517279),29628=>array(-82.55923,34.089119),29630=>array(-82.799161,34.738673),29631=>array(-82.815832,34.681567),29634=>array(-82.83595,34.676518),29635=>array(-82.626703,35.077658),29638=>array(-82.338204,34.363867),29639=>array(-82.428815,34.303618),29640=>array(-82.579832,34.883978),29642=>array(-82.563663,34.775165),29643=>array(-82.996445,34.51619),29644=>array(-82.190059,34.668477),29645=>array(-82.12461,34.592282),29646=>array(-82.14847,34.136053),29649=>array(-82.145019,34.238919),29650=>array(-82.257851,34.898246),29651=>array(-82.279564,35.02383),29653=>array(-82.232469,34.306003),29654=>array(-82.361886,34.460528),29655=>array(-82.642346,34.265624),29657=>array(-82.686571,34.767088),29658=>array(-83.284445,34.760806),29659=>array(-82.646988,34.20977),29661=>array(-82.529539,35.147593),29662=>array(-82.301835,34.778208),29664=>array(-83.157553,34.860889),29665=>array(-82.913642,34.725435),29666=>array(-81.979552,34.113326),29667=>array(-82.75669,34.764792),29669=>array(-82.413576,34.639372),29670=>array(-82.723237,34.643979),29671=>array(-82.728691,34.934777),29672=>array(-82.934285,34.751278),29673=>array(-82.455898,34.713864),29676=>array(-82.982932,34.950234),29678=>array(-82.939747,34.635217),29680=>array(-82.288811,34.685122),29681=>array(-82.225003,34.767679),29682=>array(-82.854386,34.833946),29683=>array(-82.494173,35.029999),29684=>array(-82.718488,34.37941),29685=>array(-82.842298,34.991238),29686=>array(-83.053602,34.95955),29687=>array(-82.327451,34.986636),29689=>array(-82.868342,34.534253),29690=>array(-82.417198,35.059806),29691=>array(-83.083166,34.782583),29692=>array(-82.219492,34.41263),29693=>array(-83.146844,34.646708),29696=>array(-83.00884,34.78007),29697=>array(-82.548639,34.625593),29702=>array(-81.473073,35.116068),29704=>array(-80.909786,34.831891),29706=>array(-81.234538,34.715492),29707=>array(-80.862388,34.974384),29708=>array(-80.987118,35.048705),29709=>array(-80.098457,34.720167),29710=>array(-81.221471,35.106284),29712=>array(-80.975531,34.797966),29714=>array(-80.915313,34.712239),29715=>array(-80.928739,35.009844),29717=>array(-81.448844,34.950733),29718=>array(-80.331295,34.624163),29720=>array(-80.732729,34.740563),29724=>array(-81.011121,34.773948),29726=>array(-81.236135,34.860843),29727=>array(-80.264601,34.719265),29728=>array(-80.400558,34.764953),29729=>array(-81.00676,34.689134),29730=>array(-81.017838,34.88987),29732=>array(-81.081285,34.971373),29733=>array(-81.031961,34.939585),29741=>array(-80.195526,34.725288),29742=>array(-81.392257,34.869975),29743=>array(-81.386674,35.011187),29745=>array(-81.21418,34.991118),29801=>array(-81.697037,33.588993),29803=>array(-81.762699,33.490267),29805=>array(-81.604486,33.646054),29809=>array(-81.69249,33.418902),29810=>array(-81.37811,32.986368),29812=>array(-81.431281,33.230843),29816=>array(-81.873493,33.501116),29817=>array(-81.273172,33.370534),29819=>array(-82.227378,34.044227),29821=>array(-82.107049,33.643047),29824=>array(-81.997605,33.821285),29826=>array(-81.359112,33.385403),29827=>array(-81.253906,32.963155),29828=>array(-81.828197,33.522812),29829=>array(-81.857801,33.574691),29831=>array(-81.799578,33.297451),29832=>array(-81.803656,33.838994),29834=>array(-81.856747,33.51293),29835=>array(-82.288971,33.919499),29836=>array(-81.560185,33.124861),29838=>array(-82.150948,33.746791),29840=>array(-82.521302,34.007202),29841=>array(-81.939337,33.526407),29842=>array(-81.863403,33.451527),29843=>array(-81.179772,33.182069),29844=>array(-82.241925,33.769606),29845=>array(-82.201423,33.817844),29847=>array(-81.85276,33.694096),29848=>array(-82.075911,33.970417),29849=>array(-81.234474,33.100255),29850=>array(-81.816976,33.609668),29851=>array(-81.811783,33.507439),29853=>array(-81.422629,33.403217),29856=>array(-81.509942,33.484137),29860=>array(-81.984429,33.614687),29899=>array(-82.250602,33.928023),29902=>array(-80.684304,32.334933),29904=>array(-80.717905,32.457441),29905=>array(-80.682217,32.351589),29906=>array(-80.752875,32.445112),29907=>array(-80.599222,32.474692),29909=>array(-80.847799,32.336836),29910=>array(-80.890837,32.217752),29911=>array(-81.141681,32.94116),29912=>array(-80.929358,32.583486),29915=>array(-80.865898,32.115435),29916=>array(-80.967103,32.718462),29918=>array(-81.247269,32.744511),29920=>array(-80.544887,32.367446),29921=>array(-81.172909,32.682581),29922=>array(-81.277273,32.625831),29923=>array(-81.246422,32.859518),29924=>array(-81.111209,32.876885),29926=>array(-80.740263,32.238247),29927=>array(-81.057867,32.226799),29928=>array(-80.755765,32.163171),29929=>array(-80.938536,32.927872),29932=>array(-81.348641,32.818148),29934=>array(-81.107381,32.591591),29935=>array(-80.695169,32.383612),29936=>array(-80.97173,32.481344),29939=>array(-81.244025,32.672512),29940=>array(-80.702432,32.550437),29941=>array(-80.806715,32.550309),29943=>array(-81.190824,32.479103),29944=>array(-81.035372,32.793115),29945=>array(-80.765932,32.673313),30002=>array(-84.261667,33.773335),30004=>array(-84.293133,34.143879),30005=>array(-84.221044,34.08715),30008=>array(-84.589572,33.897634),30009=>array(-84.305281,34.07896),30011=>array(-83.837163,34.019859),30012=>array(-84.002515,33.717806),30013=>array(-83.971948,33.64502),30014=>array(-83.823102,33.580062),30016=>array(-83.928703,33.517433),30017=>array(-83.961879,33.890533),30019=>array(-83.883747,33.97561),30021=>array(-84.237588,33.806929),30022=>array(-84.241932,34.030333),30024=>array(-84.09077,34.062971),30025=>array(-83.696581,33.655902),30028=>array(-84.176166,34.293049),30030=>array(-84.29027,33.771947),30032=>array(-84.263593,33.739309),30033=>array(-84.28323,33.811659),30034=>array(-84.248622,33.690867),30035=>array(-84.204244,33.724452),30038=>array(-84.139855,33.66646),30039=>array(-84.033549,33.797955),30040=>array(-84.187789,34.210349),30041=>array(-84.100357,34.204626),30043=>array(-84.00951,33.99928),30044=>array(-84.065651,33.92209),30045=>array(-83.927669,33.936518),30046=>array(-83.995764,33.948631),30047=>array(-84.112327,33.870144),30052=>array(-83.893561,33.815151),30054=>array(-83.871806,33.67325),30055=>array(-83.749992,33.496702),30056=>array(-83.659584,33.50025),30058=>array(-84.108844,33.74033),30060=>array(-84.541629,33.926431),30062=>array(-84.47031,34.002532),30064=>array(-84.613787,33.939737),30066=>array(-84.505154,34.032388),30067=>array(-84.462185,33.934278),30068=>array(-84.433463,33.967328),30070=>array(-83.894702,33.574432),30071=>array(-84.206233,33.939949),30072=>array(-84.206463,33.792116),30075=>array(-84.390264,34.0557),30076=>array(-84.311406,34.028474),30078=>array(-84.017993,33.861019),30079=>array(-84.257369,33.792055),30080=>array(-84.498844,33.869656),30082=>array(-84.53595,33.854598),30083=>array(-84.197984,33.797412),30084=>array(-84.216155,33.854097),30087=>array(-84.126928,33.805871),30088=>array(-84.182363,33.756052),30092=>array(-84.231986,33.972386),30093=>array(-84.177349,33.908536),30094=>array(-84.053557,33.613639),30096=>array(-84.145426,33.974292),30097=>array(-84.145592,34.026142),30101=>array(-84.707349,34.034515),30102=>array(-84.633785,34.103138),30103=>array(-84.919232,34.367374),30104=>array(-85.056489,34.087138),30105=>array(-85.172546,34.432605),30106=>array(-84.628247,33.83901),30107=>array(-84.345793,34.336291),30108=>array(-85.262996,33.5317),30110=>array(-85.136162,33.744411),30113=>array(-85.205308,33.850746),30114=>array(-84.524468,34.247838),30115=>array(-84.400462,34.204092),30116=>array(-85.003082,33.54059),30117=>array(-85.132439,33.581851),30118=>array(-85.103432,33.572374),30120=>array(-84.851983,34.167895),30121=>array(-84.777991,34.209234),30122=>array(-84.641356,33.766909),30124=>array(-85.345801,34.133691),30125=>array(-85.276,34.002052),30126=>array(-84.553831,33.815025),30127=>array(-84.695004,33.873653),30132=>array(-84.858967,33.988832),30134=>array(-84.781392,33.777518),30135=>array(-84.734357,33.670162),30137=>array(-84.760937,34.124107),30139=>array(-84.705495,34.432341),30141=>array(-84.769642,33.860951),30143=>array(-84.431752,34.459958),30144=>array(-84.591009,34.036864),30145=>array(-84.985928,34.245709),30147=>array(-85.208239,34.150627),30148=>array(-84.258613,34.458792),30149=>array(-85.226015,34.309754),30152=>array(-84.646572,33.989648),30153=>array(-85.054452,33.959882),30157=>array(-84.874622,33.884995),30161=>array(-85.17159,34.241733),30164=>array(-83.833971,33.395837),30165=>array(-85.269103,34.302923),30168=>array(-84.588106,33.783542),30170=>array(-85.169473,33.429229),30171=>array(-84.725681,34.343551),30173=>array(-85.153505,34.133121),30175=>array(-84.526711,34.534915),30176=>array(-85.300142,33.767736),30177=>array(-84.377876,34.411307),30178=>array(-84.971074,34.095453),30179=>array(-85.013502,33.779335),30180=>array(-84.918032,33.717103),30182=>array(-85.248832,33.655819),30183=>array(-84.602796,34.339036),30184=>array(-84.74099,34.252034),30185=>array(-84.917819,33.519402),30187=>array(-84.847233,33.662549),30188=>array(-84.457649,34.123528),30189=>array(-84.570684,34.124213),30204=>array(-84.12104,33.056052),30205=>array(-84.475139,33.267425),30206=>array(-84.458228,33.096058),30213=>array(-84.636766,33.589298),30214=>array(-84.485997,33.490464),30215=>array(-84.456432,33.391613),30216=>array(-83.884864,33.228849),30217=>array(-85.133844,33.281895),30218=>array(-84.587178,33.129318),30220=>array(-84.823547,33.225499),30222=>array(-84.743495,33.044355),30223=>array(-84.279923,33.288801),30224=>array(-84.238945,33.204495),30228=>array(-84.30735,33.404147),30230=>array(-84.920565,33.16449),30233=>array(-83.969544,33.292157),30234=>array(-84.030964,33.323884),30236=>array(-84.324863,33.523974),30238=>array(-84.379295,33.493252),30240=>array(-85.120216,33.036796),30241=>array(-84.949445,33.022344),30248=>array(-84.106652,33.351433),30250=>array(-84.314206,33.436532),30251=>array(-84.703189,33.19502),30252=>array(-84.057165,33.473512),30253=>array(-84.18357,33.448926),30256=>array(-84.3099,33.007484),30257=>array(-84.18622,33.143414),30258=>array(-84.4491,32.972488),30259=>array(-84.737458,33.266198),30260=>array(-84.327348,33.584687),30263=>array(-84.858937,33.388415),30265=>array(-84.710976,33.411664),30268=>array(-84.722815,33.546197),30269=>array(-84.570611,33.391884),30273=>array(-84.271027,33.583798),30274=>array(-84.400443,33.554618),30275=>array(-84.874183,33.437124),30276=>array(-84.571617,33.262754),30277=>array(-84.649196,33.375308),30281=>array(-84.193388,33.567898),30284=>array(-84.288959,33.342874),30285=>array(-84.258191,32.987673),30286=>array(-84.330566,32.879167),30288=>array(-84.327109,33.652831),30289=>array(-84.63387,33.322887),30290=>array(-84.589709,33.476407),30291=>array(-84.543292,33.572312),30292=>array(-84.393225,33.168489),30293=>array(-84.6115,32.976672),30294=>array(-84.267148,33.639853),30295=>array(-84.310405,33.090279),30296=>array(-84.441151,33.563185),30297=>array(-84.373002,33.615841),30303=>array(-84.389953,33.753259),30305=>array(-84.389116,33.835696),30306=>array(-84.351498,33.789323),30307=>array(-84.3336,33.771079),30308=>array(-84.378108,33.771126),30309=>array(-84.385903,33.799832),30310=>array(-84.425995,33.726586),30311=>array(-84.475994,33.723262),30312=>array(-84.375231,33.744725),30313=>array(-84.397339,33.764539),30314=>array(-84.432245,33.757576),30315=>array(-84.382515,33.702829),30316=>array(-84.331796,33.711546),30317=>array(-84.315586,33.747999),30318=>array(-84.448312,33.792736),30319=>array(-84.336316,33.87745),30322=>array(-84.32657,33.794492),30324=>array(-84.358175,33.818405),30326=>array(-84.363971,33.849518),30327=>array(-84.417135,33.869768),30328=>array(-84.385947,33.932538),30329=>array(-84.323017,33.827479),30331=>array(-84.543902,33.707293),30332=>array(-84.404537,33.778271),30334=>array(-84.387243,33.748855),30336=>array(-84.567535,33.738366),30337=>array(-84.450081,33.640147),30338=>array(-84.318119,33.946218),30339=>array(-84.46209,33.87632),30340=>array(-84.252804,33.897873),30341=>array(-84.288866,33.888096),30342=>array(-84.375289,33.882179),30344=>array(-84.460794,33.676362),30345=>array(-84.283624,33.851722),30346=>array(-84.338876,33.92423),30349=>array(-84.523908,33.622488),30350=>array(-84.332407,33.977483),30354=>array(-84.386895,33.661498),30360=>array(-84.272577,33.933808),30363=>array(-84.398978,33.791004),30401=>array(-82.352575,32.599617),30410=>array(-82.51461,32.187516),30411=>array(-82.794572,32.128123),30412=>array(-82.490792,32.078922),30413=>array(-82.510648,32.88898),30415=>array(-81.603497,32.324484),30417=>array(-81.920992,32.170468),30420=>array(-82.152736,32.288422),30421=>array(-82.107566,32.179599),30423=>array(-81.830648,32.148808),30425=>array(-82.095422,32.684036),30426=>array(-81.641935,33.031646),30427=>array(-81.962446,31.922905),30428=>array(-82.715129,32.224545),30429=>array(-81.936169,32.165446),30434=>array(-82.383791,33.025668),30436=>array(-82.293751,32.155951),30438=>array(-82.020521,32.165611),30439=>array(-82.07563,32.404758),30441=>array(-82.224962,32.797066),30442=>array(-81.983529,32.799793),30445=>array(-82.588479,32.163981),30446=>array(-81.463016,32.563486),30448=>array(-82.363384,32.48824),30449=>array(-81.561033,32.515224),30450=>array(-81.923046,32.562333),30451=>array(-81.952461,32.390728),30452=>array(-81.888781,32.325315),30453=>array(-82.121749,32.011066),30454=>array(-82.730358,32.436077),30455=>array(-81.802282,32.690978),30456=>array(-81.796159,32.980749),30457=>array(-82.567512,32.400272),30458=>array(-81.828266,32.399676),30460=>array(-81.781595,32.419052),30461=>array(-81.7189,32.511789),30464=>array(-82.22496,32.43723),30467=>array(-81.603534,32.753793),30470=>array(-82.560981,32.313919),30471=>array(-82.180919,32.543274),30473=>array(-82.46883,32.016897),30474=>array(-82.417773,32.238578),30475=>array(-82.368594,32.224698),30477=>array(-82.401582,32.861525),30501=>array(-83.815174,34.318834),30504=>array(-83.890269,34.273118),30506=>array(-83.895595,34.346947),30507=>array(-83.774423,34.254846),30510=>array(-83.571657,34.444832),30511=>array(-83.486718,34.449701),30512=>array(-83.967855,34.856724),30513=>array(-84.322383,34.821043),30516=>array(-83.031351,34.379515),30517=>array(-83.797204,34.130358),30518=>array(-84.027398,34.130846),30519=>array(-83.944991,34.087437),30520=>array(-83.082621,34.34005),30521=>array(-83.292322,34.362448),30522=>array(-84.340461,34.796102),30523=>array(-83.553605,34.716605),30525=>array(-83.369354,34.907215),30527=>array(-83.783789,34.481368),30528=>array(-83.793245,34.621058),30529=>array(-83.482653,34.217179),30530=>array(-83.3937,34.222298),30531=>array(-83.592212,34.512602),30533=>array(-84.020072,34.56356),30534=>array(-84.144329,34.4311),30535=>array(-83.57541,34.573483),30536=>array(-84.366774,34.648872),30537=>array(-83.320177,34.976315),30538=>array(-83.263844,34.500986),30540=>array(-84.543528,34.728127),30541=>array(-84.539104,34.912906),30542=>array(-83.909134,34.177647),30543=>array(-83.649536,34.290463),30545=>array(-83.762194,34.76251),30546=>array(-83.696585,34.898796),30547=>array(-83.455885,34.361833),30548=>array(-83.766912,34.089799),30549=>array(-83.577448,34.10799),30552=>array(-83.443724,34.770857),30553=>array(-83.083989,34.44384),30554=>array(-83.660793,34.399148),30555=>array(-84.42894,34.974787),30557=>array(-83.18496,34.479804),30558=>array(-83.568717,34.266191),30559=>array(-84.274178,34.957838),30560=>array(-84.204831,34.876756),30562=>array(-83.381112,34.921514),30563=>array(-83.454897,34.567865),30564=>array(-83.886898,34.469726),30565=>array(-83.411497,34.086211),30566=>array(-83.895195,34.236169),30567=>array(-83.676617,34.180818),30568=>array(-83.432688,34.959452),30571=>array(-83.694014,34.707523),30572=>array(-84.072487,34.735794),30573=>array(-83.416673,34.749597),30575=>array(-83.713476,34.207642),30576=>array(-83.460157,34.840487),30577=>array(-83.325929,34.552419),30581=>array(-83.423725,34.795248),30582=>array(-83.895706,34.95375),30601=>array(-83.344913,34.001592),30602=>array(-83.372937,33.944542),30605=>array(-83.323577,33.905911),30606=>array(-83.429389,33.938592),30607=>array(-83.447551,34.017305),30609=>array(-83.382007,33.949464),30619=>array(-83.244694,33.855811),30620=>array(-83.758422,33.929472),30621=>array(-83.492132,33.791462),30622=>array(-83.51752,33.925221),30623=>array(-83.541786,33.728465),30624=>array(-83.044149,34.186246),30625=>array(-83.33353,33.520284),30627=>array(-82.958053,33.973309),30628=>array(-83.213297,34.028875),30629=>array(-83.110117,34.076932),30630=>array(-83.147279,33.913366),30631=>array(-82.875208,33.559314),30633=>array(-83.254872,34.178174),30634=>array(-82.945483,34.195694),30635=>array(-82.793249,34.105769),30641=>array(-83.574025,33.778357),30642=>array(-83.194368,33.554129),30643=>array(-82.908971,34.362655),30646=>array(-83.298792,34.08303),30648=>array(-83.052055,33.879979),30650=>array(-83.473754,33.583711),30655=>array(-83.696095,33.781688),30656=>array(-83.716175,33.862137),30660=>array(-82.951476,33.784234),30662=>array(-83.1541,34.267311),30663=>array(-83.600993,33.615797),30664=>array(-82.798319,33.556259),30665=>array(-83.062684,33.542772),30666=>array(-83.584659,33.962144),30667=>array(-83.14533,33.776347),30668=>array(-82.697208,33.895747),30669=>array(-83.120938,33.672149),30673=>array(-82.71394,33.71085),30677=>array(-83.373342,33.783202),30678=>array(-83.065832,33.453078),30680=>array(-83.700168,33.996105),30683=>array(-83.256267,33.94698),30701=>array(-84.956866,34.490515),30705=>array(-84.745087,34.754392),30707=>array(-85.359193,34.77195),30708=>array(-84.664614,34.961782),30710=>array(-84.91335,34.954553),30711=>array(-84.715779,34.920232),30720=>array(-85.000824,34.733644),30721=>array(-84.916087,34.788631),30725=>array(-85.352675,34.924777),30726=>array(-85.139577,34.976243),30728=>array(-85.22579,34.684875),30730=>array(-85.417499,34.348052),30731=>array(-85.477364,34.587768),30733=>array(-85.050554,34.414593),30734=>array(-84.714916,34.532804),30735=>array(-84.882661,34.602883),30736=>array(-85.13397,34.902663),30738=>array(-85.480919,34.796535),30739=>array(-85.215984,34.805931),30740=>array(-85.072119,34.75715),30741=>array(-85.281297,34.952685),30742=>array(-85.243239,34.950583),30746=>array(-85.027273,34.577083),30747=>array(-85.302791,34.502597),30750=>array(-85.388227,34.941414),30751=>array(-84.73269,34.984504),30752=>array(-85.537961,34.914982),30753=>array(-85.285775,34.58231),30755=>array(-85.042839,34.86801),30756=>array(-84.977052,34.89765),30757=>array(-85.441516,34.935801),30802=>array(-82.299935,33.601437),30803=>array(-82.549061,33.133196),30805=>array(-82.191822,33.279746),30807=>array(-82.648621,33.457408),30808=>array(-82.391923,33.384114),30809=>array(-82.170379,33.555948),30810=>array(-82.590456,33.235677),30812=>array(-82.0287,33.367075),30813=>array(-82.220051,33.471668),30814=>array(-82.299828,33.440406),30815=>array(-82.088937,33.287235),30816=>array(-82.167067,33.156879),30817=>array(-82.43023,33.77835),30818=>array(-82.330984,33.262941),30820=>array(-82.709869,33.217572),30821=>array(-82.742067,33.490433),30822=>array(-81.852686,32.926337),30823=>array(-82.45338,33.226005),30824=>array(-82.514855,33.512953),30828=>array(-82.656312,33.368038),30830=>array(-81.975337,33.079811),30833=>array(-82.353132,33.19125),30901=>array(-81.956157,33.43722),30903=>array(-82.162688,33.490148),30904=>array(-82.014102,33.478289),30905=>array(-82.142573,33.41516),30906=>array(-81.967703,33.346732),30907=>array(-82.085688,33.523809),30909=>array(-82.082981,33.470373),30912=>array(-81.988078,33.470501),31001=>array(-83.339665,31.976256),31002=>array(-82.595322,32.554049),31003=>array(-83.212516,32.606281),31005=>array(-83.597459,32.544201),31006=>array(-84.251849,32.581861),31007=>array(-83.927243,32.188594),31008=>array(-83.785924,32.665346),31009=>array(-83.019789,32.281608),31011=>array(-83.074875,32.129578),31012=>array(-83.170943,32.394437),31014=>array(-83.349077,32.415886),31015=>array(-83.774945,31.935),31016=>array(-84.115961,32.842251),31017=>array(-83.23222,32.621094),31018=>array(-82.627586,32.977092),31019=>array(-83.051342,32.424244),31020=>array(-83.498578,32.690507),31021=>array(-82.943064,32.493414),31022=>array(-83.116631,32.51154),31023=>array(-83.199454,32.183213),31024=>array(-83.37549,33.320918),31025=>array(-83.741003,32.335837),31027=>array(-82.804221,32.581108),31028=>array(-83.695724,32.627198),31029=>array(-83.936448,33.041202),31030=>array(-83.890124,32.570683),31031=>array(-83.328348,32.866283),31032=>array(-83.569169,33.011683),31033=>array(-83.428265,33.084568),31035=>array(-82.696035,32.845795),31036=>array(-83.523221,32.282058),31037=>array(-82.969633,32.081274),31038=>array(-83.647114,33.142737),31039=>array(-84.387121,32.594332),31041=>array(-84.204238,32.333518),31042=>array(-83.172257,32.748954),31044=>array(-83.384795,32.654992),31045=>array(-82.785442,33.280835),31046=>array(-83.79673,33.057565),31047=>array(-83.595342,32.46728),31049=>array(-82.526508,32.686106),31050=>array(-83.955972,32.739677),31051=>array(-83.886797,32.155877),31052=>array(-83.848511,32.784433),31054=>array(-83.214067,32.889861),31055=>array(-82.900735,32.005073),31057=>array(-83.936561,32.435),31058=>array(-84.410396,32.488651),31060=>array(-83.063507,31.975665),31061=>array(-83.246171,33.077282),31062=>array(-83.215582,33.046624),31063=>array(-83.96326,32.288966),31064=>array(-83.702347,33.286297),31065=>array(-83.167623,32.552375),31066=>array(-84.018077,32.806735),31067=>array(-82.936674,32.860339),31068=>array(-84.117049,32.328618),31069=>array(-83.748603,32.440068),31070=>array(-83.789771,32.18658),31071=>array(-83.540786,32.129456),31072=>array(-83.56684,31.974465),31075=>array(-82.956349,32.351617),31076=>array(-84.110141,32.53887),31077=>array(-83.19837,31.921144),31078=>array(-84.074538,32.694909),31079=>array(-83.458767,31.942896),31081=>array(-84.282732,32.419232),31082=>array(-82.903117,32.996417),31083=>array(-82.814155,32.040353),31084=>array(-83.607862,31.961703),31085=>array(-83.627679,33.427353),31087=>array(-83.001031,33.251362),31088=>array(-83.653003,32.580403),31089=>array(-82.860314,32.850766),31090=>array(-83.068206,32.829744),31091=>array(-83.704462,32.237888),31092=>array(-83.785552,32.090962),31093=>array(-83.657206,32.647873),31094=>array(-82.795759,33.113614),31096=>array(-82.704531,32.722219),31097=>array(-84.166895,32.890411),31098=>array(-83.56856,32.614215),31201=>array(-83.617554,32.804382),31204=>array(-83.674775,32.848513),31206=>array(-83.693698,32.800857),31207=>array(-83.649156,32.828448),31210=>array(-83.735303,32.907304),31211=>array(-83.576017,32.901362),31213=>array(-83.63935,32.840081),31216=>array(-83.68534,32.729664),31217=>array(-83.500661,32.843569),31220=>array(-83.809485,32.871225),31301=>array(-81.60235,31.750629),31302=>array(-81.341739,32.121659),31303=>array(-81.313427,32.505422),31304=>array(-81.354554,31.510772),31305=>array(-81.393957,31.396816),31307=>array(-81.398602,32.172843),31308=>array(-81.471289,32.180316),31309=>array(-81.438392,31.879886),31312=>array(-81.401806,32.311117),31313=>array(-81.612554,31.844789),31314=>array(-81.631076,31.870154),31315=>array(-81.588978,31.892873),31316=>array(-81.724662,31.717608),31318=>array(-81.371941,32.142025),31320=>array(-81.368411,31.765504),31321=>array(-81.659775,32.185059),31322=>array(-81.255465,32.109885),31323=>array(-81.427666,31.687482),31324=>array(-81.265025,31.850231),31326=>array(-81.229931,32.2952),31327=>array(-81.248753,31.467922),31328=>array(-80.88895,32.006351),31329=>array(-81.350634,32.425638),31331=>array(-81.441116,31.52458),31401=>array(-81.088261,32.074679),31404=>array(-81.049224,32.051578),31405=>array(-81.179127,32.039413),31406=>array(-81.083838,31.981768),31407=>array(-81.191478,32.18559),31408=>array(-81.184333,32.11755),31409=>array(-81.144672,32.016111),31410=>array(-80.994533,32.024928),31411=>array(-81.034643,31.942989),31415=>array(-81.128152,32.079158),31419=>array(-81.230649,31.997154),31501=>array(-82.350198,31.223623),31503=>array(-82.413073,31.202246),31510=>array(-82.440693,31.545485),31512=>array(-83.018356,31.545696),31513=>array(-82.347726,31.77705),31516=>array(-82.25325,31.309373),31518=>array(-82.185093,31.512607),31519=>array(-82.879356,31.684279),31520=>array(-81.493973,31.180919),31522=>array(-81.342045,31.25668),31523=>array(-81.621987,31.217977),31524=>array(-81.473395,31.241022),31525=>array(-81.526435,31.3211),31527=>array(-81.433275,31.06699),31532=>array(-82.758822,31.72207),31533=>array(-82.828039,31.560258),31535=>array(-82.867955,31.461219),31537=>array(-82.00523,30.885212),31539=>array(-82.605344,31.8317),31542=>array(-82.119407,31.142701),31543=>array(-81.827173,31.32969),31544=>array(-82.963561,31.840713),31545=>array(-81.934173,31.663955),31546=>array(-81.777301,31.509811),31547=>array(-81.559737,30.790547),31548=>array(-81.697298,30.795637),31549=>array(-82.714917,31.9282),31550=>array(-82.595623,31.14708),31551=>array(-82.273212,31.495826),31552=>array(-82.599146,31.289855),31553=>array(-81.972104,31.181701),31554=>array(-82.620813,31.486069),31555=>array(-82.080662,31.705666),31556=>array(-82.112013,31.414003),31557=>array(-82.098122,31.374943),31558=>array(-81.427587,30.899344),31560=>array(-82.021183,31.499205),31561=>array(-81.309944,31.207836),31562=>array(-82.170373,30.422391),31563=>array(-82.181464,31.751319),31565=>array(-81.632529,31.066705),31566=>array(-81.805594,31.182764),31567=>array(-82.706228,31.630886),31568=>array(-81.819101,31.013362),31569=>array(-81.703565,30.90319),31601=>array(-83.319023,30.758721),31602=>array(-83.34214,30.867904),31605=>array(-83.227813,30.929823),31606=>array(-83.190044,30.806085),31620=>array(-83.434243,31.116928),31622=>array(-83.192225,31.378501),31623=>array(-82.644004,31.074434),31624=>array(-82.728715,31.296514),31625=>array(-83.533505,30.992647),31626=>array(-83.796113,30.778307),31627=>array(-83.392615,31.043183),31629=>array(-83.689394,30.816844),31630=>array(-82.876732,30.950818),31631=>array(-82.742085,30.644329),31632=>array(-83.360498,30.986988),31634=>array(-82.767459,31.042485),31635=>array(-83.049507,31.095236),31636=>array(-83.111372,30.730986),31637=>array(-83.440347,31.292447),31638=>array(-83.512186,30.906417),31639=>array(-83.190727,31.216548),31641=>array(-83.092297,30.91957),31642=>array(-82.894614,31.272143),31643=>array(-83.558387,30.770785),31645=>array(-83.218688,31.060719),31647=>array(-83.427337,31.208842),31648=>array(-83.019027,30.706502),31649=>array(-82.995472,30.963885),31650=>array(-83.025392,31.395823),31698=>array(-83.28957,30.848944),31699=>array(-83.205199,30.974915),31701=>array(-84.159214,31.552695),31705=>array(-84.042942,31.51689),31707=>array(-84.206431,31.586919),31709=>array(-84.123251,32.064834),31711=>array(-84.130254,32.190399),31712=>array(-83.707348,31.834992),31714=>array(-83.694004,31.720266),31716=>array(-84.129515,31.35677),31719=>array(-84.310735,32.090302),31720=>array(-83.724533,30.878167),31721=>array(-84.301465,31.52526),31722=>array(-83.622768,31.067453),31730=>array(-84.310924,31.194884),31733=>array(-83.489763,31.59319),31735=>array(-83.973306,31.969555),31738=>array(-83.871858,31.012696),31743=>array(-84.001125,31.909726),31744=>array(-83.901613,31.341346),31747=>array(-83.587067,31.176703),31749=>array(-83.327184,31.41359),31750=>array(-83.215037,31.736465),31756=>array(-83.96576,31.183017),31757=>array(-83.903185,30.871249),31763=>array(-84.139065,31.750082),31764=>array(-84.088839,31.976312),31765=>array(-84.027154,31.087551),31768=>array(-83.841107,31.189103),31771=>array(-83.654247,31.248233),31772=>array(-83.961027,31.724154),31773=>array(-84.048091,30.973428),31774=>array(-83.269657,31.558198),31775=>array(-83.598579,31.330841),31778=>array(-83.700075,30.974992),31779=>array(-84.211128,31.108047),31780=>array(-84.388837,32.031884),31781=>array(-83.796292,31.560578),31783=>array(-83.470125,31.758976),31784=>array(-84.03667,31.24725),31787=>array(-84.243318,31.899179),31788=>array(-83.676797,31.111441),31789=>array(-83.739835,31.479734),31790=>array(-83.577968,31.652476),31791=>array(-83.894073,31.528624),31792=>array(-84.043704,30.770798),31793=>array(-83.593543,31.462511),31794=>array(-83.452678,31.445884),31795=>array(-83.687462,31.473618),31796=>array(-83.856468,31.770118),31798=>array(-83.065969,31.613378),31801=>array(-84.594333,32.51883),31803=>array(-84.508479,32.300368),31804=>array(-84.889464,32.664526),31805=>array(-84.739504,32.263053),31806=>array(-84.322724,32.263441),31807=>array(-84.800836,32.63823),31808=>array(-85.012245,32.631009),31810=>array(-84.525722,32.568463),31811=>array(-84.931472,32.739065),31812=>array(-84.402869,32.640087),31814=>array(-84.842639,32.221713),31815=>array(-84.84488,32.030013),31816=>array(-84.60815,32.881465),31820=>array(-84.8247,32.579398),31821=>array(-84.963449,32.116128),31822=>array(-84.910348,32.864979),31823=>array(-84.822587,32.810641),31824=>array(-84.522924,32.052297),31825=>array(-84.6709,32.116195),31826=>array(-84.703286,32.792963),31827=>array(-84.521816,32.686718),31829=>array(-84.731738,32.563373),31830=>array(-84.726708,32.899494),31831=>array(-84.706837,32.685573),31832=>array(-84.614915,31.95798),31833=>array(-85.091845,32.8429),31836=>array(-84.53509,32.796402),31901=>array(-84.980285,32.465313),31903=>array(-84.954244,32.414148),31904=>array(-85.009258,32.554272),31905=>array(-84.90685,32.378795),31906=>array(-84.950173,32.467811),31907=>array(-84.901475,32.482037),31909=>array(-84.924106,32.548807),32003=>array(-81.710157,30.095585),32008=>array(-82.913343,29.910047),32009=>array(-81.973824,30.422502),32011=>array(-81.839579,30.571111),32024=>array(-82.733585,30.089246),32025=>array(-82.579118,30.107103),32026=>array(-82.18168,30.054148),32033=>array(-81.434324,29.788112),32034=>array(-81.49172,30.609692),32038=>array(-82.693272,29.935223),32040=>array(-82.238884,30.243516),32043=>array(-81.732479,29.936725),32044=>array(-82.169415,29.859458),32046=>array(-81.916442,30.701544),32052=>array(-82.936084,30.486131),32053=>array(-83.12606,30.575561),32054=>array(-82.394324,30.033622),32055=>array(-82.62413,30.270103),32058=>array(-82.111729,30.076852),32059=>array(-83.24902,30.373884),32060=>array(-83.041039,30.27403),32061=>array(-82.510313,30.097553),32062=>array(-82.978338,30.137457),32063=>array(-82.113199,30.245965),32064=>array(-82.984108,30.295625),32065=>array(-81.797016,30.152238),32066=>array(-83.228097,30.039624),32068=>array(-81.890854,30.083265),32071=>array(-82.955828,30.058117),32072=>array(-82.424491,30.18816),32073=>array(-81.739144,30.169821),32079=>array(-81.807023,29.977726),32080=>array(-81.269782,29.819001),32081=>array(-81.407584,30.131119),32082=>array(-81.369578,30.125226),32083=>array(-82.232829,30.114651),32084=>array(-81.367087,29.918235),32086=>array(-81.301979,29.759316),32087=>array(-82.28046,30.377434),32091=>array(-82.127565,29.929682),32092=>array(-81.5073,29.936161),32094=>array(-82.822118,30.188269),32095=>array(-81.411637,30.014616),32096=>array(-82.624487,30.537916),32097=>array(-81.618793,30.661202),32102=>array(-81.546429,29.137291),32110=>array(-81.339209,29.428804),32112=>array(-81.577182,29.422007),32113=>array(-82.089218,29.409977),32114=>array(-81.047652,29.194),32117=>array(-81.063969,29.235588),32118=>array(-81.002321,29.209639),32119=>array(-81.02646,29.160515),32124=>array(-81.141403,29.170716),32127=>array(-80.973604,29.106257),32128=>array(-81.071829,29.100739),32129=>array(-81.023957,29.136974),32130=>array(-81.341043,29.148342),32131=>array(-81.56645,29.684541),32132=>array(-80.922741,28.978742),32133=>array(-81.909262,29.020177),32134=>array(-81.837948,29.385007),32136=>array(-81.147376,29.463685),32137=>array(-81.219358,29.581655),32139=>array(-81.608865,29.375342),32140=>array(-81.87056,29.763094),32141=>array(-80.919135,28.928953),32145=>array(-81.421332,29.677558),32147=>array(-81.787885,29.598761),32148=>array(-81.884332,29.610135),32157=>array(-81.577652,29.468285),32159=>array(-81.898475,28.933207),32162=>array(-81.98956,28.914383),32164=>array(-81.237755,29.519896),32168=>array(-81.029413,28.963773),32169=>array(-80.866467,28.965461),32174=>array(-81.161348,29.284784),32176=>array(-81.062507,29.331582),32177=>array(-81.708149,29.690907),32179=>array(-81.891367,29.087485),32180=>array(-81.443836,29.220632),32181=>array(-81.602008,29.508059),32187=>array(-81.550038,29.578946),32189=>array(-81.647122,29.550867),32190=>array(-81.483957,29.33724),32193=>array(-81.643809,29.505449),32195=>array(-81.886336,28.98808),32202=>array(-81.647114,30.324592),32204=>array(-81.680837,30.317005),32205=>array(-81.72124,30.298806),32206=>array(-81.638776,30.350191),32207=>array(-81.641022,30.290018),32208=>array(-81.682946,30.39309),32209=>array(-81.696254,30.361015),32210=>array(-81.745526,30.266582),32211=>array(-81.582792,30.332207),32212=>array(-81.666829,30.216924),32216=>array(-81.582904,30.277467),32217=>array(-81.625052,30.237991),32218=>array(-81.667141,30.487775),32219=>array(-81.813046,30.424964),32220=>array(-81.869877,30.367918),32221=>array(-81.853581,30.256279),32222=>array(-81.828353,30.216757),32223=>array(-81.649266,30.156644),32224=>array(-81.468756,30.270482),32225=>array(-81.505829,30.357756),32226=>array(-81.506148,30.48124),32227=>array(-81.404408,30.389189),32228=>array(-81.400074,30.39186),32233=>array(-81.419275,30.358516),32234=>array(-81.983522,30.226001),32244=>array(-81.752545,30.217669),32246=>array(-81.517139,30.29376),32250=>array(-81.412032,30.280508),32254=>array(-81.734788,30.340961),32256=>array(-81.472825,30.175149),32257=>array(-81.612465,30.189355),32258=>array(-81.549024,30.137199),32259=>array(-81.584395,30.080228),32266=>array(-81.409066,30.317386),32277=>array(-81.59389,30.377535),32301=>array(-84.258472,30.427753),32303=>array(-84.341629,30.515516),32304=>array(-84.352721,30.45367),32305=>array(-84.296361,30.332299),32308=>array(-84.226927,30.47745),32309=>array(-84.097649,30.56683),32310=>array(-84.512181,30.385436),32311=>array(-84.174237,30.382208),32312=>array(-84.229562,30.605283),32317=>array(-84.116832,30.470692),32320=>array(-85.111304,29.731714),32321=>array(-84.979665,30.26544),32322=>array(-84.576593,29.957304),32323=>array(-84.613733,29.891511),32324=>array(-84.783254,30.654712),32327=>array(-84.305327,30.182261),32328=>array(-84.909118,29.751831),32330=>array(-84.750533,30.579934),32331=>array(-83.638355,30.441057),32332=>array(-84.677031,30.620273),32333=>array(-84.417533,30.607607),32334=>array(-84.740243,30.258575),32336=>array(-83.847969,30.260764),32340=>array(-83.433967,30.46033),32343=>array(-84.480288,30.475365),32344=>array(-83.96229,30.526076),32346=>array(-84.384581,29.990836),32347=>array(-83.609333,30.17247),32348=>array(-83.596157,29.977404),32350=>array(-83.325791,30.574964),32351=>array(-84.675023,30.520392),32352=>array(-84.591623,30.662356),32355=>array(-84.208422,30.172037),32356=>array(-83.415003,29.859235),32358=>array(-84.558003,30.105666),32359=>array(-83.386582,29.680062),32361=>array(-83.988583,30.357712),32399=>array(-84.282546,30.436901),32401=>array(-85.660922,30.159737),32403=>array(-85.553231,30.048562),32404=>array(-85.506149,30.196305),32405=>array(-85.667428,30.201994),32407=>array(-85.790694,30.198324),32408=>array(-85.732678,30.142185),32409=>array(-85.653691,30.356756),32410=>array(-85.414223,29.995187),32413=>array(-85.905314,30.3103),32420=>array(-85.38457,30.632365),32421=>array(-85.179795,30.531817),32423=>array(-85.061166,30.943727),32424=>array(-85.08306,30.362385),32425=>array(-85.720492,30.853184),32426=>array(-85.370413,30.946886),32427=>array(-85.792206,30.710704),32428=>array(-85.572945,30.61575),32430=>array(-85.234083,30.418361),32431=>array(-85.410816,30.787482),32432=>array(-85.077571,30.714871),32433=>array(-86.200838,30.851178),32435=>array(-86.131273,30.656732),32437=>array(-85.909221,30.436248),32438=>array(-85.424081,30.501287),32439=>array(-86.112068,30.468337),32440=>array(-85.52619,30.922426),32442=>array(-85.017163,30.678553),32443=>array(-85.10942,30.872521),32444=>array(-85.6516,30.239945),32445=>array(-85.197742,30.968635),32446=>array(-85.231403,30.848192),32447=>array(-85.251567,30.75995),32448=>array(-85.227422,30.670313),32449=>array(-85.240257,30.286856),32455=>array(-85.962701,30.638626),32456=>array(-85.298199,29.838272),32459=>array(-86.185532,30.360668),32460=>array(-84.954234,30.764089),32461=>array(-86.027719,30.289685),32462=>array(-85.833399,30.5542),32463=>array(-85.590275,30.631413),32464=>array(-85.952559,30.902879),32465=>array(-85.181889,30.007868),32466=>array(-85.512314,30.394337),32501=>array(-87.222515,30.428781),32502=>array(-87.223506,30.409367),32503=>array(-87.213643,30.459667),32504=>array(-87.186672,30.472483),32505=>array(-87.26065,30.454624),32506=>array(-87.369394,30.391628),32507=>array(-87.373783,30.339837),32508=>array(-87.316598,30.350765),32509=>array(-87.334279,30.467726),32511=>array(-87.291696,30.406055),32514=>array(-87.221604,30.531268),32526=>array(-87.365573,30.499226),32530=>array(-87.030361,30.598239),32531=>array(-86.700335,30.874169),32533=>array(-87.326783,30.610506),32534=>array(-87.281718,30.528939),32535=>array(-87.345635,30.963418),32536=>array(-86.591616,30.763783),32539=>array(-86.464476,30.776138),32541=>array(-86.469506,30.392765),32542=>array(-86.525167,30.464551),32544=>array(-86.696265,30.426974),32547=>array(-86.668362,30.473869),32548=>array(-86.650482,30.403001),32550=>array(-86.346246,30.385086),32561=>array(-87.113185,30.347061),32563=>array(-87.028821,30.396879),32564=>array(-86.781932,30.728849),32565=>array(-87.131683,30.892603),32566=>array(-86.880319,30.436005),32567=>array(-86.445786,30.924677),32568=>array(-87.449977,30.873178),32569=>array(-86.733151,30.409856),32570=>array(-86.974484,30.805548),32571=>array(-87.199429,30.677679),32577=>array(-87.365012,30.727473),32578=>array(-86.447541,30.506696),32579=>array(-86.574504,30.449473),32580=>array(-86.514831,30.490067),32583=>array(-86.970668,30.592428),32601=>array(-82.324515,29.648993),32603=>array(-82.3475,29.656712),32605=>array(-82.372822,29.67918),32606=>array(-82.444096,29.682004),32607=>array(-82.418917,29.647328),32608=>array(-82.407808,29.597009),32609=>array(-82.282534,29.76899),32612=>array(-82.353845,29.64312),32615=>array(-82.486085,29.819094),32616=>array(-82.495253,29.788492),32617=>array(-82.074366,29.308388),32618=>array(-82.516538,29.545873),32619=>array(-82.86012,29.762577),32621=>array(-82.610144,29.424698),32622=>array(-82.318845,29.908054),32625=>array(-82.997039,29.208264),32626=>array(-82.898424,29.425025),32628=>array(-83.207,29.625434),32631=>array(-82.092105,29.704846),32639=>array(-82.712558,29.227004),32640=>array(-82.087043,29.577338),32641=>array(-82.231714,29.642524),32643=>array(-82.651245,29.824665),32648=>array(-83.270475,29.503781),32653=>array(-82.393796,29.744787),32656=>array(-81.959454,29.813684),32658=>array(-82.397103,29.846767),32664=>array(-82.217423,29.445934),32666=>array(-81.997495,29.723637),32667=>array(-82.305264,29.511966),32668=>array(-82.474807,29.257343),32669=>array(-82.589957,29.632154),32680=>array(-83.13231,29.542562),32681=>array(-82.205579,29.423388),32683=>array(-82.786384,29.295643),32686=>array(-82.275016,29.355545),32692=>array(-83.122358,29.333289),32693=>array(-82.78531,29.626477),32694=>array(-82.144315,29.807932),32696=>array(-82.461818,29.397511),32697=>array(-82.429553,29.932587),32701=>array(-81.370266,28.665548),32702=>array(-81.624998,29.039041),32703=>array(-81.553055,28.671439),32707=>array(-81.315021,28.663959),32708=>array(-81.273258,28.686894),32709=>array(-80.959302,28.500893),32712=>array(-81.48747,28.75169),32713=>array(-81.325287,28.88373),32714=>array(-81.411756,28.662559),32720=>array(-81.368585,29.003431),32724=>array(-81.225582,29.05725),32725=>array(-81.251563,28.886079),32726=>array(-81.678843,28.855051),32730=>array(-81.343713,28.654162),32732=>array(-81.102337,28.750367),32735=>array(-81.739041,28.89042),32736=>array(-81.490108,28.916491),32738=>array(-81.185176,28.905269),32744=>array(-81.219826,28.985019),32746=>array(-81.354882,28.766592),32750=>array(-81.348035,28.70795),32751=>array(-81.365046,28.6304),32754=>array(-80.91964,28.686657),32757=>array(-81.638118,28.773053),32759=>array(-80.902705,28.825785),32763=>array(-81.29682,28.941315),32764=>array(-81.084904,28.848057),32765=>array(-81.196224,28.665141),32766=>array(-81.074925,28.643576),32767=>array(-81.534474,29.026591),32771=>array(-81.325003,28.813563),32773=>array(-81.247905,28.755429),32776=>array(-81.508803,28.820128),32778=>array(-81.734873,28.780881),32779=>array(-81.414779,28.727263),32780=>array(-80.792256,28.532779),32784=>array(-81.716422,28.974539),32789=>array(-81.352273,28.599188),32792=>array(-81.298342,28.610096),32796=>array(-80.845853,28.625287),32798=>array(-81.58772,28.723714),32801=>array(-81.374351,28.541774),32803=>array(-81.346209,28.555514),32804=>array(-81.396447,28.57868),32805=>array(-81.403681,28.529996),32806=>array(-81.360438,28.511789),32807=>array(-81.299722,28.554584),32808=>array(-81.4443,28.58011),32809=>array(-81.385959,28.462146),32810=>array(-81.42769,28.625101),32811=>array(-81.447421,28.521568),32812=>array(-81.322855,28.483996),32814=>array(-81.322358,28.572584),32817=>array(-81.243645,28.590992),32818=>array(-81.486895,28.586751),32819=>array(-81.472422,28.453439),32820=>array(-81.124388,28.583601),32821=>array(-81.479599,28.381999),32822=>array(-81.290154,28.489898),32824=>array(-81.33304,28.384164),32825=>array(-81.229003,28.518028),32826=>array(-81.184561,28.588358),32827=>array(-81.29875,28.415886),32828=>array(-81.166358,28.529208),32829=>array(-81.246093,28.484548),32830=>array(-81.573614,28.383063),32831=>array(-81.148241,28.473077),32832=>array(-81.191537,28.40318),32833=>array(-81.079755,28.495069),32835=>array(-81.482513,28.518602),32836=>array(-81.519295,28.407838),32837=>array(-81.429129,28.379425),32839=>array(-81.407208,28.488069),32901=>array(-80.623618,28.079357),32903=>array(-80.593357,28.104536),32904=>array(-80.678441,28.0665),32905=>array(-80.600412,28.031367),32907=>array(-80.681257,28.020804),32908=>array(-80.698949,27.956345),32909=>array(-80.644232,27.919258),32920=>array(-80.616071,28.39652),32922=>array(-80.742906,28.372999),32925=>array(-80.629046,28.246103),32926=>array(-80.818135,28.388705),32927=>array(-80.812888,28.457509),32931=>array(-80.623102,28.323196),32934=>array(-80.713073,28.135306),32935=>array(-80.649969,28.145549),32937=>array(-80.60177,28.178766),32940=>array(-80.795699,28.213275),32948=>array(-80.733582,27.888805),32949=>array(-80.56769,27.909843),32950=>array(-80.569593,27.980571),32951=>array(-80.504706,27.947337),32952=>array(-80.660577,28.31093),32953=>array(-80.702668,28.441687),32955=>array(-80.725043,28.296697),32958=>array(-80.49146,27.794384),32960=>array(-80.402619,27.641533),32962=>array(-80.382865,27.587819),32963=>array(-80.393276,27.718239),32966=>array(-80.707641,27.683619),32967=>array(-80.454301,27.715446),32968=>array(-80.472479,27.584207),32970=>array(-80.449289,27.750398),32976=>array(-80.554209,27.84624),33001=>array(-80.806001,24.81713),33004=>array(-80.137623,26.057792),33009=>array(-80.147265,25.985191),33010=>array(-80.27872,25.833202),33012=>array(-80.301115,25.866106),33013=>array(-80.269677,25.86219),33014=>array(-80.302417,25.903447),33015=>array(-80.31818,25.940565),33016=>array(-80.332455,25.895005),33018=>array(-80.384416,25.917734),33019=>array(-80.120219,26.027459),33020=>array(-80.152944,26.019191),33021=>array(-80.186539,26.02313),33023=>array(-80.217067,25.9892),33024=>array(-80.24471,26.027261),33025=>array(-80.281374,25.98821),33026=>array(-80.295994,26.026198),33027=>array(-80.343473,25.985442),33028=>array(-80.340396,26.021239),33029=>array(-80.416084,25.9743),33030=>array(-80.510882,25.485147),33031=>array(-80.501317,25.524653),33032=>array(-80.390738,25.531334),33033=>array(-80.414478,25.48319),33034=>array(-80.632499,25.274354),33035=>array(-80.384155,25.409275),33036=>array(-80.710993,24.893835),33037=>array(-80.395451,25.228322),33039=>array(-80.398423,25.501679),33040=>array(-81.909735,24.561353),33042=>array(-81.505144,24.671216),33043=>array(-81.329949,24.725861),33050=>array(-81.010326,24.747487),33051=>array(-81.021524,24.720625),33054=>array(-80.265122,25.908575),33055=>array(-80.278855,25.948468),33056=>array(-80.243582,25.948877),33060=>array(-80.120584,26.234772),33062=>array(-80.091233,26.241077),33063=>array(-80.209454,26.251573),33064=>array(-80.1153,26.278502),33065=>array(-80.260118,26.27377),33066=>array(-80.170374,26.252615),33067=>array(-80.22539,26.305815),33068=>array(-80.217951,26.215954),33069=>array(-80.156969,26.23583),33070=>array(-80.518498,25.017205),33071=>array(-80.265311,26.244602),33073=>array(-80.181416,26.298241),33076=>array(-80.277978,26.315322),33101=>array(-80.198739,25.779298),33109=>array(-80.140066,25.756717),33122=>array(-80.28835,25.79485),33125=>array(-80.237812,25.783753),33126=>array(-80.299475,25.7794),33127=>array(-80.205808,25.813175),33128=>array(-80.203733,25.776168),33129=>array(-80.190028,25.750167),33130=>array(-80.203359,25.768524),33131=>array(-80.182897,25.766206),33132=>array(-80.175785,25.778369),33133=>array(-80.239996,25.728662),33134=>array(-80.270379,25.753332),33135=>array(-80.235095,25.766544),33136=>array(-80.204722,25.787182),33137=>array(-80.171528,25.816281),33138=>array(-80.178002,25.853765),33139=>array(-80.1532,25.779808),33140=>array(-80.133711,25.819714),33141=>array(-80.138726,25.851854),33142=>array(-80.239315,25.812023),33143=>array(-80.297375,25.703032),33144=>array(-80.312667,25.763458),33145=>array(-80.234427,25.753132),33146=>array(-80.272571,25.72085),33147=>array(-80.238166,25.851225),33149=>array(-80.168541,25.719513),33150=>array(-80.207174,25.85219),33154=>array(-80.131831,25.883337),33155=>array(-80.310768,25.736887),33156=>array(-80.29701,25.668203),33157=>array(-80.343496,25.606126),33158=>array(-80.311316,25.63884),33160=>array(-80.135801,25.933997),33161=>array(-80.181539,25.893664),33162=>array(-80.177175,25.927997),33165=>array(-80.358271,25.734345),33166=>array(-80.316183,25.827855),33167=>array(-80.236913,25.884244),33168=>array(-80.209181,25.893051),33169=>array(-80.214686,25.943117),33170=>array(-80.457897,25.557912),33172=>array(-80.361253,25.786909),33173=>array(-80.357503,25.70232),33174=>array(-80.364697,25.761518),33175=>array(-80.406757,25.734734),33176=>array(-80.358354,25.659873),33177=>array(-80.404194,25.596129),33178=>array(-80.422908,25.834607),33179=>array(-80.179998,25.95762),33180=>array(-80.143113,25.960389),33181=>array(-80.152505,25.898061),33182=>array(-80.441531,25.780762),33183=>array(-80.404436,25.70313),33184=>array(-80.406473,25.759711),33185=>array(-80.451643,25.727513),33186=>array(-80.412286,25.654346),33187=>array(-80.506909,25.595896),33189=>array(-80.335434,25.572213),33190=>array(-80.350543,25.559318),33193=>array(-80.465111,25.70077),33194=>array(-80.583619,25.713938),33196=>array(-80.486317,25.651006),33301=>array(-80.127909,26.121323),33304=>array(-80.121179,26.140453),33305=>array(-80.11944,26.153361),33306=>array(-80.113853,26.165442),33308=>array(-80.104988,26.188511),33309=>array(-80.172424,26.185954),33311=>array(-80.172785,26.144208),33312=>array(-80.181724,26.08849),33313=>array(-80.22621,26.151416),33314=>array(-80.222643,26.067601),33315=>array(-80.152991,26.087025),33316=>array(-80.121773,26.097266),33317=>array(-80.227875,26.1126),33319=>array(-80.225802,26.181382),33321=>array(-80.270272,26.213579),33322=>array(-80.274503,26.150204),33323=>array(-80.316519,26.152016),33324=>array(-80.27494,26.112485),33325=>array(-80.318335,26.111872),33326=>array(-80.37067,26.114337),33327=>array(-80.422825,26.111079),33328=>array(-80.275056,26.067529),33330=>array(-80.319068,26.060992),33331=>array(-80.368583,26.059533),33332=>array(-80.460152,26.006735),33334=>array(-80.133587,26.182573),33351=>array(-80.274599,26.17937),33401=>array(-80.070249,26.715844),33403=>array(-80.076368,26.803747),33404=>array(-80.063738,26.781022),33405=>array(-80.058452,26.669649),33406=>array(-80.092385,26.664085),33407=>array(-80.091099,26.757668),33408=>array(-80.052061,26.840418),33409=>array(-80.099367,26.72036),33410=>array(-80.087612,26.848356),33411=>array(-80.193112,26.720009),33412=>array(-80.207673,26.794729),33413=>array(-80.153849,26.663862),33414=>array(-80.247144,26.648656),33415=>array(-80.126573,26.660205),33417=>array(-80.124507,26.719196),33418=>array(-80.165705,26.87272),33426=>array(-80.083152,26.533736),33428=>array(-80.208054,26.352947),33430=>array(-80.554002,26.641965),33431=>array(-80.107317,26.376191),33432=>array(-80.082735,26.343902),33433=>array(-80.159235,26.347159),33434=>array(-80.167138,26.382712),33435=>array(-80.061367,26.525785),33436=>array(-80.107263,26.522954),33437=>array(-80.148217,26.511382),33438=>array(-80.592632,26.932739),33440=>array(-81.037938,26.564549),33441=>array(-80.09787,26.311102),33442=>array(-80.145699,26.309788),33444=>array(-80.079637,26.458903),33445=>array(-80.10635,26.455288),33446=>array(-80.186185,26.450443),33449=>array(-80.232634,26.590073),33455=>array(-80.161232,27.053143),33458=>array(-80.131851,26.936558),33460=>array(-80.056715,26.619664),33461=>array(-80.090703,26.620406),33462=>array(-80.072284,26.579999),33463=>array(-80.128892,26.592859),33467=>array(-80.175714,26.596487),33469=>array(-80.108541,26.989221),33470=>array(-80.320037,26.726784),33471=>array(-81.203814,26.885952),33472=>array(-80.185602,26.538412),33473=>array(-80.191553,26.503764),33476=>array(-80.624722,26.802148),33477=>array(-80.076589,26.920226),33478=>array(-80.246071,26.935021),33480=>array(-80.042626,26.68654),33483=>array(-80.061718,26.462644),33484=>array(-80.134433,26.454216),33486=>array(-80.112571,26.347501),33487=>array(-80.088525,26.409962),33493=>array(-80.728719,26.538819),33496=>array(-80.160556,26.406722),33498=>array(-80.219558,26.386067),33503=>array(-82.276174,27.763831),33510=>array(-82.296693,27.955637),33511=>array(-82.295738,27.909778),33513=>array(-82.194756,28.714341),33514=>array(-81.9947,28.686313),33521=>array(-82.068553,28.798271),33523=>array(-82.212103,28.416397),33525=>array(-82.198375,28.341557),33527=>array(-82.212663,27.973604),33534=>array(-82.37887,27.823188),33538=>array(-82.185148,28.849763),33540=>array(-82.133231,28.257337),33541=>array(-82.228112,28.236875),33542=>array(-82.177617,28.23578),33543=>array(-82.297428,28.211232),33544=>array(-82.366224,28.254041),33545=>array(-82.296721,28.272663),33547=>array(-82.135516,27.791084),33548=>array(-82.483778,28.147189),33549=>array(-82.446252,28.137944),33556=>array(-82.591459,28.134809),33558=>array(-82.511384,28.165519),33559=>array(-82.414612,28.161002),33563=>array(-82.124953,28.017222),33565=>array(-82.148114,28.085906),33566=>array(-82.095709,27.977965),33567=>array(-82.116772,27.920609),33569=>array(-82.288545,27.84635),33570=>array(-82.461203,27.690759),33572=>array(-82.40858,27.761109),33573=>array(-82.357237,27.722757),33576=>array(-82.328644,28.336151),33578=>array(-82.350044,27.8622),33579=>array(-82.293653,27.796231),33584=>array(-82.288403,28.007232),33585=>array(-82.0893,28.732957),33592=>array(-82.283236,28.101871),33594=>array(-82.242479,27.940934),33596=>array(-82.22587,27.887215),33597=>array(-82.080532,28.545531),33598=>array(-82.284659,27.693423),33602=>array(-82.457113,27.95353),33603=>array(-82.464439,27.985618),33604=>array(-82.45535,28.017154),33605=>array(-82.42968,27.951122),33606=>array(-82.452279,27.917452),33607=>array(-82.492176,27.962012),33609=>array(-82.517675,27.944272),33610=>array(-82.378016,27.998214),33611=>array(-82.505665,27.891345),33612=>array(-82.449573,28.050827),33613=>array(-82.450768,28.083973),33614=>array(-82.506088,28.004724),33615=>array(-82.580284,28.005103),33616=>array(-82.535394,27.865136),33617=>array(-82.39157,28.037486),33618=>array(-82.498405,28.074807),33619=>array(-82.37869,27.935372),33620=>array(-82.413225,28.062),33621=>array(-82.493273,27.841658),33624=>array(-82.528248,28.080255),33625=>array(-82.561218,28.066876),33626=>array(-82.620348,28.067045),33629=>array(-82.509043,27.921536),33634=>array(-82.54778,28.00982),33635=>array(-82.619402,28.027318),33637=>array(-82.361113,28.045334),33647=>array(-82.354093,28.126958),33701=>array(-82.632806,27.770793),33702=>array(-82.62869,27.846613),33703=>array(-82.61975,27.817056),33704=>array(-82.630066,27.798158),33705=>array(-82.643403,27.734491),33706=>array(-82.751128,27.740169),33707=>array(-82.725505,27.755558),33708=>array(-82.801134,27.817558),33709=>array(-82.731621,27.816844),33710=>array(-82.730734,27.790669),33711=>array(-82.688217,27.738736),33712=>array(-82.667894,27.734375),33713=>array(-82.677508,27.789186),33714=>array(-82.677708,27.815246),33715=>array(-82.722404,27.66268),33716=>array(-82.648609,27.87506),33744=>array(-82.773788,27.806363),33755=>array(-82.780506,27.979914),33756=>array(-82.793867,27.945386),33759=>array(-82.701482,27.975284),33760=>array(-82.71419,27.907573),33761=>array(-82.724374,28.033061),33762=>array(-82.679506,27.899189),33763=>array(-82.743418,28.002893),33764=>array(-82.740042,27.93447),33765=>array(-82.745191,27.974863),33767=>array(-82.825268,27.975574),33770=>array(-82.804068,27.915173),33771=>array(-82.758784,27.906822),33772=>array(-82.796854,27.844208),33773=>array(-82.75592,27.882294),33774=>array(-82.827877,27.883819),33776=>array(-82.825814,27.850256),33777=>array(-82.759349,27.853532),33778=>array(-82.798582,27.888129),33781=>array(-82.714996,27.838362),33782=>array(-82.708145,27.859631),33785=>array(-82.849808,27.892449),33786=>array(-82.833345,27.927096),33801=>array(-81.899669,28.035908),33803=>array(-81.932662,28.009358),33805=>array(-81.908334,28.1007),33809=>array(-81.969167,28.222746),33810=>array(-82.030327,28.1318),33811=>array(-82.014696,27.984748),33812=>array(-81.893002,27.971267),33813=>array(-81.939522,27.965132),33815=>array(-81.99759,28.041258),33823=>array(-81.81372,28.085763),33825=>array(-81.458826,27.620252),33827=>array(-81.508647,27.815891),33830=>array(-81.811452,27.87302),33834=>array(-82.001418,27.620675),33837=>array(-81.58917,28.191997),33838=>array(-81.614048,28.019442),33839=>array(-81.750503,27.976763),33841=>array(-81.754602,27.741146),33843=>array(-81.531809,27.723184),33844=>array(-81.590049,28.088805),33847=>array(-81.822039,27.802754),33848=>array(-81.50507,28.284163),33849=>array(-82.068888,28.22607),33850=>array(-81.732585,28.122375),33851=>array(-81.623893,28.044636),33852=>array(-81.373963,27.239337),33853=>array(-81.58445,27.900707),33854=>array(-81.410106,27.85644),33855=>array(-81.35276,27.795372),33856=>array(-81.428375,27.856354),33857=>array(-81.189442,27.336195),33859=>array(-81.626401,27.872695),33860=>array(-82.028186,27.767271),33865=>array(-81.963257,27.433787),33867=>array(-81.195762,27.777856),33868=>array(-81.827822,28.251383),33870=>array(-81.407942,27.506501),33872=>array(-81.545953,27.505251),33873=>array(-81.781215,27.570973),33875=>array(-81.510556,27.392317),33876=>array(-81.349938,27.411131),33877=>array(-81.613248,27.989784),33880=>array(-81.779946,27.979055),33881=>array(-81.711644,28.056447),33884=>array(-81.672447,27.97848),33890=>array(-81.70001,27.432982),33896=>array(-81.58285,28.256905),33897=>array(-81.688866,28.284872),33898=>array(-81.373419,27.841254),33901=>array(-81.878139,26.621074),33903=>array(-81.90663,26.679968),33904=>array(-81.944393,26.576012),33905=>array(-81.760927,26.667872),33907=>array(-81.871286,26.563628),33908=>array(-81.979469,26.515834),33909=>array(-81.945126,26.693201),33912=>array(-81.826183,26.53402),33913=>array(-81.696796,26.514239),33914=>array(-82.020944,26.554392),33916=>array(-81.838162,26.637074),33917=>array(-81.844783,26.738607),33919=>array(-81.901095,26.556626),33920=>array(-81.63605,26.742298),33921=>array(-82.252804,26.772225),33922=>array(-82.162513,26.638155),33924=>array(-82.209305,26.617555),33928=>array(-81.704685,26.398865),33930=>array(-81.407629,26.569818),33931=>array(-81.902995,26.433124),33935=>array(-81.432858,26.760328),33936=>array(-81.601499,26.623407),33944=>array(-81.291042,26.994443),33945=>array(-82.220545,26.602244),33946=>array(-82.281369,26.847524),33947=>array(-82.271615,26.879089),33948=>array(-82.152363,26.985889),33950=>array(-82.046244,26.902989),33952=>array(-82.097042,26.986134),33953=>array(-82.212275,26.999702),33954=>array(-82.122407,27.024724),33955=>array(-81.994031,26.81614),33956=>array(-82.143657,26.546315),33957=>array(-82.093031,26.46392),33960=>array(-81.402766,27.044099),33965=>array(-81.773019,26.463373),33966=>array(-81.830726,26.591636),33967=>array(-81.81224,26.471507),33971=>array(-81.699699,26.639584),33972=>array(-81.616279,26.64928),33973=>array(-81.727906,26.602596),33974=>array(-81.601925,26.562706),33976=>array(-81.68613,26.591277),33980=>array(-82.047288,26.979255),33981=>array(-82.219616,26.918213),33982=>array(-81.767196,26.910534),33983=>array(-82.017871,27.009117),33990=>array(-81.944774,26.62799),33991=>array(-82.024123,26.625053),33993=>array(-82.034065,26.692897),34101=>array(-81.761821,26.032137),34102=>array(-81.799105,26.137498),34103=>array(-81.806496,26.193911),34104=>array(-81.741562,26.149955),34105=>array(-81.764906,26.190061),34108=>array(-81.808323,26.246308),34109=>array(-81.763823,26.240842),34110=>array(-81.788461,26.30038),34112=>array(-81.741549,26.11931),34113=>array(-81.732424,26.043649),34114=>array(-81.538206,25.943846),34116=>array(-81.710803,26.189294),34117=>array(-81.605313,26.180909),34119=>array(-81.714053,26.26791),34120=>array(-81.570093,26.326101),34134=>array(-81.82405,26.353032),34135=>array(-81.75453,26.356331),34137=>array(-81.383188,25.942742),34138=>array(-81.368569,25.816512),34139=>array(-81.403372,25.830882),34140=>array(-81.662917,25.925194),34141=>array(-81.096082,25.94691),34142=>array(-81.313689,26.342525),34145=>array(-81.675851,25.904093),34201=>array(-82.468511,27.401694),34202=>array(-82.388721,27.406267),34203=>array(-82.507558,27.438094),34205=>array(-82.581821,27.484084),34207=>array(-82.579674,27.438677),34208=>array(-82.515923,27.487487),34209=>array(-82.651386,27.500129),34210=>array(-82.620102,27.439536),34211=>array(-82.389361,27.436918),34212=>array(-82.408468,27.499234),34215=>array(-82.685924,27.471141),34216=>array(-82.732652,27.536772),34217=>array(-82.705049,27.492089),34219=>array(-82.299034,27.576379),34221=>array(-82.554803,27.581094),34222=>array(-82.506553,27.535782),34223=>array(-82.3542,26.982666),34224=>array(-82.30394,26.917603),34228=>array(-82.638767,27.402247),34229=>array(-82.485461,27.193124),34231=>array(-82.516651,27.266027),34232=>array(-82.471887,27.324845),34233=>array(-82.476631,27.280031),34234=>array(-82.542782,27.37086),34235=>array(-82.476458,27.369739),34236=>array(-82.553527,27.316487),34237=>array(-82.512645,27.338992),34238=>array(-82.470536,27.235792),34239=>array(-82.521168,27.310893),34240=>array(-82.318479,27.364656),34241=>array(-82.377574,27.250668),34242=>array(-82.540907,27.260222),34243=>array(-82.527887,27.401013),34251=>array(-82.171574,27.377853),34266=>array(-81.823844,27.191071),34268=>array(-81.895327,27.149245),34269=>array(-82.013189,27.067637),34275=>array(-82.422444,27.151792),34285=>array(-82.439653,27.093485),34286=>array(-82.181256,27.080871),34287=>array(-82.245371,27.049618),34288=>array(-82.109851,27.054069),34289=>array(-82.132601,27.079862),34291=>array(-82.240218,27.094062),34292=>array(-82.341525,27.101944),34293=>array(-82.334744,27.030082),34420=>array(-82.038906,29.053715),34428=>array(-82.647566,28.956773),34429=>array(-82.667285,28.850605),34431=>array(-82.531443,29.134717),34432=>array(-82.384272,29.067061),34433=>array(-82.524892,29.002221),34434=>array(-82.439628,28.995934),34436=>array(-82.29798,28.72058),34442=>array(-82.383754,28.931847),34445=>array(-82.420744,28.96799),34446=>array(-82.522162,28.747282),34448=>array(-82.625156,28.768105),34449=>array(-82.679451,29.07472),34450=>array(-82.267684,28.830395),34452=>array(-82.343655,28.816305),34453=>array(-82.335722,28.874347),34461=>array(-82.494513,28.866136),34465=>array(-82.489203,28.929491),34470=>array(-82.087425,29.198907),34471=>array(-82.13077,29.160561),34472=>array(-81.997961,29.114198),34473=>array(-82.18395,29.005695),34474=>array(-82.209486,29.156461),34475=>array(-82.166961,29.258909),34476=>array(-82.19683,29.081607),34479=>array(-82.109112,29.255724),34480=>array(-82.096588,29.102401),34481=>array(-82.309621,29.1328),34482=>array(-82.275028,29.244402),34484=>array(-82.09742,28.945241),34488=>array(-81.938619,29.22809),34491=>array(-82.055144,28.995626),34498=>array(-82.736087,29.031552),34601=>array(-82.351098,28.588644),34602=>array(-82.282351,28.502482),34604=>array(-82.434791,28.476942),34606=>array(-82.595728,28.468477),34607=>array(-82.625285,28.500524),34608=>array(-82.552854,28.482826),34609=>array(-82.507906,28.479476),34610=>array(-82.511406,28.369253),34613=>array(-82.572217,28.570623),34614=>array(-82.539665,28.64631),34637=>array(-82.455707,28.302024),34638=>array(-82.512738,28.256862),34639=>array(-82.423239,28.26543),34652=>array(-82.73783,28.237465),34653=>array(-82.688415,28.244055),34654=>array(-82.62912,28.280875),34655=>array(-82.617279,28.208884),34661=>array(-82.245271,28.604751),34667=>array(-82.661275,28.391238),34668=>array(-82.708521,28.300793),34669=>array(-82.610361,28.357019),34677=>array(-82.673575,28.037522),34679=>array(-82.66123,28.432204),34681=>array(-82.77597,28.082809),34683=>array(-82.761134,28.087706),34684=>array(-82.726829,28.080744),34685=>array(-82.689101,28.093341),34688=>array(-82.678972,28.147125),34689=>array(-82.759877,28.148306),34690=>array(-82.725706,28.193745),34691=>array(-82.816078,28.198023),34695=>array(-82.688398,28.0082),34698=>array(-82.78632,28.037553),34705=>array(-81.718669,28.69976),34711=>array(-81.753341,28.530496),34714=>array(-81.778865,28.403889),34715=>array(-81.723696,28.630523),34731=>array(-81.898631,28.864109),34734=>array(-81.515454,28.537003),34736=>array(-81.901876,28.555277),34737=>array(-81.797171,28.69254),34739=>array(-81.11706,27.9305),34741=>array(-81.425522,28.30639),34743=>array(-81.355152,28.329308),34744=>array(-81.338221,28.291853),34746=>array(-81.445287,28.238886),34747=>array(-81.595543,28.311488),34748=>array(-81.882169,28.766846),34753=>array(-81.885098,28.576522),34756=>array(-81.682587,28.586318),34758=>array(-81.485986,28.194196),34759=>array(-81.419371,28.103896),34760=>array(-81.632164,28.554745),34761=>array(-81.534116,28.578576),34762=>array(-81.914243,28.756192),34769=>array(-81.290847,28.244625),34771=>array(-81.173701,28.284493),34772=>array(-81.26957,28.163926),34773=>array(-81.007563,28.159813),34785=>array(-82.040622,28.837287),34786=>array(-81.551884,28.487167),34787=>array(-81.619298,28.484973),34788=>array(-81.808248,28.895617),34797=>array(-81.825702,28.729516),34945=>array(-80.55723,27.437265),34946=>array(-80.36048,27.503294),34947=>array(-80.3752,27.454876),34949=>array(-80.299808,27.467258),34950=>array(-80.330974,27.443788),34951=>array(-80.418954,27.532134),34952=>array(-80.300095,27.296004),34953=>array(-80.382767,27.24913),34956=>array(-80.498221,27.094542),34957=>array(-80.238923,27.280287),34972=>array(-80.930424,27.504987),34974=>array(-80.949686,27.145973),34981=>array(-80.370857,27.393969),34982=>array(-80.308018,27.373264),34983=>array(-80.352498,27.323951),34984=>array(-80.330756,27.249123),34986=>array(-80.402409,27.323655),34987=>array(-80.48533,27.301825),34990=>array(-80.346948,27.137133),34994=>array(-80.257153,27.200948),34996=>array(-80.189813,27.192817),34997=>array(-80.270195,27.055637),35004=>array(-86.493795,33.603417),35005=>array(-87.000649,33.59595),35006=>array(-87.20973,33.422765),35007=>array(-86.797578,33.215501),35010=>array(-85.940602,32.916507),35013=>array(-86.517777,33.902168),35014=>array(-86.262233,33.355635),35016=>array(-86.502006,34.32387),35019=>array(-86.634094,34.302078),35020=>array(-86.951784,33.402429),35022=>array(-86.971458,33.322849),35023=>array(-87.088306,33.467902),35031=>array(-86.554899,34.097791),35032=>array(-86.336417,33.264859),35033=>array(-87.031801,33.926475),35034=>array(-87.271681,32.911122),35035=>array(-86.973505,33.043787),35036=>array(-86.919599,33.643922),35040=>array(-86.728894,33.102967),35042=>array(-87.103816,32.957991),35043=>array(-86.659205,33.314203),35044=>array(-86.380748,33.243708),35045=>array(-86.676761,32.799962),35046=>array(-86.534157,32.931141),35049=>array(-86.612064,33.961807),35051=>array(-86.618915,33.205032),35052=>array(-86.409897,33.590682),35053=>array(-87.073134,34.051416),35054=>array(-86.337957,33.501987),35055=>array(-86.758714,34.151183),35057=>array(-86.934257,34.180462),35058=>array(-86.737261,34.228856),35060=>array(-86.951726,33.55775),35061=>array(-86.956022,33.471804),35062=>array(-87.010252,33.72492),35063=>array(-87.025862,33.82055),35064=>array(-86.920253,33.476072),35068=>array(-86.831073,33.607519),35070=>array(-86.754203,34.012545),35071=>array(-86.848101,33.695005),35072=>array(-86.064464,33.095425),35073=>array(-86.986831,33.651226),35074=>array(-87.12427,33.222349),35077=>array(-86.832668,34.021165),35078=>array(-86.444487,33.324276),35079=>array(-86.749708,33.938066),35080=>array(-86.913936,33.262518),35082=>array(-86.153394,33.157893),35083=>array(-86.59917,34.199871),35085=>array(-86.734189,32.978121),35087=>array(-86.584296,34.306453),35089=>array(-86.081832,32.945782),35091=>array(-86.789554,33.779236),35094=>array(-86.553303,33.530066),35096=>array(-86.107917,33.620753),35097=>array(-86.627129,33.89223),35098=>array(-87.04688,34.1211),35111=>array(-87.094878,33.284352),35112=>array(-86.470622,33.690914),35114=>array(-86.87276,33.22372),35115=>array(-86.897186,33.123338),35116=>array(-86.766091,33.730117),35117=>array(-86.893406,33.668371),35118=>array(-87.039234,33.535007),35119=>array(-86.77093,33.646571),35120=>array(-86.423736,33.666813),35121=>array(-86.455102,33.941185),35124=>array(-86.742177,33.321899),35125=>array(-86.288661,33.633254),35126=>array(-86.655119,33.730771),35127=>array(-86.976366,33.491657),35128=>array(-86.337819,33.5524),35130=>array(-87.136688,33.633156),35131=>array(-86.196865,33.727406),35133=>array(-86.596134,33.829949),35135=>array(-86.199595,33.616462),35136=>array(-86.286795,32.879247),35139=>array(-86.969064,33.709174),35143=>array(-86.543885,33.09485),35146=>array(-86.453341,33.795118),35147=>array(-86.530992,33.415884),35148=>array(-87.045799,33.755992),35149=>array(-86.187525,33.249436),35150=>array(-86.238384,33.189306),35151=>array(-86.3922,33.081328),35160=>array(-86.052523,33.357919),35171=>array(-86.740256,32.88254),35172=>array(-86.695951,33.847991),35173=>array(-86.563039,33.655399),35175=>array(-86.511199,34.435668),35176=>array(-86.498033,33.485382),35178=>array(-86.398435,33.419769),35179=>array(-86.96897,34.273307),35180=>array(-86.83517,33.82555),35183=>array(-86.35201,33.016108),35184=>array(-87.136714,33.114345),35186=>array(-86.510394,33.256842),35187=>array(-86.885794,33.080534),35188=>array(-87.163583,33.18046),35203=>array(-86.809807,33.518601),35204=>array(-86.839847,33.522114),35205=>array(-86.808077,33.494995),35206=>array(-86.712978,33.569909),35207=>array(-86.82369,33.565051),35208=>array(-86.879298,33.496819),35209=>array(-86.811516,33.466348),35210=>array(-86.670318,33.540927),35211=>array(-86.856491,33.455373),35212=>array(-86.75291,33.547391),35213=>array(-86.744458,33.506671),35214=>array(-86.893345,33.576978),35215=>array(-86.707359,33.649052),35216=>array(-86.789433,33.419246),35217=>array(-86.760265,33.607882),35218=>array(-86.893995,33.507667),35221=>array(-86.898962,33.449487),35222=>array(-86.770115,33.523712),35223=>array(-86.734834,33.488141),35224=>array(-86.943842,33.517287),35226=>array(-86.845896,33.399153),35228=>array(-86.920957,33.456099),35229=>array(-86.788592,33.465807),35233=>array(-86.801964,33.508748),35234=>array(-86.802758,33.540811),35235=>array(-86.647907,33.624485),35242=>array(-86.671627,33.423203),35243=>array(-86.741508,33.440918),35244=>array(-86.825333,33.352918),35254=>array(-86.85755,33.516225),35401=>array(-87.616169,33.170238),35404=>array(-87.483406,33.215157),35405=>array(-87.541105,33.120761),35406=>array(-87.469325,33.338867),35441=>array(-87.750329,32.852762),35442=>array(-88.19097,33.079677),35443=>array(-88.000762,32.755279),35444=>array(-87.292884,33.328725),35446=>array(-87.751031,33.207796),35447=>array(-88.157754,33.251868),35452=>array(-87.68022,33.279026),35453=>array(-87.389459,33.163776),35456=>array(-87.41475,33.063695),35457=>array(-87.773144,33.304145),35458=>array(-87.812782,33.400593),35459=>array(-88.275851,32.791636),35460=>array(-88.153712,32.713161),35461=>array(-88.213856,33.417692),35462=>array(-87.967124,32.920743),35463=>array(-87.682451,33.064731),35464=>array(-88.15459,32.80613),35466=>array(-87.919484,33.248527),35469=>array(-87.781565,32.973874),35470=>array(-88.06638,32.561986),35473=>array(-87.581612,33.270519),35474=>array(-87.587135,32.945108),35475=>array(-87.594006,33.434462),35476=>array(-87.591272,33.227448),35477=>array(-88.24116,32.956225),35480=>array(-87.817352,33.091223),35481=>array(-88.037417,33.394624),35490=>array(-87.238215,33.218419),35501=>array(-87.292749,33.81891),35503=>array(-87.29666,33.941239),35504=>array(-87.170812,33.894135),35540=>array(-87.209961,34.234507),35541=>array(-87.177527,34.082317),35542=>array(-87.676051,33.719085),35543=>array(-87.758438,34.211156),35544=>array(-88.017137,33.959985),35545=>array(-87.93488,33.651546),35546=>array(-87.542714,33.619425),35548=>array(-87.750485,34.056419),35549=>array(-87.544905,33.851343),35550=>array(-87.161688,33.747682),35552=>array(-88.142204,34.072276),35553=>array(-87.381712,34.125909),35554=>array(-87.671678,33.885727),35555=>array(-87.815637,33.658512),35559=>array(-87.728143,33.905485),35563=>array(-87.903874,33.977512),35564=>array(-87.845572,34.258432),35565=>array(-87.563474,34.237259),35570=>array(-87.993156,34.162581),35571=>array(-87.944109,34.36871),35572=>array(-87.287856,34.210696),35574=>array(-87.949993,33.567578),35575=>array(-87.587912,34.036141),35576=>array(-88.143851,33.575382),35577=>array(-87.620057,34.102378),35578=>array(-87.466391,33.980483),35579=>array(-87.360275,33.636305),35580=>array(-87.255549,33.673294),35581=>array(-87.713097,34.359912),35582=>array(-88.112899,34.4868),35584=>array(-87.088015,33.819368),35585=>array(-87.832483,34.420835),35586=>array(-88.134464,33.878186),35587=>array(-87.456864,33.795555),35592=>array(-88.084807,33.746099),35593=>array(-88.095624,34.339101),35594=>array(-87.774369,33.932693),35601=>array(-87.011052,34.608016),35603=>array(-86.971226,34.535452),35610=>array(-87.245959,34.954458),35611=>array(-87.084145,34.773833),35613=>array(-86.882397,34.820162),35614=>array(-86.990112,34.853722),35615=>array(-86.875294,34.663172),35616=>array(-88.019381,34.739504),35618=>array(-87.304983,34.641403),35619=>array(-87.152105,34.382723),35620=>array(-87.020185,34.930812),35621=>array(-86.729536,34.348973),35622=>array(-86.898961,34.34659),35630=>array(-87.661652,34.82298),35633=>array(-87.798371,34.875101),35634=>array(-87.614548,34.91927),35640=>array(-86.943677,34.440702),35643=>array(-87.201931,34.672577),35645=>array(-87.500965,34.903048),35646=>array(-87.523343,34.677104),35647=>array(-87.117034,34.967655),35648=>array(-87.387836,34.95866),35649=>array(-86.869284,34.617619),35650=>array(-87.308593,34.447233),35651=>array(-87.495702,34.469857),35652=>array(-87.310208,34.846744),35653=>array(-87.871965,34.518191),35654=>array(-87.632549,34.498056),35660=>array(-87.701265,34.755494),35661=>array(-87.562802,34.768526),35670=>array(-86.729344,34.455176),35671=>array(-86.934004,34.672271),35672=>array(-87.406487,34.648533),35673=>array(-87.137349,34.576336),35674=>array(-87.781901,34.66241),35677=>array(-88.026555,34.955707),35739=>array(-86.791036,34.968586),35740=>array(-85.777446,34.966847),35741=>array(-86.483264,34.717312),35744=>array(-85.909061,34.610512),35745=>array(-86.180196,34.943634),35746=>array(-86.005957,34.828619),35747=>array(-86.298991,34.494943),35748=>array(-86.38937,34.721229),35749=>array(-86.757645,34.82151),35750=>array(-86.59423,34.958604),35751=>array(-86.27646,34.811157),35752=>array(-85.946047,34.7459),35754=>array(-86.604511,34.525473),35755=>array(-86.150278,34.488304),35756=>array(-86.818117,34.643795),35757=>array(-86.74538,34.784162),35758=>array(-86.746935,34.711281),35759=>array(-86.546196,34.867431),35760=>array(-86.383856,34.543906),35761=>array(-86.409214,34.916206),35763=>array(-86.46215,34.622017),35764=>array(-86.310155,34.726301),35765=>array(-85.814085,34.690313),35766=>array(-86.299843,34.867493),35768=>array(-86.104193,34.768891),35769=>array(-86.104809,34.597984),35771=>array(-86.005423,34.538598),35772=>array(-85.949066,34.937382),35773=>array(-86.707941,34.891069),35774=>array(-86.226525,34.765246),35775=>array(-86.705959,34.542934),35776=>array(-86.239414,34.659404),35801=>array(-86.560866,34.725269),35802=>array(-86.558882,34.668212),35803=>array(-86.519304,34.563686),35805=>array(-86.62029,34.709368),35806=>array(-86.685033,34.762538),35808=>array(-86.659057,34.633027),35810=>array(-86.601506,34.803249),35811=>array(-86.509948,34.795354),35816=>array(-86.630751,34.739954),35824=>array(-86.752118,34.644926),35896=>array(-86.654641,34.754673),35901=>array(-85.934285,34.049367),35903=>array(-85.863703,34.02427),35904=>array(-85.987949,34.075012),35905=>array(-85.922221,33.962029),35906=>array(-86.095113,33.927149),35907=>array(-86.01802,33.890841),35950=>array(-86.261095,34.249752),35951=>array(-86.163425,34.33888),35952=>array(-86.310738,34.052385),35953=>array(-86.229742,33.809618),35954=>array(-86.057449,34.089754),35956=>array(-86.146749,34.146146),35957=>array(-86.196898,34.196159),35958=>array(-85.645957,34.916005),35959=>array(-85.607959,34.242383),35960=>array(-85.570557,34.124328),35961=>array(-85.846221,34.303946),35962=>array(-86.036441,34.303881),35963=>array(-85.9272,34.359787),35966=>array(-85.671552,34.789647),35967=>array(-85.694569,34.407663),35968=>array(-85.738662,34.551152),35971=>array(-85.945131,34.455491),35972=>array(-86.24687,33.993999),35973=>array(-85.551513,34.344016),35974=>array(-86.010291,34.362751),35975=>array(-86.060368,34.436463),35976=>array(-86.330025,34.345767),35978=>array(-85.728979,34.642798),35979=>array(-85.609647,34.832324),35980=>array(-86.389598,34.172086),35981=>array(-85.648802,34.722345),35983=>array(-85.76502,34.172968),35984=>array(-85.563859,34.536843),35986=>array(-85.835889,34.500336),35987=>array(-86.242208,33.91337),35988=>array(-85.797242,34.558223),35989=>array(-85.619868,34.6135),35990=>array(-86.304688,34.06778),36003=>array(-86.723689,32.451985),36005=>array(-85.7196,31.888214),36006=>array(-86.722635,32.642055),36009=>array(-86.301377,31.594781),36010=>array(-85.797803,31.663655),36013=>array(-85.985235,32.284669),36016=>array(-85.414706,31.850223),36017=>array(-85.55772,31.679443),36020=>array(-86.322997,32.479374),36022=>array(-86.405578,32.623499),36024=>array(-86.025021,32.671798),36025=>array(-86.324972,32.544042),36026=>array(-86.130993,32.77548),36027=>array(-85.116624,32.060643),36028=>array(-86.392802,31.49547),36029=>array(-85.933154,32.181872),36030=>array(-86.87622,31.870914),36031=>array(-85.737437,32.24712),36032=>array(-86.568637,31.99463),36033=>array(-86.770613,31.671714),36034=>array(-86.111209,31.621045),36035=>array(-86.126215,31.788705),36036=>array(-86.161676,31.97394),36037=>array(-86.628615,31.799009),36038=>array(-86.491253,31.435078),36039=>array(-85.83756,32.298948),36040=>array(-86.684172,32.173924),36041=>array(-86.319978,31.9138),36042=>array(-86.459989,31.868619),36043=>array(-86.420747,32.201153),36046=>array(-86.336448,32.022765),36047=>array(-86.517854,32.075247),36048=>array(-85.59226,31.804471),36049=>array(-86.277257,31.768143),36051=>array(-86.50002,32.685457),36052=>array(-86.048285,32.184093),36053=>array(-85.443571,32.02924),36054=>array(-86.366311,32.481879),36064=>array(-86.077885,32.296635),36066=>array(-86.424001,32.479684),36067=>array(-86.564904,32.509379),36069=>array(-86.149865,32.094138),36071=>array(-86.397754,31.706685),36075=>array(-85.9237,32.378389),36078=>array(-85.934103,32.538247),36079=>array(-86.003013,31.764156),36080=>array(-86.281358,32.701863),36081=>array(-85.898152,31.903745),36082=>array(-85.954635,31.802761),36083=>array(-85.682934,32.385764),36088=>array(-85.720314,32.415281),36089=>array(-85.697807,32.152306),36091=>array(-86.508548,32.750447),36092=>array(-86.201587,32.617007),36093=>array(-86.133634,32.494564),36104=>array(-86.326502,32.39882),36105=>array(-86.288698,32.209701),36106=>array(-86.257585,32.35282),36107=>array(-86.279303,32.383689),36108=>array(-86.401107,32.3391),36109=>array(-86.242148,32.388957),36110=>array(-86.255772,32.446582),36111=>array(-86.271324,32.336579),36112=>array(-86.349141,32.380826),36113=>array(-86.363389,32.38244),36115=>array(-86.246702,32.406769),36116=>array(-86.214473,32.273588),36117=>array(-86.145011,32.378728),36201=>array(-85.879642,33.64916),36203=>array(-85.834626,33.58308),36205=>array(-85.794817,33.717379),36206=>array(-85.809715,33.733284),36207=>array(-85.70911,33.680005),36250=>array(-85.901096,33.765322),36251=>array(-85.86925,33.226536),36255=>array(-85.73044,33.168154),36256=>array(-85.704818,33.046308),36258=>array(-85.717338,33.477734),36260=>array(-85.996958,33.582149),36262=>array(-85.475464,33.791445),36263=>array(-85.35933,33.466234),36264=>array(-85.550422,33.596601),36265=>array(-85.784916,33.847655),36266=>array(-85.734316,33.349846),36267=>array(-85.948287,33.197365),36268=>array(-85.929452,33.494798),36269=>array(-85.383876,33.739797),36271=>array(-86.01869,33.78123),36272=>array(-85.594514,33.942955),36273=>array(-85.377204,33.545385),36274=>array(-85.362824,33.172139),36276=>array(-85.570266,33.132677),36277=>array(-85.818226,33.757469),36278=>array(-85.522981,33.331042),36279=>array(-85.889336,33.872274),36280=>array(-85.388737,33.380406),36301=>array(-85.39829,31.140068),36303=>array(-85.401317,31.266568),36305=>array(-85.495839,31.204368),36310=>array(-85.208852,31.595148),36311=>array(-85.686916,31.607649),36312=>array(-85.236826,31.170833),36313=>array(-85.793943,31.178551),36314=>array(-85.772824,31.018937),36316=>array(-85.863975,31.175691),36317=>array(-85.404255,31.643557),36318=>array(-85.950531,31.169524),36319=>array(-85.149182,31.331819),36320=>array(-85.31582,31.049965),36321=>array(-85.29923,31.21084),36322=>array(-85.735807,31.257605),36323=>array(-86.072471,31.428104),36330=>array(-85.86295,31.305778),36340=>array(-85.890943,31.051672),36343=>array(-85.120765,31.060704),36344=>array(-85.708147,31.09789),36345=>array(-85.304595,31.368148),36346=>array(-85.930086,31.560574),36350=>array(-85.495521,31.350214),36351=>array(-85.906598,31.425528),36352=>array(-85.609699,31.264999),36353=>array(-85.348885,31.478396),36360=>array(-85.61703,31.467469),36362=>array(-85.679787,31.350932),36370=>array(-85.158109,31.142219),36371=>array(-85.551996,31.31242),36373=>array(-85.109364,31.525075),36374=>array(-85.49369,31.578737),36375=>array(-85.544966,31.071216),36376=>array(-85.269809,31.251143),36401=>array(-86.950501,31.473454),36420=>array(-86.567188,31.177363),36421=>array(-86.506928,31.324729),36425=>array(-87.195168,31.76474),36426=>array(-87.069972,31.142284),36432=>array(-87.027691,31.293567),36435=>array(-87.451616,31.869694),36436=>array(-87.649528,31.785367),36439=>array(-87.345189,31.419287),36441=>array(-87.255149,31.039357),36442=>array(-86.356872,31.071569),36444=>array(-87.446699,31.661913),36445=>array(-87.453392,31.444585),36446=>array(-87.719956,31.79246),36451=>array(-87.803568,31.700517),36453=>array(-86.149163,31.191678),36454=>array(-87.200318,31.328428),36455=>array(-86.351972,31.013096),36456=>array(-86.806151,31.568405),36460=>array(-87.304829,31.518972),36467=>array(-86.256945,31.281017),36470=>array(-87.567505,31.529297),36471=>array(-87.248947,31.616419),36473=>array(-87.202487,31.307469),36474=>array(-86.626045,31.429685),36475=>array(-87.219745,31.387683),36476=>array(-86.549731,31.362361),36477=>array(-86.061375,31.097123),36480=>array(-87.599127,31.325005),36481=>array(-87.382559,31.771512),36482=>array(-87.6369,31.639318),36483=>array(-86.693624,31.039499),36502=>array(-87.494821,31.147733),36505=>array(-88.016709,30.946825),36507=>array(-87.742931,30.859596),36509=>array(-88.270178,30.39302),36511=>array(-87.747247,30.315155),36512=>array(-88.018411,30.998814),36513=>array(-88.005748,31.174003),36518=>array(-88.282495,31.45395),36521=>array(-88.17733,30.964986),36522=>array(-88.274824,31.093382),36523=>array(-88.175517,30.369635),36524=>array(-88.010863,31.802618),36525=>array(-88.018704,30.890103),36526=>array(-87.859624,30.611107),36527=>array(-87.881866,30.702075),36528=>array(-88.236233,30.235498),36529=>array(-88.238559,31.271041),36530=>array(-87.555585,30.40821),36532=>array(-87.861306,30.480713),36535=>array(-87.726796,30.384723),36538=>array(-88.143271,31.657053),36539=>array(-88.380629,31.348614),36540=>array(-87.675843,31.448949),36541=>array(-88.344106,30.489535),36542=>array(-87.750611,30.26972),36543=>array(-87.466126,31.221584),36544=>array(-88.230266,30.480146),36545=>array(-87.871704,31.488511),36548=>array(-87.967725,31.48898),36549=>array(-87.456014,30.410937),36550=>array(-87.730436,31.24943),36551=>array(-87.754643,30.64067),36553=>array(-88.067813,31.243301),36555=>array(-87.783492,30.396615),36556=>array(-87.976023,31.197708),36558=>array(-88.315922,31.604406),36559=>array(-87.908653,30.567794),36560=>array(-88.040068,31.097767),36561=>array(-87.572361,30.285677),36562=>array(-87.670416,31.037057),36564=>array(-87.926509,30.478695),36567=>array(-87.55696,30.623536),36568=>array(-88.27264,30.511926),36569=>array(-88.091294,31.542478),36571=>array(-88.109965,30.854676),36572=>array(-88.06122,30.857692),36574=>array(-87.478628,30.500689),36575=>array(-88.273387,30.769164),36576=>array(-87.763833,30.522953),36578=>array(-87.781138,30.74759),36579=>array(-87.796932,31.106823),36580=>array(-87.703414,30.478898),36581=>array(-87.965583,31.375357),36582=>array(-88.173001,30.509877),36583=>array(-88.187884,31.356822),36584=>array(-88.376408,31.19441),36585=>array(-88.081329,31.388747),36587=>array(-88.351243,30.844238),36590=>array(-88.174421,30.531802),36602=>array(-88.045544,30.693327),36603=>array(-88.024072,30.67419),36604=>array(-88.068135,30.682219),36605=>array(-88.087824,30.604547),36606=>array(-88.106092,30.670446),36607=>array(-88.10578,30.698586),36608=>array(-88.300212,30.681503),36609=>array(-88.16353,30.661093),36610=>array(-88.073506,30.73647),36611=>array(-88.080073,30.769623),36612=>array(-88.113135,30.752882),36613=>array(-88.19139,30.80658),36615=>array(-88.069843,30.630177),36616=>array(-88.081588,30.724504),36617=>array(-88.095705,30.716025),36618=>array(-88.173282,30.739067),36619=>array(-88.196637,30.596087),36688=>array(-88.182099,30.696157),36693=>array(-88.149746,30.6257),36695=>array(-88.280303,30.628385),36701=>array(-87.05545,32.476405),36703=>array(-86.912858,32.427349),36720=>array(-87.34687,32.15885),36722=>array(-87.571497,32.094921),36723=>array(-87.274538,32.05363),36726=>array(-87.295936,31.963626),36727=>array(-88.03391,31.910985),36728=>array(-87.476215,32.161399),36732=>array(-87.914179,32.429314),36736=>array(-87.776198,32.060282),36738=>array(-87.624965,32.42097),36740=>array(-87.836571,32.626783),36742=>array(-87.729452,32.467872),36744=>array(-87.599604,32.696057),36748=>array(-87.780901,32.267275),36749=>array(-86.859545,32.539961),36750=>array(-86.849377,32.789616),36751=>array(-87.545748,31.824299),36752=>array(-86.631995,32.298669),36753=>array(-87.074655,31.805238),36754=>array(-87.700902,32.154061),36756=>array(-87.285068,32.69482),36758=>array(-86.889972,32.638756),36759=>array(-87.277593,32.416752),36761=>array(-86.978039,32.106169),36763=>array(-87.980902,32.276807),36765=>array(-87.522229,32.588171),36766=>array(-87.086691,31.955121),36767=>array(-87.191091,32.259288),36768=>array(-87.019696,31.912626),36769=>array(-87.547444,32.007856),36773=>array(-87.357531,32.258944),36775=>array(-86.979628,32.175085),36776=>array(-87.741128,32.736022),36782=>array(-87.911901,32.13091),36783=>array(-87.597827,32.247762),36784=>array(-87.787887,31.926927),36785=>array(-86.84581,32.260516),36786=>array(-87.479256,32.431262),36790=>array(-86.893627,32.733603),36792=>array(-86.906373,32.932428),36793=>array(-87.027517,32.821605),36801=>array(-85.395626,32.694763),36804=>array(-85.34405,32.53224),36830=>array(-85.492653,32.538887),36832=>array(-85.586673,32.591182),36849=>array(-85.487341,32.60242),36850=>array(-85.658566,32.783232),36852=>array(-85.293959,32.758314),36853=>array(-85.76859,32.81435),36854=>array(-85.189484,32.751613),36855=>array(-85.308151,33.028908),36856=>array(-84.997829,32.274495),36858=>array(-85.330375,32.328274),36859=>array(-85.01104,32.235095),36860=>array(-85.419096,32.253477),36861=>array(-85.850604,32.890875),36862=>array(-85.455157,32.903965),36863=>array(-85.26375,32.889494),36865=>array(-85.589334,32.602618),36866=>array(-85.712082,32.565305),36867=>array(-85.024588,32.495317),36869=>array(-85.064964,32.421383),36870=>array(-85.120305,32.482878),36871=>array(-85.157233,32.178708),36874=>array(-85.198549,32.564252),36875=>array(-85.166552,32.336837),36877=>array(-85.099414,32.575034),36879=>array(-85.558378,32.727568),36901=>array(-88.157876,32.425717),36904=>array(-88.260758,32.100587),36907=>array(-88.346704,32.426384),36908=>array(-88.391508,31.869253),36910=>array(-88.146953,32.204602),36912=>array(-88.302607,32.230412),36913=>array(-88.44709,31.960963),36915=>array(-88.358729,31.955091),36916=>array(-88.059887,32.209837),36919=>array(-88.282862,31.769052),36921=>array(-88.18278,31.93843),36922=>array(-88.141975,32.300344),36925=>array(-88.183591,32.432254),37010=>array(-87.101199,36.575109),37012=>array(-86.001565,36.07383),37013=>array(-86.632503,36.052237),37014=>array(-86.632954,35.875229),37015=>array(-87.075554,36.279401),37016=>array(-86.100226,35.957452),37018=>array(-86.211258,35.630679),37019=>array(-86.709825,35.392281),37020=>array(-86.407093,35.634389),37022=>array(-86.317038,36.514582),37023=>array(-87.782744,36.592456),37025=>array(-87.307754,35.948733),37026=>array(-86.105655,35.696497),37027=>array(-86.785062,35.999288),37028=>array(-87.862973,36.627542),37029=>array(-87.264603,36.042551),37030=>array(-85.942108,36.271536),37031=>array(-86.292718,36.366154),37032=>array(-87.017154,36.524214),37033=>array(-87.55784,35.744616),37034=>array(-86.690998,35.640624),37035=>array(-87.124806,36.383876),37036=>array(-87.262176,36.233308),37037=>array(-86.351238,35.703083),37040=>array(-87.334932,36.522633),37042=>array(-87.416322,36.568751),37043=>array(-87.240533,36.490934),37046=>array(-86.70074,35.781876),37047=>array(-86.835786,35.3173),37048=>array(-86.595909,36.491315),37049=>array(-86.673094,36.557059),37050=>array(-87.630998,36.374338),37051=>array(-87.410243,36.304293),37052=>array(-87.401828,36.378818),37055=>array(-87.442912,36.077149),37057=>array(-86.029944,36.418109),37058=>array(-87.876657,36.444343),37059=>array(-85.898328,35.981046),37060=>array(-86.637752,35.745465),37061=>array(-87.635077,36.287708),37062=>array(-87.135932,35.990876),37064=>array(-86.954138,35.884862),37066=>array(-86.45554,36.398757),37067=>array(-86.780257,35.912217),37069=>array(-86.903598,35.987493),37072=>array(-86.746651,36.35214),37073=>array(-86.81663,36.432426),37074=>array(-86.152749,36.426436),37075=>array(-86.607922,36.339969),37076=>array(-86.576839,36.14929),37078=>array(-87.74454,35.912603),37079=>array(-87.658719,36.478557),37080=>array(-86.916886,36.332761),37082=>array(-87.115266,36.094872),37083=>array(-86.011048,36.535354),37085=>array(-86.280498,35.954824),37086=>array(-86.559357,36.022228),37087=>array(-86.268888,36.263321),37090=>array(-86.299189,36.11174),37091=>array(-86.767472,35.489239),37095=>array(-85.970274,35.982447),37096=>array(-87.870302,35.612807),37097=>array(-87.82348,35.779865),37098=>array(-87.319372,35.872377),37101=>array(-87.629074,36.060244),37110=>array(-85.741067,35.645205),37115=>array(-86.69553,36.253847),37118=>array(-86.190225,35.93024),37122=>array(-86.480715,36.182639),37127=>array(-86.327533,35.781304),37128=>array(-86.489369,35.784183),37129=>array(-86.442648,35.932526),37130=>array(-86.317204,35.884923),37132=>array(-86.364315,35.849273),37134=>array(-87.948031,35.992357),37135=>array(-86.676604,35.915796),37137=>array(-87.505366,35.88416),37138=>array(-86.609391,36.244014),37140=>array(-87.652527,35.859175),37141=>array(-86.701927,36.614915),37142=>array(-87.509688,36.410888),37143=>array(-87.031243,36.127732),37144=>array(-86.660358,35.305223),37145=>array(-85.90653,36.377361),37146=>array(-87.032016,36.402067),37148=>array(-86.495247,36.566636),37149=>array(-86.192696,35.804004),37150=>array(-85.81041,36.541483),37151=>array(-86.04302,36.309201),37153=>array(-86.554126,35.763808),37160=>array(-86.484563,35.455761),37165=>array(-87.470936,36.292696),37166=>array(-85.786903,35.917978),37167=>array(-86.53159,35.959541),37171=>array(-87.295564,36.361313),37172=>array(-86.862191,36.532416),37174=>array(-86.898449,35.719834),37175=>array(-87.889055,36.324692),37178=>array(-87.790475,36.323887),37179=>array(-86.924482,35.811405),37180=>array(-86.586661,35.606468),37181=>array(-87.469137,36.244554),37183=>array(-86.303181,35.494482),37184=>array(-86.144093,36.082419),37185=>array(-87.857678,36.064237),37186=>array(-86.221711,36.596738),37187=>array(-87.197891,36.144149),37188=>array(-86.681321,36.48027),37189=>array(-86.834803,36.29888),37190=>array(-86.021204,35.816539),37191=>array(-87.529654,36.494075),37201=>array(-86.777305,36.166001),37203=>array(-86.790618,36.149614),37204=>array(-86.774283,36.106735),37205=>array(-86.870442,36.113195),37206=>array(-86.731083,36.179319),37207=>array(-86.775969,36.233774),37208=>array(-86.808023,36.177714),37209=>array(-86.94857,36.1854),37210=>array(-86.732957,36.149265),37211=>array(-86.723711,36.067234),37212=>array(-86.801254,36.133877),37213=>array(-86.767542,36.166156),37214=>array(-86.670867,36.162189),37215=>array(-86.834691,36.081868),37216=>array(-86.726843,36.216583),37217=>array(-86.65636,36.108313),37218=>array(-86.889416,36.164095),37219=>array(-86.783177,36.166811),37220=>array(-86.793127,36.068447),37221=>array(-86.968798,36.051294),37228=>array(-86.803583,36.196291),37240=>array(-86.805471,36.144893),37243=>array(-86.782141,36.165011),37246=>array(-86.791447,36.159857),37301=>array(-85.793486,35.415905),37302=>array(-85.019818,35.008329),37303=>array(-84.640077,35.442462),37305=>array(-85.69423,35.46519),37306=>array(-86.191804,35.096574),37307=>array(-84.621319,35.174229),37308=>array(-84.993756,35.342635),37309=>array(-84.741487,35.301912),37310=>array(-84.717221,35.224608),37311=>array(-84.928186,35.113133),37312=>array(-84.879821,35.232461),37313=>array(-85.7128,35.357709),37315=>array(-85.051555,35.048259),37317=>array(-84.443056,35.031001),37318=>array(-85.99278,35.177916),37321=>array(-85.008024,35.502103),37322=>array(-84.823888,35.503397),37323=>array(-84.816533,35.096183),37324=>array(-85.991204,35.239373),37325=>array(-84.591718,35.251359),37326=>array(-84.384985,35.040004),37327=>array(-85.41477,35.42347),37328=>array(-86.357374,35.036942),37329=>array(-84.46104,35.394355),37330=>array(-86.130578,35.279542),37331=>array(-84.529833,35.319312),37332=>array(-84.971947,35.598701),37333=>array(-84.335338,35.153754),37334=>array(-86.580895,35.166452),37335=>array(-86.403992,35.068898),37336=>array(-84.931502,35.308865),37337=>array(-84.850664,35.787056),37338=>array(-85.216944,35.427296),37339=>array(-85.63423,35.379959),37340=>array(-85.517519,35.034063),37341=>array(-85.077961,35.224361),37342=>array(-85.948,35.391968),37343=>array(-85.21228,35.166669),37345=>array(-86.203018,35.016754),37347=>array(-85.620035,35.061348),37348=>array(-86.434051,35.131615),37350=>array(-85.350184,34.993921),37351=>array(-85.260363,35.100285),37352=>array(-86.353027,35.27752),37353=>array(-84.989096,35.11501),37354=>array(-84.348168,35.50645),37355=>array(-86.08393,35.499769),37356=>array(-85.823416,35.229586),37357=>array(-85.91734,35.585288),37359=>array(-86.412877,35.2042),37360=>array(-86.254339,35.437596),37361=>array(-84.686634,35.101249),37362=>array(-84.680799,35.031384),37363=>array(-85.063804,35.115688),37365=>array(-85.559742,35.38253),37366=>array(-85.829999,35.338865),37367=>array(-85.23622,35.624983),37369=>array(-84.479694,35.190622),37370=>array(-84.699155,35.356695),37373=>array(-85.092816,35.407459),37374=>array(-85.646585,35.16841),37375=>array(-85.890914,35.150642),37376=>array(-85.955824,35.047765),37377=>array(-85.334972,35.204919),37379=>array(-85.177144,35.295181),37380=>array(-85.754605,35.070937),37381=>array(-84.876993,35.68718),37385=>array(-84.236984,35.333158),37387=>array(-85.746581,35.273286),37388=>array(-86.221295,35.343672),37391=>array(-84.354023,35.093243),37394=>array(-85.860045,35.539396),37396=>array(-85.499729,35.005799),37397=>array(-85.516317,35.222225),37398=>array(-86.138387,35.181209),37402=>array(-85.317871,35.043722),37403=>array(-85.294267,35.048015),37404=>array(-85.273662,35.027911),37405=>array(-85.407828,35.120403),37406=>array(-85.245571,35.073134),37407=>array(-85.289724,35.001943),37408=>array(-85.308549,35.028633),37409=>array(-85.335346,35.013749),37410=>array(-85.31422,35.001899),37411=>array(-85.226165,35.028764),37412=>array(-85.22743,34.997526),37415=>array(-85.281199,35.124725),37416=>array(-85.17678,35.101399),37419=>array(-85.404129,35.039786),37421=>array(-85.147624,35.031635),37601=>array(-82.317625,36.330485),37604=>array(-82.38319,36.299581),37614=>array(-82.37121,36.301393),37615=>array(-82.457201,36.402412),37616=>array(-82.746798,36.228473),37617=>array(-82.365576,36.524578),37618=>array(-82.208744,36.460339),37620=>array(-82.09405,36.5496),37640=>array(-81.974686,36.326824),37641=>array(-82.667344,36.196373),37642=>array(-82.7268,36.530987),37643=>array(-82.137118,36.377345),37645=>array(-82.662199,36.562152),37650=>array(-82.450622,36.095024),37656=>array(-82.629857,36.398802),37657=>array(-82.560126,36.017623),37658=>array(-82.118135,36.249709),37659=>array(-82.49122,36.280141),37660=>array(-82.571652,36.526731),37663=>array(-82.488779,36.461493),37664=>array(-82.498988,36.520428),37665=>array(-82.570554,36.578779),37680=>array(-81.72543,36.579284),37681=>array(-82.617741,36.261677),37682=>array(-82.290892,36.300986),37683=>array(-81.822037,36.454744),37686=>array(-82.348811,36.440209),37687=>array(-82.092629,36.179017),37688=>array(-81.882882,36.545442),37690=>array(-82.557584,36.25012),37691=>array(-81.756695,36.371668),37692=>array(-82.300829,36.189822),37694=>array(-82.276728,36.387795),37701=>array(-83.986067,35.79274),37705=>array(-84.00869,36.228674),37708=>array(-83.316303,36.330524),37709=>array(-83.664552,36.162997),37710=>array(-84.316134,36.158632),37711=>array(-83.045425,36.28133),37713=>array(-83.134295,36.081454),37714=>array(-84.304426,36.261516),37715=>array(-83.960522,36.554227),37716=>array(-84.175183,36.097124),37719=>array(-84.429381,36.022415),37721=>array(-83.812584,36.11842),37722=>array(-83.202696,35.814833),37723=>array(-84.817612,35.965822),37724=>array(-83.706353,36.550819),37725=>array(-83.399349,35.996106),37726=>array(-84.830473,36.204182),37727=>array(-83.021497,35.886936),37729=>array(-84.034443,36.516651),37730=>array(-83.975516,36.547384),37731=>array(-83.009063,36.548667),37732=>array(-84.606365,36.327038),37733=>array(-84.711232,36.354076),37737=>array(-84.120064,35.760359),37738=>array(-83.474881,35.670251),37742=>array(-84.179247,35.675845),37743=>array(-82.856325,36.068913),37745=>array(-82.820602,36.278033),37748=>array(-84.516324,35.945607),37752=>array(-83.545062,36.553211),37753=>array(-83.100349,35.823088),37754=>array(-84.029761,36.139185),37755=>array(-84.526705,36.402394),37756=>array(-84.419801,36.304565),37757=>array(-84.137299,36.299009),37760=>array(-83.45819,36.11106),37762=>array(-84.12617,36.577304),37763=>array(-84.492265,35.82023),37764=>array(-83.616165,35.970355),37765=>array(-83.058618,36.572343),37766=>array(-84.080824,36.399701),37769=>array(-84.153543,36.218671),37770=>array(-84.663293,36.153311),37771=>array(-84.32153,35.840669),37772=>array(-84.218553,35.79114),37774=>array(-84.358969,35.729133),37777=>array(-84.054192,35.826849),37779=>array(-83.756089,36.215119),37801=>array(-84.094594,35.66392),37803=>array(-83.981389,35.660842),37804=>array(-83.893153,35.792057),37806=>array(-83.727986,36.084693),37807=>array(-83.82599,36.259656),37809=>array(-83.041113,36.158391),37810=>array(-83.115488,36.184579),37811=>array(-83.209759,36.355516),37813=>array(-83.257023,36.175136),37814=>array(-83.337421,36.233235),37818=>array(-82.971084,36.188787),37819=>array(-84.205753,36.568255),37820=>array(-83.566057,36.085171),37821=>array(-83.195566,35.97517),37825=>array(-83.695807,36.407104),37826=>array(-84.589664,35.558276),37828=>array(-84.069009,36.197927),37829=>array(-84.637685,36.010201),37830=>array(-84.290549,35.966483),37840=>array(-84.409158,36.070393),37841=>array(-84.5694,36.51684),37843=>array(-83.048369,36.010701),37845=>array(-84.439501,36.09337),37846=>array(-84.481811,35.679244),37847=>array(-84.27895,36.434173),37848=>array(-83.680106,36.235745),37849=>array(-84.046042,36.054313),37851=>array(-83.907579,36.584059),37852=>array(-84.589959,36.328779),37853=>array(-83.910713,35.836719),37854=>array(-84.719008,35.883735),37857=>array(-82.9414,36.424289),37860=>array(-83.185313,36.251184),37861=>array(-83.513713,36.240743),37862=>array(-83.612571,35.778007),37863=>array(-83.562198,35.785959),37865=>array(-83.734626,35.850344),37866=>array(-83.856613,36.342069),37869=>array(-83.24497,36.514752),37870=>array(-83.833801,36.462895),37871=>array(-83.681021,36.052084),37872=>array(-84.649496,36.269532),37873=>array(-82.843047,36.52627),37874=>array(-84.456484,35.59833),37876=>array(-83.481101,35.865019),37877=>array(-83.406942,36.151167),37878=>array(-83.894011,35.620642),37879=>array(-83.490313,36.476371),37880=>array(-84.677934,35.685695),37881=>array(-83.342508,36.406476),37882=>array(-83.813078,35.601218),37885=>array(-84.132339,35.476426),37886=>array(-83.804718,35.745588),37887=>array(-84.583165,36.094965),37888=>array(-83.608265,36.310172),37890=>array(-83.298857,36.085282),37891=>array(-83.138103,36.29207),37892=>array(-84.357644,36.555696),37902=>array(-83.92061,35.963643),37909=>array(-84.02141,35.947566),37912=>array(-83.984876,36.007549),37914=>array(-83.795797,35.983165),37915=>array(-83.900432,35.970813),37916=>array(-83.934197,35.952723),37917=>array(-83.913702,36.001191),37918=>array(-83.916946,36.056122),37919=>array(-84.000169,35.914748),37920=>array(-83.869153,35.908753),37921=>array(-84.002156,35.979767),37922=>array(-84.100535,35.860496),37923=>array(-84.079528,35.926395),37924=>array(-83.803298,36.027895),37931=>array(-84.125445,35.976399),37932=>array(-84.198756,35.917328),37934=>array(-84.176643,35.856771),37938=>array(-83.938618,36.123933),38001=>array(-89.160049,35.816288),38002=>array(-89.700255,35.286366),38004=>array(-89.76004,35.411728),38006=>array(-89.089516,35.693693),38007=>array(-89.426956,36.159414),38008=>array(-88.99718,35.246459),38011=>array(-89.711687,35.462176),38012=>array(-89.273232,35.610611),38015=>array(-89.823415,35.556935),38016=>array(-89.760052,35.181507),38017=>array(-89.648939,35.066971),38018=>array(-89.760016,35.13851),38019=>array(-89.628878,35.562373),38021=>array(-89.16475,35.875848),38023=>array(-89.942438,35.468284),38024=>array(-89.380814,36.035542),38028=>array(-89.6322,35.183099),38029=>array(-89.821895,35.238741),38030=>array(-89.583626,36.018136),38034=>array(-89.236962,35.911414),38036=>array(-89.625825,35.32022),38037=>array(-89.398895,35.797359),38039=>array(-89.15057,35.063548),38040=>array(-89.444872,35.89239),38041=>array(-89.704347,35.659774),38042=>array(-89.137403,35.14516),38044=>array(-88.809547,35.199329),38046=>array(-89.247931,35.069904),38047=>array(-89.5034,36.090531),38049=>array(-89.53821,35.390333),38050=>array(-89.23307,35.829629),38052=>array(-88.917801,35.090254),38053=>array(-89.951532,35.346216),38054=>array(-89.873398,35.336356),38057=>array(-89.368397,35.052974),38058=>array(-89.819262,35.461347),38059=>array(-89.248757,36.105685),38060=>array(-89.505468,35.209347),38061=>array(-88.766924,35.067042),38063=>array(-89.640503,35.764057),38066=>array(-89.513696,35.069561),38067=>array(-89.041788,35.081609),38068=>array(-89.343048,35.261613),38069=>array(-89.329085,35.47846),38070=>array(-89.23701,35.94356),38075=>array(-89.135495,35.381986),38076=>array(-89.442078,35.138706),38077=>array(-89.474394,36.328075),38079=>array(-89.462502,36.427748),38080=>array(-89.519208,36.207086),38103=>array(-90.054995,35.15309),38104=>array(-90.003728,35.132549),38105=>array(-90.034758,35.151235),38106=>array(-90.090113,35.104113),38107=>array(-90.023442,35.170165),38108=>array(-89.967917,35.176666),38109=>array(-90.163407,35.040014),38111=>array(-89.943501,35.110521),38112=>array(-89.976392,35.147662),38114=>array(-89.985848,35.096479),38115=>array(-89.862806,35.053329),38116=>array(-90.011396,35.033181),38117=>array(-89.905344,35.115181),38118=>array(-89.932532,35.032631),38119=>array(-89.845385,35.079511),38120=>array(-89.852645,35.123633),38122=>array(-89.921214,35.158933),38125=>array(-89.788637,35.025913),38126=>array(-90.043671,35.126982),38127=>array(-90.019556,35.238363),38128=>array(-89.926689,35.224574),38131=>array(-89.992094,35.066359),38132=>array(-89.99483,35.073171),38133=>array(-89.794289,35.212901),38134=>array(-89.859874,35.174969),38135=>array(-89.848559,35.238925),38138=>array(-89.799327,35.084826),38139=>array(-89.755097,35.079657),38141=>array(-89.858616,35.016729),38152=>array(-89.93139,35.123648),38201=>array(-88.530234,36.123772),38220=>array(-88.670909,35.993575),38221=>array(-88.03501,36.244754),38222=>array(-88.157903,36.445536),38224=>array(-88.492197,36.387017),38225=>array(-88.674295,36.325102),38226=>array(-88.686637,36.483883),38229=>array(-88.606426,36.22313),38230=>array(-88.775865,36.15523),38231=>array(-88.426138,36.213058),38232=>array(-89.332564,36.35305),38233=>array(-89.04908,36.203444),38235=>array(-88.563889,35.989375),38236=>array(-88.272476,36.17192),38237=>array(-88.837864,36.357922),38240=>array(-89.318119,36.245091),38241=>array(-88.591844,36.427772),38242=>array(-88.330803,36.306561),38251=>array(-88.355755,36.45893),38253=>array(-89.040359,36.293824),38254=>array(-89.347404,36.374904),38255=>array(-88.859211,36.238355),38256=>array(-88.131436,36.308647),38257=>array(-88.87706,36.456475),38258=>array(-88.619287,36.032792),38259=>array(-89.183658,36.199152),38260=>array(-89.200363,36.360777),38261=>array(-89.113506,36.42886),38301=>array(-88.853395,35.588164),38305=>array(-88.768058,35.701654),38310=>array(-88.408628,35.261735),38311=>array(-88.104204,35.437098),38313=>array(-88.621051,35.604517),38315=>array(-88.62762,35.26486),38316=>array(-88.816891,36.069862),38317=>array(-88.263813,36.057937),38318=>array(-88.258084,35.950509),38320=>array(-88.1126,36.051656),38321=>array(-88.532266,35.845504),38326=>array(-88.286151,35.054654),38327=>array(-88.308574,35.22441),38328=>array(-88.215686,35.680535),38329=>array(-88.107281,35.536869),38330=>array(-89.034414,36.070503),38332=>array(-88.426456,35.419091),38333=>array(-87.954454,36.128133),38334=>array(-88.571549,35.361066),38337=>array(-89.014025,35.785275),38339=>array(-88.515021,35.052271),38340=>array(-88.68325,35.401322),38341=>array(-88.083895,35.877577),38342=>array(-88.288871,36.07174),38343=>array(-88.926056,35.827534),38344=>array(-88.424138,35.978164),38345=>array(-88.505481,35.59818),38347=>array(-88.4986,35.477766),38348=>array(-88.650963,35.872744),38351=>array(-88.399499,35.670883),38352=>array(-88.533846,35.529455),38355=>array(-88.775061,35.784009),38356=>array(-88.89381,35.438418),38357=>array(-88.415338,35.044826),38358=>array(-88.758664,35.916675),38359=>array(-88.351362,35.369853),38361=>array(-88.297188,35.311866),38362=>array(-88.782978,35.729072),38363=>array(-88.112201,35.687479),38365=>array(-88.232127,35.05425),38366=>array(-88.741273,35.479),38367=>array(-88.626992,35.052128),38368=>array(-88.34813,35.510913),38369=>array(-88.942666,36.131922),38370=>array(-88.245131,35.383433),38371=>array(-88.295085,35.424293),38372=>array(-88.149011,35.165581),38374=>array(-88.230904,35.50561),38375=>array(-88.591666,35.157895),38376=>array(-88.368705,35.099209),38379=>array(-88.433753,35.164244),38380=>array(-88.032881,35.789889),38381=>array(-88.971358,35.3572),38382=>array(-88.984393,35.968463),38387=>array(-88.277462,35.87292),38388=>array(-88.319887,35.78162),38390=>array(-88.37229,35.840552),38391=>array(-88.992177,35.546571),38392=>array(-89.03551,35.462653),38401=>array(-87.021526,35.629164),38425=>array(-87.943013,35.412209),38449=>array(-86.818172,35.040439),38450=>array(-87.792739,35.183623),38451=>array(-86.992239,35.460534),38452=>array(-87.796308,35.080354),38453=>array(-86.812108,35.12136),38454=>array(-87.352102,35.723195),38455=>array(-86.885707,35.043543),38456=>array(-87.266379,35.335477),38457=>array(-87.284446,35.029325),38459=>array(-86.80545,35.194281),38460=>array(-87.153186,35.088664),38461=>array(-87.341971,35.593001),38462=>array(-87.562921,35.528232),38463=>array(-87.645115,35.070595),38464=>array(-87.433722,35.290794),38468=>array(-87.291063,35.135146),38469=>array(-87.428629,35.074665),38471=>array(-87.932397,35.083901),38472=>array(-87.038523,35.37761),38473=>array(-87.171674,35.021246),38474=>array(-87.226224,35.517968),38475=>array(-88.016092,35.253477),38476=>array(-87.21376,35.841188),38477=>array(-86.993081,35.064923),38478=>array(-87.005885,35.232899),38481=>array(-87.492298,35.031269),38482=>array(-87.149926,35.768837),38483=>array(-87.333653,35.440767),38485=>array(-87.773021,35.361977),38486=>array(-87.545112,35.170567),38487=>array(-87.233402,35.718427),38488=>array(-86.670916,35.04196),38501=>array(-85.533285,36.226045),38504=>array(-84.724743,36.395565),38505=>array(-85.505075,36.175064),38506=>array(-85.433312,36.187107),38541=>array(-85.335604,36.538018),38542=>array(-85.202215,36.317132),38543=>array(-85.150479,36.346673),38544=>array(-85.663143,36.123588),38545=>array(-85.662826,36.232094),38547=>array(-86.006801,36.155562),38548=>array(-85.790513,36.164152),38549=>array(-85.149087,36.562131),38551=>array(-85.487154,36.558038),38552=>array(-85.813648,36.217756),38553=>array(-85.006317,36.201869),38554=>array(-85.161655,36.24949),38555=>array(-84.989016,35.887881),38556=>array(-84.918949,36.406761),38558=>array(-84.866567,36.009882),38559=>array(-85.508014,35.808437),38560=>array(-85.867548,36.226979),38562=>array(-85.657669,36.354002),38563=>array(-86.030414,36.207154),38564=>array(-85.735915,36.275933),38565=>array(-85.009469,36.262759),38567=>array(-85.925809,36.132195),38568=>array(-85.473057,36.438492),38569=>array(-85.863126,36.092342),38570=>array(-85.326452,36.376276),38571=>array(-85.012804,36.051604),38572=>array(-85.12896,35.849059),38573=>array(-85.223882,36.493416),38574=>array(-85.229289,36.143643),38575=>array(-85.636403,36.555337),38577=>array(-84.972395,36.565976),38578=>array(-85.198328,35.981795),38579=>array(-85.548177,35.835867),38580=>array(-85.299934,36.290013),38581=>array(-85.620827,35.74104),38582=>array(-85.750823,36.094825),38583=>array(-85.442214,35.94454),38585=>array(-85.488673,35.615688),38587=>array(-85.613998,35.864761),38588=>array(-85.730671,36.446386),38589=>array(-85.077112,36.285583),38601=>array(-89.443056,34.492325),38603=>array(-89.148618,34.838608),38606=>array(-89.952316,34.303262),38610=>array(-89.025549,34.651787),38611=>array(-89.67601,34.856225),38614=>array(-90.603549,34.156569),38617=>array(-90.522226,34.350729),38618=>array(-89.936872,34.719451),38619=>array(-89.835541,34.518142),38620=>array(-89.90251,34.230138),38621=>array(-90.170459,34.447192),38622=>array(-90.138492,34.171912),38623=>array(-90.282849,34.367662),38625=>array(-88.826435,34.612136),38626=>array(-90.414527,34.517362),38627=>array(-89.207944,34.41783),38629=>array(-89.009788,34.862808),38630=>array(-90.685609,34.278839),38631=>array(-90.618306,34.360868),38632=>array(-90.015431,34.795717),38633=>array(-89.194971,34.647337),38635=>array(-89.486327,34.766909),38637=>array(-90.049209,34.952081),38639=>array(-90.432003,34.303108),38641=>array(-90.188582,34.914692),38642=>array(-89.334667,34.928904),38643=>array(-90.260865,34.148487),38644=>array(-90.49353,34.460809),38645=>array(-90.476523,34.246494),38646=>array(-90.314386,34.289637),38647=>array(-89.216526,34.961423),38650=>array(-89.145451,34.528102),38651=>array(-90.002154,34.895098),38652=>array(-88.996667,34.483075),38654=>array(-89.81628,34.933929),38655=>array(-89.47331,34.333213),38658=>array(-89.908188,34.192669),38659=>array(-89.331527,34.621515),38661=>array(-89.561056,34.896991),38663=>array(-88.882216,34.734051),38664=>array(-90.329253,34.811462),38665=>array(-90.166135,34.586548),38666=>array(-89.917826,34.4277),38668=>array(-89.912171,34.586066),38670=>array(-90.288714,34.416895),38671=>array(-89.998152,34.966282),38672=>array(-89.927925,34.911423),38673=>array(-89.635398,34.293442),38674=>array(-88.892398,34.86837),38676=>array(-90.383731,34.66645),38677=>array(-89.53718,34.365411),38680=>array(-90.146147,34.951674),38683=>array(-88.865292,34.932631),38685=>array(-89.488458,34.593013),38701=>array(-91.044262,33.310738),38702=>array(-91.180051,33.535666),38703=>array(-91.052834,33.475662),38704=>array(-91.021252,33.007175),38720=>array(-90.780951,34.106548),38721=>array(-90.746359,32.989634),38722=>array(-90.883939,33.260304),38723=>array(-91.038367,33.229662),38725=>array(-91.030947,33.648757),38726=>array(-90.988708,33.755796),38730=>array(-90.790778,33.682859),38731=>array(-91.046742,33.0666),38732=>array(-90.725595,33.758855),38736=>array(-90.537368,33.64279),38737=>array(-90.524172,33.863521),38738=>array(-90.533141,33.945099),38740=>array(-90.79876,34.057678),38744=>array(-91.037148,33.014154),38745=>array(-90.992816,32.972278),38746=>array(-90.909267,33.961973),38748=>array(-90.902048,33.151196),38749=>array(-90.752367,33.447423),38751=>array(-90.680525,33.447392),38753=>array(-90.576284,33.347339),38754=>array(-90.623293,33.249452),38756=>array(-90.860225,33.389797),38759=>array(-90.730327,33.825158),38760=>array(-90.989273,33.458034),38761=>array(-90.484464,33.430153),38762=>array(-90.716631,33.89594),38764=>array(-90.866202,33.780114),38765=>array(-90.874611,33.069113),38767=>array(-90.784721,34.140502),38768=>array(-90.496091,33.972174),38769=>array(-90.985297,33.864775),38771=>array(-90.528989,33.739965),38772=>array(-91.052351,33.559244),38773=>array(-90.776876,33.607259),38774=>array(-90.763309,33.958993),38778=>array(-90.531332,33.547117),38781=>array(-90.756588,33.908553),38801=>array(-88.775002,34.221257),38804=>array(-88.672873,34.281378),38821=>array(-88.436749,33.977521),38824=>array(-88.643025,34.520784),38826=>array(-88.841501,34.301266),38827=>array(-88.177452,34.51691),38828=>array(-88.86919,34.429858),38829=>array(-88.527423,34.650371),38833=>array(-88.319045,34.91816),38834=>array(-88.571777,34.917111),38838=>array(-88.254065,34.549134),38841=>array(-89.015267,34.352586),38843=>array(-88.376308,34.262049),38844=>array(-88.255262,33.838614),38846=>array(-88.382931,34.851359),38847=>array(-88.23296,34.41254),38848=>array(-88.271066,33.937645),38849=>array(-88.69606,34.460965),38850=>array(-89.057937,34.058891),38851=>array(-88.968194,33.9105),38852=>array(-88.213248,34.843688),38855=>array(-88.485375,34.323306),38856=>array(-88.455149,34.467115),38857=>array(-88.577902,34.281098),38858=>array(-88.5486,34.100102),38859=>array(-88.375211,34.515364),38860=>array(-88.761409,33.971749),38862=>array(-88.623239,34.168139),38863=>array(-89.019053,34.217915),38864=>array(-89.207666,34.15728),38865=>array(-88.595406,34.788031),38866=>array(-88.680045,34.367287),38868=>array(-88.762644,34.123549),38869=>array(-88.835132,34.357456),38870=>array(-88.336282,34.067434),38871=>array(-89.247255,34.381713),38873=>array(-88.242903,34.659698),38876=>array(-88.230292,34.21359),38878=>array(-89.187459,33.904506),38879=>array(-88.717188,34.186122),38901=>array(-89.802915,33.762528),38913=>array(-89.384872,34.138881),38914=>array(-89.416592,33.846213),38915=>array(-89.388855,34.03764),38916=>array(-89.35274,33.816534),38917=>array(-90.00653,33.556911),38920=>array(-89.995338,33.910061),38921=>array(-90.144181,33.982154),38922=>array(-89.645604,33.932586),38923=>array(-89.988589,33.388567),38924=>array(-90.224611,33.29149),38925=>array(-89.634279,33.62603),38927=>array(-90.032433,34.137997),38928=>array(-90.291749,33.869644),38929=>array(-89.531313,33.73946),38930=>array(-90.154409,33.538034),38940=>array(-90.029435,33.757504),38941=>array(-90.358231,33.484573),38943=>array(-89.845569,33.539901),38944=>array(-90.345818,33.762133),38945=>array(-90.168029,33.600948),38946=>array(-90.378549,33.364004),38947=>array(-89.907144,33.530018),38948=>array(-89.882155,34.067718),38949=>array(-89.425419,34.191573),38950=>array(-90.201369,33.733165),38951=>array(-89.29049,33.973783),38952=>array(-90.346974,33.628338),38953=>array(-89.933405,33.930672),38954=>array(-90.212551,33.416167),38957=>array(-90.350322,33.991776),38958=>array(-90.428149,33.303673),38961=>array(-89.914974,33.954527),38962=>array(-90.185145,33.871721),38963=>array(-90.389041,34.026122),38964=>array(-90.398491,34.09906),38965=>array(-89.60175,34.135544),38966=>array(-90.319159,33.947038),38967=>array(-89.732453,33.457399),39038=>array(-90.484577,33.18606),39039=>array(-90.217495,32.81655),39040=>array(-90.423181,32.641738),39041=>array(-90.4688,32.404857),39042=>array(-89.895597,32.198148),39044=>array(-89.974668,32.029303),39045=>array(-89.784552,32.819535),39046=>array(-89.983933,32.632163),39047=>array(-89.9455,32.421114),39051=>array(-89.493725,32.773554),39054=>array(-90.939277,32.774344),39056=>array(-90.351758,32.377538),39057=>array(-89.284427,32.490854),39059=>array(-90.355929,31.982082),39061=>array(-90.8178,33.085796),39062=>array(-89.89831,31.985097),39063=>array(-89.897489,33.116674),39066=>array(-90.605851,32.298256),39067=>array(-89.443782,33.110083),39069=>array(-91.043249,31.68616),39071=>array(-90.318382,32.554114),39073=>array(-90.135817,32.102431),39074=>array(-89.478007,32.393704),39078=>array(-90.188204,31.878048),39079=>array(-89.89855,32.935327),39082=>array(-90.120075,31.941844),39083=>array(-90.477306,31.844615),39086=>array(-90.759188,31.947443),39088=>array(-90.708326,32.766647),39090=>array(-89.543898,33.002016),39092=>array(-89.362401,32.319548),39094=>array(-89.663156,32.58625),39095=>array(-90.087121,33.129605),39096=>array(-91.115372,31.820913),39097=>array(-90.607517,32.989535),39108=>array(-89.338532,33.149349),39110=>array(-90.147164,32.50421),39111=>array(-89.718092,31.896635),39113=>array(-91.017222,32.913834),39114=>array(-89.824616,31.951841),39115=>array(-90.566898,33.044863),39116=>array(-89.538254,31.896441),39117=>array(-89.654596,32.306434),39119=>array(-89.670777,31.751549),39120=>array(-91.357494,31.509057),39140=>array(-90.008555,31.750881),39144=>array(-90.792933,31.822623),39145=>array(-89.7943,32.340469),39146=>array(-89.994907,32.876001),39149=>array(-90.010649,31.831965),39150=>array(-90.976048,32.004742),39152=>array(-89.585474,32.207475),39153=>array(-89.48828,32.046463),39154=>array(-90.444671,32.225111),39156=>array(-90.778416,32.548314),39157=>array(-90.169852,32.425874),39159=>array(-90.935377,32.826566),39160=>array(-89.762307,32.993805),39162=>array(-90.630068,32.622735),39166=>array(-90.481639,33.04082),39167=>array(-90.041116,32.094088),39168=>array(-89.411823,31.831878),39169=>array(-90.23862,33.218364),39170=>array(-90.330006,32.111889),39174=>array(-90.159625,32.401521),39175=>array(-90.631288,32.090647),39176=>array(-89.768327,33.306079),39177=>array(-90.800274,32.623273),39179=>array(-90.096939,32.802438),39180=>array(-90.857925,32.230115),39183=>array(-90.806574,32.447095),39189=>array(-89.400149,32.608003),39191=>array(-90.424334,31.711309),39192=>array(-89.762234,33.183639),39193=>array(-90.079336,32.234476),39194=>array(-90.512983,32.828894),39201=>array(-90.184201,32.289656),39202=>array(-90.170982,32.311113),39203=>array(-90.200338,32.308884),39204=>array(-90.206753,32.278603),39206=>array(-90.172455,32.372405),39208=>array(-90.091589,32.259773),39209=>array(-90.293193,32.395522),39211=>array(-90.122605,32.372134),39212=>array(-90.280351,32.243261),39213=>array(-90.23659,32.392757),39216=>array(-90.159551,32.333861),39217=>array(-90.210495,32.299131),39218=>array(-90.159703,32.230403),39232=>array(-90.091793,32.330663),39269=>array(-90.18889,32.301109),39272=>array(-90.258327,32.19061),39301=>array(-88.580363,32.273648),39305=>array(-88.714721,32.463029),39307=>array(-88.798726,32.337935),39309=>array(-88.615563,32.548966),39320=>array(-88.744163,32.569335),39322=>array(-88.503696,31.535469),39323=>array(-88.923736,32.352251),39325=>array(-88.877932,32.562024),39326=>array(-88.656165,32.602744),39327=>array(-89.119043,32.446464),39328=>array(-88.698611,32.743509),39330=>array(-88.843394,32.180797),39332=>array(-88.996763,32.302524),39335=>array(-88.49109,32.533136),39336=>array(-89.2622,32.300601),39337=>array(-88.979953,32.513555),39338=>array(-89.230935,32.106782),39339=>array(-89.011663,33.101905),39341=>array(-88.566395,33.098547),39342=>array(-88.648338,32.424496),39345=>array(-89.121899,32.291789),39346=>array(-89.095516,32.965029),39347=>array(-88.942004,32.060443),39348=>array(-89.023995,32.013623),39350=>array(-89.125241,32.796469),39352=>array(-88.481694,32.684044),39354=>array(-88.833423,32.874511),39355=>array(-88.624649,32.054731),39356=>array(-89.021973,32.134212),39358=>array(-88.471116,32.870415),39359=>array(-89.333571,32.567824),39360=>array(-88.754017,31.864814),39361=>array(-88.596416,32.995488),39362=>array(-88.541129,31.39096),39363=>array(-88.7652,32.126654),39364=>array(-88.486617,32.405281),39365=>array(-89.126133,32.602694),39366=>array(-88.918193,31.943818),39367=>array(-88.66586,31.676874),39401=>array(-89.26589,31.234109),39402=>array(-89.415848,31.334884),39406=>array(-89.334624,31.328451),39421=>array(-89.721243,31.492362),39422=>array(-89.257708,31.959313),39423=>array(-88.915119,31.170495),39425=>array(-89.080545,31.059779),39426=>array(-89.661262,30.6552),39427=>array(-89.814542,31.48013),39428=>array(-89.574039,31.650408),39429=>array(-89.756634,31.240977),39437=>array(-89.218571,31.579926),39439=>array(-89.013984,31.849174),39440=>array(-89.147245,31.693212),39443=>array(-89.075641,31.717522),39451=>array(-88.621661,31.1772),39452=>array(-88.602718,30.876501),39455=>array(-89.458807,31.011868),39456=>array(-88.823703,31.06007),39459=>array(-89.304575,31.489786),39461=>array(-88.742086,31.187698),39462=>array(-89.056274,31.235369),39464=>array(-89.08394,31.491996),39465=>array(-89.188147,31.339576),39466=>array(-89.585934,30.520513),39470=>array(-89.568805,30.823369),39474=>array(-89.855254,31.613449),39475=>array(-89.420252,31.152569),39476=>array(-88.876342,31.395406),39477=>array(-89.033802,31.788272),39478=>array(-89.85681,31.054177),39479=>array(-89.46237,31.53115),39480=>array(-89.315093,31.71151),39481=>array(-89.238168,31.868444),39482=>array(-89.579154,31.372022),39483=>array(-89.932348,31.242774),39501=>array(-89.102426,30.382966),39503=>array(-89.152878,30.474612),39507=>array(-89.034466,30.400484),39520=>array(-89.480153,30.26967),39525=>array(-89.370784,30.381932),39530=>array(-88.880304,30.409826),39531=>array(-88.966183,30.403986),39532=>array(-88.964318,30.493085),39534=>array(-88.924614,30.407452),39540=>array(-88.897015,30.443063),39553=>array(-88.644264,30.410268),39556=>array(-89.439893,30.441506),39560=>array(-89.172458,30.376022),39561=>array(-89.154883,30.702516),39562=>array(-88.489452,30.546682),39563=>array(-88.522157,30.420901),39564=>array(-88.758742,30.405228),39565=>array(-88.741183,30.5802),39567=>array(-88.540115,30.365446),39571=>array(-89.275043,30.420066),39572=>array(-89.601734,30.250996),39573=>array(-89.097566,30.729416),39574=>array(-89.089935,30.611848),39576=>array(-89.38329,30.290097),39577=>array(-89.086488,30.904729),39581=>array(-88.489791,30.357809),39601=>array(-90.470661,31.563223),39629=>array(-90.45685,31.436637),39630=>array(-90.84535,31.459306),39631=>array(-91.134282,31.067164),39633=>array(-91.181953,31.290709),39635=>array(-90.46343,31.191429),39638=>array(-90.995924,31.225004),39641=>array(-90.174857,31.355199),39643=>array(-90.014258,31.246549),39645=>array(-90.798891,31.148785),39647=>array(-90.722694,31.525939),39648=>array(-90.384302,31.189344),39652=>array(-90.475396,31.113659),39653=>array(-90.864478,31.481823),39654=>array(-90.136681,31.544944),39656=>array(-89.931798,31.443901),39657=>array(-90.506268,31.040324),39661=>array(-91.083468,31.484447),39662=>array(-90.285394,31.386372),39663=>array(-90.03835,31.594843),39664=>array(-90.674153,31.32597),39665=>array(-90.209176,31.64281),39666=>array(-90.482726,31.294966),39667=>array(-90.12604,31.124985),39668=>array(-90.809347,31.710523),39669=>array(-91.392666,31.123168),39701=>array(-88.504719,33.393933),39702=>array(-88.344713,33.439736),39705=>array(-88.436418,33.583667),39730=>array(-88.5653,33.843668),39735=>array(-89.1878,33.3532),39736=>array(-88.652317,33.431914),39737=>array(-89.330323,33.670566),39739=>array(-88.573868,33.239783),39740=>array(-88.305334,33.722448),39741=>array(-88.86629,33.649982),39743=>array(-88.613855,33.326358),39744=>array(-89.307271,33.57994),39745=>array(-89.451227,33.296546),39746=>array(-88.415414,33.752234),39747=>array(-89.554553,33.409239),39750=>array(-89.044772,33.568955),39751=>array(-89.093267,33.695301),39752=>array(-89.150748,33.522607),39755=>array(-88.957514,33.609399),39756=>array(-88.741085,33.756717),39759=>array(-88.825166,33.437929),39760=>array(-88.705141,33.464234),39762=>array(-88.79522,33.452779),39766=>array(-88.312071,33.587707),39767=>array(-89.448715,33.475509),39769=>array(-89.017838,33.321926),39771=>array(-89.275295,33.606242),39772=>array(-89.304493,33.295122),39773=>array(-88.690332,33.647676),39776=>array(-89.040474,33.780141),39813=>array(-84.684305,31.423156),39815=>array(-84.490698,30.73885),39817=>array(-84.602003,30.943525),39819=>array(-84.634069,30.788581),39823=>array(-84.946067,31.336246),39824=>array(-84.925018,31.495163),39825=>array(-84.740871,30.909841),39826=>array(-84.348887,31.820634),39827=>array(-84.209264,30.950847),39828=>array(-84.224088,30.808346),39834=>array(-84.428953,30.900371),39836=>array(-84.868547,31.665983),39837=>array(-84.677706,31.152104),39840=>array(-84.764694,31.780895),39841=>array(-84.685044,31.292866),39842=>array(-84.437475,31.760949),39845=>array(-84.892839,30.951468),39846=>array(-84.746115,31.563126),39851=>array(-84.992583,31.619831),39854=>array(-85.052581,31.869226),39859=>array(-84.812747,30.987652),39861=>array(-84.98718,31.135454),39862=>array(-84.517381,31.459371),39866=>array(-84.594331,31.559434),39867=>array(-84.927893,31.828416),39870=>array(-84.414137,31.322028),39877=>array(-84.511576,31.915159),39885=>array(-84.351063,31.717425),39886=>array(-84.621515,31.745736),39897=>array(-84.329813,30.911205),40003=>array(-85.043822,38.276689),40004=>array(-85.465955,37.803188),40006=>array(-85.333593,38.597612),40007=>array(-84.99915,38.458345),40008=>array(-85.275003,37.908948),40009=>array(-85.107358,37.470226),40010=>array(-85.459505,38.372519),40011=>array(-85.170096,38.527667),40012=>array(-85.191982,37.900841),40013=>array(-85.458027,37.934851),40014=>array(-85.429678,38.340259),40019=>array(-85.164341,38.380793),40020=>array(-85.387398,37.934782),40022=>array(-85.355023,38.153467),40023=>array(-85.432339,38.17414),40025=>array(-85.648691,38.299699),40026=>array(-85.532639,38.431156),40031=>array(-85.400731,38.430654),40033=>array(-85.225553,37.544124),40036=>array(-84.982456,38.41588),40037=>array(-85.417677,37.660798),40040=>array(-85.069286,37.777043),40041=>array(-85.664161,38.255905),40045=>array(-85.358514,38.68691),40046=>array(-85.169791,38.023931),40047=>array(-85.555239,38.039402),40048=>array(-85.470265,37.84704),40049=>array(-85.395025,37.663524),40050=>array(-85.186747,38.446036),40051=>array(-85.551307,37.677146),40052=>array(-85.487942,37.604128),40055=>array(-85.326025,38.495202),40056=>array(-85.488965,38.305594),40057=>array(-85.042908,38.394194),40058=>array(-85.170464,38.432738),40059=>array(-85.593622,38.358108),40060=>array(-85.466267,37.542332),40062=>array(-85.441513,37.605455),40063=>array(-85.339457,37.571367),40065=>array(-85.206928,38.2165),40067=>array(-85.368158,38.222511),40068=>array(-85.274186,38.395535),40069=>array(-85.209126,37.722374),40070=>array(-85.232149,38.468642),40071=>array(-85.378807,38.043009),40075=>array(-85.11267,38.568134),40076=>array(-85.086142,38.113729),40077=>array(-85.444636,38.495455),40078=>array(-85.153631,37.835641),40104=>array(-86.333004,38.08554),40107=>array(-85.598828,37.725327),40108=>array(-86.172833,37.970097),40109=>array(-85.751385,38.061072),40110=>array(-85.658363,37.932836),40111=>array(-86.628999,37.774709),40115=>array(-86.228337,37.727892),40117=>array(-86.124289,37.896583),40118=>array(-85.751202,38.097497),40119=>array(-86.553158,37.608198),40121=>array(-85.924406,37.952624),40140=>array(-86.353952,37.763133),40142=>array(-86.204086,37.893218),40143=>array(-86.509757,37.781355),40144=>array(-86.368271,37.74009),40145=>array(-86.314394,37.640459),40146=>array(-86.33084,37.849377),40150=>array(-85.713277,37.88023),40152=>array(-86.443858,37.614452),40155=>array(-85.992029,37.935748),40157=>array(-86.436187,38.04996),40160=>array(-85.937545,37.813422),40161=>array(-86.388706,37.999385),40162=>array(-86.059932,37.756799),40165=>array(-85.671626,37.969778),40170=>array(-86.509001,37.963833),40171=>array(-86.471826,37.973118),40175=>array(-86.089891,37.819003),40176=>array(-86.333203,37.918739),40177=>array(-85.921804,38.006379),40178=>array(-86.413619,37.660112),40202=>array(-85.754048,38.256783),40203=>array(-85.765167,38.252697),40204=>array(-85.721591,38.239913),40205=>array(-85.683261,38.223001),40206=>array(-85.704721,38.260083),40207=>array(-85.657736,38.265215),40208=>array(-85.767609,38.221279),40209=>array(-85.748301,38.189888),40210=>array(-85.786206,38.23153),40211=>array(-85.823737,38.23611),40212=>array(-85.799332,38.271962),40213=>array(-85.719409,38.177589),40214=>array(-85.780765,38.151772),40215=>array(-85.785734,38.190476),40216=>array(-85.840057,38.189833),40217=>array(-85.737515,38.216712),40218=>array(-85.654311,38.189321),40219=>array(-85.688316,38.138599),40220=>array(-85.617821,38.21641),40222=>array(-85.619448,38.271765),40223=>array(-85.539878,38.258349),40228=>array(-85.626299,38.134078),40229=>array(-85.653882,38.089498),40231=>array(-85.69492,38.195065),40241=>array(-85.575689,38.299974),40242=>array(-85.590514,38.277471),40243=>array(-85.536121,38.241801),40245=>array(-85.448219,38.266363),40258=>array(-85.877927,38.14627),40272=>array(-85.853119,38.078458),40280=>array(-85.688309,38.247636),40291=>array(-85.583895,38.130822),40299=>array(-85.517251,38.151676),40310=>array(-84.764512,37.749373),40311=>array(-83.996774,38.332224),40312=>array(-83.938668,37.855024),40313=>array(-83.376611,38.146989),40316=>array(-83.540136,37.941452),40322=>array(-83.634973,37.938657),40324=>array(-84.550616,38.246926),40328=>array(-85.067062,37.603953),40330=>array(-84.888056,37.787723),40334=>array(-83.762317,38.013489),40336=>array(-83.990952,37.682978),40337=>array(-83.854535,37.941491),40339=>array(-84.638897,37.944094),40342=>array(-84.979522,37.995815),40346=>array(-83.745639,37.985638),40347=>array(-84.728351,38.158286),40348=>array(-84.129361,38.288717),40350=>array(-83.873854,38.304672),40351=>array(-83.415533,38.204798),40353=>array(-83.948728,38.065328),40356=>array(-84.563367,37.874952),40358=>array(-83.67819,38.059899),40359=>array(-84.802855,38.491906),40360=>array(-83.789543,38.155202),40361=>array(-84.226885,38.208257),40363=>array(-85.009763,38.514407),40370=>array(-84.525082,38.403476),40371=>array(-83.580224,38.103804),40372=>array(-84.888114,37.911756),40374=>array(-83.889725,38.222724),40376=>array(-83.690134,37.772736),40379=>array(-84.686831,38.312851),40380=>array(-83.792349,37.815615),40383=>array(-84.738859,38.006552),40385=>array(-84.133019,37.737704),40387=>array(-83.492267,37.933577),40390=>array(-84.666918,37.849691),40391=>array(-84.144974,37.970133),40402=>array(-83.975517,37.292686),40403=>array(-84.271388,37.570745),40404=>array(-84.290836,37.573456),40409=>array(-84.434837,37.369255),40419=>array(-84.489312,37.437808),40422=>array(-84.797275,37.640997),40434=>array(-83.940822,37.394162),40437=>array(-84.870139,37.435588),40440=>array(-84.81999,37.585885),40442=>array(-84.741734,37.338738),40444=>array(-84.577248,37.666655),40445=>array(-84.187292,37.338854),40447=>array(-84.032317,37.485787),40448=>array(-84.756783,37.459547),40456=>array(-84.319499,37.353469),40460=>array(-84.226793,37.397757),40461=>array(-84.406,37.58253),40464=>array(-84.920625,37.56227),40468=>array(-84.978242,37.633934),40472=>array(-83.859673,37.732125),40475=>array(-84.312658,37.761655),40481=>array(-84.090064,37.448874),40484=>array(-84.673931,37.52058),40486=>array(-83.858912,37.36972),40489=>array(-84.637255,37.365743),40502=>array(-84.483191,38.010953),40503=>array(-84.533469,38.005828),40504=>array(-84.544016,38.042413),40505=>array(-84.457264,38.060601),40506=>array(-84.50314,38.028302),40507=>array(-84.496353,38.046955),40508=>array(-84.511664,38.061351),40509=>array(-84.377731,37.997335),40510=>array(-84.583839,38.0712),40511=>array(-84.478298,38.132379),40513=>array(-84.605767,38.017678),40514=>array(-84.563051,37.98246),40515=>array(-84.391441,37.917671),40516=>array(-84.36378,38.071752),40517=>array(-84.489425,37.982958),40601=>array(-84.868786,38.234919),40604=>array(-84.86254,38.176731),40701=>array(-84.157936,36.921918),40729=>array(-84.137943,37.252563),40734=>array(-83.953721,36.924391),40737=>array(-84.130808,37.010813),40740=>array(-84.037313,37.020582),40741=>array(-84.127273,37.136791),40743=>array(-84.115361,37.072518),40744=>array(-84.118983,37.029447),40759=>array(-84.057124,36.812972),40763=>array(-83.925551,36.689214),40769=>array(-84.178636,36.711538),40771=>array(-84.034516,36.863749),40801=>array(-83.246379,36.862117),40806=>array(-83.297065,36.891253),40807=>array(-82.946,36.964094),40808=>array(-83.203375,36.996323),40810=>array(-83.374634,36.906934),40813=>array(-83.591917,36.709925),40815=>array(-83.219076,36.784466),40816=>array(-83.27138,37.006822),40818=>array(-83.243138,36.821595),40819=>array(-83.446102,36.804974),40820=>array(-83.178536,36.748626),40823=>array(-82.990311,36.957891),40824=>array(-83.375373,36.825291),40826=>array(-82.781635,37.058809),40827=>array(-83.51332,37.038332),40828=>array(-83.134079,36.880342),40829=>array(-83.302252,36.79601),40830=>array(-83.328571,36.760178),40831=>array(-83.354262,36.766574),40840=>array(-83.44013,36.899994),40843=>array(-82.990854,36.891037),40844=>array(-83.341426,37.057797),40845=>array(-83.51797,36.798817),40847=>array(-83.174781,36.850594),40849=>array(-83.1312,36.894013),40854=>array(-83.353853,36.845558),40855=>array(-82.893779,36.941051),40856=>array(-83.529257,36.725419),40858=>array(-83.414336,36.984485),40862=>array(-82.855656,37.018411),40863=>array(-83.43093,36.727157),40865=>array(-83.211147,36.920103),40868=>array(-83.497782,37.070108),40870=>array(-83.144327,36.923407),40873=>array(-83.409322,36.818242),40874=>array(-83.483171,36.986377),40902=>array(-83.594365,36.871828),40903=>array(-83.814814,36.79844),40906=>array(-83.885898,36.880297),40913=>array(-83.558358,36.93675),40914=>array(-83.567772,37.142595),40915=>array(-83.80754,36.887298),40921=>array(-83.886514,36.767163),40923=>array(-83.844555,36.919179),40927=>array(-83.063102,36.873203),40935=>array(-83.721242,36.892872),40939=>array(-83.696262,36.811921),40940=>array(-83.939089,36.60262),40941=>array(-83.732364,37.124945),40943=>array(-83.86277,36.970297),40946=>array(-83.807193,36.974203),40949=>array(-83.870853,36.887056),40953=>array(-83.801714,36.937816),40958=>array(-83.59693,36.809877),40962=>array(-83.734933,37.144486),40964=>array(-83.310832,36.770091),40965=>array(-83.715703,36.633945),40972=>array(-83.577046,37.25964),40977=>array(-83.772324,36.700132),40979=>array(-83.51125,37.005784),40982=>array(-83.690087,36.932745),40983=>array(-83.754614,37.330951),40988=>array(-83.516041,36.865182),40995=>array(-83.815456,36.761013),40997=>array(-83.661992,36.894531),41001=>array(-84.40337,38.917606),41002=>array(-83.968175,38.740005),41003=>array(-84.390246,38.52964),41004=>array(-84.087983,38.644125),41005=>array(-84.760116,39.006759),41006=>array(-84.345639,38.78443),41007=>array(-84.294627,38.892187),41008=>array(-85.16864,38.663314),41010=>array(-84.608194,38.499633),41011=>array(-84.532685,39.067114),41014=>array(-84.505282,39.06629),41015=>array(-84.484328,38.979011),41016=>array(-84.54799,39.089673),41017=>array(-84.561887,39.029089),41018=>array(-84.602186,39.014901),41030=>array(-84.589506,38.788499),41031=>array(-84.288716,38.418648),41033=>array(-84.458755,38.767235),41034=>array(-83.891318,38.723934),41035=>array(-84.654354,38.719224),41039=>array(-83.869813,38.415115),41040=>array(-84.331458,38.650874),41041=>array(-83.720679,38.407395),41042=>array(-84.651005,39.000968),41043=>array(-84.195507,38.763933),41044=>array(-83.972434,38.610431),41045=>array(-85.038033,38.726929),41046=>array(-84.803336,38.717378),41048=>array(-84.706333,39.098839),41049=>array(-83.640286,38.268969),41051=>array(-84.548265,38.934248),41052=>array(-84.768518,38.677987),41055=>array(-83.866465,38.525392),41056=>array(-83.778115,38.594901),41059=>array(-84.35138,39.013395),41062=>array(-83.92284,38.70401),41063=>array(-84.495123,38.84653),41064=>array(-84.063757,38.513826),41071=>array(-84.48332,39.073947),41073=>array(-84.479187,39.102398),41074=>array(-84.46446,39.112758),41075=>array(-84.453172,39.081974),41076=>array(-84.453965,39.012728),41080=>array(-84.824178,39.05469),41083=>array(-84.96746,38.666019),41085=>array(-84.393332,39.03641),41086=>array(-84.87144,38.689205),41091=>array(-84.736327,38.910267),41092=>array(-84.691082,38.815603),41093=>array(-83.558464,38.387403),41094=>array(-84.624108,38.882754),41095=>array(-84.747515,38.773681),41097=>array(-84.581444,38.621179),41098=>array(-85.008171,38.58687),41099=>array(-84.468189,39.035893),41101=>array(-82.647933,38.473824),41102=>array(-82.730185,38.427628),41121=>array(-82.833635,38.439426),41124=>array(-82.851398,38.033073),41129=>array(-82.648956,38.322078),41132=>array(-82.812826,38.272196),41135=>array(-83.301975,38.344302),41139=>array(-82.726618,38.514155),41141=>array(-83.170636,38.538083),41142=>array(-83.073062,38.277675),41143=>array(-82.975412,38.334906),41144=>array(-82.943173,38.539423),41146=>array(-82.896006,38.279174),41149=>array(-83.06203,38.107118),41159=>array(-82.997365,37.999169),41164=>array(-83.157131,38.288377),41166=>array(-83.093709,38.637168),41168=>array(-82.751009,38.30699),41169=>array(-82.73789,38.535531),41171=>array(-83.106178,38.088864),41174=>array(-83.011802,38.704035),41175=>array(-82.969552,38.650336),41179=>array(-83.373303,38.532051),41180=>array(-82.874882,38.137267),41183=>array(-82.737832,38.553369),41189=>array(-83.561568,38.546435),41201=>array(-82.738305,38.074459),41203=>array(-82.459536,37.840704),41204=>array(-82.676404,37.814671),41214=>array(-82.626345,37.793736),41216=>array(-82.803369,37.732573),41219=>array(-82.905328,37.926112),41222=>array(-82.858454,37.755891),41224=>array(-82.559913,37.798001),41226=>array(-82.952067,37.981562),41230=>array(-82.672792,38.043724),41231=>array(-82.385714,37.807549),41232=>array(-82.729722,37.941055),41234=>array(-82.746785,37.78866),41238=>array(-82.961186,37.846223),41240=>array(-82.796748,37.823945),41250=>array(-82.469106,37.722435),41254=>array(-82.715358,37.887162),41255=>array(-82.832837,37.904268),41256=>array(-82.891812,37.837353),41257=>array(-82.795669,37.93001),41260=>array(-82.752825,37.825557),41262=>array(-82.630111,37.845089),41263=>array(-82.75218,37.856896),41264=>array(-82.681439,37.924913),41265=>array(-82.705776,37.748314),41267=>array(-82.440987,37.878227),41268=>array(-82.785602,37.788779),41271=>array(-82.723584,37.822449),41274=>array(-82.810705,37.86416),41301=>array(-83.492319,37.728709),41311=>array(-83.710711,37.58322),41314=>array(-83.640207,37.425581),41317=>array(-83.153213,37.445626),41332=>array(-83.389223,37.800748),41339=>array(-83.269101,37.51618),41348=>array(-83.301029,37.409359),41352=>array(-83.33029,37.822932),41360=>array(-83.614611,37.801388),41365=>array(-83.628873,37.706784),41366=>array(-83.21778,37.595031),41367=>array(-83.232979,37.40869),41385=>array(-83.314769,37.663801),41390=>array(-83.376921,37.409391),41397=>array(-83.673356,37.689048),41408=>array(-83.284967,37.778659),41421=>array(-83.193358,37.995371),41425=>array(-83.394303,37.888469),41464=>array(-82.954481,37.669803),41465=>array(-83.104679,37.705079),41472=>array(-83.219757,37.947391),41501=>array(-82.513614,37.514701),41503=>array(-82.287483,37.664367),41512=>array(-82.476079,37.253714),41513=>array(-82.340427,37.346646),41514=>array(-82.3171,37.670612),41517=>array(-82.578639,37.195397),41519=>array(-82.321568,37.58404),41522=>array(-82.398684,37.303497),41524=>array(-82.231133,37.417987),41526=>array(-82.510757,37.433325),41527=>array(-82.289018,37.632121),41528=>array(-82.139906,37.548982),41531=>array(-82.232756,37.592806),41534=>array(-82.476578,37.277524),41535=>array(-82.279672,37.596357),41537=>array(-82.613734,37.22262),41538=>array(-82.590072,37.31558),41539=>array(-82.327132,37.506832),41540=>array(-82.334873,37.390941),41543=>array(-82.285498,37.547898),41544=>array(-82.17409,37.593903),41547=>array(-82.090741,37.536055),41548=>array(-82.269778,37.392305),41553=>array(-82.163613,37.477137),41554=>array(-82.289057,37.436457),41555=>array(-82.258488,37.538033),41557=>array(-82.402869,37.482067),41558=>array(-82.209218,37.53858),41559=>array(-82.383098,37.37443),41560=>array(-82.578344,37.395551),41562=>array(-82.463611,37.39871),41563=>array(-82.536634,37.232192),41564=>array(-82.364783,37.607594),41566=>array(-82.201444,37.403386),41567=>array(-82.283322,37.575019),41568=>array(-82.093744,37.501616),41571=>array(-82.435568,37.627536),41572=>array(-82.643581,37.313498),41601=>array(-82.721784,37.600073),41602=>array(-82.754891,37.745909),41603=>array(-82.70399,37.570321),41604=>array(-82.660754,37.38348),41605=>array(-82.624621,37.550128),41606=>array(-82.734287,37.336895),41607=>array(-82.856919,37.625075),41612=>array(-82.723004,37.354326),41615=>array(-82.692532,37.537442),41616=>array(-82.879946,37.568311),41619=>array(-82.735427,37.483681),41621=>array(-82.731292,37.626661),41622=>array(-82.816952,37.522691),41630=>array(-82.798478,37.467577),41631=>array(-82.655511,37.472836),41632=>array(-82.951759,37.564908),41635=>array(-82.626066,37.48437),41636=>array(-82.731808,37.39915),41640=>array(-82.952184,37.471413),41642=>array(-82.648611,37.592169),41643=>array(-82.832233,37.460203),41645=>array(-82.795306,37.523824),41647=>array(-82.717672,37.442267),41649=>array(-82.776712,37.570949),41650=>array(-82.683267,37.354509),41653=>array(-82.75821,37.655082),41655=>array(-82.735442,37.507205),41659=>array(-82.621948,37.579616),41660=>array(-82.631727,37.414098),41663=>array(-82.662177,37.565904),41666=>array(-82.807592,37.439031),41667=>array(-82.694618,37.308123),41669=>array(-82.715525,37.331634),41701=>array(-83.19055,37.292881),41712=>array(-83.133498,37.365957),41713=>array(-83.276435,37.219388),41714=>array(-83.516892,37.143467),41719=>array(-83.257183,37.306272),41721=>array(-83.47322,37.309057),41722=>array(-83.115979,37.369184),41723=>array(-83.319126,37.263257),41725=>array(-83.035062,37.339144),41727=>array(-83.278803,37.377305),41729=>array(-83.215515,37.264628),41731=>array(-83.0796,37.095398),41735=>array(-83.097478,37.015056),41739=>array(-83.120828,37.324334),41740=>array(-83.072519,37.364326),41745=>array(-83.433008,37.340209),41746=>array(-83.095753,37.214632),41749=>array(-83.434495,37.20721),41751=>array(-83.138607,37.210858),41754=>array(-83.320849,37.30138),41759=>array(-83.012593,37.219807),41760=>array(-83.076493,37.205706),41762=>array(-83.478516,37.264186),41763=>array(-83.150357,37.066992),41764=>array(-83.254014,37.116657),41766=>array(-83.465731,37.179868),41772=>array(-83.052958,37.424293),41773=>array(-83.02667,37.231881),41774=>array(-83.135351,37.139752),41775=>array(-83.346784,37.099564),41776=>array(-83.295015,37.168293),41777=>array(-83.256322,37.072346),41804=>array(-83.002154,37.151503),41810=>array(-82.673873,37.185169),41812=>array(-82.745507,37.254175),41815=>array(-82.798142,37.160405),41817=>array(-82.929809,37.347483),41819=>array(-83.107011,36.987109),41821=>array(-83.014762,37.059123),41822=>array(-82.977183,37.327714),41824=>array(-82.873263,37.191542),41825=>array(-82.708422,37.229392),41826=>array(-82.912088,37.163357),41828=>array(-82.787943,37.288135),41831=>array(-82.953376,37.387165),41832=>array(-82.959284,37.148686),41833=>array(-82.98577,37.025999),41834=>array(-82.955207,37.252309),41835=>array(-82.667983,37.221077),41836=>array(-82.892356,37.237561),41837=>array(-82.758347,37.12515),41838=>array(-82.756689,37.203757),41839=>array(-82.89402,37.40332),41840=>array(-82.720878,37.198987),41843=>array(-82.845386,37.283517),41844=>array(-82.866733,37.31488),41845=>array(-82.901327,37.141394),41847=>array(-82.967693,37.201844),41848=>array(-82.94792,37.093381),41849=>array(-82.734853,37.175839),41855=>array(-82.784701,37.190487),41858=>array(-82.854849,37.136055),41859=>array(-82.771916,37.387925),41861=>array(-82.821902,37.405758),41862=>array(-82.773252,37.342758),42001=>array(-88.7094,37.030572),42003=>array(-88.581285,37.005344),42020=>array(-88.289872,36.692634),42021=>array(-89.027668,36.82256),42022=>array(-88.944769,37.144988),42023=>array(-88.990221,36.87255),42024=>array(-89.050311,37.077408),42025=>array(-88.335064,36.856894),42027=>array(-88.627686,36.916671),42028=>array(-88.336844,37.238907),42029=>array(-88.39196,37.006472),42031=>array(-88.991397,36.685748),42032=>array(-89.108099,36.775917),42035=>array(-88.840382,36.900226),42036=>array(-88.214544,36.711521),42037=>array(-88.187707,37.172781),42038=>array(-88.027242,37.048002),42039=>array(-88.825434,36.788709),42040=>array(-88.497073,36.625296),42041=>array(-88.877352,36.550373),42044=>array(-88.263311,36.959185),42045=>array(-88.263094,37.063997),42047=>array(-88.399352,37.295041),42048=>array(-88.228582,36.765705),42049=>array(-88.333756,36.521138),42050=>array(-89.219274,36.555421),42051=>array(-88.647174,36.850728),42053=>array(-88.877823,37.112649),42054=>array(-88.433457,36.714454),42055=>array(-88.174049,37.075226),42056=>array(-88.986746,37.107275),42058=>array(-88.465707,37.058337),42060=>array(-88.82813,36.965854),42061=>array(-88.766366,36.882838),42064=>array(-88.089515,37.357138),42066=>array(-88.639882,36.732532),42069=>array(-88.756493,36.918791),42071=>array(-88.284907,36.624585),42076=>array(-88.106951,36.571455),42078=>array(-88.286799,37.277815),42079=>array(-88.588811,36.567762),42081=>array(-88.416633,37.226678),42082=>array(-88.500423,36.919858),42083=>array(-88.287818,37.161098),42084=>array(-88.245662,37.434663),42085=>array(-88.800945,36.569521),42086=>array(-88.771835,37.088547),42087=>array(-88.996318,36.975903),42088=>array(-88.747697,36.621222),42101=>array(-86.463061,37.058096),42102=>array(-86.418234,37.003731),42103=>array(-86.281066,36.945656),42104=>array(-86.44775,36.883066),42120=>array(-86.262112,36.672853),42122=>array(-86.353679,36.85707),42123=>array(-85.984847,36.816327),42124=>array(-85.643964,36.87054),42127=>array(-85.918463,37.113569),42129=>array(-85.583379,36.991218),42130=>array(-85.786306,36.925865),42133=>array(-85.957537,36.725886),42134=>array(-86.564467,36.72452),42140=>array(-85.828893,36.656541),42141=>array(-85.918331,36.947551),42151=>array(-85.553812,36.649748),42153=>array(-86.066301,36.662368),42154=>array(-85.73132,37.042605),42156=>array(-86.053664,36.851328),42157=>array(-85.81969,36.781415),42159=>array(-86.247946,36.993145),42160=>array(-86.035699,37.106544),42163=>array(-86.134145,37.07906),42164=>array(-86.181864,36.775664),42166=>array(-85.708775,36.880186),42167=>array(-85.674109,36.720987),42170=>array(-86.576675,36.840553),42171=>array(-86.17046,37.03619),42202=>array(-86.847555,36.689923),42204=>array(-87.076167,36.684754),42206=>array(-86.743019,36.886677),42207=>array(-86.266888,37.293995),42210=>array(-86.252303,37.206716),42211=>array(-87.838269,36.817943),42214=>array(-85.683348,37.138077),42215=>array(-87.667395,36.996009),42217=>array(-87.458463,37.040667),42220=>array(-87.178636,36.893234),42223=>array(-87.462873,36.628264),42232=>array(-87.655039,36.872641),42234=>array(-87.180194,36.71161),42236=>array(-87.614237,36.716286),42240=>array(-87.463142,36.880182),42254=>array(-87.654367,36.660877),42256=>array(-86.93744,37.000918),42259=>array(-86.148284,37.243161),42261=>array(-86.671334,37.217107),42262=>array(-87.449417,36.679919),42265=>array(-87.004306,36.739223),42266=>array(-87.357236,36.744319),42273=>array(-86.843897,37.21593),42274=>array(-86.598782,36.950235),42275=>array(-86.456967,37.217046),42276=>array(-86.879778,36.857008),42280=>array(-87.099164,36.956981),42285=>array(-86.297848,37.26406),42286=>array(-87.28984,36.729179),42301=>array(-87.249397,37.735778),42303=>array(-87.046199,37.758954),42320=>array(-86.861075,37.335491),42321=>array(-87.055061,37.165489),42322=>array(-87.395313,37.613648),42323=>array(-87.035443,37.173379),42324=>array(-87.004577,37.134997),42325=>array(-87.274016,37.327891),42326=>array(-87.008142,37.226524),42327=>array(-87.297311,37.58053),42328=>array(-87.045245,37.430627),42330=>array(-87.117943,37.321824),42332=>array(-87.088665,37.250429),42333=>array(-86.758669,37.364262),42337=>array(-86.948897,37.198542),42338=>array(-86.800687,37.544028),42339=>array(-86.974733,37.094248),42343=>array(-86.700827,37.635989),42344=>array(-87.317827,37.269654),42345=>array(-87.183717,37.135863),42347=>array(-86.882159,37.525035),42348=>array(-86.767657,37.830706),42349=>array(-86.6766,37.422583),42350=>array(-87.186913,37.455012),42351=>array(-86.866633,37.898577),42352=>array(-87.0859,37.514811),42354=>array(-86.930719,37.376776),42355=>array(-86.991155,37.852948),42356=>array(-87.324109,37.693255),42361=>array(-86.683941,37.517166),42366=>array(-86.93761,37.723668),42367=>array(-87.159905,37.239421),42368=>array(-86.754071,37.702946),42369=>array(-87.003767,37.358648),42370=>array(-86.738928,37.44902),42371=>array(-87.289967,37.509858),42372=>array(-87.272953,37.40411),42374=>array(-87.156766,37.325579),42376=>array(-87.086437,37.617483),42378=>array(-86.863261,37.667286),42404=>array(-87.838413,37.474356),42406=>array(-87.73824,37.762139),42408=>array(-87.692699,37.179537),42409=>array(-87.692934,37.538637),42410=>array(-87.511771,37.278539),42411=>array(-88.012512,37.196036),42413=>array(-87.467001,37.448656),42420=>array(-87.515005,37.810607),42431=>array(-87.481387,37.334473),42436=>array(-87.575537,37.37395),42437=>array(-87.93807,37.666657),42440=>array(-87.464606,37.240706),42441=>array(-87.66645,37.360691),42442=>array(-87.495808,37.163858),42445=>array(-87.85174,37.133339),42450=>array(-87.763402,37.39587),42451=>array(-87.390707,37.884533),42452=>array(-87.531672,37.686512),42453=>array(-87.590712,37.157854),42455=>array(-87.542551,37.593375),42456=>array(-87.496097,37.507705),42458=>array(-87.420942,37.839563),42459=>array(-88.019048,37.566806),42461=>array(-87.889216,37.797397),42462=>array(-87.801718,37.743982),42463=>array(-87.869452,37.47262),42464=>array(-87.356148,37.18125),42501=>array(-84.450896,37.056193),42503=>array(-84.524653,37.155209),42516=>array(-84.786116,37.222051),42518=>array(-84.632646,36.94237),42519=>array(-84.534998,36.955324),42528=>array(-85.0234,37.181526),42533=>array(-84.592621,37.072259),42539=>array(-84.951008,37.308926),42541=>array(-84.794929,37.359577),42544=>array(-84.815125,37.029948),42553=>array(-84.697266,37.166676),42565=>array(-84.889661,37.148862),42566=>array(-84.783143,37.278605),42567=>array(-84.604696,37.265935),42602=>array(-85.110438,36.739629),42603=>array(-85.029028,36.782248),42629=>array(-85.137744,36.912633),42631=>array(-84.480987,36.74039),42633=>array(-84.83044,36.802011),42634=>array(-84.43182,36.882843),42635=>array(-84.395984,36.680268),42638=>array(-84.47046,36.674414),42642=>array(-85.035151,37.058681),42647=>array(-84.628434,36.685874),42649=>array(-84.429108,36.622681),42653=>array(-84.453492,36.783103),42701=>array(-85.836999,37.703827),42712=>array(-86.108877,37.518754),42713=>array(-85.883731,37.38313),42715=>array(-85.395478,36.954929),42716=>array(-85.606104,37.479953),42717=>array(-85.378995,36.788363),42718=>array(-85.373081,37.385228),42721=>array(-86.499353,37.423011),42722=>array(-85.716132,37.276586),42724=>array(-86.070835,37.675918),42726=>array(-86.151169,37.41993),42728=>array(-85.289858,37.117103),42729=>array(-86.096501,37.30647),42731=>array(-85.557382,36.847822),42732=>array(-86.133317,37.588954),42733=>array(-85.18643,37.343603),42740=>array(-85.948305,37.586199),42741=>array(-85.238426,36.999228),42743=>array(-85.532234,37.227403),42746=>array(-85.732393,37.212381),42748=>array(-85.707146,37.571623),42749=>array(-85.878231,37.184614),42753=>array(-85.184826,37.217403),42754=>array(-86.316299,37.472934),42757=>array(-85.719536,37.402832),42758=>array(-85.198742,37.374401),42762=>array(-86.39315,37.455344),42764=>array(-85.620545,37.429592),42765=>array(-85.935197,37.332746),42776=>array(-85.927093,37.514508),42782=>array(-85.64307,37.336802),42784=>array(-85.934803,37.45082),42788=>array(-86.027886,37.529664),43001=>array(-82.613984,40.088073),43002=>array(-83.170873,40.062362),43003=>array(-82.979342,40.412257),43004=>array(-82.798786,40.017344),43005=>array(-82.276823,40.286152),43006=>array(-82.149286,40.459722),43008=>array(-82.480911,39.93389),43009=>array(-83.639488,40.171539),43010=>array(-83.622593,39.999963),43011=>array(-82.679662,40.302997),43013=>array(-82.688323,40.233121),43014=>array(-82.262514,40.466759),43015=>array(-83.060181,40.297786),43016=>array(-83.150103,40.09746),43017=>array(-83.1305,40.116621),43019=>array(-82.578515,40.49294),43021=>array(-82.882787,40.191554),43022=>array(-82.339811,40.345039),43023=>array(-82.536394,40.078895),43025=>array(-82.517373,39.970889),43026=>array(-83.194413,40.02085),43028=>array(-82.297266,40.401712),43029=>array(-83.440642,40.097477),43030=>array(-82.415819,39.961458),43031=>array(-82.665157,40.160842),43032=>array(-82.958823,40.328624),43033=>array(-82.604328,39.961408),43035=>array(-82.995118,40.188543),43036=>array(-83.261098,40.352201),43037=>array(-82.323443,40.284469),43040=>array(-83.359687,40.261002),43044=>array(-83.550419,40.054708),43045=>array(-83.458675,40.168381),43046=>array(-82.541954,39.896382),43050=>array(-82.495551,40.374153),43054=>array(-82.798908,40.083073),43055=>array(-82.377784,40.119897),43056=>array(-82.340989,40.008493),43060=>array(-83.571542,40.222353),43061=>array(-83.203052,40.289506),43062=>array(-82.682268,40.007079),43064=>array(-83.283763,40.098119),43065=>array(-83.094187,40.17754),43066=>array(-83.171969,40.39129),43067=>array(-83.468202,40.340479),43068=>array(-82.784665,39.956185),43070=>array(-83.957945,40.215778),43071=>array(-82.359463,40.180695),43072=>array(-83.956704,40.119674),43074=>array(-82.850669,40.270014),43076=>array(-82.39875,39.897004),43077=>array(-83.341267,40.13705),43078=>array(-83.78379,40.117639),43080=>array(-82.429738,40.240586),43081=>array(-82.890646,40.110443),43082=>array(-82.884874,40.149185),43084=>array(-83.556715,40.148352),43085=>array(-83.013402,40.100924),43101=>array(-82.74613,39.464519),43102=>array(-82.762562,39.640398),43103=>array(-82.935709,39.732375),43105=>array(-82.612369,39.86676),43106=>array(-83.421179,39.642318),43107=>array(-82.414529,39.692825),43109=>array(-82.831944,39.916675),43110=>array(-82.800074,39.826682),43111=>array(-82.242722,39.502073),43112=>array(-82.70462,39.797808),43113=>array(-82.963776,39.592553),43115=>array(-83.150971,39.491771),43116=>array(-83.062012,39.771637),43117=>array(-83.206122,39.768789),43119=>array(-83.205719,39.940928),43123=>array(-83.114347,39.869489),43125=>array(-82.887941,39.838052),43126=>array(-83.165765,39.815503),43127=>array(-82.321987,39.480597),43128=>array(-83.594024,39.659722),43130=>array(-82.614164,39.696616),43135=>array(-82.69342,39.468184),43136=>array(-82.812481,39.801317),43137=>array(-82.987481,39.80884),43138=>array(-82.41409,39.518348),43140=>array(-83.429006,39.879858),43142=>array(-83.587259,39.593715),43143=>array(-83.288346,39.712707),43144=>array(-82.193959,39.528775),43145=>array(-83.259784,39.564942),43146=>array(-83.136925,39.773521),43147=>array(-82.74402,39.897778),43148=>array(-82.499992,39.820316),43149=>array(-82.577874,39.542972),43150=>array(-82.40617,39.777495),43151=>array(-83.476424,39.732952),43152=>array(-82.615799,39.395448),43153=>array(-83.556821,39.743695),43154=>array(-82.829414,39.599871),43155=>array(-82.528905,39.634641),43156=>array(-82.776295,39.55352),43157=>array(-82.546206,39.842653),43158=>array(-82.357566,39.449001),43160=>array(-83.441323,39.526516),43162=>array(-83.308394,39.949398),43164=>array(-83.118396,39.585238),43201=>array(-82.999946,39.99083),43202=>array(-83.0151,40.019812),43203=>array(-82.969026,39.973084),43204=>array(-83.081964,39.961292),43205=>array(-82.962071,39.957019),43206=>array(-82.974175,39.942452),43207=>array(-82.962832,39.894679),43209=>array(-82.930721,39.953616),43210=>array(-83.023227,40.005435),43211=>array(-82.970532,40.011814),43212=>array(-83.042824,39.987145),43213=>array(-82.862134,39.966873),43214=>array(-83.016269,40.051734),43215=>array(-83.01296,39.966856),43217=>array(-82.92277,39.81642),43219=>array(-82.921346,40.006193),43220=>array(-83.074244,40.049153),43221=>array(-83.076127,40.023112),43222=>array(-83.035484,39.961192),43223=>array(-83.033424,39.927633),43224=>array(-82.964856,40.04266),43227=>array(-82.890437,39.944059),43228=>array(-83.125661,39.966378),43229=>array(-82.978198,40.08587),43230=>array(-82.870875,40.035763),43231=>array(-82.934777,40.079333),43232=>array(-82.870182,39.921124),43235=>array(-83.027626,40.118363),43240=>array(-82.982863,40.144858),43302=>array(-83.128808,40.599809),43310=>array(-83.786442,40.535325),43311=>array(-83.756432,40.365633),43314=>array(-82.959411,40.649148),43315=>array(-82.874359,40.483968),43316=>array(-83.380698,40.954177),43317=>array(-82.680654,40.474727),43318=>array(-83.91264,40.306812),43319=>array(-83.57512,40.302682),43320=>array(-82.898039,40.588536),43321=>array(-82.829783,40.457343),43322=>array(-83.20784,40.532181),43323=>array(-83.247809,40.729183),43324=>array(-83.813789,40.444533),43326=>array(-83.614912,40.639365),43330=>array(-83.419408,40.813493),43331=>array(-83.921643,40.517943),43332=>array(-83.371544,40.590903),43333=>array(-83.924616,40.443022),43334=>array(-82.798877,40.399755),43336=>array(-83.582332,40.290833),43337=>array(-83.266637,40.681312),43338=>array(-82.760333,40.564167),43340=>array(-83.475995,40.543906),43341=>array(-83.315294,40.596568),43342=>array(-83.18398,40.471236),43343=>array(-83.978712,40.309159),43344=>array(-83.344615,40.430934),43345=>array(-83.583824,40.5112),43347=>array(-83.65958,40.477854),43348=>array(-83.889132,40.462671),43351=>array(-83.303252,40.82548),43356=>array(-83.032615,40.465076),43357=>array(-83.746806,40.253579),43358=>array(-83.537653,40.414555),43359=>array(-83.45488,40.873493),43360=>array(-83.643522,40.33314),43402=>array(-83.656646,41.417547),43403=>array(-83.637118,41.376979),43406=>array(-83.433071,41.333897),43407=>array(-83.249407,41.277832),43408=>array(-83.363462,41.571832),43410=>array(-82.957585,41.31187),43412=>array(-83.32035,41.627632),43413=>array(-83.65159,41.243222),43416=>array(-83.267229,41.483937),43420=>array(-83.110264,41.358062),43430=>array(-83.370037,41.522208),43431=>array(-83.335312,41.390755),43432=>array(-83.252471,41.563259),43433=>array(-82.880261,41.504694),43434=>array(-83.444689,41.693022),43435=>array(-83.312858,41.325312),43437=>array(-83.602309,41.253686),43438=>array(-82.706506,41.602607),43439=>array(-83.041286,41.517665),43440=>array(-82.776839,41.526266),43442=>array(-83.216448,41.426172),43443=>array(-83.470237,41.461331),43445=>array(-83.296408,41.583459),43446=>array(-82.808714,41.683506),43447=>array(-83.445582,41.562886),43449=>array(-83.13557,41.534376),43450=>array(-83.491254,41.400871),43451=>array(-83.617493,41.318301),43452=>array(-82.980945,41.515792),43456=>array(-82.822664,41.646844),43457=>array(-83.427465,41.267325),43458=>array(-83.213365,41.530446),43460=>array(-83.564999,41.601192),43462=>array(-83.722865,41.283785),43463=>array(-83.508034,41.508665),43464=>array(-82.924109,41.404879),43465=>array(-83.500302,41.565472),43466=>array(-83.514821,41.295359),43467=>array(-83.483841,41.243203),43468=>array(-83.341493,41.597867),43469=>array(-83.363903,41.46062),43501=>array(-84.461796,41.672655),43502=>array(-84.296944,41.531146),43504=>array(-83.836749,41.695773),43505=>array(-84.731263,41.523946),43506=>array(-84.557133,41.466211),43511=>array(-83.814795,41.262403),43512=>array(-84.358279,41.303378),43515=>array(-84.010615,41.584215),43516=>array(-83.915474,41.215029),43517=>array(-84.72855,41.433947),43518=>array(-84.757748,41.596488),43519=>array(-84.40707,41.419359),43521=>array(-84.297994,41.660489),43522=>array(-83.839146,41.419122),43523=>array(-83.989254,41.337065),43524=>array(-84.038446,41.227119),43525=>array(-83.70445,41.466582),43526=>array(-84.725309,41.312806),43527=>array(-84.157502,41.246109),43528=>array(-83.749575,41.628855),43529=>array(-83.781585,41.187605),43531=>array(-84.495666,41.635044),43532=>array(-83.974967,41.450496),43533=>array(-84.081479,41.691723),43534=>array(-83.926981,41.349611),43535=>array(-84.022034,41.30728),43536=>array(-84.632895,41.309794),43537=>array(-83.686571,41.574153),43540=>array(-83.928025,41.692846),43541=>array(-83.829536,41.300755),43542=>array(-83.765027,41.566675),43543=>array(-84.645346,41.606489),43545=>array(-84.127337,41.390884),43547=>array(-83.876316,41.49216),43548=>array(-84.175116,41.185334),43549=>array(-84.520756,41.371207),43551=>array(-83.572004,41.517951),43553=>array(-84.228836,41.531227),43554=>array(-84.563491,41.658422),43555=>array(-84.254322,41.434129),43556=>array(-84.563655,41.303225),43557=>array(-84.392466,41.487386),43558=>array(-83.878403,41.594729),43560=>array(-83.738852,41.700591),43565=>array(-83.740107,41.419971),43566=>array(-83.75339,41.492653),43567=>array(-84.161063,41.580346),43569=>array(-83.789227,41.349834),43570=>array(-84.441141,41.588117),43571=>array(-83.822816,41.513316),43604=>array(-83.540954,41.651526),43605=>array(-83.506863,41.648026),43606=>array(-83.611414,41.673136),43607=>array(-83.604132,41.648634),43608=>array(-83.528551,41.679891),43609=>array(-83.58088,41.626694),43610=>array(-83.561372,41.678031),43611=>array(-83.48503,41.705139),43612=>array(-83.549232,41.708462),43613=>array(-83.603731,41.706245),43614=>array(-83.630091,41.604201),43615=>array(-83.673822,41.650277),43616=>array(-83.408909,41.658372),43617=>array(-83.728264,41.664636),43619=>array(-83.47049,41.603711),43620=>array(-83.554271,41.665184),43623=>array(-83.650062,41.702945),43701=>array(-81.991033,39.96922),43711=>array(-81.576903,39.841356),43713=>array(-81.174557,39.987744),43716=>array(-81.0119,39.829249),43717=>array(-81.555673,39.789724),43718=>array(-80.998288,40.014775),43719=>array(-81.079098,39.997343),43720=>array(-81.876427,39.796078),43721=>array(-82.265041,39.949993),43722=>array(-81.517572,39.919184),43723=>array(-81.53949,39.960601),43724=>array(-81.498697,39.720898),43725=>array(-81.58933,40.044987),43727=>array(-81.785087,39.86139),43728=>array(-81.895088,39.480144),43730=>array(-82.10144,39.618641),43731=>array(-82.061172,39.725343),43732=>array(-81.642737,39.845125),43733=>array(-81.538067,39.927407),43734=>array(-81.891027,39.884547),43735=>array(-82.118507,39.866889),43736=>array(-81.237909,40.061242),43738=>array(-82.141513,39.855589),43739=>array(-82.286312,39.903133),43740=>array(-82.212846,39.952203),43746=>array(-82.183858,39.965416),43747=>array(-81.124904,39.860813),43748=>array(-82.316294,39.692384),43749=>array(-81.561488,40.166779),43750=>array(-81.513191,39.996867),43754=>array(-81.23395,39.760808),43755=>array(-81.432376,40.053283),43756=>array(-81.795493,39.691754),43758=>array(-81.945549,39.627898),43759=>array(-81.074799,40.065733),43760=>array(-82.194743,39.888632),43761=>array(-82.148307,39.668343),43762=>array(-81.741187,40.025878),43764=>array(-82.192529,39.71234),43766=>array(-82.252886,39.593272),43767=>array(-81.783664,40.06427),43768=>array(-81.444869,40.037789),43771=>array(-81.945402,39.835562),43772=>array(-81.526601,39.886085),43773=>array(-81.29851,39.982394),43777=>array(-82.113868,39.818733),43778=>array(-81.378862,39.99929),43779=>array(-81.427766,39.81957),43780=>array(-81.437981,39.908681),43782=>array(-82.212467,39.621795),43783=>array(-82.278555,39.804491),43786=>array(-81.277012,39.710464),43787=>array(-81.803695,39.530275),43788=>array(-81.333948,39.805526),43793=>array(-81.098591,39.741635),43802=>array(-81.852057,40.091161),43804=>array(-81.740962,40.450792),43805=>array(-81.972565,40.392968),43811=>array(-81.920772,40.179894),43812=>array(-81.880904,40.263768),43821=>array(-82.000512,40.136752),43822=>array(-82.174029,40.178846),43824=>array(-81.758449,40.36391),43830=>array(-82.137473,40.06282),43832=>array(-81.585062,40.275813),43836=>array(-81.719748,40.208723),43837=>array(-81.477938,40.298389),43840=>array(-81.601371,40.410708),43842=>array(-82.012755,40.136929),43843=>array(-82.17561,40.349011),43844=>array(-82.060739,40.32539),43845=>array(-81.731425,40.265226),43901=>array(-80.855814,40.223586),43902=>array(-80.951993,39.88285),43903=>array(-80.973297,40.472134),43905=>array(-80.840268,40.102487),43906=>array(-80.808832,40.011071),43907=>array(-81.024569,40.254613),43908=>array(-80.874019,40.506269),43910=>array(-80.826332,40.372682),43912=>array(-80.795478,40.085427),43913=>array(-80.63571,40.267682),43914=>array(-80.952819,39.77526),43915=>array(-80.899372,39.763457),43917=>array(-80.797645,40.233488),43920=>array(-80.595022,40.677396),43925=>array(-80.86232,40.447632),43926=>array(-80.62161,40.508061),43927=>array(-80.937132,40.119735),43928=>array(-80.9148,40.010409),43930=>array(-80.762834,40.563211),43931=>array(-80.87263,39.67334),43932=>array(-80.76074,40.516991),43933=>array(-80.8958,39.935227),43934=>array(-80.789273,40.077931),43935=>array(-80.755389,40.127765),43938=>array(-80.673326,40.304495),43939=>array(-80.800019,40.167151),43940=>array(-80.827283,40.028999),43942=>array(-80.854883,39.861027),43943=>array(-80.733072,40.20957),43944=>array(-80.76899,40.429337),43945=>array(-80.84801,40.63683),43946=>array(-80.964911,39.652165),43947=>array(-80.807586,39.956139),43948=>array(-80.778257,40.270132),43950=>array(-80.924669,40.096889),43951=>array(-81.01163,40.111902),43952=>array(-80.662786,40.406817),43953=>array(-80.702518,40.352522),43961=>array(-80.630282,40.524994),43962=>array(-80.879921,40.672039),43963=>array(-80.696907,40.171369),43964=>array(-80.662477,40.480905),43967=>array(-80.940094,40.026455),43968=>array(-80.683847,40.632407),43970=>array(-80.889127,40.463201),43971=>array(-80.713392,40.159108),43972=>array(-80.973089,40.102594),43973=>array(-81.276328,40.190266),43974=>array(-80.887565,40.18224),43976=>array(-80.920847,40.373557),43977=>array(-81.083447,40.134851),43983=>array(-81.199082,40.141432),43985=>array(-81.132747,40.163934),43986=>array(-80.995648,40.385195),43988=>array(-81.120838,40.401128),44001=>array(-82.259924,41.366331),44003=>array(-80.585942,41.615736),44004=>array(-80.791866,41.85594),44010=>array(-80.847485,41.765276),44011=>array(-82.005109,41.445156),44012=>array(-82.017368,41.498342),44017=>array(-81.861757,41.370548),44021=>array(-81.144465,41.44326),44022=>array(-81.402969,41.446269),44023=>array(-81.285759,41.384751),44024=>array(-81.192433,41.577765),44026=>array(-81.324706,41.528147),44028=>array(-81.937426,41.300515),44030=>array(-80.585178,41.896637),44032=>array(-80.67011,41.669245),44035=>array(-82.137075,41.364148),44039=>array(-82.024728,41.386152),44040=>array(-81.410737,41.535663),44041=>array(-80.949898,41.7769),44044=>array(-82.04179,41.266284),44045=>array(-81.284345,41.748658),44046=>array(-81.068714,41.542545),44047=>array(-80.735874,41.727931),44048=>array(-80.639309,41.850255),44049=>array(-82.305788,41.266529),44050=>array(-82.1282,41.248733),44052=>array(-82.164612,41.459377),44053=>array(-82.225503,41.426622),44054=>array(-82.090338,41.4716),44055=>array(-82.134095,41.434058),44056=>array(-81.50163,41.314916),44057=>array(-81.060305,41.760117),44060=>array(-81.32814,41.67653),44062=>array(-81.036697,41.45181),44064=>array(-81.032323,41.598063),44065=>array(-81.221612,41.475924),44067=>array(-81.542933,41.316283),44070=>array(-81.918942,41.415032),44072=>array(-81.32492,41.471152),44074=>array(-82.231223,41.289495),44076=>array(-80.823712,41.530875),44077=>array(-81.20974,41.697563),44080=>array(-81.057947,41.366271),44081=>array(-81.142989,41.764257),44082=>array(-80.567535,41.761873),44084=>array(-80.899161,41.671377),44085=>array(-80.874544,41.603272),44086=>array(-81.058597,41.675726),44087=>array(-81.438675,41.313171),44089=>array(-82.377455,41.392084),44090=>array(-82.228683,41.167515),44092=>array(-81.468699,41.599909),44093=>array(-80.614356,41.530785),44094=>array(-81.379324,41.610724),44095=>array(-81.441721,41.652326),44099=>array(-80.983305,41.549205),44101=>array(-81.667486,41.489381),44102=>array(-81.738327,41.479222),44103=>array(-81.642123,41.519415),44104=>array(-81.626665,41.483845),44105=>array(-81.630289,41.449476),44106=>array(-81.605496,41.505181),44107=>array(-81.801683,41.48386),44108=>array(-81.607394,41.544784),44109=>array(-81.694468,41.447576),44110=>array(-81.564665,41.56939),44111=>array(-81.788608,41.458266),44112=>array(-81.574143,41.535841),44113=>array(-81.697166,41.483241),44114=>array(-81.680327,41.51843),44115=>array(-81.671226,41.493546),44116=>array(-81.853831,41.472964),44117=>array(-81.523653,41.570921),44118=>array(-81.556571,41.502337),44119=>array(-81.547386,41.58935),44120=>array(-81.579956,41.473947),44121=>array(-81.53213,41.526495),44122=>array(-81.512442,41.469494),44123=>array(-81.524123,41.604699),44124=>array(-81.467584,41.496597),44125=>array(-81.608852,41.405557),44126=>array(-81.853002,41.44182),44127=>array(-81.650362,41.473016),44128=>array(-81.538518,41.439871),44129=>array(-81.735307,41.390456),44130=>array(-81.787317,41.376642),44131=>array(-81.651749,41.383164),44132=>array(-81.497314,41.606292),44133=>array(-81.745238,41.313664),44134=>array(-81.700991,41.380492),44135=>array(-81.817199,41.427912),44136=>array(-81.808441,41.311488),44137=>array(-81.562527,41.409217),44138=>array(-81.923295,41.373662),44139=>array(-81.444249,41.383262),44140=>array(-81.931442,41.487816),44141=>array(-81.616544,41.299666),44142=>array(-81.834335,41.39966),44143=>array(-81.475507,41.554054),44144=>array(-81.739724,41.437465),44145=>array(-81.93016,41.449529),44146=>array(-81.529226,41.381223),44147=>array(-81.679264,41.318155),44149=>array(-81.856217,41.315913),44201=>array(-81.184282,41.02866),44202=>array(-81.338371,41.315087),44203=>array(-81.628652,41.020888),44212=>array(-81.828732,41.244503),44214=>array(-81.999755,40.951918),44215=>array(-81.895771,41.067757),44216=>array(-81.581744,40.945779),44217=>array(-81.913359,40.952287),44221=>array(-81.475047,41.138985),44223=>array(-81.531057,41.169665),44224=>array(-81.436523,41.176261),44230=>array(-81.687607,40.964265),44231=>array(-81.070474,41.302963),44233=>array(-81.737866,41.249084),44234=>array(-81.15224,41.325805),44235=>array(-82.11677,41.031119),44236=>array(-81.449582,41.246425),44240=>array(-81.332781,41.132323),44241=>array(-81.347707,41.242618),44243=>array(-81.341421,41.14796),44250=>array(-81.437338,41.020304),44251=>array(-81.927401,41.029138),44253=>array(-82.032049,41.166865),44254=>array(-82.01437,41.042952),44255=>array(-81.229132,41.286694),44256=>array(-81.860559,41.139872),44260=>array(-81.338441,41.035186),44262=>array(-81.436066,41.139576),44264=>array(-81.540017,41.22961),44265=>array(-81.253084,41.035722),44266=>array(-81.208224,41.166252),44270=>array(-81.774537,40.960943),44272=>array(-81.180523,41.089759),44273=>array(-81.877935,41.027999),44274=>array(-81.73267,41.098341),44275=>array(-82.102602,41.10186),44276=>array(-81.835725,40.937837),44278=>array(-81.425596,41.106119),44280=>array(-81.93066,41.24919),44281=>array(-81.741052,41.059588),44285=>array(-81.071596,41.159666),44286=>array(-81.643952,41.23315),44287=>array(-82.098449,40.940136),44288=>array(-81.07605,41.239104),44301=>array(-81.524017,41.04349),44302=>array(-81.538663,41.089437),44303=>array(-81.536941,41.104685),44304=>array(-81.507848,41.083174),44305=>array(-81.461652,41.075304),44306=>array(-81.48317,41.039346),44307=>array(-81.546125,41.069455),44308=>array(-81.517014,41.081658),44310=>array(-81.494631,41.105174),44311=>array(-81.520712,41.064229),44312=>array(-81.443702,41.01412),44313=>array(-81.572704,41.130064),44314=>array(-81.560073,41.041069),44319=>array(-81.527637,40.981499),44320=>array(-81.582414,41.07314),44321=>array(-81.652446,41.088647),44333=>array(-81.630871,41.16061),44401=>array(-80.938604,41.02099),44402=>array(-80.852506,41.38029),44403=>array(-80.582126,41.240319),44404=>array(-80.556627,41.324106),44405=>array(-80.592359,41.077984),44406=>array(-80.770396,41.01088),44408=>array(-80.688425,40.886139),44410=>array(-80.72779,41.346332),44411=>array(-81.037731,41.036421),44412=>array(-81.02663,41.093871),44413=>array(-80.549334,40.843898),44417=>array(-80.663897,41.436336),44418=>array(-80.603473,41.307372),44420=>array(-80.68277,41.179112),44423=>array(-80.895946,40.748517),44425=>array(-80.573514,41.170439),44427=>array(-80.949859,40.709172),44428=>array(-80.573808,41.436821),44429=>array(-80.979645,41.097137),44430=>array(-80.908167,41.240234),44431=>array(-80.749469,40.851614),44432=>array(-80.766739,40.744473),44436=>array(-80.534818,41.058771),44437=>array(-80.729884,41.15594),44438=>array(-80.530615,41.239631),44439=>array(-80.956375,41.455747),44440=>array(-80.802908,41.141176),44441=>array(-80.550233,40.756048),44442=>array(-80.546111,40.966173),44443=>array(-80.604431,40.933667),44444=>array(-80.974394,41.171122),44445=>array(-80.619964,40.848321),44446=>array(-80.749296,41.189561),44449=>array(-81.037123,40.975289),44450=>array(-80.834495,41.453014),44451=>array(-80.868193,41.079368),44452=>array(-80.664007,40.947372),44454=>array(-80.551733,40.917464),44455=>array(-80.610166,40.772301),44460=>array(-80.870171,40.899324),44470=>array(-80.972791,41.300331),44471=>array(-80.590176,41.048564),44473=>array(-80.649904,41.254957),44481=>array(-80.902344,41.176641),44483=>array(-80.816754,41.263566),44484=>array(-80.750201,41.235857),44485=>array(-80.847586,41.240357),44490=>array(-80.768062,40.896293),44491=>array(-80.964377,41.368427),44493=>array(-80.888617,40.825018),44502=>array(-80.639487,41.082788),44503=>array(-80.649074,41.099326),44504=>array(-80.654651,41.123512),44505=>array(-80.622105,41.129242),44506=>array(-80.626397,41.093003),44507=>array(-80.655251,41.074229),44509=>array(-80.696075,41.108505),44510=>array(-80.673433,41.122254),44511=>array(-80.696703,41.069085),44512=>array(-80.668279,41.025661),44514=>array(-80.606448,41.000614),44515=>array(-80.761825,41.100678),44601=>array(-81.129176,40.920269),44606=>array(-81.7944,40.733999),44607=>array(-81.025735,40.689518),44608=>array(-81.592823,40.656427),44609=>array(-80.990071,40.917414),44610=>array(-81.799762,40.559625),44611=>array(-82.074986,40.610103),44612=>array(-81.475952,40.633124),44613=>array(-81.600741,40.71297),44614=>array(-81.576285,40.889547),44615=>array(-81.074849,40.564539),44618=>array(-81.681101,40.770383),44620=>array(-81.210132,40.578124),44621=>array(-81.297852,40.436959),44622=>array(-81.482958,40.546033),44624=>array(-81.662094,40.60853),44625=>array(-81.003737,40.763369),44626=>array(-81.381772,40.688904),44627=>array(-81.836421,40.663996),44628=>array(-82.168818,40.534703),44629=>array(-81.44135,40.354147),44632=>array(-81.313031,40.963232),44633=>array(-81.935268,40.629759),44634=>array(-81.041397,40.837991),44637=>array(-82.039032,40.48956),44638=>array(-82.141059,40.650615),44640=>array(-81.150705,40.985543),44641=>array(-81.246485,40.857398),44643=>array(-81.302903,40.638733),44644=>array(-81.176443,40.687012),44645=>array(-81.719426,40.912061),44646=>array(-81.497182,40.814381),44647=>array(-81.565063,40.797864),44651=>array(-80.9511,40.628056),44652=>array(-81.326138,40.900221),44653=>array(-81.370333,40.436106),44654=>array(-81.870867,40.537937),44656=>array(-81.334945,40.568721),44657=>array(-81.092666,40.7411),44659=>array(-81.702555,40.694922),44661=>array(-82.113008,40.595626),44662=>array(-81.556289,40.71101),44663=>array(-81.452391,40.459991),44666=>array(-81.638693,40.848342),44667=>array(-81.766531,40.833815),44669=>array(-81.157456,40.79247),44670=>array(-81.188753,40.762639),44671=>array(-81.365669,40.646033),44672=>array(-81.025268,40.920003),44675=>array(-81.253774,40.502358),44676=>array(-82.033794,40.690773),44677=>array(-81.858577,40.87452),44678=>array(-81.349941,40.566644),44680=>array(-81.541474,40.605568),44681=>array(-81.661848,40.507952),44682=>array(-81.405289,40.397262),44683=>array(-81.325281,40.364832),44685=>array(-81.424372,40.955405),44687=>array(-81.719984,40.537922),44688=>array(-81.255382,40.683908),44689=>array(-81.659132,40.64521),44690=>array(-81.693638,40.613106),44691=>array(-81.982479,40.805756),44693=>array(-81.186168,40.301856),44695=>array(-81.170166,40.442011),44697=>array(-81.424219,40.612058),44699=>array(-81.280917,40.277289),44702=>array(-81.375811,40.79979),44703=>array(-81.381352,40.810563),44704=>array(-81.340379,40.800388),44705=>array(-81.331149,40.834614),44706=>array(-81.418645,40.753525),44707=>array(-81.34984,40.761094),44708=>array(-81.435881,40.817882),44709=>array(-81.386175,40.842337),44710=>array(-81.425964,40.78971),44714=>array(-81.358279,40.836317),44718=>array(-81.451327,40.847623),44720=>array(-81.433275,40.903441),44721=>array(-81.332063,40.892581),44730=>array(-81.265784,40.767017),44802=>array(-83.419418,41.045626),44804=>array(-83.534122,41.105589),44805=>array(-82.317038,40.872668),44807=>array(-82.876936,41.059801),44809=>array(-83.288906,41.133492),44811=>array(-82.846601,41.246328),44813=>array(-82.529699,40.599849),44814=>array(-82.47216,41.324106),44815=>array(-83.239471,41.246607),44816=>array(-82.352522,41.330202),44817=>array(-83.549482,41.203853),44818=>array(-82.989373,40.998342),44820=>array(-82.974028,40.817186),44822=>array(-82.398092,40.556688),44824=>array(-82.805892,41.383228),44825=>array(-82.94319,40.954204),44826=>array(-82.477643,41.24234),44827=>array(-82.75506,40.822444),44828=>array(-82.860916,41.231935),44830=>array(-83.397303,41.16814),44833=>array(-82.793744,40.710586),44836=>array(-83.059914,41.23642),44837=>array(-82.472683,41.021221),44838=>array(-82.256135,40.771578),44839=>array(-82.556921,41.380951),44840=>array(-82.178267,40.787971),44841=>array(-83.30603,41.251213),44842=>array(-82.22463,40.649292),44843=>array(-82.407602,40.689497),44844=>array(-83.26093,40.992079),44846=>array(-82.605836,41.319413),44847=>array(-82.712888,41.230414),44849=>array(-83.130473,40.809261),44850=>array(-82.684018,41.035393),44851=>array(-82.391571,41.109175),44853=>array(-83.303003,41.055286),44854=>array(-82.867819,40.943646),44855=>array(-82.591626,41.106391),44856=>array(-82.856755,40.793974),44857=>array(-82.577642,41.216499),44859=>array(-82.330724,41.021963),44861=>array(-83.147917,41.239479),44864=>array(-82.320618,40.667614),44865=>array(-82.676942,40.993405),44866=>array(-82.197756,40.924008),44867=>array(-82.98222,41.149035),44870=>array(-82.744814,41.42828),44874=>array(-82.367336,40.967869),44875=>array(-82.651686,40.88999),44878=>array(-82.520733,40.941616),44880=>array(-82.220113,41.034602),44881=>array(-82.876037,40.870017),44882=>array(-83.140144,40.946635),44883=>array(-83.173911,41.123331),44887=>array(-82.790657,40.916191),44889=>array(-82.382433,41.245882),44890=>array(-82.710562,41.085172),44901=>array(-82.509404,40.791707),44902=>array(-82.510589,40.758156),44903=>array(-82.527634,40.776344),44904=>array(-82.61444,40.663724),44905=>array(-82.467189,40.778095),44906=>array(-82.572626,40.767349),44907=>array(-82.520406,40.727662),45001=>array(-84.712238,39.141445),45002=>array(-84.757565,39.196791),45003=>array(-84.78647,39.586583),45005=>array(-84.295877,39.538613),45011=>array(-84.497608,39.426562),45013=>array(-84.652679,39.413632),45014=>array(-84.55239,39.325714),45015=>array(-84.567353,39.37703),45030=>array(-84.759577,39.259888),45032=>array(-84.010203,39.502773),45033=>array(-84.762971,39.176783),45034=>array(-84.242753,39.358163),45036=>array(-84.214158,39.444047),45039=>array(-84.246085,39.328579),45040=>array(-84.313198,39.350783),45041=>array(-84.702261,39.210424),45042=>array(-84.420158,39.556885),45044=>array(-84.410917,39.482346),45050=>array(-84.359182,39.445352),45051=>array(-84.646609,39.097961),45052=>array(-84.779062,39.144456),45053=>array(-84.78792,39.352993),45054=>array(-84.08054,39.441468),45056=>array(-84.744187,39.490929),45062=>array(-84.552961,39.479663),45064=>array(-84.596385,39.562006),45065=>array(-84.211218,39.370229),45066=>array(-84.224353,39.551158),45067=>array(-84.480997,39.494819),45068=>array(-84.065635,39.524739),45069=>array(-84.413538,39.346921),45070=>array(-84.558089,39.589695),45101=>array(-83.738431,38.693759),45102=>array(-84.204345,39.01719),45103=>array(-84.13448,39.097086),45106=>array(-84.064915,38.94502),45107=>array(-83.968591,39.292169),45111=>array(-84.289827,39.196499),45112=>array(-84.139912,38.793092),45113=>array(-83.985801,39.396971),45115=>array(-83.699155,38.824132),45118=>array(-83.934069,39.172249),45120=>array(-84.090027,38.828417),45121=>array(-83.90352,38.869746),45122=>array(-84.115369,39.216745),45123=>array(-83.38602,39.349996),45130=>array(-83.998661,38.909438),45131=>array(-83.966938,38.790338),45132=>array(-83.600257,39.343919),45133=>array(-83.576231,39.16185),45135=>array(-83.541912,39.347615),45140=>array(-84.241953,39.257273),45142=>array(-83.810822,39.204555),45144=>array(-83.610309,38.705934),45145=>array(-84.005165,39.145329),45146=>array(-83.804201,39.314119),45147=>array(-84.284277,39.20512),45148=>array(-83.887266,39.290218),45150=>array(-84.230308,39.166379),45152=>array(-84.121028,39.351315),45153=>array(-84.187265,38.864534),45154=>array(-83.915647,39.060222),45155=>array(-83.752161,39.042506),45156=>array(-84.213826,38.815161),45157=>array(-84.23017,38.953739),45158=>array(-84.089598,39.181517),45159=>array(-83.691741,39.336834),45160=>array(-84.136621,39.122876),45162=>array(-84.075075,39.269652),45164=>array(-83.782167,39.554033),45166=>array(-83.687759,39.476597),45167=>array(-83.797606,38.772821),45168=>array(-83.754643,38.850496),45169=>array(-83.650882,39.506479),45171=>array(-83.800276,39.014545),45172=>array(-83.386883,39.074472),45174=>array(-84.312214,39.158525),45176=>array(-84.029729,39.079262),45177=>array(-83.844424,39.463017),45202=>array(-84.502584,39.109356),45203=>array(-84.53354,39.105288),45204=>array(-84.553193,39.106537),45205=>array(-84.575206,39.110038),45206=>array(-84.484393,39.127337),45207=>array(-84.471336,39.142067),45208=>array(-84.43443,39.134746),45209=>array(-84.426671,39.153022),45211=>array(-84.596637,39.15609),45212=>array(-84.452189,39.16419),45213=>array(-84.420095,39.180801),45214=>array(-84.534356,39.115007),45215=>array(-84.461948,39.235279),45216=>array(-84.481754,39.200917),45217=>array(-84.497807,39.166056),45218=>array(-84.518217,39.263764),45219=>array(-84.513064,39.127376),45220=>array(-84.520309,39.148783),45223=>array(-84.549528,39.17081),45224=>array(-84.53169,39.201067),45225=>array(-84.551212,39.142809),45226=>array(-84.421674,39.111687),45227=>array(-84.385808,39.153872),45229=>array(-84.486802,39.152745),45230=>array(-84.389281,39.073748),45231=>array(-84.53483,39.247497),45232=>array(-84.510096,39.188263),45233=>array(-84.672583,39.116767),45236=>array(-84.39729,39.209844),45237=>array(-84.45226,39.193038),45238=>array(-84.610282,39.107658),45239=>array(-84.580623,39.203625),45240=>array(-84.52933,39.284509),45241=>array(-84.397108,39.276362),45242=>array(-84.352996,39.242803),45243=>array(-84.336021,39.188557),45244=>array(-84.326436,39.114232),45245=>array(-84.276136,39.061125),45246=>array(-84.469214,39.289592),45247=>array(-84.661108,39.216693),45248=>array(-84.662549,39.164331),45249=>array(-84.32889,39.280355),45251=>array(-84.597876,39.27464),45252=>array(-84.628137,39.270192),45255=>array(-84.328333,39.059554),45301=>array(-84.02221,39.711329),45302=>array(-84.20915,40.40591),45303=>array(-84.659636,40.213971),45304=>array(-84.52531,39.989273),45305=>array(-84.078557,39.632188),45306=>array(-84.187139,40.459234),45307=>array(-83.723592,39.580814),45308=>array(-84.45769,40.129638),45309=>array(-84.414705,39.842731),45310=>array(-84.642673,40.352937),45311=>array(-84.667499,39.626388),45312=>array(-84.093008,40.052153),45314=>array(-83.77625,39.75008),45315=>array(-84.339063,39.85699),45316=>array(-83.8256,39.797001),45317=>array(-83.988585,40.211018),45318=>array(-84.353716,40.12907),45319=>array(-83.94306,39.916364),45320=>array(-84.681425,39.750639),45321=>array(-84.686054,39.878597),45322=>array(-84.32783,39.899781),45323=>array(-83.927621,39.849966),45324=>array(-83.990794,39.819023),45325=>array(-84.430204,39.692609),45326=>array(-84.093589,40.140632),45327=>array(-84.403005,39.62876),45328=>array(-84.496233,40.116196),45330=>array(-84.528608,39.648255),45331=>array(-84.650546,40.098606),45332=>array(-84.790873,39.990846),45333=>array(-84.331773,40.249465),45334=>array(-84.043362,40.443454),45335=>array(-83.741205,39.639799),45336=>array(-84.257321,40.44268),45337=>array(-84.42262,39.981478),45338=>array(-84.543549,39.849751),45339=>array(-84.34203,40.012759),45340=>array(-84.052152,40.368571),45341=>array(-84.024458,39.875585),45342=>array(-84.275969,39.629338),45344=>array(-84.009766,39.952394),45345=>array(-84.407471,39.737813),45346=>array(-84.709956,39.982115),45347=>array(-84.750967,39.884214),45348=>array(-84.64879,40.329646),45349=>array(-83.94157,39.988475),45350=>array(-84.57374,40.324339),45351=>array(-84.495151,40.339415),45352=>array(-84.744283,40.050123),45353=>array(-84.042704,40.292573),45354=>array(-84.399687,39.910552),45356=>array(-84.22821,40.16284),45358=>array(-84.4877,39.98658),45359=>array(-84.350706,40.046535),45360=>array(-84.092195,40.330159),45361=>array(-84.414818,39.963708),45362=>array(-84.627731,40.292481),45363=>array(-84.400069,40.239308),45365=>array(-84.159773,40.28374),45368=>array(-83.647979,39.844915),45369=>array(-83.593695,39.952816),45370=>array(-84.032996,39.608306),45371=>array(-84.16064,39.939546),45372=>array(-83.842304,40.016003),45373=>array(-84.194575,40.032528),45377=>array(-84.224285,39.896083),45378=>array(-84.488721,39.902924),45380=>array(-84.516917,40.244498),45381=>array(-84.524833,39.725292),45382=>array(-84.608917,39.898396),45383=>array(-84.343208,39.955577),45384=>array(-83.884739,39.714149),45385=>array(-83.911874,39.669121),45387=>array(-83.887362,39.797224),45388=>array(-84.47814,40.316916),45389=>array(-84.0276,40.057169),45390=>array(-84.760567,40.215185),45402=>array(-84.209094,39.75936),45403=>array(-84.147428,39.768856),45404=>array(-84.159969,39.791105),45405=>array(-84.216028,39.79216),45406=>array(-84.24108,39.784214),45409=>array(-84.18797,39.721305),45410=>array(-84.158124,39.748047),45414=>array(-84.207558,39.847871),45415=>array(-84.257387,39.835581),45416=>array(-84.258107,39.807155),45417=>array(-84.288826,39.735172),45418=>array(-84.260728,39.699392),45419=>array(-84.167179,39.713376),45420=>array(-84.129169,39.718818),45424=>array(-84.110015,39.843157),45426=>array(-84.319726,39.804459),45428=>array(-84.260635,39.742877),45429=>array(-84.158915,39.682905),45430=>array(-84.084844,39.709674),45431=>array(-84.084229,39.763796),45432=>array(-84.085195,39.739492),45433=>array(-84.049873,39.821901),45434=>array(-84.031824,39.721385),45439=>array(-84.219335,39.699728),45440=>array(-84.095621,39.675916),45449=>array(-84.237763,39.664052),45458=>array(-84.156971,39.600591),45459=>array(-84.170598,39.647433),45502=>array(-83.752812,39.860825),45503=>array(-83.771782,39.959574),45504=>array(-83.867291,39.946846),45505=>array(-83.757349,39.902038),45506=>array(-83.836862,39.907948),45601=>array(-82.957071,39.31206),45612=>array(-83.279087,39.206876),45613=>array(-82.8509,39.034216),45614=>array(-82.277196,38.929678),45616=>array(-83.314325,38.760962),45617=>array(-83.155641,39.279646),45618=>array(-83.616413,38.885494),45619=>array(-82.452233,38.471364),45620=>array(-82.141796,38.960269),45621=>array(-82.607744,39.110788),45622=>array(-82.490842,39.375004),45623=>array(-82.269786,38.641686),45624=>array(-83.347015,39.170232),45628=>array(-83.198042,39.39098),45629=>array(-82.815896,38.657553),45630=>array(-83.091559,38.699141),45631=>array(-82.261287,38.819839),45634=>array(-82.484582,39.183844),45636=>array(-82.828993,38.587615),45638=>array(-82.680194,38.561201),45640=>array(-82.656336,39.019673),45642=>array(-83.054463,39.047033),45644=>array(-82.844762,39.459532),45645=>array(-82.527002,38.566357),45646=>array(-83.322787,39.075169),45647=>array(-82.733029,39.294341),45648=>array(-83.007754,38.917892),45650=>array(-83.422328,38.738293),45651=>array(-82.483478,39.28542),45652=>array(-83.095018,38.823821),45653=>array(-82.821976,38.889635),45654=>array(-82.377618,39.366498),45656=>array(-82.593729,38.880772),45657=>array(-83.236452,38.843671),45658=>array(-82.411555,38.762928),45659=>array(-82.64113,38.65498),45660=>array(-83.367397,38.991389),45661=>array(-83.10822,39.045633),45662=>array(-82.918349,38.782086),45663=>array(-83.088819,38.738811),45669=>array(-82.358442,38.498413),45671=>array(-83.248012,38.970254),45672=>array(-82.694823,39.192718),45673=>array(-82.811991,39.203916),45674=>array(-82.374667,38.882424),45678=>array(-82.379581,38.610443),45679=>array(-83.555915,38.964573),45680=>array(-82.546829,38.467808),45681=>array(-83.256236,39.308342),45682=>array(-82.694911,38.806931),45684=>array(-83.191469,38.651441),45685=>array(-82.456548,38.931802),45686=>array(-82.376867,39.014131),45688=>array(-82.543255,38.731078),45690=>array(-83.007782,39.136727),45692=>array(-82.541066,39.113937),45693=>array(-83.54029,38.807103),45694=>array(-82.780883,38.743875),45695=>array(-82.372654,39.161543),45696=>array(-82.452118,38.601157),45697=>array(-83.673716,38.931555),45698=>array(-82.39173,39.2858),45701=>array(-82.08602,39.311963),45710=>array(-82.237676,39.189862),45711=>array(-81.931976,39.428432),45714=>array(-81.614345,39.316984),45715=>array(-81.628021,39.605069),45716=>array(-82.181731,39.462855),45719=>array(-82.126627,39.400532),45721=>array(-81.584377,39.565488),45723=>array(-81.823487,39.22625),45724=>array(-81.800411,39.383437),45727=>array(-81.488187,39.650087),45729=>array(-81.604397,39.418373),45732=>array(-82.068357,39.515733),45734=>array(-81.191281,39.641444),45735=>array(-81.928198,39.261786),45740=>array(-82.076656,39.478091),45741=>array(-82.247085,39.075062),45742=>array(-81.730393,39.287076),45743=>array(-81.847644,39.07644),45744=>array(-81.493983,39.548767),45745=>array(-81.329638,39.606169),45746=>array(-81.458824,39.607107),45750=>array(-81.422175,39.429949),45760=>array(-82.121701,39.016845),45761=>array(-82.075255,39.42576),45764=>array(-82.231394,39.442499),45766=>array(-82.257669,39.325249),45767=>array(-81.128173,39.539275),45768=>array(-81.295091,39.422645),45769=>array(-82.05104,39.109284),45770=>array(-81.798272,38.982608),45771=>array(-81.894582,38.98169),45772=>array(-81.819169,39.148706),45773=>array(-81.267304,39.458516),45775=>array(-82.154233,39.082882),45776=>array(-82.024066,39.18141),45778=>array(-81.893065,39.353531),45779=>array(-81.965765,38.997761),45780=>array(-82.130881,39.366438),45782=>array(-82.08102,39.487627),45784=>array(-81.678142,39.388458),45786=>array(-81.656332,39.501918),45787=>array(-81.632005,39.468248),45788=>array(-81.367568,39.514987),45789=>array(-81.255011,39.551276),45801=>array(-84.034097,40.772873),45804=>array(-84.061155,40.709622),45805=>array(-84.165459,40.728042),45806=>array(-84.126166,40.672435),45807=>array(-84.171653,40.805996),45808=>array(-83.968919,40.830591),45809=>array(-84.187163,40.845494),45810=>array(-83.81327,40.784403),45812=>array(-83.823151,40.681882),45813=>array(-84.733173,41.192293),45814=>array(-83.630161,40.899318),45816=>array(-83.794042,41.004457),45817=>array(-83.883975,40.878759),45819=>array(-84.260393,40.624019),45820=>array(-84.084002,40.834954),45821=>array(-84.558775,41.226064),45822=>array(-84.598725,40.555742),45826=>array(-84.493693,40.436217),45827=>array(-84.298851,40.998103),45828=>array(-84.671645,40.483279),45830=>array(-84.095933,40.90846),45831=>array(-84.250346,41.111205),45832=>array(-84.730092,40.926421),45833=>array(-84.348665,40.834219),45835=>array(-83.699893,40.754415),45836=>array(-83.639896,40.792911),45838=>array(-84.477662,40.742048),45840=>array(-83.651983,41.025371),45841=>array(-83.741573,40.873705),45843=>array(-83.544556,40.771707),45844=>array(-84.282481,40.910907),45845=>array(-84.382544,40.331338),45846=>array(-84.74252,40.411515),45849=>array(-84.446662,41.013772),45850=>array(-83.918239,40.704698),45851=>array(-84.600051,41.032333),45853=>array(-84.1985,40.985266),45854=>array(-83.952126,40.757571),45855=>array(-84.584089,41.087908),45856=>array(-83.999866,41.111678),45858=>array(-83.804696,41.106604),45859=>array(-83.778658,40.683735),45860=>array(-84.516848,40.399273),45861=>array(-84.426503,41.082814),45862=>array(-84.516009,40.668866),45863=>array(-84.444959,40.908049),45864=>array(-84.146577,41.097045),45865=>array(-84.368261,40.391875),45866=>array(-84.551169,40.490375),45867=>array(-83.526562,40.897586),45868=>array(-83.849662,40.966283),45869=>array(-84.40387,40.457931),45870=>array(-83.951424,40.556279),45871=>array(-84.300445,40.493423),45872=>array(-83.685661,41.188726),45873=>array(-84.390198,41.117776),45874=>array(-84.672051,40.788114),45875=>array(-84.061201,41.022008),45876=>array(-84.340922,40.927246),45877=>array(-83.933578,40.959121),45879=>array(-84.563581,41.128714),45880=>array(-84.732946,41.071213),45881=>array(-83.780047,40.946247),45882=>array(-84.678497,40.681856),45883=>array(-84.622937,40.410203),45884=>array(-84.082742,40.554315),45885=>array(-84.390644,40.569863),45886=>array(-84.620781,40.9969),45887=>array(-84.365224,40.710947),45888=>array(-84.08682,40.602358),45889=>array(-83.638317,41.152324),45890=>array(-83.489969,40.975432),45891=>array(-84.574267,40.874541),45894=>array(-84.461379,40.759089),45895=>array(-84.154664,40.577695),45896=>array(-83.929663,40.607436),45897=>array(-83.655599,40.828798),45898=>array(-84.769653,40.743473),45899=>array(-84.773851,40.80046),46001=>array(-85.657942,40.251251),46011=>array(-85.760597,40.129896),46012=>array(-85.621229,40.1532),46013=>array(-85.681768,40.047934),46016=>array(-85.681513,40.097817),46017=>array(-85.60716,40.069277),46030=>array(-86.009191,40.166144),46031=>array(-86.018095,40.210969),46032=>array(-86.174761,39.962604),46033=>array(-86.085557,39.979283),46034=>array(-86.046784,40.127927),46035=>array(-86.677986,40.190015),46036=>array(-85.831108,40.295166),46037=>array(-85.947162,39.960563),46038=>array(-86.017173,39.966704),46039=>array(-86.312273,40.369458),46040=>array(-85.834287,39.92728),46041=>array(-86.49384,40.295038),46044=>array(-85.792705,40.211777),46045=>array(-86.14986,40.288764),46047=>array(-85.947357,40.28414),46048=>array(-85.801727,39.955512),46049=>array(-86.221816,40.294988),46050=>array(-86.348899,40.204434),46051=>array(-85.837287,40.057932),46052=>array(-86.456533,40.042906),46055=>array(-85.90221,39.888415),46056=>array(-85.611956,39.975815),46057=>array(-86.377326,40.336261),46058=>array(-86.647374,40.361165),46060=>array(-85.915911,40.064624),46062=>array(-86.056039,40.061266),46063=>array(-85.723973,40.270448),46064=>array(-85.741604,39.983678),46065=>array(-86.612176,40.427754),46068=>array(-86.115827,40.376963),46069=>array(-86.228367,40.138691),46070=>array(-85.662341,40.335565),46071=>array(-86.608756,40.120056),46072=>array(-86.067353,40.286104),46074=>array(-86.172532,40.036139),46075=>array(-86.330672,40.020864),46076=>array(-85.928005,40.356035),46077=>array(-86.282625,39.984562),46103=>array(-86.613632,39.688623),46104=>array(-85.60183,39.65847),46105=>array(-86.810568,39.764072),46106=>array(-86.205119,39.513173),46107=>array(-86.091459,39.716413),46110=>array(-85.92202,39.56146),46111=>array(-86.369536,39.538824),46112=>array(-86.382425,39.86391),46113=>array(-86.302553,39.636299),46115=>array(-85.566649,39.738754),46117=>array(-85.615963,39.814706),46118=>array(-86.518005,39.662375),46120=>array(-86.788928,39.511512),46121=>array(-86.678813,39.679033),46122=>array(-86.551142,39.773322),46123=>array(-86.403457,39.764395),46124=>array(-85.92791,39.370017),46125=>array(-86.641603,39.521518),46126=>array(-85.88034,39.618024),46127=>array(-85.312209,39.711952),46128=>array(-86.742562,39.658583),46130=>array(-85.835022,39.672748),46131=>array(-86.043001,39.472968),46133=>array(-85.310829,39.595056),46135=>array(-86.893996,39.654571),46140=>array(-85.772071,39.801973),46142=>array(-86.175319,39.62181),46143=>array(-86.116319,39.59586),46144=>array(-85.647354,39.655159),46146=>array(-85.568334,39.585666),46147=>array(-86.622827,39.971149),46148=>array(-85.512466,39.8114),46149=>array(-86.555992,39.883604),46150=>array(-85.601919,39.546574),46151=>array(-86.43328,39.457212),46155=>array(-85.429741,39.743501),46156=>array(-85.49445,39.489361),46157=>array(-86.528731,39.55363),46158=>array(-86.373602,39.579356),46160=>array(-86.268607,39.350884),46161=>array(-85.696284,39.66988),46162=>array(-85.953085,39.550982),46163=>array(-85.902033,39.729088),46164=>array(-86.114278,39.323705),46165=>array(-86.640151,39.849828),46166=>array(-86.587297,39.432913),46167=>array(-86.467801,39.876973),46168=>array(-86.392912,39.685257),46171=>array(-86.960902,39.525101),46172=>array(-86.818464,39.827835),46173=>array(-85.430594,39.600903),46175=>array(-86.966359,39.815724),46176=>array(-85.774394,39.527281),46180=>array(-86.618525,39.592189),46181=>array(-86.169997,39.373373),46182=>array(-85.669492,39.458501),46183=>array(-86.281653,39.652679),46184=>array(-86.073225,39.559808),46186=>array(-85.644782,39.894213),46201=>array(-86.1092,39.774142),46202=>array(-86.163477,39.784102),46203=>array(-86.096931,39.737586),46204=>array(-86.156997,39.771994),46205=>array(-86.134374,39.829397),46208=>array(-86.171059,39.819328),46214=>array(-86.291528,39.792817),46216=>array(-86.009743,39.868014),46217=>array(-86.191493,39.674616),46218=>array(-86.099745,39.807262),46219=>array(-86.042939,39.782412),46220=>array(-86.108848,39.867114),46221=>array(-86.236776,39.691926),46222=>array(-86.21526,39.790968),46224=>array(-86.25689,39.795413),46225=>array(-86.163255,39.740314),46226=>array(-86.052485,39.838896),46227=>array(-86.132676,39.674763),46228=>array(-86.200725,39.848228),46229=>array(-85.977075,39.788484),46231=>array(-86.32062,39.715527),46234=>array(-86.326363,39.813309),46235=>array(-85.974537,39.836957),46236=>array(-85.967501,39.895722),46237=>array(-86.07211,39.671143),46239=>array(-85.999033,39.721517),46240=>array(-86.124892,39.906354),46241=>array(-86.285424,39.729852),46250=>array(-86.064843,39.902125),46254=>array(-86.271637,39.849717),46256=>array(-86.013138,39.908383),46259=>array(-85.981339,39.650935),46260=>array(-86.177595,39.898143),46268=>array(-86.233341,39.898613),46278=>array(-86.29805,39.892946),46280=>array(-86.13128,39.932373),46290=>array(-86.163218,39.938297),46301=>array(-86.978774,41.691148),46303=>array(-87.479269,41.373793),46304=>array(-87.04613,41.613626),46307=>array(-87.326033,41.403917),46310=>array(-87.230774,41.182987),46311=>array(-87.508915,41.465085),46312=>array(-87.453983,41.646953),46319=>array(-87.422201,41.525472),46320=>array(-87.510921,41.691701),46321=>array(-87.503268,41.54751),46322=>array(-87.457213,41.546491),46323=>array(-87.453729,41.589434),46324=>array(-87.501583,41.583084),46327=>array(-87.498701,41.62787),46340=>array(-86.770664,41.382571),46341=>array(-87.214561,41.309672),46342=>array(-87.244909,41.518186),46345=>array(-86.698674,41.527357),46346=>array(-86.692635,41.472001),46347=>array(-87.013293,41.306668),46348=>array(-86.861892,41.310322),46349=>array(-87.41562,41.098599),46350=>array(-86.721724,41.607057),46356=>array(-87.422184,41.256618),46360=>array(-86.869177,41.68934),46365=>array(-86.545465,41.611548),46366=>array(-86.768059,41.215648),46368=>array(-87.180707,41.59082),46371=>array(-86.595221,41.688094),46373=>array(-87.467901,41.448355),46374=>array(-86.89878,41.204372),46375=>array(-87.448746,41.491818),46376=>array(-87.46989,41.184845),46377=>array(-87.338678,41.194734),46379=>array(-87.439972,41.167886),46381=>array(-87.324544,41.168474),46382=>array(-86.761986,41.461306),46383=>array(-87.00748,41.463169),46385=>array(-87.129705,41.460058),46390=>array(-86.881519,41.419467),46391=>array(-86.918985,41.554106),46392=>array(-87.048317,41.178401),46393=>array(-87.17762,41.508211),46394=>array(-87.489493,41.677695),46402=>array(-87.330662,41.599334),46403=>array(-87.262233,41.608093),46404=>array(-87.37403,41.584047),46405=>array(-87.262305,41.575007),46406=>array(-87.408048,41.602997),46407=>array(-87.330183,41.578457),46408=>array(-87.368484,41.545938),46409=>array(-87.324243,41.548371),46410=>array(-87.333065,41.480207),46501=>array(-86.245254,41.224603),46502=>array(-85.976238,41.259415),46504=>array(-86.111272,41.301061),46506=>array(-86.1724,41.462622),46507=>array(-85.818047,41.720077),46508=>array(-85.976783,41.150407),46510=>array(-85.870707,41.121661),46511=>array(-86.426977,41.21942),46514=>array(-85.976908,41.722642),46516=>array(-85.944127,41.676594),46517=>array(-85.997855,41.62729),46524=>array(-86.014116,41.305641),46526=>array(-85.876662,41.55878),46528=>array(-85.784864,41.600525),46530=>array(-86.126918,41.740931),46531=>array(-86.519382,41.356985),46532=>array(-86.611346,41.411435),46534=>array(-86.617818,41.285345),46536=>array(-86.298011,41.514551),46537=>array(-86.310197,41.459879),46538=>array(-85.823365,41.330242),46539=>array(-86.026511,41.163149),46540=>array(-85.69792,41.679807),46542=>array(-85.869691,41.396628),46543=>array(-85.672121,41.535194),46544=>array(-86.14782,41.615082),46545=>array(-86.146824,41.693766),46550=>array(-86.000647,41.445994),46552=>array(-86.481879,41.706315),46553=>array(-85.849206,41.479526),46554=>array(-86.416992,41.557413),46555=>array(-85.680481,41.326506),46556=>array(-86.251338,41.707119),46561=>array(-86.075352,41.663978),46562=>array(-85.684442,41.208344),46563=>array(-86.32628,41.355854),46565=>array(-85.577499,41.69485),46567=>array(-85.731166,41.414246),46570=>array(-86.121792,41.197926),46571=>array(-85.547199,41.57559),46573=>array(-86.069668,41.544364),46574=>array(-86.486629,41.481951),46580=>array(-85.869547,41.213832),46582=>array(-85.854448,41.280602),46590=>array(-85.812683,41.216843),46595=>array(-86.166605,41.526336),46601=>array(-86.252661,41.670274),46613=>array(-86.258431,41.655494),46614=>array(-86.27921,41.603188),46615=>array(-86.21171,41.673953),46616=>array(-86.266028,41.697826),46617=>array(-86.234758,41.684553),46619=>array(-86.35375,41.660941),46628=>array(-86.328342,41.723298),46635=>array(-86.201743,41.714357),46637=>array(-86.24147,41.733701),46701=>array(-85.431238,41.360791),46702=>array(-85.628114,40.831378),46703=>array(-85.00655,41.649589),46704=>array(-85.292577,41.103975),46705=>array(-85.061977,41.519103),46706=>array(-85.032655,41.341594),46710=>array(-85.242144,41.342351),46711=>array(-84.926879,40.661951),46714=>array(-85.176645,40.722791),46721=>array(-84.876607,41.422994),46723=>array(-85.326226,41.2452),46725=>array(-85.475768,41.148544),46730=>array(-85.151597,41.458442),46731=>array(-85.099634,40.793538),46732=>array(-85.622389,41.379566),46733=>array(-84.940039,40.828228),46737=>array(-84.92983,41.719282),46738=>array(-85.148865,41.318908),46740=>array(-84.964762,40.60428),46741=>array(-84.951226,41.216969),46742=>array(-84.879092,41.548594),46743=>array(-84.851125,41.215359),46745=>array(-85.009422,40.951657),46746=>array(-85.344932,41.725354),46747=>array(-85.157978,41.565687),46748=>array(-85.161149,41.248585),46750=>array(-85.496399,40.87846),46755=>array(-85.274859,41.449155),46759=>array(-85.178498,40.603927),46760=>array(-85.552692,41.345491),46761=>array(-85.377399,41.63445),46763=>array(-85.232689,41.301427),46764=>array(-85.620412,41.224389),46765=>array(-85.048745,41.232447),46766=>array(-85.282814,40.708605),46767=>array(-85.570411,41.470841),46770=>array(-85.324251,40.837684),46771=>array(-85.296149,41.694296),46772=>array(-84.913716,40.721508),46773=>array(-84.875607,40.982148),46774=>array(-84.972549,41.089259),46776=>array(-85.165915,41.721181),46777=>array(-85.147577,40.869136),46779=>array(-85.039473,41.577202),46781=>array(-85.26889,40.63238),46783=>array(-85.357314,40.969261),46784=>array(-85.388679,41.5005),46785=>array(-84.877756,41.323197),46786=>array(-85.272374,41.532044),46787=>array(-85.619724,41.066251),46788=>array(-84.909196,41.273021),46791=>array(-85.232101,40.837816),46792=>array(-85.443356,40.684332),46793=>array(-85.015268,41.452403),46794=>array(-85.45875,41.462413),46795=>array(-85.330905,41.553974),46797=>array(-84.85898,41.128395),46798=>array(-85.214712,40.938582),46799=>array(-85.285755,40.911504),46802=>array(-85.16516,41.069304),46803=>array(-85.088544,41.069874),46804=>array(-85.242156,41.053221),46805=>array(-85.117711,41.10011),46806=>array(-85.08837,41.046823),46807=>array(-85.147602,41.044893),46808=>array(-85.177021,41.097775),46809=>array(-85.205048,40.998304),46814=>array(-85.299234,41.050882),46815=>array(-85.058629,41.102735),46816=>array(-85.036179,41.000785),46818=>array(-85.253014,41.155856),46819=>array(-85.133593,40.974587),46825=>array(-85.127091,41.152413),46835=>array(-85.0408,41.15298),46845=>array(-85.109366,41.207641),46901=>array(-86.169537,40.531266),46902=>array(-86.094553,40.437275),46910=>array(-86.038676,41.042987),46911=>array(-85.945821,40.637417),46913=>array(-86.503452,40.503001),46914=>array(-86.094769,40.628598),46915=>array(-86.38659,40.477734),46917=>array(-86.475047,40.626869),46919=>array(-85.869644,40.594183),46920=>array(-86.494811,40.464409),46922=>array(-86.413626,41.13813),46923=>array(-86.641726,40.608872),46926=>array(-86.049986,40.887938),46928=>array(-85.682305,40.405898),46929=>array(-86.476386,40.554751),46930=>array(-85.571378,40.40744),46931=>array(-86.26427,40.947539),46932=>array(-86.250469,40.597241),46933=>array(-85.582288,40.479845),46936=>array(-85.927782,40.484302),46938=>array(-85.626941,40.459646),46939=>array(-86.400545,40.992876),46940=>array(-85.689231,40.690906),46941=>array(-85.689919,40.822976),46943=>array(-85.84293,40.975386),46946=>array(-85.728422,41.04043),46947=>array(-86.376113,40.759919),46950=>array(-86.364948,40.888204),46951=>array(-86.105392,40.947573),46952=>array(-85.629225,40.599427),46953=>array(-85.643344,40.519416),46957=>array(-85.495962,40.388298),46958=>array(-86.117007,40.821933),46959=>array(-86.107153,40.620859),46960=>array(-86.535546,41.161352),46961=>array(-86.191686,40.76651),46962=>array(-85.768524,40.988209),46967=>array(-86.195106,40.694682),46968=>array(-86.546361,41.175341),46970=>array(-86.061471,40.760125),46974=>array(-85.933503,40.951905),46975=>array(-86.250342,41.075328),46978=>array(-86.512501,40.856627),46979=>array(-86.275733,40.429421),46982=>array(-85.882956,41.06342),46984=>array(-85.830127,40.667769),46985=>array(-86.573883,40.950787),46986=>array(-85.819279,40.497945),46987=>array(-85.765327,40.568653),46988=>array(-86.234743,40.877117),46989=>array(-85.481366,40.448635),46990=>array(-85.731383,40.897336),46991=>array(-85.51421,40.628038),46992=>array(-85.826434,40.787305),46994=>array(-86.25455,40.667327),46996=>array(-86.658262,41.064687),46998=>array(-86.349666,40.567605),47001=>array(-84.965538,39.072665),47003=>array(-84.834261,39.559685),47006=>array(-85.215884,39.291996),47010=>array(-84.848717,39.501581),47011=>array(-85.076128,38.88162),47012=>array(-84.98339,39.4273),47016=>array(-84.890237,39.372217),47017=>array(-85.185945,38.935533),47018=>array(-85.086623,38.996765),47020=>array(-84.924412,38.815142),47022=>array(-84.951741,39.2049),47023=>array(-85.38185,39.080549),47024=>array(-85.199038,39.476872),47025=>array(-84.866317,39.165524),47030=>array(-85.132377,39.424093),47031=>array(-85.156451,39.124244),47032=>array(-85.043662,39.086912),47034=>array(-85.327471,39.203982),47035=>array(-84.905542,39.309224),47036=>array(-85.245929,39.39111),47037=>array(-85.325656,39.169482),47038=>array(-84.84995,38.850304),47040=>array(-84.941033,38.922057),47041=>array(-85.083768,39.234052),47042=>array(-85.255113,39.01944),47043=>array(-85.090993,38.790365),47060=>array(-84.885706,39.301338),47102=>array(-85.792736,38.765011),47104=>array(-85.421392,38.540304),47106=>array(-85.899844,38.464301),47108=>array(-86.248533,38.640027),47110=>array(-86.185044,38.098852),47111=>array(-85.632579,38.466197),47112=>array(-86.162499,38.195517),47114=>array(-86.084556,38.285817),47115=>array(-86.209964,38.348952),47116=>array(-86.62201,38.324227),47117=>array(-85.967356,38.106642),47118=>array(-86.49743,38.310091),47119=>array(-85.881583,38.372038),47120=>array(-86.188852,38.46306),47122=>array(-85.984844,38.30596),47123=>array(-86.479372,38.267133),47124=>array(-86.010607,38.371492),47125=>array(-86.313139,38.4636),47126=>array(-85.77586,38.547092),47129=>array(-85.768453,38.313141),47130=>array(-85.697211,38.333402),47135=>array(-86.074351,38.048816),47136=>array(-85.966747,38.235085),47137=>array(-86.390479,38.168121),47138=>array(-85.584686,38.682475),47140=>array(-86.362912,38.380965),47141=>array(-85.612115,38.547956),47142=>array(-86.213131,38.084881),47143=>array(-85.768158,38.468612),47145=>array(-86.306582,38.329877),47147=>array(-85.545105,38.592788),47150=>array(-85.847601,38.283506),47160=>array(-86.050997,38.164455),47161=>array(-86.103592,38.321795),47162=>array(-85.460052,38.54586),47163=>array(-85.669844,38.533074),47164=>array(-86.102925,38.414685),47165=>array(-86.00694,38.50348),47166=>array(-86.167419,38.306882),47167=>array(-86.095905,38.61146),47170=>array(-85.844056,38.685201),47172=>array(-85.774269,38.399505),47175=>array(-86.567953,38.376762),47177=>array(-85.791856,38.58974),47201=>array(-85.993199,39.158873),47203=>array(-85.83216,39.230403),47220=>array(-86.049057,38.876281),47223=>array(-85.472026,39.050074),47224=>array(-85.215093,38.888028),47226=>array(-85.868982,39.282369),47227=>array(-85.654136,38.867579),47229=>array(-85.867725,38.803096),47230=>array(-85.625116,38.79238),47231=>array(-85.493849,38.901485),47232=>array(-85.789256,39.112058),47234=>array(-85.7679,39.377362),47235=>array(-86.136101,38.991705),47240=>array(-85.478417,39.305991),47243=>array(-85.482235,38.668701),47244=>array(-85.70154,39.21904),47246=>array(-85.767011,39.299253),47247=>array(-85.888138,39.059532),47250=>array(-85.351135,38.815317),47260=>array(-86.197754,38.836742),47263=>array(-85.330177,39.30944),47264=>array(-86.249978,38.97439),47265=>array(-85.629937,39.014661),47270=>array(-85.722862,38.839337),47272=>array(-85.621407,39.411013),47273=>array(-85.736847,39.07579),47274=>array(-85.937722,38.966511),47280=>array(-85.950521,39.296587),47281=>array(-86.106341,38.788527),47282=>array(-85.610731,38.982353),47283=>array(-85.588747,39.173689),47302=>array(-85.382469,40.12691),47303=>array(-85.377772,40.271643),47304=>array(-85.459814,40.236332),47305=>array(-85.385939,40.194099),47306=>array(-85.404608,40.202376),47320=>array(-85.272799,40.271703),47324=>array(-84.851809,39.741105),47325=>array(-85.020236,39.691146),47326=>array(-84.967266,40.54868),47327=>array(-85.175101,39.827428),47330=>array(-85.022256,39.786249),47331=>array(-85.157338,39.624084),47334=>array(-85.52699,40.118754),47335=>array(-85.205168,39.812374),47336=>array(-85.210356,40.386723),47337=>array(-85.437276,39.802476),47338=>array(-85.341841,40.34037),47339=>array(-85.079129,39.938777),47340=>array(-85.133663,40.180757),47341=>array(-84.891734,39.97232),47342=>array(-85.507983,40.32858),47344=>array(-85.465375,39.878372),47345=>array(-85.06018,39.893863),47346=>array(-85.1682,39.931657),47348=>array(-85.340374,40.466214),47351=>array(-85.522087,39.906998),47352=>array(-85.367066,39.79572),47353=>array(-84.925152,39.623111),47354=>array(-85.192539,40.040842),47355=>array(-84.927052,40.044174),47356=>array(-85.507425,40.031458),47357=>array(-85.146917,39.751359),47358=>array(-85.113523,40.057306),47359=>array(-85.283667,40.551281),47360=>array(-85.258203,40.011265),47361=>array(-85.385059,40.00419),47362=>array(-85.36958,39.930459),47367=>array(-85.387219,40.082648),47368=>array(-85.194189,40.182196),47369=>array(-85.142062,40.507343),47371=>array(-84.962799,40.418997),47373=>array(-85.160845,40.337508),47374=>array(-84.889699,39.832079),47380=>array(-85.030029,40.286745),47381=>array(-84.866884,40.381786),47382=>array(-84.917484,40.236391),47383=>array(-85.266121,40.141861),47384=>array(-85.550892,39.909241),47385=>array(-85.446008,39.832905),47386=>array(-85.385654,40.055073),47387=>array(-85.298534,39.838465),47388=>array(-85.443437,40.005637),47390=>array(-84.846428,40.205668),47393=>array(-85.003691,39.962996),47394=>array(-84.987308,40.167974),47396=>array(-85.517178,40.189183),47401=>array(-86.442957,39.102552),47403=>array(-86.61234,39.085219),47404=>array(-86.591196,39.219531),47405=>array(-86.518614,39.168209),47406=>array(-86.515448,39.177797),47408=>array(-86.467254,39.229815),47420=>array(-86.548919,38.913158),47421=>array(-86.45223,38.863494),47424=>array(-86.882428,39.020048),47427=>array(-87.016135,39.232829),47429=>array(-86.615938,39.273277),47431=>array(-86.902939,39.236601),47432=>array(-86.641906,38.485527),47433=>array(-86.641547,39.355787),47434=>array(-86.547286,39.011912),47436=>array(-86.385977,38.954149),47437=>array(-86.676968,38.714743),47438=>array(-87.187281,39.158728),47441=>array(-87.165501,39.044695),47443=>array(-87.099145,38.95817),47446=>array(-86.51815,38.747192),47448=>array(-86.235511,39.17953),47449=>array(-87.00329,38.926988),47451=>array(-86.52355,38.892959),47452=>array(-86.43343,38.647143),47453=>array(-86.775709,38.94163),47454=>array(-86.451821,38.510025),47455=>array(-86.956153,39.316496),47456=>array(-86.691333,39.465239),47457=>array(-86.90475,38.909139),47458=>array(-86.507227,39.070329),47459=>array(-86.749576,39.112793),47460=>array(-86.797936,39.286656),47462=>array(-86.647567,38.958323),47464=>array(-86.649996,39.299803),47465=>array(-87.034871,39.047972),47467=>array(-86.344361,38.767864),47468=>array(-86.392866,39.271083),47469=>array(-86.599153,38.6376),47470=>array(-86.637114,38.818283),47471=>array(-87.003808,39.142894),47501=>array(-87.173647,38.66206),47512=>array(-87.320813,38.78374),47513=>array(-86.714111,38.304258),47514=>array(-86.586209,38.1562),47515=>array(-86.703982,38.183913),47516=>array(-87.419265,38.771006),47519=>array(-86.992661,38.602659),47520=>array(-86.668241,37.945058),47521=>array(-86.724575,38.396081),47522=>array(-86.816735,38.89232),47523=>array(-87.025759,38.178794),47524=>array(-87.610887,38.49477),47525=>array(-86.559697,38.032344),47527=>array(-86.785924,38.468858),47528=>array(-87.253221,38.833136),47529=>array(-87.080001,38.854967),47531=>array(-86.851428,38.03971),47532=>array(-86.860563,38.221348),47535=>array(-87.307664,38.872344),47536=>array(-86.836519,38.11229),47537=>array(-87.036126,38.074167),47541=>array(-87.046164,38.235278),47542=>array(-86.967215,38.296593),47546=>array(-86.932557,38.418779),47550=>array(-86.921311,38.067186),47551=>array(-86.569572,38.114113),47552=>array(-86.999676,38.114551),47553=>array(-86.903839,38.660751),47557=>array(-87.342777,38.578834),47558=>array(-87.040439,38.646137),47561=>array(-87.438287,38.863684),47562=>array(-86.973432,38.833089),47564=>array(-87.093828,38.483041),47567=>array(-87.305019,38.4627),47568=>array(-87.102429,38.764087),47574=>array(-86.562127,37.950036),47575=>array(-86.804462,38.317808),47576=>array(-86.617939,38.175537),47577=>array(-86.808938,38.152526),47578=>array(-87.193522,38.902344),47579=>array(-86.915134,38.110933),47580=>array(-86.767156,38.355203),47581=>array(-86.7626,38.655694),47584=>array(-87.259526,38.255502),47585=>array(-87.157956,38.268269),47586=>array(-86.701995,38.039096),47588=>array(-86.778403,38.072389),47590=>array(-87.100344,38.360654),47591=>array(-87.501485,38.628561),47596=>array(-87.227734,38.866496),47597=>array(-87.2988,38.654389),47598=>array(-87.211613,38.386893),47601=>array(-87.254533,38.051443),47610=>array(-87.401743,38.057764),47611=>array(-87.057458,38.027918),47612=>array(-87.699246,38.193026),47613=>array(-87.417471,38.158948),47615=>array(-86.963548,37.969851),47616=>array(-87.890844,38.240052),47619=>array(-87.303614,38.185397),47620=>array(-87.905711,37.931959),47630=>array(-87.34647,37.952897),47631=>array(-87.901792,38.109131),47633=>array(-87.787892,38.175907),47634=>array(-87.182452,37.939468),47635=>array(-87.106525,37.883679),47637=>array(-87.151319,38.135734),47638=>array(-87.776101,38.065443),47639=>array(-87.572944,38.176096),47640=>array(-87.484032,38.478176),47648=>array(-87.557788,38.24758),47649=>array(-87.451228,38.353466),47654=>array(-87.392292,38.249505),47660=>array(-87.322203,38.295045),47665=>array(-87.722673,38.27667),47666=>array(-87.600469,38.417797),47670=>array(-87.584821,38.34489),47683=>array(-87.376955,38.276782),47708=>array(-87.573574,37.974553),47710=>array(-87.575809,38.025505),47711=>array(-87.536743,38.015301),47712=>array(-87.665531,37.926457),47713=>array(-87.559175,37.954531),47714=>array(-87.521291,37.956614),47715=>array(-87.479665,37.972424),47720=>array(-87.641573,38.062897),47725=>array(-87.524939,38.106329),47802=>array(-87.411768,39.350956),47803=>array(-87.307322,39.466092),47804=>array(-87.389953,39.497812),47805=>array(-87.326483,39.546274),47807=>array(-87.402752,39.471333),47809=>array(-87.410106,39.471249),47832=>array(-87.258433,39.880882),47833=>array(-86.975238,39.358609),47834=>array(-87.121971,39.525549),47836=>array(-87.179079,39.646104),47837=>array(-87.114906,39.627224),47838=>array(-87.383679,38.961773),47840=>array(-87.056514,39.408055),47841=>array(-87.114256,39.273724),47842=>array(-87.463596,39.678584),47846=>array(-87.193598,39.378638),47847=>array(-87.485836,39.831343),47848=>array(-87.261971,39.042043),47849=>array(-87.56374,39.195304),47850=>array(-87.435782,39.251931),47853=>array(-87.072828,39.5382),47854=>array(-87.403057,39.803019),47855=>array(-87.304098,39.189827),47857=>array(-87.091111,39.524158),47858=>array(-87.224587,39.262171),47859=>array(-87.172196,39.88184),47860=>array(-87.330273,39.721857),47861=>array(-87.570355,39.073459),47862=>array(-87.342366,39.767091),47863=>array(-87.454348,39.589125),47865=>array(-87.391428,39.020999),47866=>array(-87.321116,39.292406),47868=>array(-86.897154,39.409468),47869=>array(-87.496713,39.273917),47871=>array(-87.299875,39.38968),47872=>array(-87.153112,39.753541),47874=>array(-87.270746,39.628499),47876=>array(-87.459799,39.514586),47879=>array(-87.378686,39.197692),47880=>array(-87.418844,39.599748),47881=>array(-87.192415,39.48593),47882=>array(-87.410855,39.091315),47884=>array(-87.449043,39.613325),47885=>array(-87.477056,39.510414),47901=>array(-86.889633,40.417778),47904=>array(-86.87692,40.438632),47905=>array(-86.766044,40.420015),47906=>array(-86.989241,40.479679),47907=>array(-86.915479,40.424403),47909=>array(-86.896302,40.324563),47916=>array(-87.05543,39.983646),47917=>array(-87.473426,40.466838),47918=>array(-87.198005,40.298678),47920=>array(-86.833864,40.540759),47921=>array(-87.375376,40.477151),47922=>array(-87.348923,40.876936),47923=>array(-86.940003,40.610401),47924=>array(-86.762846,40.487945),47925=>array(-86.748403,40.878281),47926=>array(-86.595516,40.780384),47928=>array(-87.472313,39.921337),47929=>array(-86.91276,40.670159),47930=>array(-86.742355,40.237087),47932=>array(-87.415241,40.134328),47933=>array(-86.896849,40.038913),47940=>array(-86.746635,40.117577),47941=>array(-86.77398,40.376135),47942=>array(-87.444303,40.686285),47943=>array(-87.273449,41.063383),47944=>array(-87.330108,40.616019),47946=>array(-86.868425,40.981738),47948=>array(-87.281735,40.777015),47949=>array(-87.137329,40.06054),47950=>array(-86.654857,40.802441),47951=>array(-87.444437,40.789528),47952=>array(-87.299105,39.959636),47954=>array(-86.8185,39.899963),47955=>array(-86.861865,40.196331),47957=>array(-86.874731,41.086146),47958=>array(-87.142399,40.164219),47959=>array(-86.900749,40.862568),47960=>array(-86.751024,40.779015),47963=>array(-87.431944,40.984253),47964=>array(-87.298642,40.95212),47965=>array(-86.920264,39.954454),47966=>array(-87.396984,39.88582),47967=>array(-87.001633,40.196681),47968=>array(-86.749957,39.959518),47969=>array(-87.148731,40.205717),47970=>array(-87.143054,40.46212),47971=>array(-87.233923,40.532018),47974=>array(-87.480363,40.042921),47975=>array(-87.253258,40.449132),47977=>array(-87.164567,40.755909),47978=>array(-87.112979,40.986173),47980=>array(-86.897372,40.751634),47981=>array(-86.930413,40.245025),47982=>array(-87.527069,40.197348),47983=>array(-86.767288,40.279131),47987=>array(-87.232989,40.125748),47989=>array(-87.04904,39.890345),47990=>array(-87.054281,40.061841),47991=>array(-87.463075,40.284444),47992=>array(-87.048999,40.319373),47993=>array(-87.409423,40.308279),47994=>array(-87.062127,40.169249),47995=>array(-87.030109,40.761189),47997=>array(-86.723596,40.667696),48001=>array(-82.581737,42.639328),48002=>array(-82.91712,42.936383),48003=>array(-83.039632,42.929993),48005=>array(-82.923828,42.850742),48006=>array(-82.691035,43.083019),48009=>array(-83.217653,42.544048),48014=>array(-82.931553,43.025719),48015=>array(-83.027149,42.480497),48017=>array(-83.150361,42.536695),48021=>array(-82.946341,42.46608),48022=>array(-82.802404,43.023396),48023=>array(-82.657699,42.70102),48025=>array(-83.264824,42.520357),48026=>array(-82.946742,42.537633),48027=>array(-82.694041,42.944289),48028=>array(-82.61662,42.580209),48030=>array(-83.097689,42.461924),48032=>array(-82.596952,43.133203),48033=>array(-83.293205,42.459322),48034=>array(-83.291078,42.496949),48035=>array(-82.907589,42.5566),48036=>array(-82.913144,42.597045),48038=>array(-82.937588,42.606163),48039=>array(-82.546478,42.692907),48040=>array(-82.480603,42.910313),48041=>array(-82.806288,42.937825),48042=>array(-82.907975,42.683658),48043=>array(-82.881506,42.598055),48044=>array(-82.928905,42.650226),48045=>array(-82.818113,42.586409),48047=>array(-82.773842,42.67424),48048=>array(-82.79587,42.745747),48049=>array(-82.570207,43.041577),48050=>array(-82.799467,42.787537),48051=>array(-82.821001,42.693641),48054=>array(-82.528976,42.770358),48059=>array(-82.494773,43.08762),48060=>array(-82.461014,42.980388),48062=>array(-82.796471,42.852495),48063=>array(-82.683111,42.859332),48064=>array(-82.666777,42.764617),48065=>array(-83.03929,42.845195),48066=>array(-82.936582,42.507586),48067=>array(-83.137524,42.490558),48069=>array(-83.144332,42.471325),48070=>array(-83.168088,42.481899),48071=>array(-83.10337,42.507266),48072=>array(-83.185859,42.497902),48073=>array(-83.164362,42.519205),48074=>array(-82.561555,42.950223),48075=>array(-83.230398,42.462064),48076=>array(-83.230874,42.497517),48079=>array(-82.548404,42.858849),48080=>array(-82.896175,42.464424),48081=>array(-82.895039,42.494669),48082=>array(-82.887195,42.528022),48083=>array(-83.116859,42.557021),48084=>array(-83.175706,42.560633),48085=>array(-83.122111,42.604032),48088=>array(-82.982991,42.515645),48089=>array(-82.993857,42.468096),48091=>array(-83.057986,42.468168),48092=>array(-83.058938,42.513593),48093=>array(-83.016483,42.51589),48094=>array(-83.037491,42.736802),48095=>array(-83.04807,42.778736),48096=>array(-82.92047,42.762151),48097=>array(-82.827417,43.121947),48098=>array(-83.17845,42.598433),48101=>array(-83.21039,42.259473),48103=>array(-83.846438,42.261356),48104=>array(-83.715564,42.263886),48105=>array(-83.695817,42.327704),48108=>array(-83.732265,42.221694),48109=>array(-83.70878,42.289187),48111=>array(-83.488444,42.177312),48114=>array(-83.74763,42.570452),48116=>array(-83.782892,42.505744),48117=>array(-83.410188,42.050259),48118=>array(-84.03402,42.312244),48120=>array(-83.176211,42.306327),48122=>array(-83.182589,42.278537),48124=>array(-83.24761,42.298036),48125=>array(-83.264832,42.277334),48126=>array(-83.183213,42.32579),48127=>array(-83.283296,42.335793),48128=>array(-83.259969,42.320411),48130=>array(-83.90936,42.364141),48131=>array(-83.671398,41.965924),48133=>array(-83.486028,41.782381),48134=>array(-83.296157,42.106559),48135=>array(-83.341212,42.324384),48137=>array(-84.07501,42.462186),48138=>array(-83.153921,42.133978),48139=>array(-83.80605,42.452452),48140=>array(-83.580507,41.882184),48141=>array(-83.319867,42.294054),48143=>array(-83.851969,42.459978),48144=>array(-83.628666,41.752443),48145=>array(-83.45997,41.844247),48146=>array(-83.181258,42.243291),48150=>array(-83.376788,42.371604),48152=>array(-83.374264,42.424935),48154=>array(-83.372319,42.397183),48157=>array(-83.438215,41.814624),48158=>array(-84.029434,42.155829),48159=>array(-83.547956,42.019159),48160=>array(-83.674971,42.078164),48161=>array(-83.472457,41.907196),48162=>array(-83.429323,41.960425),48164=>array(-83.386866,42.124571),48165=>array(-83.616922,42.501565),48166=>array(-83.294714,41.982805),48167=>array(-83.524658,42.432315),48168=>array(-83.540498,42.405262),48169=>array(-83.947737,42.462451),48170=>array(-83.534306,42.367689),48173=>array(-83.212774,42.073679),48174=>array(-83.394324,42.234298),48176=>array(-83.82925,42.136836),48177=>array(-83.580926,41.803955),48178=>array(-83.656872,42.443768),48179=>array(-83.25545,42.035092),48180=>array(-83.268308,42.225262),48182=>array(-83.583849,41.789858),48183=>array(-83.217792,42.131459),48184=>array(-83.395623,42.274479),48185=>array(-83.384209,42.333901),48186=>array(-83.370739,42.293764),48187=>array(-83.483576,42.325573),48188=>array(-83.482719,42.283688),48189=>array(-83.782854,42.412336),48190=>array(-83.593807,42.131536),48191=>array(-83.57059,42.121629),48192=>array(-83.161498,42.208455),48193=>array(-83.209837,42.173282),48195=>array(-83.206511,42.204975),48197=>array(-83.639984,42.194034),48198=>array(-83.58634,42.275075),48201=>array(-83.060184,42.347021),48202=>array(-83.077718,42.374786),48203=>array(-83.104338,42.420736),48204=>array(-83.142935,42.365812),48205=>array(-82.981142,42.433156),48206=>array(-83.107897,42.375123),48207=>array(-83.01896,42.349654),48208=>array(-83.091937,42.348491),48209=>array(-83.116863,42.306723),48210=>array(-83.128331,42.336212),48211=>array(-83.045733,42.381347),48212=>array(-83.056394,42.409721),48213=>array(-82.995213,42.397931),48214=>array(-82.987644,42.365116),48215=>array(-82.954344,42.375051),48216=>array(-83.078746,42.326484),48217=>array(-83.155078,42.277651),48218=>array(-83.126672,42.272709),48219=>array(-83.251428,42.425328),48220=>array(-83.135213,42.458066),48221=>array(-83.148609,42.427),48223=>array(-83.246327,42.393453),48224=>array(-82.941265,42.410693),48225=>array(-82.92961,42.438984),48226=>array(-83.050267,42.331542),48227=>array(-83.192592,42.387249),48228=>array(-83.217014,42.355455),48229=>array(-83.142867,42.250559),48230=>array(-82.921842,42.382395),48233=>array(-83.061662,42.323697),48234=>array(-83.039501,42.431197),48235=>array(-83.194803,42.427058),48236=>array(-82.893194,42.425373),48237=>array(-83.18242,42.464968),48238=>array(-83.141352,42.396286),48239=>array(-83.283174,42.376046),48240=>array(-83.3013,42.42446),48242=>array(-83.345136,42.22121),48243=>array(-83.039506,42.329975),48301=>array(-83.282168,42.5424),48302=>array(-83.293467,42.585108),48304=>array(-83.233152,42.588866),48306=>array(-83.147306,42.724318),48307=>array(-83.122679,42.659316),48309=>array(-83.183588,42.656374),48310=>array(-83.068397,42.563435),48312=>array(-83.008926,42.558228),48313=>array(-83.002903,42.600651),48314=>array(-83.053489,42.612074),48315=>array(-82.996562,42.671548),48316=>array(-83.057244,42.690173),48317=>array(-83.051972,42.64484),48320=>array(-83.338092,42.611935),48322=>array(-83.381721,42.538168),48323=>array(-83.377909,42.570804),48324=>array(-83.392463,42.594161),48326=>array(-83.244075,42.688246),48327=>array(-83.409987,42.636933),48328=>array(-83.359098,42.646381),48329=>array(-83.388622,42.687016),48331=>array(-83.408935,42.502483),48334=>array(-83.349203,42.504697),48335=>array(-83.405151,42.462885),48336=>array(-83.34727,42.463144),48340=>array(-83.287904,42.672146),48341=>array(-83.296841,42.627985),48342=>array(-83.273415,42.642264),48346=>array(-83.428904,42.717697),48348=>array(-83.403875,42.770131),48350=>array(-83.531044,42.739418),48353=>array(-83.715943,42.64687),48356=>array(-83.592905,42.654414),48357=>array(-83.6464,42.658533),48359=>array(-83.275522,42.720743),48360=>array(-83.260083,42.747574),48362=>array(-83.270339,42.784477),48363=>array(-83.162499,42.772483),48367=>array(-83.136902,42.836232),48370=>array(-83.200365,42.842876),48371=>array(-83.291531,42.84097),48374=>array(-83.522863,42.473226),48375=>array(-83.463958,42.464141),48377=>array(-83.474163,42.504926),48380=>array(-83.666824,42.583002),48381=>array(-83.591793,42.558412),48382=>array(-83.507157,42.592558),48383=>array(-83.525841,42.655609),48386=>array(-83.480281,42.660319),48390=>array(-83.474218,42.550711),48393=>array(-83.545088,42.521838),48397=>array(-83.041035,42.495017),48401=>array(-82.670591,43.347342),48411=>array(-83.528907,42.931981),48412=>array(-83.175549,43.070433),48413=>array(-82.993851,43.798617),48414=>array(-84.079846,42.861694),48415=>array(-83.808105,43.271876),48416=>array(-82.985115,43.21687),48417=>array(-83.939194,43.261282),48418=>array(-83.969891,42.794295),48419=>array(-82.660545,43.435673),48420=>array(-83.700508,43.179103),48421=>array(-83.393187,43.155496),48422=>array(-82.653704,43.261472),48423=>array(-83.51096,43.038705),48426=>array(-83.058098,43.510728),48427=>array(-82.725482,43.535638),48428=>array(-83.154454,42.938195),48429=>array(-84.003812,42.905895),48430=>array(-83.743683,42.758215),48432=>array(-82.972074,43.898698),48433=>array(-83.867227,43.075348),48434=>array(-82.611777,43.661889),48435=>array(-83.359338,43.245379),48436=>array(-83.87683,42.865316),48437=>array(-83.612394,43.115745),48438=>array(-83.484165,42.913657),48439=>array(-83.629571,42.916674),48440=>array(-83.412259,42.951094),48441=>array(-82.70863,43.797892),48442=>array(-83.606102,42.78868),48444=>array(-83.045197,43.058491),48445=>array(-82.990555,43.950222),48446=>array(-83.338704,43.05374),48449=>array(-83.944772,42.991452),48450=>array(-82.542438,43.25866),48451=>array(-83.819172,42.801222),48453=>array(-83.032572,43.348144),48454=>array(-82.812721,43.195011),48455=>array(-83.290783,42.937951),48456=>array(-82.762208,43.666971),48457=>array(-83.89517,43.186801),48458=>array(-83.681457,43.125269),48460=>array(-83.984997,43.130612),48461=>array(-83.206162,43.193661),48462=>array(-83.421668,42.848513),48463=>array(-83.519301,43.165799),48464=>array(-83.42246,43.220341),48465=>array(-82.70777,43.607998),48466=>array(-82.808877,43.280507),48467=>array(-82.982415,44.015356),48468=>array(-82.775181,43.938412),48469=>array(-82.558181,43.441469),48470=>array(-82.751064,43.73513),48471=>array(-82.85208,43.41942),48472=>array(-82.963212,43.512323),48473=>array(-83.820544,42.93695),48475=>array(-82.947987,43.673156),48476=>array(-84.03005,42.938707),48502=>array(-83.688376,43.013727),48503=>array(-83.708864,42.999923),48504=>array(-83.743784,43.054791),48505=>array(-83.686168,43.070657),48506=>array(-83.624392,43.067472),48507=>array(-83.717359,42.966966),48509=>array(-83.606593,43.02421),48519=>array(-83.604953,42.981891),48529=>array(-83.65859,42.970338),48532=>array(-83.794854,43.011064),48551=>array(-83.7169,42.980994),48553=>array(-83.723561,42.977762),48554=>array(-83.790734,42.975881),48601=>array(-83.893998,43.405947),48602=>array(-83.974472,43.420026),48603=>array(-84.029471,43.458786),48604=>array(-83.969084,43.499764),48607=>array(-83.933996,43.431811),48609=>array(-84.087006,43.388857),48610=>array(-84.192194,44.141692),48611=>array(-84.097206,43.634148),48612=>array(-84.439434,43.883024),48613=>array(-84.175193,43.947803),48614=>array(-84.298042,43.250991),48615=>array(-84.474806,43.42981),48616=>array(-84.11346,43.191074),48617=>array(-84.717297,43.851308),48618=>array(-84.556707,43.736779),48619=>array(-84.020613,44.819736),48621=>array(-84.012427,44.736899),48622=>array(-84.881266,43.840836),48623=>array(-84.13284,43.52008),48624=>array(-84.45737,44.061093),48625=>array(-84.839621,44.052769),48626=>array(-84.221436,43.421372),48627=>array(-84.750203,44.461919),48628=>array(-84.328366,43.784121),48629=>array(-84.784698,44.312238),48630=>array(-84.772497,44.324794),48631=>array(-83.995895,43.688645),48632=>array(-85.020525,43.858387),48633=>array(-84.931062,43.936975),48634=>array(-84.056178,43.747641),48635=>array(-83.99443,44.387169),48636=>array(-84.295564,44.598899),48637=>array(-84.335573,43.413693),48638=>array(-84.018242,43.418925),48640=>array(-84.337227,43.582166),48642=>array(-84.236964,43.712749),48647=>array(-84.113065,44.658121),48649=>array(-84.217431,43.150461),48650=>array(-83.997777,43.847504),48651=>array(-84.614813,44.254775),48652=>array(-84.19688,43.860201),48653=>array(-84.599452,44.490944),48654=>array(-84.137319,44.457421),48655=>array(-84.159695,43.294499),48656=>array(-84.450997,44.341665),48657=>array(-84.41616,43.706126),48658=>array(-83.936798,43.975339),48659=>array(-84.050783,44.065548),48661=>array(-84.236213,44.318406),48662=>array(-84.41681,43.409942),48667=>array(-84.233324,43.602088),48701=>array(-83.557827,43.586877),48703=>array(-83.675914,44.063642),48705=>array(-83.656322,44.696064),48706=>array(-83.950504,43.599622),48708=>array(-83.84968,43.55706),48710=>array(-83.987669,43.556513),48720=>array(-83.339177,43.838602),48721=>array(-83.33948,44.808106),48722=>array(-83.844762,43.346724),48723=>array(-83.388738,43.485294),48724=>array(-83.928244,43.456815),48725=>array(-83.209593,43.943956),48726=>array(-83.167997,43.607381),48727=>array(-83.174484,43.313384),48728=>array(-83.819275,44.732959),48729=>array(-83.173779,43.495939),48730=>array(-83.455677,44.343486),48731=>array(-83.15105,43.843633),48732=>array(-83.789822,43.612331),48733=>array(-83.593113,43.534102),48734=>array(-83.74851,43.357562),48735=>array(-83.270883,43.667593),48737=>array(-83.685206,44.545688),48738=>array(-83.329568,44.555551),48739=>array(-83.841608,44.370907),48740=>array(-83.372024,44.663889),48741=>array(-83.179873,43.402479),48742=>array(-83.435666,44.742724),48743=>array(-83.863151,44.441124),48744=>array(-83.359255,43.348042),48745=>array(-83.475246,44.566419),48746=>array(-83.55025,43.259333),48747=>array(-83.764616,43.518714),48748=>array(-83.612927,44.352923),48749=>array(-83.900647,44.053775),48750=>array(-83.471971,44.445649),48754=>array(-83.231016,43.733259),48755=>array(-83.24562,43.791501),48756=>array(-83.973027,44.233582),48757=>array(-83.676311,43.469859),48759=>array(-83.385904,43.730478),48760=>array(-83.255006,43.323051),48761=>array(-83.89171,44.510924),48762=>array(-83.46162,44.82166),48763=>array(-83.614901,44.25509),48765=>array(-83.717952,44.151556),48766=>array(-83.839392,44.105722),48767=>array(-83.463154,43.650518),48768=>array(-83.577539,43.370831),48770=>array(-83.814166,44.251182),48801=>array(-84.678002,43.375171),48806=>array(-84.500161,43.186891),48807=>array(-84.402006,43.150476),48808=>array(-84.444776,42.828836),48809=>array(-85.257962,43.075299),48811=>array(-84.854439,43.180629),48813=>array(-84.84583,42.579702),48815=>array(-85.258593,42.83437),48816=>array(-83.955981,42.765009),48817=>array(-84.042884,43.013949),48818=>array(-84.888184,43.271447),48819=>array(-84.280994,42.547396),48820=>array(-84.592296,42.863913),48821=>array(-84.647418,42.641171),48822=>array(-84.762988,42.835429),48823=>array(-84.458771,42.763888),48825=>array(-84.481415,42.727613),48827=>array(-84.660239,42.509348),48829=>array(-85.015378,43.398205),48831=>array(-84.372488,43.096219),48832=>array(-84.776582,43.411883),48834=>array(-85.032114,43.132585),48835=>array(-84.749057,43.024903),48836=>array(-84.076583,42.669319),48837=>array(-84.770601,42.746728),48838=>array(-85.256667,43.183357),48840=>array(-84.379361,42.763138),48841=>array(-84.239468,43.112258),48842=>array(-84.538076,42.633522),48843=>array(-83.923411,42.575483),48845=>array(-84.845897,43.102441),48846=>array(-85.057887,42.986125),48847=>array(-84.575579,43.273232),48848=>array(-84.353703,42.887696),48849=>array(-85.124536,42.806313),48850=>array(-85.245835,43.43527),48851=>array(-84.9364,42.951055),48852=>array(-85.046033,43.351697),48853=>array(-84.685303,43.099917),48854=>array(-84.451612,42.581698),48855=>array(-83.897189,42.681278),48856=>array(-84.733509,43.19721),48857=>array(-84.155615,42.840946),48858=>array(-84.795459,43.616033),48860=>array(-84.908954,43.050812),48861=>array(-84.925032,42.732509),48864=>array(-84.392139,42.70417),48865=>array(-85.103981,43.086684),48866=>array(-84.37613,42.997581),48867=>array(-84.188977,43.002718),48870=>array(-84.984752,43.110408),48871=>array(-84.673805,43.156653),48872=>array(-84.223099,42.79865),48873=>array(-84.844139,42.996861),48874=>array(-84.594937,43.186449),48875=>array(-84.941448,42.860813),48876=>array(-84.731344,42.644253),48877=>array(-84.840802,43.403734),48878=>array(-84.779858,43.706095),48879=>array(-84.578668,43.003017),48880=>array(-84.578359,43.458864),48881=>array(-85.201584,42.933122),48883=>array(-84.673886,43.543727),48884=>array(-85.049208,43.209843),48885=>array(-85.147939,43.242912),48886=>array(-85.159692,43.415719),48888=>array(-85.106068,43.314815),48889=>array(-84.806493,43.28445),48890=>array(-84.966272,42.766938),48891=>array(-84.911507,43.395354),48892=>array(-84.166861,42.632741),48893=>array(-84.97505,43.685543),48894=>array(-84.785801,42.921483),48895=>array(-84.279784,42.688915),48896=>array(-84.901027,43.521275),48897=>array(-85.130349,42.703898),48906=>array(-84.585007,42.791745),48910=>array(-84.519955,42.699177),48911=>array(-84.571422,42.67301),48912=>array(-84.523976,42.738449),48915=>array(-84.570937,42.737952),48917=>array(-84.639542,42.725239),48921=>array(-84.56083,42.721347),48933=>array(-84.554683,42.731996),49001=>array(-85.561545,42.264543),49002=>array(-85.562988,42.195311),49004=>array(-85.563941,42.353583),49006=>array(-85.63146,42.292497),49007=>array(-85.588193,42.302591),49008=>array(-85.617047,42.263841),49009=>array(-85.697876,42.303748),49010=>array(-85.874766,42.533307),49011=>array(-85.216193,42.106984),49012=>array(-85.34422,42.36817),49013=>array(-86.108039,42.30552),49014=>array(-85.106213,42.314556),49015=>array(-85.22874,42.270781),49017=>array(-85.215928,42.401366),49021=>array(-85.054743,42.460434),49022=>array(-86.359048,42.112127),49024=>array(-85.617997,42.206513),49026=>array(-85.963435,42.376862),49027=>array(-86.067554,42.350721),49028=>array(-85.190234,41.851471),49029=>array(-85.100314,42.142409),49030=>array(-85.336414,41.862172),49031=>array(-85.974314,41.9047),49032=>array(-85.52287,41.911488),49033=>array(-85.088714,42.227502),49034=>array(-85.341209,42.233525),49036=>array(-85.013415,41.909987),49037=>array(-85.244499,42.330025),49038=>array(-86.320868,42.202822),49040=>array(-85.329273,41.965721),49042=>array(-85.672869,41.860358),49043=>array(-86.268503,42.285992),49045=>array(-85.999123,42.102102),49046=>array(-85.400628,42.513086),49047=>array(-86.120963,42.003786),49048=>array(-85.493,42.273752),49050=>array(-85.245704,42.504302),49051=>array(-85.242147,42.184442),49052=>array(-85.321815,42.105747),49053=>array(-85.416755,42.28924),49055=>array(-85.857813,42.368474),49056=>array(-86.056215,42.398286),49057=>array(-86.162944,42.181948),49058=>array(-85.299191,42.63499),49060=>array(-85.38597,42.423536),49061=>array(-85.815243,41.873542),49064=>array(-86.049114,42.220886),49065=>array(-85.842108,42.138273),49066=>array(-85.3415,42.037739),49067=>array(-85.798766,42.024172),49068=>array(-84.939742,42.276445),49070=>array(-85.62939,42.53933),49071=>array(-85.775499,42.226444),49072=>array(-85.460189,42.012051),49073=>array(-85.126192,42.574928),49074=>array(-85.538723,42.317468),49075=>array(-85.448603,41.917513),49076=>array(-84.88033,42.428635),49078=>array(-85.732849,42.47251),49079=>array(-85.908075,42.240155),49080=>array(-85.588337,42.456426),49082=>array(-84.876582,41.941034),49083=>array(-85.461128,42.37811),49084=>array(-86.382059,42.182551),49085=>array(-86.4626,42.054277),49087=>array(-85.700691,42.124219),49088=>array(-85.422562,42.179736),49089=>array(-85.235901,42.005033),49090=>array(-86.214544,42.407427),49091=>array(-85.454617,41.820413),49092=>array(-84.978737,42.098874),49093=>array(-85.649941,41.972875),49094=>array(-85.11357,42.050304),49095=>array(-85.881051,41.907328),49096=>array(-85.021222,42.645178),49097=>array(-85.487442,42.121971),49098=>array(-86.247522,42.163253),49099=>array(-85.671752,41.793262),49101=>array(-86.482677,41.9372),49102=>array(-86.252076,41.949226),49103=>array(-86.376474,41.946299),49104=>array(-86.358972,41.963699),49106=>array(-86.554852,41.937963),49107=>array(-86.417637,41.844909),49111=>array(-86.291132,42.022699),49112=>array(-86.03054,41.796034),49113=>array(-86.503854,41.801056),49115=>array(-86.63452,41.877027),49116=>array(-86.663428,41.853312),49117=>array(-86.726836,41.781671),49119=>array(-86.549249,41.874173),49120=>array(-86.230825,41.832805),49125=>array(-86.579415,41.891897),49126=>array(-86.369374,42.025215),49127=>array(-86.515329,42.011024),49128=>array(-86.600497,41.820406),49129=>array(-86.691068,41.815482),49130=>array(-85.860349,41.774422),49201=>array(-84.297205,42.191346),49202=>array(-84.41085,42.267179),49203=>array(-84.396625,42.221835),49220=>array(-84.338943,41.998783),49221=>array(-84.064698,41.902354),49224=>array(-84.746876,42.279617),49227=>array(-84.772966,41.950018),49228=>array(-83.875598,41.809023),49229=>array(-83.827239,41.987013),49230=>array(-84.217344,42.091609),49232=>array(-84.664597,41.740366),49233=>array(-84.362502,42.061113),49234=>array(-84.368713,42.127037),49235=>array(-84.20092,41.863913),49236=>array(-83.941703,42.075967),49237=>array(-84.65149,42.170452),49238=>array(-83.785596,41.90223),49240=>array(-84.181375,42.283303),49241=>array(-84.603335,42.107843),49242=>array(-84.622698,41.886298),49245=>array(-84.813567,42.139753),49246=>array(-84.512436,42.12779),49247=>array(-84.338208,41.837562),49248=>array(-84.011181,41.756424),49249=>array(-84.454755,42.029334),49250=>array(-84.626242,42.021731),49251=>array(-84.407978,42.466346),49252=>array(-84.765398,42.035237),49253=>array(-84.272771,41.967948),49254=>array(-84.316434,42.227976),49255=>array(-84.84455,41.771201),49256=>array(-84.215626,41.746308),49259=>array(-84.261604,42.374592),49261=>array(-84.236,42.157638),49262=>array(-84.46829,41.963612),49263=>array(-84.184302,42.158902),49264=>array(-84.555061,42.446232),49265=>array(-84.175236,42.006696),49266=>array(-84.546789,41.83975),49267=>array(-83.719429,41.757323),49268=>array(-83.929015,41.868705),49269=>array(-84.593587,42.287158),49270=>array(-83.680783,41.873675),49271=>array(-84.453091,41.831987),49272=>array(-84.348183,42.393651),49274=>array(-84.759784,41.846682),49276=>array(-83.776793,41.794655),49277=>array(-84.469336,42.388652),49279=>array(-84.103949,41.780799),49282=>array(-84.402617,42.034442),49283=>array(-84.550568,42.207352),49284=>array(-84.688297,42.391636),49285=>array(-84.213034,42.476547),49286=>array(-83.936219,42.014858),49287=>array(-84.073485,42.02303),49288=>array(-84.429587,41.733942),49289=>array(-84.107807,41.768075),49301=>array(-85.476998,42.973443),49302=>array(-85.402267,42.821523),49303=>array(-85.860632,43.271549),49304=>array(-85.872637,43.907821),49305=>array(-85.151106,43.752024),49306=>array(-85.565281,43.075016),49307=>array(-85.489194,43.699062),49309=>array(-85.876884,43.759824),49310=>array(-85.047599,43.513858),49312=>array(-85.806059,43.685353),49315=>array(-85.742196,42.803705),49316=>array(-85.550467,42.793767),49318=>array(-85.820431,43.227276),49319=>array(-85.527902,43.230088),49320=>array(-85.275467,43.753585),49321=>array(-85.680339,43.073223),49322=>array(-85.351226,43.355785),49323=>array(-85.790642,42.728548),49325=>array(-85.301726,42.760797),49326=>array(-85.316357,43.24615),49327=>array(-85.845311,43.323527),49328=>array(-85.758168,42.63368),49329=>array(-85.484884,43.406472),49330=>array(-85.736679,43.241536),49331=>array(-85.351518,42.949394),49332=>array(-85.249119,43.623061),49333=>array(-85.461796,42.699457),49335=>array(-85.668451,42.738506),49336=>array(-85.435685,43.508469),49337=>array(-85.712297,43.437082),49338=>array(-85.602264,43.771655),49339=>array(-85.496456,43.331359),49340=>array(-85.110768,43.61793),49341=>array(-85.490928,43.124135),49342=>array(-85.315591,43.690435),49343=>array(-85.535097,43.297213),49344=>array(-85.591301,42.589905),49345=>array(-85.703948,43.15534),49346=>array(-85.421128,43.594885),49347=>array(-85.347044,43.316687),49348=>array(-85.610188,42.685083),49349=>array(-85.748757,43.575359),49401=>array(-85.939287,42.975656),49402=>array(-86.029183,43.933202),49403=>array(-85.857766,43.140975),49404=>array(-85.952185,43.063438),49405=>array(-86.191237,43.914692),49406=>array(-86.202866,42.642345),49408=>array(-86.116236,42.571678),49410=>array(-86.12615,44.032042),49411=>array(-86.251761,44.100414),49412=>array(-85.948247,43.468461),49415=>array(-86.114307,43.150964),49417=>array(-86.156274,43.020291),49418=>array(-85.767881,42.877992),49419=>array(-85.980751,42.679739),49420=>array(-86.282313,43.719985),49421=>array(-86.069388,43.599328),49423=>array(-86.083703,42.743806),49424=>array(-86.134355,42.843818),49425=>array(-86.089288,43.428815),49426=>array(-85.888482,42.861132),49428=>array(-85.838844,42.920205),49431=>array(-86.406481,43.985802),49434=>array(-86.218505,42.769752),49435=>array(-85.83498,43.024459),49436=>array(-86.466113,43.678308),49437=>array(-86.386504,43.46135),49440=>array(-86.254186,43.237691),49441=>array(-86.28538,43.183871),49442=>array(-86.135719,43.241841),49444=>array(-86.199103,43.178683),49445=>array(-86.293883,43.292537),49446=>array(-86.378723,43.551434),49448=>array(-86.0713,43.093947),49449=>array(-86.388578,43.793631),49450=>array(-86.082454,42.484653),49451=>array(-85.967762,43.213069),49452=>array(-86.258425,43.509479),49453=>array(-86.172666,42.659522),49454=>array(-86.285053,43.946332),49455=>array(-86.378251,43.610287),49456=>array(-86.20687,43.089103),49457=>array(-86.146187,43.352735),49458=>array(-86.098545,43.924347),49459=>array(-86.112182,43.741385),49460=>array(-86.145345,42.933162),49461=>array(-86.319255,43.376222),49464=>array(-85.984794,42.844801),49503=>array(-85.659394,42.96212),49504=>array(-85.7107,42.981579),49505=>array(-85.637735,42.996477),49506=>array(-85.613839,42.945748),49507=>array(-85.655173,42.93066),49508=>array(-85.621084,42.87328),49509=>array(-85.692804,42.897707),49512=>array(-85.528081,42.882745),49519=>array(-85.718265,42.895737),49525=>array(-85.592909,43.018307),49534=>array(-85.787181,42.964438),49544=>array(-85.74657,43.038932),49546=>array(-85.535988,42.933092),49548=>array(-85.662605,42.870454),49601=>array(-85.510205,44.245955),49611=>array(-84.974489,44.973683),49612=>array(-85.239456,44.864922),49613=>array(-86.206892,44.50612),49614=>array(-86.114343,44.435034),49615=>array(-85.209069,44.966776),49616=>array(-86.084312,44.577306),49617=>array(-86.031754,44.643232),49618=>array(-85.607626,44.293486),49619=>array(-85.991212,44.293058),49620=>array(-85.691242,44.523532),49621=>array(-85.770301,44.868695),49622=>array(-85.260935,45.07741),49623=>array(-85.692083,43.908924),49625=>array(-85.88303,44.433447),49626=>array(-86.292027,44.239903),49627=>array(-85.344921,45.08436),49628=>array(-86.244403,44.615416),49629=>array(-85.389921,44.919539),49630=>array(-86.009304,44.818252),49631=>array(-85.262924,43.912709),49632=>array(-84.967889,44.239007),49633=>array(-85.206249,44.558702),49634=>array(-86.290297,44.214834),49635=>array(-86.192428,44.617255),49636=>array(-85.963203,44.855494),49637=>array(-85.709787,44.621616),49638=>array(-85.755675,44.286973),49639=>array(-85.408405,43.846997),49640=>array(-86.04869,44.715246),49642=>array(-85.75734,43.869586),49643=>array(-85.828941,44.639739),49644=>array(-85.921281,44.106834),49645=>array(-86.029373,44.362133),49646=>array(-85.055762,44.724482),49648=>array(-85.33633,44.996418),49649=>array(-85.525432,44.563373),49650=>array(-85.887151,44.739836),49651=>array(-85.104789,44.390519),49653=>array(-85.723949,44.973631),49654=>array(-86.051574,45.146182),49655=>array(-85.436941,44.024644),49656=>array(-85.692017,44.067819),49657=>array(-85.169164,44.212501),49659=>array(-85.019333,44.895608),49660=>array(-86.210203,44.22514),49663=>array(-85.390105,44.435322),49664=>array(-85.898651,44.887833),49665=>array(-85.118154,44.095202),49666=>array(-85.554055,44.622029),49667=>array(-84.914644,44.363328),49668=>array(-85.702617,44.405416),49670=>array(-85.647026,45.145456),49674=>array(-85.591522,45.048608),49675=>array(-86.224896,44.38362),49676=>array(-85.289181,44.832183),49677=>array(-85.552744,43.894776),49679=>array(-85.145788,43.875013),49680=>array(-85.262702,44.646003),49682=>array(-85.627013,44.978664),49683=>array(-85.926894,44.540521),49684=>array(-85.703568,44.762335),49686=>array(-85.557845,44.713682),49688=>array(-85.450376,44.117006),49689=>array(-85.902445,44.213228),49690=>array(-85.399401,44.788761),49701=>array(-84.73879,45.772638),49705=>array(-84.460991,45.355095),49706=>array(-84.779353,45.438354),49707=>array(-83.476203,45.094366),49709=>array(-84.144487,45.018684),49710=>array(-84.171031,46.274892),49712=>array(-85.009296,45.209259),49713=>array(-84.842294,45.210934),49715=>array(-84.708184,46.39742),49716=>array(-84.748136,45.517286),49717=>array(-84.691217,45.434968),49718=>array(-84.861522,45.734622),49719=>array(-84.324829,46.005621),49720=>array(-85.245092,45.280496),49721=>array(-84.460476,45.582257),49722=>array(-84.862324,45.427456),49724=>array(-84.390112,46.32764),49725=>array(-84.020784,45.978483),49726=>array(-83.615489,46.002363),49727=>array(-85.105817,45.125273),49728=>array(-85.028468,46.411594),49729=>array(-85.292072,45.166897),49730=>array(-84.867529,45.044034),49733=>array(-84.696639,44.806466),49735=>array(-84.670317,44.997939),49736=>array(-84.075903,46.067629),49738=>array(-84.609421,44.698328),49740=>array(-85.008345,45.524807),49743=>array(-83.893364,45.266958),49744=>array(-83.657097,44.993123),49745=>array(-84.522382,46.03979),49746=>array(-83.954868,45.064388),49747=>array(-83.65314,44.849651),49748=>array(-85.212879,46.374911),49749=>array(-84.567774,45.425744),49751=>array(-84.430167,44.982838),49752=>array(-84.434511,46.254145),49753=>array(-83.777981,45.01915),49755=>array(-84.801026,45.634591),49756=>array(-84.279735,44.824731),49757=>array(-84.62144,45.856211),49759=>array(-84.096086,45.417476),49760=>array(-84.90251,46.04057),49762=>array(-85.337504,46.104713),49764=>array(-84.827403,45.424174),49765=>array(-84.24252,45.328392),49766=>array(-83.432043,44.908297),49768=>array(-85.117026,46.654828),49769=>array(-84.861835,45.57077),49770=>array(-84.897137,45.331217),49774=>array(-84.315258,46.162451),49775=>array(-84.482428,45.775516),49776=>array(-83.680373,45.232202),49777=>array(-83.507135,45.30553),49779=>array(-83.863353,45.407692),49780=>array(-84.728653,46.213013),49781=>array(-84.791142,45.884117),49782=>array(-85.542708,45.674252),49783=>array(-84.289054,46.416901),49788=>array(-84.465049,46.265348),49791=>array(-84.595765,45.486755),49793=>array(-85.063688,46.202918),49795=>array(-84.578935,45.16083),49796=>array(-84.959158,45.262557),49799=>array(-84.580384,45.262297),49801=>array(-87.978445,45.960732),49802=>array(-88.077894,45.80106),49805=>array(-88.351333,47.367298),49806=>array(-86.901161,46.452414),49807=>array(-87.345866,45.771531),49808=>array(-87.846605,46.824795),49812=>array(-87.50312,45.591632),49814=>array(-87.905613,46.565613),49815=>array(-87.96424,46.185396),49816=>array(-86.895309,46.285383),49817=>array(-86.4583,45.96199),49818=>array(-87.349341,45.965215),49819=>array(-87.456296,46.108909),49820=>array(-85.654178,46.190094),49821=>array(-87.631007,45.529658),49822=>array(-87.024586,46.433521),49825=>array(-86.994898,46.346884),49826=>array(-87.052838,46.323306),49827=>array(-85.560604,46.177009),49829=>array(-87.138174,45.763637),49831=>array(-87.866119,46.012823),49833=>array(-87.32764,46.293045),49834=>array(-87.768387,45.945664),49835=>array(-86.562598,45.735775),49836=>array(-85.903573,46.201767),49837=>array(-87.077378,45.867413),49838=>array(-85.736564,46.032474),49839=>array(-86.108426,46.618009),49840=>array(-86.013107,46.095857),49841=>array(-87.465727,46.275163),49847=>array(-87.636201,45.704676),49848=>array(-87.636417,45.378247),49849=>array(-87.756405,46.432711),49852=>array(-87.816777,45.786249),49853=>array(-85.750902,46.368293),49854=>array(-86.304483,46.061609),49855=>array(-87.455319,46.578823),49858=>array(-87.57647,45.218742),49861=>array(-88.243403,46.481564),49862=>array(-86.701876,46.395079),49863=>array(-87.551575,45.613385),49864=>array(-86.672584,45.871476),49866=>array(-87.580782,46.521482),49868=>array(-85.518321,46.51035),49870=>array(-87.878972,45.867228),49871=>array(-87.552178,46.425061),49872=>array(-87.084351,46.021064),49873=>array(-87.578753,45.890463),49874=>array(-87.473942,45.714924),49876=>array(-87.98283,45.80269),49877=>array(-87.705499,46.148036),49878=>array(-86.860412,45.945698),49879=>array(-88.038808,46.358718),49880=>array(-87.222361,46.110988),49881=>array(-88.047262,46.07322),49883=>array(-86.000888,46.431726),49884=>array(-86.32377,46.405214),49885=>array(-87.19832,46.33805),49886=>array(-87.527012,45.739188),49887=>array(-87.550635,45.42934),49891=>array(-87.022529,46.241277),49892=>array(-87.785711,45.818087),49893=>array(-87.605155,45.297038),49894=>array(-87.075139,45.786047),49895=>array(-86.665885,46.165312),49896=>array(-87.389319,45.677575),49901=>array(-88.395376,47.307745),49902=>array(-88.379881,46.043004),49903=>array(-88.445286,46.332624),49905=>array(-88.722062,47.121853),49908=>array(-88.557216,46.768216),49910=>array(-89.609523,46.613001),49911=>array(-90.050345,46.490623),49912=>array(-89.194224,46.496716),49913=>array(-88.458488,47.243192),49915=>array(-88.622018,46.065123),49916=>array(-88.586331,46.9841),49917=>array(-88.359132,47.281359),49918=>array(-87.867327,47.434599),49919=>array(-88.456848,46.486141),49920=>array(-88.295423,46.142545),49921=>array(-88.582649,47.092564),49922=>array(-88.483267,47.100599),49925=>array(-89.374684,46.544419),49927=>array(-88.566239,46.041681),49929=>array(-89.149533,46.781097),49930=>array(-88.539582,47.16483),49931=>array(-88.572787,47.084375),49934=>array(-88.44045,47.174273),49935=>array(-88.752142,46.175626),49938=>array(-90.131856,46.584324),49942=>array(-88.408098,47.274975),49945=>array(-88.317268,47.183187),49946=>array(-88.321592,46.720894),49947=>array(-89.616356,46.385417),49948=>array(-89.020015,46.711175),49950=>array(-88.133198,47.386209),49952=>array(-88.785769,46.70225),49953=>array(-89.371849,46.803804),49955=>array(-88.694561,47.006492),49958=>array(-88.668431,46.828387),49959=>array(-89.998383,46.470636),49960=>array(-89.258371,46.711853),49961=>array(-88.73263,46.522677),49962=>array(-88.131113,46.839281),49963=>array(-88.689132,47.041467),49965=>array(-88.857655,46.954515),49967=>array(-88.966045,46.506028),49968=>array(-89.887207,46.490267),49969=>array(-89.210723,46.251655),49970=>array(-88.600365,46.547419),49971=>array(-89.705285,46.70924),50001=>array(-93.433418,41.362724),50002=>array(-94.648341,41.514778),50003=>array(-94.043026,41.611504),50005=>array(-93.034602,42.131988),50006=>array(-93.401924,42.508362),50007=>array(-93.602008,41.806814),50008=>array(-93.380265,40.679672),50009=>array(-93.45909,41.645012),50010=>array(-93.58849,42.030822),50011=>array(-93.636451,42.024034),50012=>array(-93.645873,42.026751),50014=>array(-93.694448,42.046297),50020=>array(-94.747041,41.438416),50021=>array(-93.565423,41.724208),50022=>array(-94.996266,41.414337),50023=>array(-93.631857,41.731286),50025=>array(-94.923571,41.757959),50026=>array(-94.44958,41.858516),50027=>array(-92.469368,41.482026),50028=>array(-93.153672,41.812016),50029=>array(-94.555933,41.828956),50032=>array(-93.542387,41.666521),50033=>array(-93.792843,41.363038),50034=>array(-93.661406,42.521662),50035=>array(-93.458076,41.723913),50036=>array(-93.864204,42.085554),50038=>array(-93.903282,41.525073),50039=>array(-93.996778,41.814205),50041=>array(-93.248148,42.638454),50042=>array(-94.905323,41.533745),50044=>array(-92.881898,41.203094),50046=>array(-93.523012,41.893405),50047=>array(-93.47428,41.463639),50048=>array(-94.520058,41.512457),50049=>array(-93.295407,41.034517),50050=>array(-94.503593,42.158973),50051=>array(-93.141399,42.135392),50052=>array(-93.444379,40.64326),50054=>array(-93.231856,41.689643),50055=>array(-93.296135,41.878681),50056=>array(-93.296527,42.013198),50057=>array(-93.134256,41.179914),50058=>array(-94.690994,41.85571),50060=>array(-93.31886,40.751408),50061=>array(-93.784889,41.485929),50062=>array(-93.245092,41.235597),50063=>array(-93.940678,41.695549),50064=>array(-94.23663,42.107729),50065=>array(-93.781727,40.613858),50066=>array(-94.233396,41.798081),50067=>array(-93.861649,40.717682),50068=>array(-93.466254,40.948073),50069=>array(-94.030262,41.520765),50070=>array(-94.232632,41.445537),50071=>array(-93.504898,42.64862),50072=>array(-94.122983,41.471219),50073=>array(-93.525213,41.793831),50074=>array(-94.080133,40.865931),50075=>array(-93.550631,42.332139),50076=>array(-94.841945,41.592177),50078=>array(-92.863031,41.93858),50101=>array(-93.634644,42.667352),50102=>array(-93.400194,42.245542),50103=>array(-93.609144,40.79512),50104=>array(-92.386662,41.486799),50105=>array(-93.637284,42.110285),50106=>array(-92.806239,41.880956),50107=>array(-94.219069,42.036533),50108=>array(-93.95266,40.825643),50109=>array(-93.800631,41.77088),50111=>array(-93.805376,41.692119),50112=>array(-92.715438,41.730093),50115=>array(-94.561556,41.68324),50116=>array(-92.97361,41.179772),50117=>array(-94.849235,41.669871),50118=>array(-93.378981,41.466968),50119=>array(-92.939687,41.313093),50120=>array(-92.982857,41.933734),50122=>array(-93.311807,42.305362),50123=>array(-93.513815,40.833825),50124=>array(-93.604073,41.885672),50125=>array(-93.584634,41.335185),50126=>array(-93.2554,42.494379),50127=>array(-93.205809,41.77714),50128=>array(-94.300236,41.855589),50129=>array(-94.376743,42.014771),50130=>array(-93.669264,42.303387),50131=>array(-93.715156,41.69212),50132=>array(-93.69153,42.391673),50133=>array(-94.068993,40.713322),50134=>array(-93.671998,41.939484),50135=>array(-92.887174,41.750582),50136=>array(-92.292764,41.469501),50138=>array(-93.105185,41.300589),50139=>array(-93.369878,41.198463),50140=>array(-93.986274,40.64552),50141=>array(-92.949711,41.867559),50142=>array(-92.775596,42.006616),50143=>array(-92.804656,41.341836),50144=>array(-93.7408,40.73905),50146=>array(-94.243044,41.684117),50147=>array(-93.553727,40.629263),50148=>array(-92.992825,42.181305),50149=>array(-94.070997,41.150466),50150=>array(-92.975192,41.125508),50151=>array(-93.51779,41.081907),50153=>array(-92.807021,41.573896),50154=>array(-93.39278,42.172261),50155=>array(-94.199353,41.211018),50156=>array(-93.801235,41.89831),50157=>array(-92.563011,41.739767),50158=>array(-92.900739,42.049806),50160=>array(-93.738489,41.373789),50161=>array(-93.40403,41.84815),50162=>array(-93.072173,41.928297),50163=>array(-93.241035,41.222388),50164=>array(-94.420213,41.499518),50165=>array(-93.283695,40.843661),50166=>array(-93.430749,41.282712),50167=>array(-94.041048,41.742883),50168=>array(-93.278546,41.788361),50169=>array(-93.35232,41.655266),50170=>array(-93.124762,41.530027),50171=>array(-92.525413,41.585852),50173=>array(-92.713485,41.964659),50174=>array(-93.982304,41.033707),50201=>array(-93.434905,42.041723),50206=>array(-93.202318,42.245675),50207=>array(-92.63754,41.431966),50208=>array(-93.033958,41.711721),50210=>array(-93.698287,41.195043),50211=>array(-93.705269,41.455311),50212=>array(-94.066162,42.036562),50213=>array(-93.766137,41.031685),50214=>array(-93.05611,41.469931),50216=>array(-94.354821,41.697097),50217=>array(-94.251811,42.183763),50218=>array(-93.880405,41.348354),50219=>array(-92.896537,41.420905),50220=>array(-94.123202,41.836907),50222=>array(-93.959608,41.215845),50223=>array(-94.03783,42.173715),50225=>array(-93.268859,41.384401),50226=>array(-93.701973,41.796243),50227=>array(-93.427851,42.597441),50228=>array(-93.24196,41.576968),50229=>array(-93.775073,41.379081),50230=>array(-93.453415,42.303252),50231=>array(-93.602632,42.237123),50232=>array(-92.96972,41.556725),50233=>array(-94.21137,41.612883),50234=>array(-93.181982,41.893096),50235=>array(-94.224981,41.931777),50236=>array(-93.486487,42.16811),50237=>array(-93.368536,41.533906),50238=>array(-93.167151,40.964291),50239=>array(-93.202958,42.142843),50240=>array(-93.792788,41.29709),50242=>array(-92.693756,41.561039),50243=>array(-93.696442,41.872429),50244=>array(-93.652619,41.857528),50246=>array(-93.786105,42.274581),50247=>array(-93.164603,42.017436),50248=>array(-93.614673,42.191226),50249=>array(-93.903082,42.275327),50250=>array(-94.34641,41.480626),50251=>array(-92.869363,41.56694),50252=>array(-93.303447,41.466282),50254=>array(-94.07424,40.98752),50255=>array(-92.332273,41.455895),50256=>array(-92.905272,41.259706),50257=>array(-93.84723,41.189507),50258=>array(-93.073131,42.224136),50261=>array(-93.915872,41.475063),50262=>array(-93.808561,40.860632),50263=>array(-93.873639,41.59158),50264=>array(-93.697536,40.905654),50265=>array(-93.745011,41.552968),50266=>array(-93.799418,41.570341),50268=>array(-92.362787,41.404406),50271=>array(-93.541442,42.482752),50272=>array(-93.255936,41.095928),50273=>array(-94.054307,41.329691),50274=>array(-94.860975,41.383348),50275=>array(-93.589602,41.037536),50276=>array(-93.926489,41.862012),50277=>array(-94.350576,41.779785),50278=>array(-93.299533,42.136759),50309=>array(-93.620778,41.58445),50310=>array(-93.67266,41.627582),50311=>array(-93.672868,41.601033),50312=>array(-93.67667,41.582678),50313=>array(-93.62418,41.654477),50314=>array(-93.6312,41.604964),50315=>array(-93.622124,41.545918),50316=>array(-93.599579,41.608629),50317=>array(-93.547893,41.621347),50319=>array(-93.604288,41.590912),50320=>array(-93.567967,41.527942),50321=>array(-93.662499,41.532674),50322=>array(-93.73436,41.634164),50323=>array(-93.79365,41.625632),50324=>array(-93.712847,41.604413),50325=>array(-93.797871,41.613243),50327=>array(-93.487874,41.586324),50401=>array(-93.19982,43.153169),50420=>array(-93.460421,42.804156),50421=>array(-93.618635,42.842866),50423=>array(-93.814465,43.118224),50424=>array(-93.933846,43.39443),50426=>array(-93.017133,43.415481),50428=>array(-93.397107,43.136933),50430=>array(-93.953966,42.981564),50431=>array(-93.368223,42.737113),50432=>array(-93.797954,43.223915),50433=>array(-93.050183,42.923242),50434=>array(-93.448583,43.257488),50435=>array(-92.767049,43.158039),50436=>array(-93.671118,43.266463),50438=>array(-93.618624,43.111502),50439=>array(-93.626339,42.944717),50440=>array(-93.071258,43.333341),50441=>array(-93.220973,42.74134),50444=>array(-93.38363,43.297226),50446=>array(-93.446907,43.340739),50447=>array(-93.797708,42.9254),50448=>array(-93.240534,43.349938),50449=>array(-93.566898,43.002487),50450=>array(-93.522397,43.421178),50451=>array(-94.077615,43.381234),50452=>array(-93.367352,42.781099),50453=>array(-93.64742,43.363364),50454=>array(-92.737275,43.381889),50455=>array(-92.649842,43.456954),50456=>array(-93.216135,43.291329),50457=>array(-93.493608,42.916337),50458=>array(-93.012018,43.158733),50459=>array(-93.250439,43.457425),50460=>array(-92.688793,43.227851),50461=>array(-92.818741,43.306168),50464=>array(-93.080785,43.2534),50465=>array(-93.912229,43.48655),50466=>array(-92.538439,43.386853),50467=>array(-93.086636,43.21173),50468=>array(-92.947124,43.032213),50469=>array(-93.197099,42.999327),50470=>array(-93.560406,42.74578),50471=>array(-92.876407,43.166568),50472=>array(-92.935316,43.406746),50473=>array(-93.687767,43.465739),50475=>array(-93.218757,42.880553),50476=>array(-92.764051,43.446805),50477=>array(-93.327093,42.989247),50478=>array(-93.783601,43.407488),50479=>array(-93.409874,42.939404),50480=>array(-94.058607,43.250367),50482=>array(-93.486404,43.113101),50483=>array(-94.000915,43.112564),50484=>array(-93.915585,43.230771),50501=>array(-94.196626,42.491431),50510=>array(-94.985603,42.759296),50511=>array(-94.219184,43.074041),50514=>array(-94.47241,43.415156),50515=>array(-94.863371,43.022217),50516=>array(-94.137234,42.625007),50517=>array(-94.234205,43.30525),50518=>array(-94.386021,42.514912),50519=>array(-94.262889,42.901704),50520=>array(-94.397929,42.80919),50521=>array(-94.102821,42.346223),50522=>array(-94.194683,43.192019),50523=>array(-94.295734,42.367994),50524=>array(-94.353838,42.616853),50525=>array(-93.747437,42.736497),50527=>array(-94.785417,42.96499),50528=>array(-94.540831,43.133889),50529=>array(-94.198795,42.720898),50530=>array(-94.039695,42.270706),50531=>array(-94.609753,43.454085),50532=>array(-94.000869,42.460118),50533=>array(-93.911823,42.651928),50535=>array(-95.162489,42.453186),50536=>array(-94.705481,43.118262),50538=>array(-94.439703,42.274049),50539=>array(-94.419983,43.236961),50540=>array(-94.840146,42.600572),50541=>array(-94.452387,42.710228),50542=>array(-93.942692,42.782976),50543=>array(-94.30464,42.274696),50544=>array(-94.170545,42.250727),50545=>array(-94.080863,42.797396),50546=>array(-94.702202,42.83769),50548=>array(-94.225325,42.714769),50551=>array(-94.751117,42.479577),50554=>array(-94.84269,42.845984),50556=>array(-94.196646,43.45522),50557=>array(-94.043735,42.360802),50558=>array(-94.16377,42.861277),50559=>array(-94.329243,43.208819),50560=>array(-94.107825,42.960487),50561=>array(-94.850501,42.425099),50562=>array(-94.641788,42.961532),50563=>array(-94.524964,42.527831),50565=>array(-95.00102,42.857089),50566=>array(-94.323652,42.43777),50567=>array(-95.101883,42.525449),50568=>array(-94.984009,42.62605),50569=>array(-94.134237,42.403206),50570=>array(-94.37302,42.896101),50571=>array(-94.578693,42.630964),50573=>array(-94.623824,42.876758),50574=>array(-94.69865,42.71667),50575=>array(-94.700491,42.560344),50576=>array(-95.175275,42.803272),50577=>array(-93.977004,42.858665),50578=>array(-94.549559,43.306502),50579=>array(-94.638758,42.39431),50581=>array(-94.549778,42.842996),50582=>array(-94.295665,42.793838),50583=>array(-94.985692,42.432718),50585=>array(-95.141865,42.91753),50586=>array(-94.42556,42.41186),50588=>array(-95.166279,42.658692),50590=>array(-94.314879,43.407059),50591=>array(-94.055674,42.676032),50593=>array(-94.898808,42.657197),50594=>array(-94.040129,42.585196),50595=>array(-93.822578,42.461417),50597=>array(-94.451731,42.97525),50598=>array(-94.417046,43.081849),50599=>array(-93.823217,42.579322),50601=>array(-93.060058,42.567768),50602=>array(-92.805745,42.741405),50603=>array(-92.459489,43.187727),50604=>array(-92.896477,42.601831),50605=>array(-93.020977,42.831759),50606=>array(-91.691307,42.747316),50607=>array(-91.749864,42.61055),50609=>array(-92.809466,42.228377),50611=>array(-92.908954,42.815489),50612=>array(-92.386045,42.283447),50613=>array(-92.487461,42.531814),50616=>array(-92.65848,43.08043),50619=>array(-92.658224,42.809681),50620=>array(-92.590545,43.158425),50621=>array(-92.921016,42.251109),50622=>array(-92.335907,42.672712),50624=>array(-92.658727,42.467825),50625=>array(-92.988356,42.748385),50626=>array(-92.175533,42.587047),50627=>array(-93.093896,42.350393),50628=>array(-92.394046,43.27271),50629=>array(-92.071537,42.648669),50630=>array(-92.213959,42.95768),50632=>array(-92.699352,42.0616),50633=>array(-93.128182,42.671799),50634=>array(-92.214,42.418675),50635=>array(-92.699322,42.202061),50636=>array(-92.809048,42.895005),50638=>array(-92.793955,42.35674),50641=>array(-91.920033,42.60655),50642=>array(-92.816454,42.439697),50643=>array(-92.464199,42.357927),50644=>array(-91.893691,42.476151),50645=>array(-92.443649,43.019546),50647=>array(-92.497212,42.651075),50648=>array(-92.09323,42.453205),50650=>array(-91.65604,42.618248),50651=>array(-92.19674,42.317063),50652=>array(-92.69376,42.264292),50653=>array(-92.885717,42.968595),50654=>array(-91.64283,42.498698),50655=>array(-91.891692,42.76558),50658=>array(-92.542513,42.962781),50659=>array(-92.329051,43.095838),50660=>array(-92.631544,42.583567),50662=>array(-91.937486,42.688662),50664=>array(-92.076193,42.701249),50665=>array(-92.771879,42.580364),50666=>array(-92.520111,42.870966),50667=>array(-92.226415,42.470225),50668=>array(-92.228831,42.692906),50669=>array(-92.602549,42.343457),50670=>array(-92.618753,42.695374),50671=>array(-91.795819,42.650429),50672=>array(-93.071694,42.426286),50673=>array(-92.711273,42.524945),50674=>array(-92.11543,42.837805),50675=>array(-92.512092,42.19782),50676=>array(-92.28018,42.798899),50677=>array(-92.429682,42.766784),50680=>array(-92.923037,42.452094),50681=>array(-92.009382,42.777619),50682=>array(-91.688578,42.452643),50701=>array(-92.339821,42.418259),50702=>array(-92.312205,42.457713),50703=>array(-92.286431,42.548059),50707=>array(-92.260032,42.458164),50801=>array(-94.402219,41.078573),50830=>array(-94.191097,41.027101),50833=>array(-94.700888,40.670545),50835=>array(-94.375485,40.706299),50836=>array(-94.497484,40.632285),50837=>array(-94.692446,41.224703),50839=>array(-94.824003,41.049661),50840=>array(-94.480948,40.781959),50841=>array(-94.768812,41.009072),50842=>array(-94.461833,41.039887),50843=>array(-94.885233,41.236842),50845=>array(-94.349675,40.821491),50846=>array(-94.576117,41.308993),50847=>array(-94.982358,41.140563),50848=>array(-94.764274,40.780922),50849=>array(-94.38657,41.308278),50851=>array(-94.537032,40.908584),50853=>array(-94.767896,41.236843),50854=>array(-94.21277,40.679375),50857=>array(-94.880965,40.942592),50858=>array(-94.409669,41.221263),50859=>array(-94.597342,41.067099),50860=>array(-94.347944,40.617459),50861=>array(-94.255922,40.908431),50862=>array(-94.657541,40.811094),50863=>array(-94.175734,40.847781),50864=>array(-94.978111,40.97037),51001=>array(-96.527233,42.829942),51002=>array(-95.319027,42.688436),51003=>array(-95.987541,42.989939),51004=>array(-95.915342,42.374863),51005=>array(-95.418791,42.723603),51006=>array(-95.619612,42.320792),51007=>array(-96.187064,42.403949),51008=>array(-96.266831,42.810891),51009=>array(-95.551533,42.944357),51010=>array(-95.909504,42.086146),51011=>array(-96.514451,42.916316),51012=>array(-95.561849,42.744137),51014=>array(-95.707313,42.78764),51016=>array(-95.804645,42.471641),51018=>array(-95.680771,42.449661),51019=>array(-95.735667,42.274679),51020=>array(-95.413547,42.510109),51022=>array(-95.850025,42.976982),51023=>array(-96.460404,43.018658),51024=>array(-96.262983,42.612142),51025=>array(-95.556107,42.497646),51026=>array(-96.068143,42.255339),51027=>array(-96.322232,42.960313),51028=>array(-95.98764,42.596655),51029=>array(-95.537847,42.880551),51030=>array(-96.188321,42.497741),51031=>array(-96.186217,42.798547),51033=>array(-95.251445,42.912628),51034=>array(-95.78962,42.160754),51035=>array(-95.799368,42.778851),51036=>array(-96.189483,42.96972),51037=>array(-95.643137,42.826671),51038=>array(-96.316957,42.703191),51039=>array(-96.04956,42.449218),51040=>array(-96.087049,42.036236),51041=>array(-96.077888,43.026058),51044=>array(-95.922873,42.307816),51046=>array(-95.67802,42.961834),51047=>array(-95.369628,42.942464),51048=>array(-95.84131,42.550952),51049=>array(-95.648112,42.629277),51050=>array(-95.945925,42.793616),51051=>array(-95.96496,42.206091),51052=>array(-96.265987,42.308234),51053=>array(-95.286528,42.495017),51054=>array(-96.316111,42.380126),51055=>array(-96.261066,42.221916),51056=>array(-95.956396,42.241293),51058=>array(-95.467315,42.973945),51060=>array(-95.684871,42.042032),51061=>array(-95.718471,42.580726),51062=>array(-96.534968,42.697827),51063=>array(-96.168318,42.139159),51101=>array(-96.394184,42.493688),51103=>array(-96.439937,42.517086),51104=>array(-96.40468,42.536156),51105=>array(-96.352027,42.511913),51106=>array(-96.321505,42.463396),51108=>array(-96.352653,42.566032),51109=>array(-96.474433,42.580113),51111=>array(-96.393103,42.4185),51201=>array(-95.866091,43.17783),51230=>array(-96.323632,43.36033),51231=>array(-95.742199,43.103129),51232=>array(-95.812663,43.308625),51234=>array(-96.019335,43.192205),51235=>array(-96.218369,43.294539),51237=>array(-96.000764,43.336066),51238=>array(-95.892733,43.074351),51239=>array(-96.147481,43.203917),51240=>array(-96.458419,43.309361),51241=>array(-96.46175,43.451232),51242=>array(-96.334849,43.441109),51243=>array(-95.910459,43.43974),51244=>array(-95.935555,43.244772),51245=>array(-95.599948,43.074701),51246=>array(-96.168221,43.427915),51247=>array(-96.338127,43.193752),51248=>array(-95.657879,43.20554),51249=>array(-95.726614,43.411232),51250=>array(-96.205811,43.090933),51301=>array(-95.147654,43.15317),51331=>array(-95.127454,43.361009),51333=>array(-94.999532,43.129346),51334=>array(-94.805056,43.404109),51338=>array(-95.31875,43.205366),51341=>array(-95.038748,43.014277),51342=>array(-94.73688,43.247877),51343=>array(-95.106025,43.01851),51345=>array(-95.437473,43.407697),51346=>array(-95.459451,43.180463),51347=>array(-95.318451,43.422425),51350=>array(-95.600833,43.310963),51351=>array(-95.183646,43.315064),51354=>array(-95.541292,43.410837),51355=>array(-95.136693,43.388177),51357=>array(-95.280617,43.060773),51358=>array(-94.899551,43.131532),51360=>array(-95.08703,43.443563),51363=>array(-94.946743,43.433689),51364=>array(-94.965445,43.299552),51365=>array(-94.732527,43.305173),51366=>array(-95.002954,42.960703),51401=>array(-94.86966,42.065661),51430=>array(-95.024722,42.082258),51431=>array(-95.351693,42.344843),51433=>array(-94.875334,42.266641),51436=>array(-95.023602,42.188265),51439=>array(-95.590386,42.088789),51440=>array(-94.812977,41.913329),51441=>array(-95.315427,42.113305),51442=>array(-95.360635,42.027498),51443=>array(-94.696842,42.081884),51444=>array(-94.973118,42.004839),51445=>array(-95.462213,42.321415),51446=>array(-95.191827,41.775094),51447=>array(-95.195981,41.722094),51448=>array(-95.309789,42.205359),51449=>array(-94.734406,42.267823),51450=>array(-95.0208,42.316462),51451=>array(-94.695158,42.18408),51453=>array(-94.547338,42.269723),51454=>array(-95.202731,41.871279),51455=>array(-95.055142,41.911565),51458=>array(-95.235307,42.326374),51459=>array(-94.637957,42.045221),51461=>array(-95.485343,42.176158),51462=>array(-94.556522,42.014377),51463=>array(-94.912733,41.907466),51465=>array(-95.200725,42.086886),51466=>array(-95.106732,42.257168),51467=>array(-95.117995,42.07266),51501=>array(-95.878439,41.227277),51503=>array(-95.784458,41.223238),51510=>array(-95.916872,41.288533),51520=>array(-95.46143,41.969542),51521=>array(-95.345378,41.486094),51523=>array(-96.06771,41.915211),51525=>array(-95.416372,41.23377),51526=>array(-95.871784,41.37389),51527=>array(-95.336362,41.840075),51528=>array(-95.501099,41.909086),51529=>array(-95.643463,41.860476),51530=>array(-95.430485,41.787452),51531=>array(-95.087216,41.588685),51532=>array(-95.109116,41.137981),51533=>array(-95.378172,41.039454),51534=>array(-95.714689,41.046626),51535=>array(-95.126689,41.226455),51536=>array(-95.358715,41.386894),51537=>array(-95.297511,41.650131),51540=>array(-95.498872,41.024264),51541=>array(-95.415922,41.139051),51542=>array(-95.849085,41.431517),51543=>array(-95.075931,41.656752),51544=>array(-95.114074,41.306434),51545=>array(-96.030113,41.844316),51546=>array(-95.766018,41.637054),51548=>array(-95.636978,41.317852),51549=>array(-95.466707,41.18583),51550=>array(-95.874194,41.692141),51551=>array(-95.587501,40.99082),51552=>array(-95.113519,41.490756),51553=>array(-95.54616,41.42445),51554=>array(-95.681849,41.147388),51555=>array(-95.923061,41.560102),51556=>array(-96.029262,41.641709),51557=>array(-95.997557,41.731738),51558=>array(-95.870563,41.90169),51559=>array(-95.648897,41.46633),51560=>array(-95.399855,41.315294),51561=>array(-95.80619,41.00789),51562=>array(-95.49332,41.725074),51563=>array(-95.585585,41.570675),51564=>array(-95.922824,41.809589),51565=>array(-95.524429,41.642949),51566=>array(-95.230901,41.016459),51570=>array(-95.462569,41.526884),51571=>array(-95.606141,41.136915),51572=>array(-95.784281,41.993144),51573=>array(-95.097052,40.979559),51575=>array(-95.602215,41.24019),51576=>array(-95.714924,41.382876),51577=>array(-95.203768,41.463613),51578=>array(-95.394557,41.719356),51579=>array(-95.706999,41.753577),51601=>array(-95.349564,40.726129),51630=>array(-95.191336,40.601019),51631=>array(-95.009999,40.591418),51632=>array(-95.049325,40.744991),51636=>array(-95.232559,40.667282),51637=>array(-95.115683,40.62486),51638=>array(-95.279939,40.836198),51639=>array(-95.466403,40.720122),51640=>array(-95.656223,40.623488),51645=>array(-95.432524,40.881893),51646=>array(-94.874449,40.747685),51647=>array(-95.319718,40.608873),51648=>array(-95.800397,40.739475),51649=>array(-95.527041,40.850406),51650=>array(-95.542483,40.666385),51652=>array(-95.622069,40.772947),51653=>array(-95.6823,40.878153),51654=>array(-95.778511,40.836097),51656=>array(-95.156343,40.734708),52001=>array(-90.6963,42.545412),52002=>array(-90.773204,42.524769),52003=>array(-90.669682,42.430701),52030=>array(-90.591931,42.153216),52031=>array(-90.486421,42.252564),52032=>array(-90.839534,42.289646),52033=>array(-91.001257,42.279038),52035=>array(-91.181213,42.670738),52037=>array(-90.633754,41.96724),52038=>array(-91.561483,42.586693),52039=>array(-90.860958,42.539142),52040=>array(-91.141684,42.503666),52041=>array(-91.261385,42.505553),52042=>array(-91.357515,42.698093),52043=>array(-91.419204,42.845214),52044=>array(-91.323506,42.769019),52045=>array(-90.937541,42.460825),52046=>array(-91.013117,42.438363),52047=>array(-91.34182,42.969264),52048=>array(-91.257204,42.742126),52049=>array(-91.199378,42.885565),52050=>array(-91.3299,42.604314),52052=>array(-91.116701,42.742443),52053=>array(-90.96105,42.61115),52054=>array(-90.627254,42.305645),52057=>array(-91.455885,42.489481),52060=>array(-90.682701,42.106231),52064=>array(-90.310826,42.093574),52065=>array(-91.108655,42.593678),52066=>array(-90.951844,42.678326),52068=>array(-90.817156,42.422866),52069=>array(-90.442323,42.063596),52070=>array(-90.231402,42.079799),52072=>array(-91.377806,42.922014),52073=>array(-90.828961,42.621132),52074=>array(-90.462697,42.110569),52076=>array(-91.51015,42.69982),52077=>array(-91.562518,42.820999),52078=>array(-91.115821,42.395777),52079=>array(-90.716248,42.285554),52101=>array(-91.76605,43.35361),52132=>array(-91.928146,43.211156),52133=>array(-91.667957,43.110144),52134=>array(-92.411225,43.469554),52135=>array(-91.663225,43.015824),52136=>array(-92.111673,43.374077),52140=>array(-91.534572,43.445644),52141=>array(-91.640018,42.936424),52142=>array(-91.796851,42.824817),52144=>array(-91.962362,43.139152),52146=>array(-91.205673,43.176199),52147=>array(-91.959586,42.95985),52151=>array(-91.264794,43.346405),52154=>array(-92.166877,43.118625),52155=>array(-92.288542,43.421657),52156=>array(-91.462345,43.052512),52157=>array(-91.240309,43.021895),52158=>array(-91.182403,43.043947),52159=>array(-91.362689,43.078888),52160=>array(-91.351712,43.459653),52161=>array(-91.757125,43.12953),52162=>array(-91.551579,43.107578),52163=>array(-92.103094,43.219766),52164=>array(-91.906611,42.854706),52165=>array(-91.994487,43.309674),52166=>array(-91.93329,43.065843),52168=>array(-91.952364,43.205482),52169=>array(-91.663085,42.860729),52170=>array(-91.305191,43.223874),52171=>array(-92.052911,43.068178),52172=>array(-91.484427,43.270781),52175=>array(-91.825624,42.993945),52201=>array(-91.547062,41.32966),52202=>array(-91.63844,42.159496),52203=>array(-91.89159,41.813857),52205=>array(-91.286294,42.119767),52206=>array(-91.885466,41.99158),52207=>array(-90.831678,42.095059),52208=>array(-92.253128,41.882402),52209=>array(-92.097531,41.908987),52210=>array(-92.001362,42.335824),52211=>array(-92.449753,41.75389),52212=>array(-91.090273,42.108797),52213=>array(-91.759632,42.201852),52214=>array(-91.509266,42.187872),52215=>array(-92.405288,41.913527),52216=>array(-91.039637,41.886489),52217=>array(-92.407882,42.079987),52218=>array(-91.533585,42.290268),52219=>array(-91.425836,42.237735),52220=>array(-91.998369,41.728234),52221=>array(-92.331699,41.640929),52222=>array(-92.34065,41.576405),52223=>array(-91.324368,42.41258),52224=>array(-92.299761,42.165911),52225=>array(-92.326845,42.010822),52227=>array(-91.568527,41.894468),52228=>array(-91.788702,41.90229),52229=>array(-92.169234,42.144629),52231=>array(-92.059127,41.361656),52232=>array(-92.335802,41.80436),52233=>array(-91.686869,42.04677),52235=>array(-91.531599,41.578686),52236=>array(-91.876568,41.733573),52237=>array(-91.248693,42.344382),52240=>array(-91.49905,41.634209),52241=>array(-91.595951,41.699578),52242=>array(-91.548347,41.661777),52245=>array(-91.512158,41.672865),52246=>array(-91.570407,41.652313),52247=>array(-91.72329,41.518674),52248=>array(-91.935346,41.345772),52249=>array(-92.205426,42.014152),52251=>array(-92.20171,41.712393),52253=>array(-91.353372,41.895347),52254=>array(-90.801178,41.952101),52255=>array(-90.961247,41.863617),52257=>array(-92.178222,41.920953),52301=>array(-92.082678,41.788476),52302=>array(-91.560548,42.065358),52305=>array(-91.339225,42.019197),52306=>array(-91.254211,41.887089),52307=>array(-91.898692,41.793107),52308=>array(-92.158723,41.572284),52309=>array(-90.888642,42.131684),52310=>array(-91.195253,42.220416),52312=>array(-91.245872,42.006028),52313=>array(-92.096977,42.257377),52314=>array(-91.447684,41.935363),52315=>array(-91.970072,42.000913),52316=>array(-92.09557,41.546634),52317=>array(-91.634505,41.767125),52318=>array(-91.89273,41.88928),52320=>array(-91.148391,41.99915),52321=>array(-90.983232,42.147228),52322=>array(-91.762785,41.692718),52323=>array(-90.959184,41.983221),52324=>array(-91.806141,42.063907),52325=>array(-91.92452,41.584245),52326=>array(-91.755826,42.390661),52327=>array(-91.582988,41.47708),52328=>array(-91.666091,42.071601),52329=>array(-91.855634,42.35824),52330=>array(-91.500496,42.349445),52332=>array(-91.888293,42.098613),52333=>array(-91.492386,41.805879),52334=>array(-91.941103,41.74017),52335=>array(-92.053796,41.467961),52336=>array(-91.432362,42.070516),52337=>array(-91.142058,41.880203),52338=>array(-91.707501,41.8179),52339=>array(-92.587091,41.927944),52340=>array(-91.676825,41.705633),52341=>array(-91.726175,42.102851),52342=>array(-92.547483,42.057671),52345=>array(-91.900894,42.244652),52346=>array(-92.080653,42.010028),52347=>array(-92.284493,41.71254),52348=>array(-92.381481,41.990137),52349=>array(-92.00963,42.173246),52351=>array(-91.831726,41.877931),52352=>array(-91.774837,42.288221),52353=>array(-91.711487,41.299352),52354=>array(-91.987759,41.915981),52355=>array(-92.191832,41.460617),52356=>array(-91.845146,41.473717),52358=>array(-91.318432,41.6914),52359=>array(-91.807482,41.358506),52361=>array(-92.02988,41.649114),52362=>array(-90.983415,42.078991),52401=>array(-91.659172,41.975486),52402=>array(-91.659613,42.023172),52403=>array(-91.566054,41.965959),52404=>array(-91.698866,41.923056),52405=>array(-91.746369,41.983384),52411=>array(-91.729225,42.053802),52501=>array(-92.43137,41.035705),52530=>array(-92.292791,40.99343),52531=>array(-92.815135,41.026364),52533=>array(-92.157116,41.017538),52534=>array(-92.68193,41.271952),52535=>array(-91.959572,40.862944),52536=>array(-92.60891,40.957466),52537=>array(-92.413618,40.734988),52540=>array(-91.821579,41.156205),52542=>array(-92.056237,40.61985),52543=>array(-92.512669,41.201977),52544=>array(-92.912272,40.706642),52548=>array(-92.532981,41.085835),52549=>array(-92.943113,40.618642),52550=>array(-92.355076,41.31031),52551=>array(-92.109395,40.824773),52552=>array(-92.548748,40.827093),52553=>array(-92.654929,41.148432),52554=>array(-92.227456,40.925477),52555=>array(-92.813698,40.64368),52556=>array(-91.927545,41.0242),52557=>array(-91.964773,41.022148),52560=>array(-92.251368,40.850522),52561=>array(-92.452262,41.220285),52563=>array(-92.279307,41.169513),52565=>array(-91.934492,40.742079),52566=>array(-92.502542,41.147999),52567=>array(-92.077955,40.930193),52569=>array(-93.045561,40.983043),52570=>array(-92.146225,40.687411),52571=>array(-92.84061,40.882043),52572=>array(-92.688437,40.67049),52573=>array(-91.928849,40.627569),52574=>array(-92.971787,40.806698),52576=>array(-92.109419,41.215153),52577=>array(-92.661641,41.272983),52580=>array(-92.090331,41.105218),52581=>array(-93.063949,40.80122),52583=>array(-93.148924,40.793886),52584=>array(-92.248193,40.63767),52585=>array(-91.981001,41.193215),52586=>array(-92.467591,41.345609),52588=>array(-92.170367,40.865116),52590=>array(-93.124967,40.660221),52591=>array(-92.191374,41.316641),52593=>array(-92.746226,40.772293),52594=>array(-92.650985,40.835894),52595=>array(-92.614973,41.28863),52601=>array(-91.129717,40.85605),52619=>array(-91.563933,40.525221),52620=>array(-91.797219,40.697841),52621=>array(-91.533457,41.20875),52623=>array(-91.335673,40.863483),52624=>array(-91.337723,40.736419),52625=>array(-91.574196,40.660782),52626=>array(-91.724296,40.623515),52627=>array(-91.357584,40.68206),52630=>array(-91.711455,40.798743),52632=>array(-91.437343,40.432528),52635=>array(-91.758587,40.995562),52637=>array(-91.145949,41.017544),52638=>array(-91.242327,40.801453),52639=>array(-91.460387,40.53271),52640=>array(-91.280466,41.101237),52641=>array(-91.586354,40.992416),52644=>array(-91.41498,41.039995),52645=>array(-91.404234,40.912197),52646=>array(-90.998123,41.056576),52647=>array(-91.544658,41.135101),52649=>array(-91.612149,40.838567),52650=>array(-91.152038,40.95121),52651=>array(-91.815294,40.865321),52653=>array(-91.157419,41.163699),52654=>array(-91.671739,41.140702),52655=>array(-91.212018,40.846487),52656=>array(-91.4555,40.739814),52657=>array(-91.518819,40.767833),52658=>array(-91.229654,40.699404),52659=>array(-91.441022,41.129203),52660=>array(-91.29937,40.994596),52701=>array(-90.249117,41.981968),52720=>array(-91.173386,41.587724),52721=>array(-90.959696,41.756923),52722=>array(-90.471528,41.574299),52726=>array(-90.780377,41.496325),52727=>array(-90.32594,41.954788),52728=>array(-90.734634,41.454062),52729=>array(-90.735691,41.800183),52730=>array(-90.335349,41.77567),52731=>array(-90.486426,41.966975),52732=>array(-90.253005,41.891044),52737=>array(-91.374611,41.259277),52738=>array(-91.378479,41.273663),52739=>array(-91.367325,41.375171),52742=>array(-90.5197,41.838263),52745=>array(-90.766483,41.718602),52746=>array(-90.670392,41.716455),52747=>array(-90.905416,41.611142),52748=>array(-90.554955,41.665736),52749=>array(-91.130747,41.34563),52750=>array(-90.397049,41.937024),52751=>array(-90.679785,41.836435),52752=>array(-91.191222,41.274726),52753=>array(-90.385928,41.628548),52754=>array(-91.225861,41.346185),52755=>array(-91.438042,41.478372),52756=>array(-90.539115,41.729401),52757=>array(-90.379055,41.803854),52758=>array(-90.437349,41.742514),52760=>array(-91.086807,41.548655),52761=>array(-91.063984,41.438699),52765=>array(-90.871502,41.725473),52766=>array(-91.295418,41.467541),52767=>array(-90.423456,41.565852),52768=>array(-90.386997,41.70068),52769=>array(-90.847235,41.605804),52772=>array(-91.143672,41.755167),52773=>array(-90.752766,41.621924),52774=>array(-90.595121,41.906849),52776=>array(-91.268691,41.575411),52777=>array(-90.856109,41.854006),52778=>array(-90.990208,41.609579),52801=>array(-90.574849,41.521038),52802=>array(-90.637187,41.494514),52803=>array(-90.555977,41.538947),52804=>array(-90.681401,41.532417),52806=>array(-90.625902,41.589689),52807=>array(-90.51685,41.61068),53001=>array(-88.055245,43.607877),53002=>array(-88.352067,43.463948),53003=>array(-88.509682,43.206569),53004=>array(-87.875646,43.497835),53005=>array(-88.098804,43.062401),53006=>array(-88.533555,43.620098),53007=>array(-88.072232,43.108448),53010=>array(-88.272017,43.612528),53011=>array(-88.091389,43.659584),53012=>array(-88.034639,43.314732),53013=>array(-87.846917,43.565318),53014=>array(-88.176312,44.026076),53015=>array(-87.785999,43.907689),53016=>array(-88.71013,43.31024),53017=>array(-88.251366,43.201013),53018=>array(-88.390515,43.048165),53019=>array(-88.321059,43.697711),53020=>array(-88.011415,43.861777),53021=>array(-88.009317,43.494647),53022=>array(-88.115855,43.232227),53023=>array(-88.10667,43.780438),53024=>array(-87.928563,43.33353),53027=>array(-88.372522,43.317984),53029=>array(-88.340998,43.146603),53031=>array(-87.915628,43.639144),53032=>array(-88.625904,43.449385),53033=>array(-88.253996,43.234938),53034=>array(-88.618784,43.330168),53035=>array(-88.546919,43.390641),53036=>array(-88.575045,43.179661),53037=>array(-88.16316,43.312363),53038=>array(-88.787652,43.084329),53039=>array(-88.713347,43.369846),53040=>array(-88.191027,43.526965),53042=>array(-87.972329,43.956873),53044=>array(-87.782195,43.742514),53045=>array(-88.152779,43.058938),53046=>array(-88.157895,43.157247),53047=>array(-88.63012,43.257123),53048=>array(-88.457156,43.57379),53049=>array(-88.288605,43.886116),53050=>array(-88.547354,43.510549),53051=>array(-88.121527,43.159363),53057=>array(-88.244893,43.788987),53058=>array(-88.411504,43.112242),53059=>array(-88.525133,43.288569),53061=>array(-88.120622,43.945458),53063=>array(-87.790583,43.957651),53065=>array(-88.571629,43.679777),53066=>array(-88.490036,43.112853),53069=>array(-88.435005,43.11089),53070=>array(-87.807118,43.62043),53072=>array(-88.270816,43.081609),53073=>array(-87.988185,43.750854),53074=>array(-87.884515,43.41985),53075=>array(-87.990969,43.564515),53076=>array(-88.207066,43.268398),53078=>array(-88.466213,43.317703),53079=>array(-88.180169,43.813683),53080=>array(-87.98633,43.405793),53081=>array(-87.735217,43.71011),53083=>array(-87.764212,43.815871),53085=>array(-87.855577,43.732821),53086=>array(-88.271254,43.317652),53088=>array(-88.300913,44.070499),53089=>array(-88.233772,43.144615),53090=>array(-88.188952,43.462856),53091=>array(-88.434562,43.499624),53092=>array(-87.951218,43.214964),53093=>array(-87.94795,43.652874),53094=>array(-88.723069,43.14332),53095=>array(-88.158004,43.38963),53097=>array(-88.009823,43.242049),53098=>array(-88.710584,43.253742),53103=>array(-88.212849,42.881555),53104=>array(-88.03928,42.547457),53105=>array(-88.280346,42.663216),53108=>array(-87.943306,42.815),53110=>array(-87.860803,42.948443),53114=>array(-88.751804,42.59699),53115=>array(-88.668293,42.656603),53118=>array(-88.49154,42.962493),53119=>array(-88.485525,42.893005),53120=>array(-88.422434,42.809128),53121=>array(-88.535398,42.717008),53122=>array(-88.087029,43.04752),53125=>array(-88.554372,42.550039),53126=>array(-87.997744,42.794482),53128=>array(-88.336227,42.526865),53129=>array(-88.000857,42.939993),53130=>array(-88.049449,42.941233),53132=>array(-88.011548,42.883879),53137=>array(-88.669078,43.007883),53139=>array(-88.120797,42.685512),53140=>array(-87.828803,42.622309),53142=>array(-87.982634,42.518443),53143=>array(-87.82993,42.561312),53144=>array(-87.922461,42.615013),53146=>array(-88.155385,42.973705),53147=>array(-88.457346,42.565922),53149=>array(-88.342088,42.87809),53150=>array(-88.134318,42.871352),53151=>array(-88.098607,42.974779),53153=>array(-88.407089,42.934471),53154=>array(-87.898676,42.878693),53156=>array(-88.588838,42.889865),53158=>array(-87.88553,42.52436),53167=>array(-88.228216,42.744549),53168=>array(-88.135698,42.575072),53170=>array(-88.153803,42.550836),53172=>array(-87.859664,42.911998),53177=>array(-87.932874,42.704212),53178=>array(-88.596788,43.029545),53179=>array(-88.130588,42.513801),53181=>array(-88.243347,42.512663),53182=>array(-88.041279,42.702391),53183=>array(-88.370357,43.005837),53184=>array(-88.605447,42.52624),53185=>array(-88.194451,42.798205),53186=>array(-88.204676,43.022155),53188=>array(-88.292435,43.022273),53189=>array(-88.29103,42.944023),53190=>array(-88.736201,42.807771),53191=>array(-88.544677,42.579924),53192=>array(-88.184228,42.50259),53195=>array(-88.490181,42.513993),53202=>array(-87.891881,43.045121),53203=>array(-87.916734,43.038097),53204=>array(-87.926053,43.018587),53205=>array(-87.93381,43.053462),53206=>array(-87.933676,43.075126),53207=>array(-87.898851,42.977392),53208=>array(-87.967198,43.047073),53209=>array(-87.949473,43.12778),53210=>array(-87.973764,43.06884),53211=>array(-87.881444,43.082414),53212=>array(-87.908604,43.073857),53213=>array(-88.001511,43.048802),53214=>array(-88.01287,43.020327),53215=>array(-87.943078,42.999261),53216=>array(-87.976383,43.08639),53217=>array(-87.913268,43.157299),53218=>array(-87.99298,43.11372),53219=>array(-87.993688,42.995181),53220=>array(-87.991368,42.965204),53221=>array(-87.943306,42.953909),53222=>array(-88.036041,43.083208),53223=>array(-87.990496,43.163455),53224=>array(-88.039699,43.16333),53225=>array(-88.042944,43.115154),53226=>array(-88.04223,43.049005),53227=>array(-88.042017,42.995814),53228=>array(-88.043224,42.969046),53233=>array(-87.933823,43.036919),53235=>array(-87.867895,42.973107),53295=>array(-87.976072,43.022478),53402=>array(-87.816532,42.795888),53403=>array(-87.815533,42.684188),53404=>array(-87.811291,42.754054),53405=>array(-87.830175,42.726918),53406=>array(-87.864892,42.734537),53501=>array(-89.065499,42.60621),53502=>array(-89.438069,42.730406),53503=>array(-89.957507,43.142976),53504=>array(-89.860349,42.703516),53505=>array(-88.820854,42.661039),53506=>array(-90.281219,43.159394),53507=>array(-89.89654,42.995428),53508=>array(-89.573525,42.865677),53510=>array(-90.305238,42.745356),53511=>array(-89.094465,42.554101),53515=>array(-89.739283,43.115023),53516=>array(-89.87363,42.796638),53517=>array(-89.832329,43.056983),53518=>array(-90.59513,43.240989),53520=>array(-89.352736,42.596822),53521=>array(-89.400302,42.838105),53522=>array(-89.78349,42.556909),53523=>array(-89.028857,42.984371),53525=>array(-88.858656,42.544538),53526=>array(-90.343606,42.974051),53527=>array(-89.192257,43.051357),53528=>array(-89.638014,43.1183),53529=>array(-89.514652,43.242578),53530=>array(-90.10589,42.693829),53531=>array(-89.102393,43.062216),53532=>array(-89.326211,43.250086),53533=>array(-90.158915,42.99502),53534=>array(-89.09331,42.860824),53536=>array(-89.267911,42.761448),53537=>array(-89.210322,42.672419),53538=>array(-88.85715,42.920046),53540=>array(-90.284915,43.229262),53541=>array(-90.029362,42.56614),53543=>array(-90.351857,43.05396),53544=>array(-89.905663,42.87756),53545=>array(-89.0403,42.738888),53546=>array(-88.948166,42.652244),53548=>array(-89.124673,42.682985),53549=>array(-88.765614,42.984505),53550=>array(-89.494262,42.552572),53551=>array(-88.91565,43.081815),53553=>array(-90.302176,42.907833),53554=>array(-90.44068,42.908663),53555=>array(-89.555808,43.320142),53556=>array(-90.245275,43.2382),53557=>array(-88.797653,43.338952),53558=>array(-89.275479,42.99717),53559=>array(-89.081878,43.165583),53560=>array(-89.737666,43.192255),53561=>array(-89.638621,43.394951),53562=>array(-89.543636,43.115976),53563=>array(-88.916009,42.804501),53565=>array(-90.165771,42.833363),53566=>array(-89.649858,42.607782),53569=>array(-90.438953,42.989029),53570=>array(-89.619882,42.737195),53571=>array(-89.353226,43.277997),53572=>array(-89.733649,42.961103),53573=>array(-90.459136,43.187505),53574=>array(-89.65017,42.816517),53575=>array(-89.390551,42.933063),53576=>array(-89.233172,42.625684),53577=>array(-90.064349,43.311608),53578=>array(-89.775538,43.327442),53579=>array(-88.867735,43.295981),53580=>array(-90.378045,42.859809),53581=>array(-90.414095,43.37246),53582=>array(-89.978808,43.018376),53583=>array(-89.80448,43.250531),53585=>array(-88.715607,42.529624),53586=>array(-90.226681,42.573089),53587=>array(-89.904145,42.580307),53588=>array(-90.086262,43.193739),53589=>array(-89.212885,42.924555),53590=>array(-89.205195,43.200235),53593=>array(-89.579337,42.985198),53594=>array(-88.973812,43.190847),53597=>array(-89.457307,43.183434),53598=>array(-89.338331,43.210119),53599=>array(-89.857206,42.647308),53702=>array(-88.230636,43.060926),53703=>array(-89.378389,43.079575),53704=>array(-89.347319,43.136269),53705=>array(-89.460509,43.074014),53706=>array(-89.411502,43.074397),53711=>array(-89.41767,43.009613),53713=>array(-89.387108,43.036157),53714=>array(-89.311966,43.100348),53715=>array(-89.401708,43.06849),53716=>array(-89.313783,43.065163),53717=>array(-89.51989,43.074335),53718=>array(-89.276619,43.093146),53719=>array(-89.515378,43.045313),53726=>array(-89.422525,43.069849),53792=>array(-89.43066,43.077533),53801=>array(-91.074574,42.924819),53802=>array(-90.888563,42.80579),53803=>array(-90.353641,42.559514),53804=>array(-90.907869,42.874928),53805=>array(-90.687293,43.143528),53806=>array(-90.919927,42.729901),53807=>array(-90.472701,42.616835),53808=>array(-90.593133,42.62631),53809=>array(-90.633652,42.993767),53810=>array(-91.001945,42.820785),53811=>array(-90.49995,42.533572),53813=>array(-90.721223,42.844234),53816=>array(-90.85438,42.978845),53817=>array(-90.96768,42.945082),53818=>array(-90.492495,42.74566),53820=>array(-90.708918,42.695133),53821=>array(-91.057334,43.049076),53825=>array(-90.590628,42.91823),53826=>array(-90.918607,43.113417),53827=>array(-90.820473,43.045865),53901=>array(-89.482922,43.561484),53910=>array(-89.807759,43.886723),53911=>array(-89.367495,43.325821),53913=>array(-89.728705,43.49284),53916=>array(-88.867753,43.466797),53919=>array(-88.776015,43.733861),53920=>array(-89.594938,43.665514),53922=>array(-88.715147,43.52093),53923=>array(-89.138363,43.574139),53924=>array(-90.261729,43.483411),53925=>array(-89.057123,43.326711),53926=>array(-89.222839,43.666882),53928=>array(-89.15678,43.427058),53929=>array(-90.283608,43.751417),53930=>array(-89.486834,43.691693),53931=>array(-88.861263,43.743585),53932=>array(-89.055328,43.422362),53933=>array(-88.875253,43.584013),53934=>array(-89.820217,43.988277),53935=>array(-89.06555,43.587632),53936=>array(-89.707306,43.868893),53937=>array(-90.145434,43.386917),53939=>array(-89.130646,43.690429),53941=>array(-90.161058,43.570007),53943=>array(-90.035254,43.386819),53944=>array(-89.928668,43.685886),53946=>array(-89.020812,43.712453),53947=>array(-89.139926,43.746775),53948=>array(-90.040249,43.776559),53949=>array(-89.336006,43.783202),53950=>array(-90.137808,43.901142),53951=>array(-89.876273,43.387892),53952=>array(-89.597367,43.783202),53953=>array(-89.468292,43.772537),53954=>array(-89.313888,43.551488),53955=>array(-89.416632,43.406614),53956=>array(-89.017224,43.542123),53959=>array(-89.999636,43.533502),53960=>array(-89.235381,43.426124),53961=>array(-89.927555,43.457619),53963=>array(-88.743298,43.639467),53964=>array(-89.512502,43.912582),53965=>array(-89.748134,43.671422),53968=>array(-90.22785,43.646122),53969=>array(-89.301216,43.493215),54001=>array(-92.386607,45.33433),54002=>array(-92.371146,44.962668),54003=>array(-92.440067,44.79614),54004=>array(-92.125177,45.30222),54005=>array(-92.227501,45.236119),54006=>array(-92.646689,45.590697),54007=>array(-92.35294,45.190329),54009=>array(-92.577819,45.352521),54010=>array(-92.465629,44.734316),54011=>array(-92.464636,44.718295),54013=>array(-92.228166,45.08295),54014=>array(-92.572748,44.648721),54015=>array(-92.465001,44.971881),54016=>array(-92.69486,44.981117),54017=>array(-92.519801,45.120051),54020=>array(-92.641761,45.274846),54021=>array(-92.706319,44.734174),54022=>array(-92.606877,44.847472),54023=>array(-92.554736,44.981772),54024=>array(-92.640733,45.5017),54025=>array(-92.688729,45.143999),54026=>array(-92.535048,45.227679),54027=>array(-92.192828,44.919366),54028=>array(-92.283616,44.955033),54082=>array(-92.749369,45.06804),54101=>array(-88.075082,44.785785),54102=>array(-87.978271,45.50106),54103=>array(-88.520774,45.636396),54104=>array(-88.283014,45.448633),54106=>array(-88.456588,44.485462),54107=>array(-88.456974,44.698802),54110=>array(-88.075127,44.187689),54111=>array(-88.380546,44.812344),54112=>array(-88.054619,45.054734),54113=>array(-88.306749,44.264256),54114=>array(-88.1092,45.246006),54115=>array(-88.096333,44.397984),54119=>array(-88.159732,45.607459),54120=>array(-88.569386,45.803402),54121=>array(-88.321401,45.867774),54123=>array(-88.142532,44.211628),54124=>array(-88.345233,44.908023),54125=>array(-88.383335,45.586683),54126=>array(-88.050723,44.291905),54127=>array(-88.269602,44.796395),54128=>array(-88.804298,44.8691),54129=>array(-88.194198,44.13158),54130=>array(-88.24431,44.311313),54135=>array(-88.607936,44.927379),54136=>array(-88.338535,44.268219),54137=>array(-88.255012,44.756813),54138=>array(-88.408968,45.333616),54139=>array(-88.075505,44.956844),54140=>array(-88.309229,44.286515),54141=>array(-87.998318,44.728584),54143=>array(-87.698882,45.076199),54149=>array(-88.462371,45.196483),54150=>array(-88.853758,44.997641),54151=>array(-87.988217,45.725441),54153=>array(-87.916035,44.898083),54154=>array(-88.182068,44.87369),54155=>array(-88.200548,44.527495),54156=>array(-88.024459,45.628708),54157=>array(-87.821437,45.040575),54159=>array(-87.838864,45.193358),54160=>array(-88.100069,44.121053),54161=>array(-88.162416,45.122213),54162=>array(-88.270904,44.66254),54165=>array(-88.321789,44.5166),54166=>array(-88.634549,44.778797),54169=>array(-88.280739,44.176686),54170=>array(-88.577197,44.536158),54171=>array(-88.096472,44.715231),54173=>array(-88.030522,44.63909),54174=>array(-88.424393,45.036912),54175=>array(-88.622967,45.30901),54177=>array(-87.882986,45.384819),54180=>array(-88.173915,44.326334),54201=>array(-87.495679,44.624327),54202=>array(-87.140045,45.0873),54204=>array(-87.605295,44.755492),54205=>array(-87.632423,44.596202),54207=>array(-87.989005,44.087627),54208=>array(-87.799595,44.363565),54209=>array(-87.270394,45.017946),54210=>array(-87.036178,45.246457),54211=>array(-87.166369,45.160359),54212=>array(-87.209029,45.109775),54213=>array(-87.528256,44.695177),54214=>array(-87.713043,44.197537),54216=>array(-87.569911,44.438598),54217=>array(-87.719966,44.552207),54220=>array(-87.722744,44.101813),54227=>array(-87.807853,44.279501),54228=>array(-87.652873,44.268999),54229=>array(-87.815517,44.560061),54230=>array(-87.915906,44.160234),54232=>array(-87.923954,44.006836),54234=>array(-87.10151,45.181963),54235=>array(-87.372795,44.840884),54241=>array(-87.594706,44.215871),54245=>array(-87.898061,44.030924),54246=>array(-86.899359,45.373163),54247=>array(-87.790095,44.199973),54301=>array(-88.016063,44.480778),54302=>array(-87.976828,44.507653),54303=>array(-88.048764,44.538066),54304=>array(-88.068478,44.493498),54307=>array(-88.036686,44.470363),54311=>array(-87.892181,44.479887),54313=>array(-88.115165,44.586363),54401=>array(-89.704051,44.963304),54403=>array(-89.525216,45.018422),54405=>array(-90.28722,44.96702),54406=>array(-89.30493,44.412217),54407=>array(-89.281795,44.532182),54408=>array(-89.323997,45.025581),54409=>array(-89.170828,45.1222),54410=>array(-90.030459,44.542287),54411=>array(-90.033418,45.06256),54412=>array(-89.974151,44.66327),54413=>array(-90.13125,44.284015),54414=>array(-89.176857,44.959673),54416=>array(-88.947663,44.877732),54417=>array(-89.653673,45.026617),54418=>array(-88.940257,45.22063),54420=>array(-90.350683,44.610077),54421=>array(-90.288689,44.895191),54422=>array(-90.457501,44.985893),54423=>array(-89.421676,44.585282),54424=>array(-89.192153,45.286659),54425=>array(-90.341197,45.006838),54426=>array(-90.00979,44.907469),54427=>array(-89.258344,44.817219),54428=>array(-89.135714,45.421166),54430=>array(-88.873132,45.147659),54433=>array(-90.815821,45.195073),54435=>array(-89.438199,45.360466),54436=>array(-90.427296,44.534726),54437=>array(-90.629136,44.777208),54440=>array(-89.383375,44.81122),54441=>array(-90.104884,44.64252),54442=>array(-89.65898,45.358854),54443=>array(-89.751725,44.608922),54446=>array(-90.466411,44.747785),54447=>array(-90.747239,45.085986),54448=>array(-89.830205,44.933628),54449=>array(-90.208267,44.638415),54450=>array(-89.04097,45.004292),54451=>array(-90.407651,45.19739),54452=>array(-89.793254,45.217191),54454=>array(-89.882882,44.606715),54455=>array(-89.684474,44.766821),54456=>array(-90.632781,44.544396),54457=>array(-89.900133,44.214082),54458=>array(-89.305963,44.497176),54459=>array(-90.237492,45.413177),54460=>array(-90.543199,44.938782),54462=>array(-89.007393,45.392002),54463=>array(-89.219035,45.50253),54465=>array(-88.891217,45.383296),54466=>array(-90.306505,44.379773),54467=>array(-89.538901,44.413919),54469=>array(-89.874045,44.345145),54470=>array(-90.141512,45.286613),54471=>array(-89.424316,44.930719),54473=>array(-89.352368,44.650645),54474=>array(-89.627198,44.873616),54475=>array(-89.793069,44.484665),54476=>array(-89.530054,44.890321),54479=>array(-90.326998,44.749981),54480=>array(-90.269289,45.05431),54481=>array(-89.638254,44.510664),54482=>array(-89.518511,44.558728),54484=>array(-90.078596,44.799824),54485=>array(-89.210443,45.402959),54486=>array(-89.045228,44.717991),54487=>array(-89.775437,45.514213),54488=>array(-90.333122,44.840396),54489=>array(-90.003987,44.460777),54490=>array(-90.392334,45.343391),54491=>array(-88.753099,45.235529),54493=>array(-90.81072,44.69676),54494=>array(-89.73492,44.340837),54495=>array(-89.96406,44.378213),54498=>array(-90.629022,45.035112),54499=>array(-89.176405,44.789831),54501=>array(-89.349281,45.657611),54511=>array(-88.823099,45.73747),54512=>array(-89.658543,46.090361),54513=>array(-90.141311,45.578383),54514=>array(-90.473291,46.041777),54515=>array(-90.491015,45.512631),54517=>array(-90.930676,46.145917),54519=>array(-89.263108,46.05078),54520=>array(-88.903792,45.536731),54521=>array(-89.291205,45.936908),54524=>array(-90.34736,45.831449),54525=>array(-90.219958,46.423303),54526=>array(-90.85718,45.529271),54527=>array(-90.688207,46.124668),54529=>array(-89.667165,45.677711),54530=>array(-90.742889,45.532522),54531=>array(-89.774667,45.752815),54534=>array(-90.228091,46.347714),54536=>array(-90.370344,46.322056),54537=>array(-90.603457,45.528805),54538=>array(-89.911919,45.970064),54539=>array(-89.56214,45.81335),54540=>array(-89.381416,46.155723),54541=>array(-88.617828,45.556214),54542=>array(-88.715429,45.919506),54545=>array(-89.862692,46.13014),54546=>array(-90.694721,46.299672),54547=>array(-90.105302,46.194274),54548=>array(-89.834298,45.865456),54550=>array(-90.277112,46.360991),54552=>array(-90.31661,45.939245),54554=>array(-89.067188,46.047221),54555=>array(-90.404624,45.705551),54556=>array(-90.297332,45.535094),54557=>array(-89.757817,46.223862),54558=>array(-89.498725,45.920191),54559=>array(-90.491229,46.495208),54560=>array(-89.552305,46.036728),54561=>array(-89.51339,46.097549),54562=>array(-89.079344,45.802654),54563=>array(-90.970548,45.460162),54564=>array(-89.960408,45.598905),54565=>array(-90.46581,46.284385),54566=>array(-88.601253,45.420139),54568=>array(-89.653069,45.95805),54601=>array(-91.140529,43.806197),54603=>array(-91.241935,43.856762),54610=>array(-91.831459,44.365291),54611=>array(-90.952181,44.447714),54612=>array(-91.501347,44.249551),54613=>array(-89.923744,44.075585),54614=>array(-90.952867,43.904933),54615=>array(-90.821919,44.26478),54616=>array(-91.22351,44.30081),54618=>array(-90.285854,43.963629),54619=>array(-90.775588,43.757634),54621=>array(-91.080952,43.656295),54622=>array(-91.773881,44.273358),54623=>array(-91.006259,43.732988),54624=>array(-91.131141,43.461506),54625=>array(-91.525003,44.133418),54626=>array(-91.053955,43.219573),54627=>array(-91.226971,44.171384),54628=>array(-91.026177,43.372994),54629=>array(-91.639591,44.17376),54630=>array(-91.373938,44.121157),54631=>array(-90.830887,43.285012),54632=>array(-91.146482,43.568829),54634=>array(-90.422353,43.581742),54635=>array(-91.045552,44.402903),54636=>array(-91.224012,44.002965),54637=>array(-90.270235,43.878545),54638=>array(-90.404178,43.800044),54639=>array(-90.637834,43.601975),54641=>array(-90.330096,44.270653),54642=>array(-91.045009,44.15206),54643=>array(-90.63818,44.18697),54644=>array(-91.063408,44.036084),54645=>array(-90.932642,43.321145),54646=>array(-90.098056,44.113755),54648=>array(-90.652565,43.829428),54650=>array(-91.227211,43.910455),54651=>array(-90.573224,43.723614),54652=>array(-90.772308,43.475648),54653=>array(-90.901451,43.815991),54654=>array(-90.964052,43.269664),54655=>array(-90.759096,43.371015),54656=>array(-90.803057,43.99),54657=>array(-90.895886,43.188044),54658=>array(-91.16809,43.68213),54659=>array(-91.114785,44.299071),54660=>array(-90.494405,43.982544),54661=>array(-91.467828,44.057603),54664=>array(-90.64298,43.488227),54665=>array(-90.92869,43.531971),54666=>array(-90.449672,44.170076),54667=>array(-90.860047,43.664049),54669=>array(-91.083866,43.911252),54670=>array(-90.485881,43.837346),54701=>array(-91.514998,44.751984),54703=>array(-91.518514,44.836452),54720=>array(-91.435752,44.804142),54721=>array(-92.082731,44.633744),54722=>array(-91.103039,44.711576),54723=>array(-92.419525,44.610559),54724=>array(-91.487588,45.106248),54725=>array(-91.990956,45.073212),54726=>array(-91.021401,44.93138),54727=>array(-91.159105,44.953954),54728=>array(-91.638259,45.308093),54729=>array(-91.392954,44.945626),54730=>array(-91.719644,45.022258),54731=>array(-91.090398,45.349837),54732=>array(-91.170492,45.144614),54733=>array(-91.850182,45.27866),54734=>array(-92.125756,45.098741),54736=>array(-91.905482,44.598672),54737=>array(-91.981576,44.718395),54738=>array(-91.490654,44.587658),54739=>array(-91.701174,44.859764),54740=>array(-92.166807,44.751437),54741=>array(-90.974611,44.620343),54742=>array(-91.267018,44.766439),54745=>array(-91.123401,45.251132),54746=>array(-90.880056,44.553241),54747=>array(-91.512112,44.401394),54748=>array(-91.26302,45.075083),54749=>array(-92.107164,44.948045),54750=>array(-92.294549,44.613789),54751=>array(-91.931558,44.85067),54754=>array(-90.753321,44.427159),54755=>array(-91.681302,44.575768),54756=>array(-91.939605,44.468101),54757=>array(-91.522349,45.237197),54758=>array(-91.216523,44.557943),54759=>array(-92.12926,44.489082),54760=>array(-91.206361,44.424047),54761=>array(-92.17833,44.623256),54762=>array(-91.993154,45.246203),54763=>array(-91.881737,45.179864),54765=>array(-91.68559,45.169133),54766=>array(-90.858047,45.340713),54767=>array(-92.267998,44.823835),54768=>array(-90.929805,44.95709),54769=>array(-92.241064,44.527298),54770=>array(-91.371914,44.548564),54771=>array(-90.812536,44.93696),54772=>array(-91.881707,45.100596),54773=>array(-91.296378,44.389993),54801=>array(-91.942767,45.878861),54805=>array(-92.023417,45.412053),54806=>array(-90.871814,46.55349),54810=>array(-92.374415,45.457085),54812=>array(-91.882516,45.392528),54813=>array(-92.044813,45.652939),54814=>array(-90.901161,46.863246),54817=>array(-91.546559,45.669726),54819=>array(-91.305291,45.486919),54820=>array(-91.565044,46.572526),54821=>array(-91.166168,46.216959),54822=>array(-91.694413,45.400937),54824=>array(-92.539887,45.484715),54826=>array(-92.159669,45.495241),54827=>array(-91.096768,46.788108),54828=>array(-91.294248,45.840986),54829=>array(-92.047243,45.56665),54830=>array(-92.225683,46.106014),54832=>array(-91.343441,46.319287),54835=>array(-91.247086,45.691601),54836=>array(-92.195041,46.454438),54837=>array(-92.357709,45.674284),54838=>array(-91.818848,46.258705),54839=>array(-91.139982,46.361577),54840=>array(-92.692383,45.751262),54841=>array(-91.778611,45.606667),54842=>array(-91.854667,46.505367),54843=>array(-91.296827,46.025938),54844=>array(-91.233072,46.804845),54845=>array(-92.193801,45.797319),54846=>array(-90.720238,46.378316),54847=>array(-91.39985,46.579326),54848=>array(-91.103822,45.516039),54849=>array(-91.725682,46.481185),54850=>array(-90.57083,46.940645),54853=>array(-92.429224,45.574587),54854=>array(-91.666522,46.649916),54855=>array(-90.831029,46.378032),54856=>array(-91.129309,46.442747),54857=>array(-91.605711,45.596342),54858=>array(-92.457844,45.519382),54859=>array(-91.803653,46.123003),54861=>array(-90.656678,46.614971),54862=>array(-91.142381,45.778701),54864=>array(-91.790631,46.613354),54865=>array(-91.374991,46.739717),54867=>array(-91.202554,45.822542),54868=>array(-91.707548,45.525662),54870=>array(-91.775145,45.709265),54871=>array(-92.002023,45.749634),54872=>array(-92.401715,45.77707),54873=>array(-91.691759,46.340445),54874=>array(-91.942807,46.565542),54875=>array(-91.692217,45.965643),54876=>array(-91.493513,45.836042),54880=>array(-92.12831,46.590874),54888=>array(-91.866955,45.974818),54889=>array(-92.170107,45.415113),54891=>array(-90.964839,46.69959),54893=>array(-92.325873,45.878807),54895=>array(-91.460777,45.449439),54896=>array(-90.881747,45.817173),54901=>array(-88.535694,44.062886),54902=>array(-88.540285,43.946895),54904=>array(-88.623839,44.0234),54909=>array(-89.367441,44.280703),54911=>array(-88.381003,44.281533),54913=>array(-88.39997,44.335996),54914=>array(-88.452033,44.280839),54915=>array(-88.356058,44.243138),54921=>array(-89.559143,44.295257),54922=>array(-88.76214,44.544821),54923=>array(-88.966832,43.997757),54927=>array(-88.654369,44.103128),54928=>array(-88.874634,44.746498),54929=>array(-88.73923,44.636486),54930=>array(-89.555283,44.032622),54931=>array(-88.679132,44.274505),54932=>array(-88.590949,43.831997),54933=>array(-88.7032,44.670473),54934=>array(-88.839265,44.002969),54935=>array(-88.436782,43.77366),54937=>array(-88.388482,43.791998),54940=>array(-88.842561,44.22037),54941=>array(-88.992882,43.844703),54942=>array(-88.547362,44.294108),54943=>array(-89.59041,44.132814),54944=>array(-88.626957,44.324687),54945=>array(-89.136792,44.573645),54946=>array(-89.1444,44.336605),54947=>array(-88.698749,44.203594),54948=>array(-88.872845,44.780628),54949=>array(-88.915485,44.483988),54950=>array(-88.918064,44.657218),54952=>array(-88.329484,44.20104),54956=>array(-88.527574,44.182337),54960=>array(-89.219067,43.941908),54961=>array(-88.76169,44.410151),54962=>array(-89.030971,44.486188),54963=>array(-88.77909,44.044194),54964=>array(-88.717019,43.921644),54965=>array(-89.043887,44.167973),54966=>array(-89.504888,44.210019),54967=>array(-88.975701,44.126722),54968=>array(-89.135861,43.847061),54970=>array(-89.098184,44.072751),54971=>array(-88.829249,43.857119),54974=>array(-88.663462,43.787586),54977=>array(-89.171213,44.461173),54979=>array(-88.536374,43.872511),54980=>array(-88.767287,43.983584),54981=>array(-89.131504,44.322663),54982=>array(-89.290882,44.072748),54983=>array(-88.933068,44.319336),54984=>array(-89.223457,44.190566),54985=>array(-88.518469,44.075066),54986=>array(-88.749906,44.123302),55001=>array(-92.819108,44.898776),55003=>array(-92.779163,45.011625),55005=>array(-93.218464,45.396107),55006=>array(-93.198939,45.738266),55007=>array(-93.11782,45.971304),55008=>array(-93.276659,45.569486),55009=>array(-92.870984,44.480636),55011=>array(-93.253313,45.34074),55012=>array(-92.788113,45.438085),55013=>array(-92.905421,45.33847),55014=>array(-93.12798,45.161745),55016=>array(-92.934622,44.817691),55017=>array(-93.436364,45.672309),55018=>array(-92.996175,44.423972),55019=>array(-93.248224,44.419113),55020=>array(-93.373569,44.57554),55021=>array(-93.277222,44.299725),55024=>array(-93.124655,44.62723),55025=>array(-93.021896,45.263197),55026=>array(-92.346008,44.535111),55027=>array(-92.610066,44.407362),55029=>array(-93.198359,45.638337),55030=>array(-93.089416,45.83912),55031=>array(-92.962899,44.613024),55032=>array(-92.988158,45.586274),55033=>array(-92.863222,44.711918),55036=>array(-93.119564,45.871246),55037=>array(-92.785049,46.039021),55038=>array(-92.981626,45.167305),55040=>array(-93.280188,45.466135),55041=>array(-92.320188,44.394193),55042=>array(-92.909592,44.987826),55043=>array(-92.768997,44.940108),55044=>array(-93.276269,44.642096),55045=>array(-92.835009,45.395323),55046=>array(-93.424674,44.441784),55047=>array(-92.820729,45.200429),55049=>array(-93.230762,44.176279),55051=>array(-93.303115,45.928892),55052=>array(-93.444054,44.230887),55053=>array(-93.061232,44.346535),55054=>array(-93.350454,44.570166),55055=>array(-92.998692,44.874458),55056=>array(-92.953884,45.508583),55057=>array(-93.176142,44.470411),55060=>array(-93.223482,44.059126),55063=>array(-92.902898,45.838574),55065=>array(-93.024955,44.550758),55066=>array(-92.539132,44.511925),55068=>array(-93.062773,44.735516),55069=>array(-92.96471,45.693992),55070=>array(-93.386985,45.410032),55071=>array(-92.998798,44.821772),55072=>array(-92.526656,46.094837),55073=>array(-92.814871,45.272533),55074=>array(-92.720032,45.387779),55075=>array(-93.040497,44.888027),55076=>array(-93.032174,44.836066),55077=>array(-93.068994,44.819227),55079=>array(-93.035393,45.419467),55080=>array(-93.22223,45.666418),55082=>array(-92.839286,45.073144),55084=>array(-92.716225,45.462591),55085=>array(-92.963432,44.669775),55087=>array(-93.39488,44.24854),55088=>array(-93.383455,44.523586),55089=>array(-92.716416,44.583779),55090=>array(-92.957536,45.053333),55092=>array(-93.099816,45.334125),55101=>array(-93.090649,44.951483),55102=>array(-93.121464,44.931734),55103=>array(-93.122627,44.964258),55104=>array(-93.164457,44.953899),55105=>array(-93.168279,44.93718),55106=>array(-93.049522,44.963547),55107=>array(-93.0792,44.930998),55108=>array(-93.17488,44.982482),55109=>array(-93.025535,45.014551),55110=>array(-93.006048,45.089913),55111=>array(-93.195557,44.87828),55112=>array(-93.190493,45.081866),55113=>array(-93.151186,45.012196),55114=>array(-93.195072,44.96669),55115=>array(-92.953441,45.067903),55116=>array(-93.169581,44.910719),55117=>array(-93.09128,45.003562),55118=>array(-93.100947,44.894315),55119=>array(-93.007402,44.937421),55120=>array(-93.152093,44.874984),55121=>array(-93.154935,44.846541),55122=>array(-93.201339,44.806834),55123=>array(-93.138449,44.808933),55124=>array(-93.193842,44.739462),55125=>array(-92.938277,44.918031),55126=>array(-93.132817,45.08445),55127=>array(-93.080233,45.083907),55128=>array(-92.963553,44.987546),55129=>array(-92.892768,44.883474),55130=>array(-93.08211,44.973262),55150=>array(-93.165422,44.88664),55155=>array(-93.082613,44.956023),55301=>array(-93.65982,45.248559),55302=>array(-94.117135,45.246529),55303=>array(-93.4311,45.288281),55304=>array(-93.270906,45.252114),55305=>array(-93.428013,44.956379),55306=>array(-93.291381,44.730944),55307=>array(-94.111216,44.599706),55308=>array(-93.832031,45.441395),55309=>array(-93.744335,45.377771),55310=>array(-94.880759,44.759116),55311=>array(-93.497029,45.106403),55312=>array(-94.35129,44.70634),55313=>array(-93.851455,45.174664),55314=>array(-94.589725,44.77902),55315=>array(-93.688973,44.721096),55316=>array(-93.38725,45.172579),55317=>array(-93.550209,44.858704),55318=>array(-93.636248,44.810785),55319=>array(-93.943856,45.475266),55320=>array(-94.086052,45.396331),55321=>array(-94.193155,45.087589),55322=>array(-93.787011,44.771878),55324=>array(-94.417646,45.052822),55325=>array(-94.317152,45.084221),55327=>array(-93.475802,45.195735),55328=>array(-93.812325,45.0318),55329=>array(-94.558937,45.304542),55330=>array(-93.568216,45.334168),55331=>array(-93.607599,44.895679),55332=>array(-94.699538,44.520437),55333=>array(-94.860631,44.562955),55334=>array(-94.187476,44.53546),55335=>array(-94.553138,44.53109),55336=>array(-94.198563,44.777225),55337=>array(-93.272269,44.778472),55338=>array(-93.995771,44.669519),55339=>array(-93.956959,44.723427),55340=>array(-93.572118,45.078263),55341=>array(-93.662899,45.157963),55342=>array(-94.739028,44.742925),55343=>array(-93.416254,44.914372),55344=>array(-93.43006,44.863894),55345=>array(-93.48443,44.915442),55346=>array(-93.48128,44.878621),55347=>array(-93.462356,44.827886),55349=>array(-94.074539,45.058647),55350=>array(-94.394053,44.89558),55352=>array(-93.592608,44.651475),55353=>array(-94.324626,45.329096),55354=>array(-94.061426,44.880442),55355=>array(-94.541307,45.099093),55356=>array(-93.589528,44.994442),55357=>array(-93.673208,45.105802),55358=>array(-93.991526,45.253055),55359=>array(-93.698264,45.00959),55360=>array(-93.919645,44.91596),55362=>array(-93.838711,45.292082),55363=>array(-93.91832,45.037192),55364=>array(-93.672045,44.937764),55366=>array(-94.232341,44.672626),55367=>array(-93.975752,44.895142),55368=>array(-93.899119,44.73887),55369=>array(-93.445399,45.127446),55370=>array(-94.036783,44.77718),55371=>array(-93.590776,45.578592),55372=>array(-93.413588,44.682387),55373=>array(-93.721142,45.088621),55374=>array(-93.573794,45.175525),55375=>array(-93.721559,44.908107),55376=>array(-93.687899,45.211249),55378=>array(-93.366971,44.757299),55379=>array(-93.513329,44.755948),55381=>array(-94.199979,44.930963),55382=>array(-94.199092,45.30042),55384=>array(-93.630699,44.936941),55385=>array(-94.489204,44.739112),55386=>array(-93.666882,44.863217),55387=>array(-93.778944,44.869263),55388=>array(-93.845647,44.949843),55389=>array(-94.442626,45.297919),55390=>array(-93.979556,45.065173),55391=>array(-93.538993,44.956401),55395=>array(-94.067714,44.951833),55396=>array(-94.367013,44.546306),55397=>array(-93.937971,44.823812),55398=>array(-93.610385,45.465616),55401=>array(-93.269097,44.984577),55402=>array(-93.271443,44.976033),55403=>array(-93.284032,44.97057),55404=>array(-93.261123,44.961998),55405=>array(-93.302471,44.971871),55406=>array(-93.22104,44.940496),55407=>array(-93.253029,44.935036),55408=>array(-93.292639,44.940425),55409=>array(-93.281477,44.930326),55410=>array(-93.319632,44.911878),55411=>array(-93.298363,44.999009),55412=>array(-93.303546,45.027476),55413=>array(-93.241677,44.999463),55414=>array(-93.227354,44.979513),55415=>array(-93.257537,44.974789),55416=>array(-93.336319,44.950191),55417=>array(-93.230407,44.90444),55418=>array(-93.242853,45.021318),55419=>array(-93.287653,44.905799),55420=>array(-93.277176,44.835969),55421=>array(-93.253812,45.050884),55422=>array(-93.341105,45.009275),55423=>array(-93.282529,44.87446),55424=>array(-93.344834,44.905026),55425=>array(-93.225635,44.851555),55426=>array(-93.374096,44.958311),55427=>array(-93.37915,45.005499),55428=>array(-93.381362,45.06295),55429=>array(-93.341097,45.063552),55430=>array(-93.30147,45.067295),55431=>array(-93.310998,44.825914),55432=>array(-93.254518,45.096587),55433=>array(-93.314839,45.160411),55434=>array(-93.250487,45.163716),55435=>array(-93.33406,44.873953),55436=>array(-93.373157,44.90414),55437=>array(-93.342996,44.824347),55438=>array(-93.381428,44.823123),55439=>array(-93.374747,44.87563),55441=>array(-93.424636,45.006321),55442=>array(-93.426212,45.048851),55443=>array(-93.338118,45.117609),55444=>array(-93.301691,45.103924),55445=>array(-93.379184,45.122441),55446=>array(-93.489701,45.03914),55447=>array(-93.489561,45.001096),55448=>array(-93.299952,45.193911),55449=>array(-93.181914,45.177288),55450=>array(-93.224307,44.879528),55454=>array(-93.234611,44.967334),55455=>array(-93.233696,44.971814),55601=>array(-91.362932,47.236844),55602=>array(-91.886445,47.349842),55603=>array(-91.251187,47.546499),55604=>array(-90.555583,47.955097),55605=>array(-89.73713,47.965288),55606=>array(-89.988859,47.934516),55607=>array(-91.417324,47.563191),55609=>array(-91.780871,46.970661),55612=>array(-90.701442,47.769724),55613=>array(-90.922199,47.581682),55614=>array(-91.375995,47.368243),55615=>array(-90.823555,47.663325),55616=>array(-91.642073,47.165792),55702=>array(-92.636025,46.95676),55703=>array(-92.750065,47.730899),55704=>array(-92.751667,46.219085),55705=>array(-92.207357,47.451802),55706=>array(-91.961573,47.721713),55707=>array(-92.631629,46.554781),55708=>array(-92.347695,47.571292),55709=>array(-93.372355,47.429069),55710=>array(-92.708559,47.629693),55711=>array(-92.691219,46.844265),55712=>array(-92.520624,46.2817),55713=>array(-92.746045,47.500381),55716=>array(-93.271458,47.320392),55717=>array(-92.387216,47.068701),55718=>array(-92.486403,46.620931),55719=>array(-92.86219,47.541039),55720=>array(-92.533411,46.751111),55721=>array(-93.686796,47.220628),55722=>array(-93.442025,47.278871),55723=>array(-92.91622,47.839064),55724=>array(-92.355122,47.166394),55725=>array(-92.168114,48.209667),55726=>array(-92.829381,46.674045),55731=>array(-91.656877,47.981053),55732=>array(-92.209049,47.674409),55733=>array(-92.360792,46.713831),55734=>array(-92.444733,47.352348),55735=>array(-93.010212,46.210293),55736=>array(-92.940845,46.955641),55738=>array(-92.660294,47.264329),55741=>array(-92.398232,47.462585),55742=>array(-93.136731,47.204293),55744=>array(-93.507034,47.234577),55746=>array(-92.955661,47.361847),55748=>array(-93.621281,47.014462),55749=>array(-92.443315,46.439558),55750=>array(-91.963714,47.53185),55751=>array(-92.659139,47.397322),55752=>array(-93.285945,46.950553),55753=>array(-93.081568,47.395442),55756=>array(-92.584556,46.361182),55757=>array(-92.950125,46.512538),55758=>array(-92.720194,47.50602),55760=>array(-93.255117,46.637588),55763=>array(-92.155252,47.347594),55764=>array(-93.306669,47.332014),55765=>array(-92.756285,47.103712),55766=>array(-92.430714,47.260489),55767=>array(-92.759608,46.450718),55768=>array(-92.684322,47.486978),55769=>array(-93.18386,47.479989),55771=>array(-92.8175,48.132096),55772=>array(-93.130631,48.112705),55775=>array(-93.17158,47.320171),55779=>array(-92.448827,46.908849),55780=>array(-92.698892,46.688141),55781=>array(-93.047127,47.679928),55782=>array(-92.206008,47.832949),55783=>array(-92.892446,46.396409),55784=>array(-93.165281,47.058391),55785=>array(-93.731217,46.921584),55786=>array(-93.379444,47.318832),55787=>array(-93.102978,46.678418),55790=>array(-92.252921,47.927477),55792=>array(-92.479046,47.597165),55793=>array(-93.286131,47.115899),55795=>array(-92.882916,46.297871),55797=>array(-92.362116,46.5665),55798=>array(-92.967783,46.723256),55802=>array(-92.049345,46.740951),55803=>array(-92.070878,47.050601),55804=>array(-91.936344,46.931351),55805=>array(-92.095784,46.800825),55806=>array(-92.127612,46.76813),55807=>array(-92.168596,46.735498),55808=>array(-92.241391,46.676281),55810=>array(-92.269437,46.756745),55811=>array(-92.224332,46.842667),55812=>array(-92.070727,46.808688),55814=>array(-92.197949,46.833589),55901=>array(-92.506581,44.069818),55902=>array(-92.507101,43.971216),55904=>array(-92.400504,43.959865),55905=>array(-92.525906,44.055948),55906=>array(-92.40821,44.099889),55909=>array(-92.733693,43.562061),55910=>array(-91.971828,44.12866),55912=>array(-92.988598,43.682611),55917=>array(-93.075481,43.88482),55918=>array(-92.846462,43.740821),55919=>array(-91.299955,43.620772),55920=>array(-92.622006,44.013761),55921=>array(-91.458854,43.628993),55922=>array(-91.900947,43.558956),55923=>array(-92.186073,43.851027),55924=>array(-93.027295,44.029232),55925=>array(-91.458412,43.912092),55926=>array(-92.706883,43.743195),55927=>array(-92.870923,44.036469),55929=>array(-92.139619,43.976721),55931=>array(-91.389561,43.509812),55932=>array(-92.298336,44.152205),55933=>array(-92.680581,43.646002),55934=>array(-92.264209,44.004029),55935=>array(-92.121472,43.753751),55936=>array(-92.577693,43.717078),55939=>array(-92.091732,43.543427),55940=>array(-92.809489,43.898614),55941=>array(-91.349148,43.724845),55943=>array(-91.582769,43.782867),55944=>array(-92.717939,43.98983),55945=>array(-92.052449,44.266893),55946=>array(-92.966216,44.273212),55947=>array(-91.365543,43.822952),55949=>array(-91.928608,43.710105),55950=>array(-92.964476,43.747102),55951=>array(-92.482488,43.529233),55952=>array(-91.843577,43.943303),55953=>array(-92.966542,43.526582),55954=>array(-91.780106,43.557061),55955=>array(-92.74087,44.08732),55956=>array(-92.527569,44.286068),55957=>array(-92.264299,44.248729),55959=>array(-91.799534,44.11796),55960=>array(-92.534012,44.137569),55961=>array(-92.473757,43.608402),55962=>array(-91.845163,43.76212),55963=>array(-92.656046,44.190569),55964=>array(-92.158034,44.160083),55965=>array(-92.128187,43.623194),55967=>array(-92.513371,43.795157),55968=>array(-92.089927,44.397049),55969=>array(-91.877288,44.082477),55970=>array(-92.831962,43.595148),55971=>array(-91.75568,43.815849),55972=>array(-92.048778,43.995979),55973=>array(-92.772859,43.80624),55974=>array(-91.647985,43.577122),55975=>array(-92.364465,43.677871),55976=>array(-92.484235,43.865795),55977=>array(-92.648066,43.555778),55979=>array(-91.950764,43.920384),55981=>array(-92.050732,44.357851),55982=>array(-92.88473,43.815765),55983=>array(-92.806985,44.291403),55985=>array(-92.904348,44.158224),55987=>array(-91.625441,43.994226),55990=>array(-92.261786,43.732184),55991=>array(-92.418566,44.261215),55992=>array(-92.682769,44.322398),56001=>array(-93.978863,44.128325),56003=>array(-94.090358,44.215472),56007=>array(-93.324423,43.660992),56009=>array(-93.546424,43.661834),56010=>array(-94.179805,43.886164),56011=>array(-93.772641,44.602565),56013=>array(-94.103786,43.62018),56014=>array(-93.817898,43.583158),56016=>array(-93.343107,43.762065),56017=>array(-93.819535,44.30535),56019=>array(-94.888926,44.115896),56020=>array(-93.538328,43.607381),56021=>array(-94.316025,44.289313),56022=>array(-94.839326,44.053561),56023=>array(-94.013565,43.782339),56024=>array(-93.838818,44.143592),56025=>array(-93.917351,43.753245),56026=>array(-93.290995,43.885775),56027=>array(-94.116644,43.516714),56028=>array(-93.71742,44.226257),56029=>array(-93.522279,43.530047),56031=>array(-94.468513,43.622571),56032=>array(-93.556877,43.763635),56033=>array(-93.938149,43.56506),56034=>array(-94.181962,44.028598),56035=>array(-93.270999,43.820045),56036=>array(-93.221023,43.551882),56037=>array(-94.051769,44.016947),56039=>array(-94.31187,43.663252),56041=>array(-94.533087,44.161305),56042=>array(-93.483758,43.804234),56043=>array(-93.222394,43.649401),56044=>array(-93.956605,44.564804),56045=>array(-93.214342,43.757063),56046=>array(-93.271449,43.964524),56047=>array(-94.233494,43.732263),56048=>array(-93.721097,44.092772),56050=>array(-93.945434,44.266105),56051=>array(-93.710558,43.537461),56052=>array(-93.557905,44.327421),56054=>array(-94.373758,44.435233),56055=>array(-94.23533,44.1285),56056=>array(-94.579483,44.072691),56057=>array(-93.711668,44.39079),56058=>array(-93.913719,44.441769),56060=>array(-94.439744,43.930383),56062=>array(-94.414124,44.046244),56063=>array(-93.815742,44.21803),56065=>array(-93.92843,43.942225),56068=>array(-93.806142,43.865306),56069=>array(-93.542436,44.412094),56071=>array(-93.579424,44.534971),56072=>array(-93.517081,43.899229),56073=>array(-94.464745,44.30483),56074=>array(-94.19687,44.332862),56075=>array(-94.436687,43.735046),56078=>array(-93.760875,44.005921),56080=>array(-93.854419,44.080438),56081=>array(-94.629348,43.991089),56082=>array(-94.036965,44.357287),56083=>array(-95.134152,44.200924),56085=>array(-94.738556,44.294971),56087=>array(-94.975248,44.240509),56088=>array(-94.443294,43.824262),56089=>array(-93.431131,43.561574),56090=>array(-94.24404,43.956354),56091=>array(-93.681297,43.927424),56093=>array(-93.519385,44.05857),56096=>array(-93.603466,44.244889),56097=>array(-93.713282,43.720968),56098=>array(-94.181766,43.793016),56101=>array(-95.134004,43.879976),56110=>array(-95.944678,43.621544),56111=>array(-94.882713,43.639357),56113=>array(-96.153168,44.395415),56114=>array(-95.593254,43.976217),56115=>array(-95.905771,44.209457),56116=>array(-96.386343,43.614381),56117=>array(-95.687376,43.523116),56118=>array(-95.02918,43.950579),56119=>array(-95.462992,43.713719),56120=>array(-94.79264,43.962378),56121=>array(-94.596765,43.535981),56122=>array(-95.956,43.898445),56123=>array(-95.592414,44.086937),56125=>array(-95.552866,44.058188),56127=>array(-94.764701,43.547469),56128=>array(-96.110303,43.881542),56129=>array(-96.041931,43.529141),56131=>array(-95.572539,43.855847),56132=>array(-95.764924,44.203493),56134=>array(-96.238401,43.795694),56136=>array(-96.395226,44.500249),56137=>array(-95.330695,43.840366),56138=>array(-96.389525,43.534582),56139=>array(-96.179427,44.103929),56140=>array(-96.369409,43.907739),56141=>array(-95.80388,43.87708),56142=>array(-96.231207,44.467549),56143=>array(-95.00868,43.632603),56144=>array(-96.392004,43.851392),56145=>array(-95.175721,44.054734),56146=>array(-96.103432,43.580062),56147=>array(-96.057786,43.75741),56149=>array(-96.305564,44.304157),56150=>array(-95.197164,43.62827),56151=>array(-95.929422,44.031451),56152=>array(-95.272944,44.230458),56153=>array(-96.003104,43.826655),56155=>array(-95.944787,43.77245),56156=>array(-96.227061,43.661782),56157=>array(-95.948377,44.404175),56158=>array(-96.0785,43.640634),56159=>array(-94.931905,43.941177),56160=>array(-94.804734,43.841157),56161=>array(-95.324827,43.707031),56162=>array(-94.668746,43.841705),56164=>array(-96.342684,44.060521),56165=>array(-95.703057,43.725343),56166=>array(-95.380986,44.203001),56167=>array(-95.408728,43.553927),56168=>array(-95.809489,43.617488),56169=>array(-96.00651,44.338334),56170=>array(-96.090557,44.173686),56171=>array(-94.761789,43.671285),56172=>array(-95.775514,44.014163),56173=>array(-96.245976,43.52472),56174=>array(-95.305092,44.016336),56175=>array(-95.638718,44.260146),56176=>array(-94.720493,43.783287),56177=>array(-96.252873,43.889121),56178=>array(-96.133197,44.28461),56180=>array(-95.459592,44.246204),56181=>array(-94.626792,43.677703),56183=>array(-95.431126,44.029014),56185=>array(-95.824238,43.798534),56186=>array(-96.074258,44.033228),56187=>array(-95.58239,43.624671),56201=>array(-95.041816,45.102185),56207=>array(-96.066223,45.491698),56208=>array(-96.00477,45.246719),56209=>array(-94.812115,45.12723),56210=>array(-96.565367,45.559885),56211=>array(-96.693856,45.579017),56212=>array(-96.323833,45.130873),56214=>array(-95.322581,44.603676),56215=>array(-95.571951,45.317716),56216=>array(-95.059378,44.942507),56218=>array(-95.940466,44.826953),56219=>array(-96.81828,45.607652),56220=>array(-96.295236,44.732106),56221=>array(-96.192863,45.548133),56222=>array(-95.356764,44.985399),56223=>array(-95.818773,44.762144),56224=>array(-95.052134,44.372814),56225=>array(-96.442659,45.441004),56226=>array(-95.67812,45.421616),56227=>array(-96.168828,45.290841),56228=>array(-94.685179,44.951236),56229=>array(-95.716384,44.594036),56230=>array(-95.084058,44.763464),56231=>array(-95.763206,45.279446),56232=>array(-96.035236,44.932618),56235=>array(-96.016509,45.709703),56236=>array(-96.415963,45.664469),56237=>array(-95.433459,44.616613),56239=>array(-95.910436,44.504193),56240=>array(-96.483714,45.562591),56241=>array(-95.572923,44.797879),56243=>array(-94.686488,45.17024),56244=>array(-95.780474,45.477882),56245=>array(-95.677203,44.684043),56248=>array(-96.135813,45.786154),56249=>array(-95.904576,45.318795),56251=>array(-94.920252,45.143774),56252=>array(-95.31012,45.178253),56253=>array(-94.872528,44.959963),56255=>array(-95.419313,44.397066),56256=>array(-96.202421,45.028691),56257=>array(-96.402151,44.969258),56258=>array(-95.758167,44.44607),56260=>array(-95.482997,44.963275),56262=>array(-95.869707,45.115071),56263=>array(-95.532455,44.421485),56264=>array(-95.984716,44.57025),56265=>array(-95.706482,44.999823),56266=>array(-94.914551,44.421064),56267=>array(-95.928714,45.582554),56270=>array(-94.98738,44.570375),56271=>array(-95.404995,45.244754),56273=>array(-94.979937,45.317876),56274=>array(-96.245727,45.90222),56276=>array(-96.324208,45.24643),56277=>array(-94.98551,44.756176),56278=>array(-96.379955,45.348003),56279=>array(-95.169843,45.218831),56280=>array(-96.168267,44.632607),56281=>array(-95.169261,44.953238),56282=>array(-95.228467,45.040131),56283=>array(-95.13883,44.527995),56284=>array(-95.198352,44.781891),56285=>array(-95.346058,44.788702),56287=>array(-95.326432,44.475762),56288=>array(-94.95146,45.241206),56289=>array(-95.224451,45.333188),56291=>array(-96.08191,44.626742),56292=>array(-95.456501,44.502071),56293=>array(-95.259924,44.416508),56294=>array(-95.213533,44.313219),56295=>array(-95.826677,45.035813),56296=>array(-96.462462,45.82683),56297=>array(-95.52937,44.636634),56301=>array(-94.242777,45.487084),56303=>array(-94.213691,45.574485),56304=>array(-94.057184,45.530414),56307=>array(-94.591029,45.62681),56308=>array(-95.386055,45.878391),56309=>array(-95.805711,46.07949),56310=>array(-94.450242,45.634286),56311=>array(-95.895603,45.897472),56312=>array(-94.961846,45.470123),56313=>array(-93.552737,45.784142),56314=>array(-94.432957,45.814701),56315=>array(-95.594079,45.980141),56316=>array(-95.162659,45.488301),56318=>array(-94.67453,45.853038),56319=>array(-95.215688,46.010823),56320=>array(-94.402835,45.466629),56321=>array(-94.389459,45.579025),56323=>array(-95.723921,45.629632),56324=>array(-95.904069,46.168954),56325=>array(-94.946854,45.562815),56326=>array(-95.670809,46.039558),56327=>array(-95.607998,45.754473),56328=>array(-94.517536,45.954758),56329=>array(-93.914815,45.709067),56330=>array(-93.756384,45.753241),56331=>array(-94.671722,45.678998),56332=>array(-95.508022,45.967062),56334=>array(-95.33678,45.574381),56335=>array(-94.861632,45.600289),56336=>array(-94.762637,45.820691),56338=>array(-93.854186,46.043124),56339=>array(-95.810949,45.824849),56340=>array(-94.429019,45.759467),56342=>array(-93.369917,46.18419),56343=>array(-95.704956,45.78591),56345=>array(-94.373531,45.988419),56347=>array(-94.872023,45.967481),56349=>array(-95.513002,45.726157),56350=>array(-93.230407,46.305029),56352=>array(-94.806359,45.6418),56353=>array(-93.629079,45.803664),56354=>array(-95.248547,46.057443),56355=>array(-95.245716,45.941442),56356=>array(-94.753489,45.62895),56357=>array(-93.800686,45.697723),56358=>array(-93.449967,45.845475),56359=>array(-93.665304,46.099568),56360=>array(-95.116562,45.895491),56361=>array(-95.337678,46.15679),56362=>array(-94.71212,45.401875),56363=>array(-93.65238,45.696739),56364=>array(-94.072993,46.005009),56367=>array(-94.182049,45.763755),56368=>array(-94.561477,45.464545),56369=>array(-94.345356,45.467011),56371=>array(-94.636584,45.433229),56373=>array(-94.230562,45.85974),56374=>array(-94.303347,45.670028),56375=>array(-94.274251,45.700876),56376=>array(-94.679481,45.505644),56377=>array(-94.247791,45.646154),56378=>array(-94.987283,45.725034),56379=>array(-94.082678,45.639681),56381=>array(-95.537869,45.556674),56382=>array(-94.598327,45.907862),56384=>array(-94.567231,45.809443),56385=>array(-95.232188,45.700872),56386=>array(-93.519271,46.114329),56387=>array(-94.239676,45.53288),56389=>array(-95.091489,45.797471),56401=>array(-94.12521,46.322919),56425=>array(-94.276015,46.343935),56431=>array(-93.635959,46.489933),56433=>array(-94.697017,46.973708),56434=>array(-94.934651,46.338439),56435=>array(-94.539543,46.822929),56436=>array(-94.688534,47.161257),56437=>array(-95.056765,46.24806),56438=>array(-94.819178,46.138601),56440=>array(-94.955084,46.141951),56441=>array(-93.981476,46.577802),56442=>array(-94.101479,46.67746),56443=>array(-94.619829,46.178887),56444=>array(-93.878891,46.420525),56446=>array(-95.09749,46.128838),56447=>array(-93.914976,46.738707),56448=>array(-94.119281,46.766218),56449=>array(-94.249031,46.184733),56450=>array(-93.831513,46.231257),56452=>array(-94.448628,46.956707),56453=>array(-95.175374,46.316002),56455=>array(-94.000613,46.440977),56456=>array(-94.337292,46.637753),56458=>array(-94.975317,47.193337),56461=>array(-94.853912,47.232073),56464=>array(-95.124099,46.77289),56465=>array(-94.114383,46.537328),56466=>array(-94.642727,46.420532),56467=>array(-94.818597,46.992726),56468=>array(-94.290567,46.490313),56469=>array(-93.566778,46.781236),56470=>array(-95.098576,47.0275),56472=>array(-94.356201,46.577263),56473=>array(-94.493302,46.357526),56474=>array(-94.402843,46.719853),56475=>array(-94.545992,46.079719),56477=>array(-95.000175,46.644616),56479=>array(-94.790234,46.442599),56481=>array(-94.919653,46.475418),56482=>array(-95.147753,46.464195),56484=>array(-94.468355,47.093644),56501=>array(-95.81395,46.837283),56510=>array(-96.524868,47.35881),56511=>array(-95.995301,46.839951),56514=>array(-96.428806,46.642707),56515=>array(-95.693048,46.294011),56516=>array(-95.97601,47.442035),56517=>array(-96.54963,47.560338),56518=>array(-95.250369,46.49007),56519=>array(-96.478978,47.161941),56520=>array(-96.497076,46.28975),56521=>array(-95.901811,46.999297),56522=>array(-96.379373,46.131921),56523=>array(-96.813366,47.650242),56524=>array(-95.615481,46.216786),56525=>array(-96.750053,46.666328),56527=>array(-95.319712,46.378318),56528=>array(-95.823814,46.521354),56529=>array(-96.690238,46.877139),56531=>array(-95.981265,45.987271),56533=>array(-96.156471,46.409003),56534=>array(-96.011397,46.471572),56535=>array(-96.041858,47.677583),56536=>array(-96.522969,47.046794),56537=>array(-96.089852,46.275351),56540=>array(-96.269583,47.55771),56541=>array(-96.141503,47.162393),56542=>array(-95.736221,47.550326),56543=>array(-96.338325,46.287011),56544=>array(-95.605415,46.757782),56545=>array(-96.241952,47.39063),56546=>array(-96.727263,47.100228),56547=>array(-96.553728,46.889472),56548=>array(-96.745362,47.368272),56549=>array(-96.312324,46.847447),56550=>array(-96.74306,47.273933),56551=>array(-95.446913,46.31739),56552=>array(-96.204295,46.984605),56553=>array(-96.618255,46.428827),56554=>array(-96.116127,46.885525),56556=>array(-95.879974,47.662952),56557=>array(-95.79496,47.317222),56560=>array(-96.735562,46.842028),56565=>array(-96.297639,46.049586),56566=>array(-95.612901,47.238908),56567=>array(-95.374417,46.549825),56568=>array(-96.762906,47.534968),56569=>array(-95.859666,47.073766),56570=>array(-95.367145,46.91793),56571=>array(-95.542716,46.433856),56572=>array(-96.073714,46.602178),56573=>array(-95.548277,46.618769),56574=>array(-96.714289,47.20212),56575=>array(-95.434841,47.042407),56576=>array(-95.699414,46.463112),56577=>array(-95.8012,46.974377),56578=>array(-95.641496,46.940894),56579=>array(-96.338999,46.46353),56580=>array(-96.604014,46.736062),56581=>array(-96.761828,47.462333),56583=>array(-96.410973,46.01057),56584=>array(-96.237402,47.223671),56585=>array(-96.246304,47.088367),56586=>array(-95.8309,46.318269),56587=>array(-95.856523,46.636628),56588=>array(-95.496947,46.209136),56589=>array(-95.745654,47.167325),56590=>array(-96.153316,46.050399),56591=>array(-95.842386,47.085957),56592=>array(-96.009471,47.538201),56593=>array(-95.353468,46.803537),56594=>array(-96.64298,46.548256),56601=>array(-94.864016,47.507361),56621=>array(-95.412927,47.419058),56623=>array(-94.600591,48.597453),56626=>array(-94.246106,47.320538),56627=>array(-94.070723,48.256132),56628=>array(-93.59004,47.69421),56629=>array(-94.101623,48.545164),56630=>array(-94.497762,47.757029),56633=>array(-94.50118,47.318784),56634=>array(-95.39813,47.680725),56636=>array(-93.919202,47.437935),56637=>array(-93.829972,47.608115),56639=>array(-93.536303,47.917841),56641=>array(-94.252758,47.222364),56644=>array(-95.495088,47.797005),56646=>array(-95.632726,47.773594),56647=>array(-94.618731,47.689935),56649=>array(-92.917067,48.574989),56650=>array(-94.557478,47.998056),56651=>array(-95.616723,47.454496),56652=>array(-95.248518,47.733484),56653=>array(-93.509558,48.272085),56654=>array(-93.976772,48.473941),56655=>array(-94.231326,47.028931),56657=>array(-93.634311,47.573005),56658=>array(-93.842402,48.063342),56659=>array(-94.017436,47.653088),56660=>array(-94.192377,47.991314),56661=>array(-94.195382,47.860563),56662=>array(-93.852993,46.862191),56663=>array(-94.446625,47.466429),56666=>array(-94.821241,48.033237),56667=>array(-94.968511,47.722587),56668=>array(-93.346928,48.613385),56669=>array(-93.135452,48.38395),56670=>array(-94.863596,47.853262),56671=>array(-95.305386,47.895133),56672=>array(-94.00184,47.072504),56673=>array(-95.105483,48.82233),56676=>array(-95.195778,47.539652),56678=>array(-95.118076,47.421954),56680=>array(-93.957158,47.659089),56681=>array(-94.237388,47.611763),56683=>array(-94.751107,47.736307),56684=>array(-95.698912,47.855617),56685=>array(-94.531271,48.238688),56686=>array(-94.911697,48.784049),56687=>array(-94.994123,47.501024),56688=>array(-93.912179,47.772963),56701=>array(-96.192034,48.121195),56710=>array(-97.00182,48.215386),56711=>array(-94.95895,49.311073),56713=>array(-96.814494,48.351356),56714=>array(-96.00464,48.783858),56715=>array(-95.941278,47.808974),56716=>array(-96.555403,47.743248),56720=>array(-96.892978,48.569749),56721=>array(-96.94698,47.969729),56722=>array(-96.646021,47.985086),56723=>array(-96.80643,47.809408),56724=>array(-95.735912,48.445803),56725=>array(-95.79769,48.150367),56726=>array(-96.239203,48.753797),56727=>array(-95.412061,48.288717),56728=>array(-97.008219,48.782511),56729=>array(-96.569079,48.669682),56731=>array(-97.072561,48.913017),56732=>array(-96.46733,48.584211),56733=>array(-96.895762,48.638068),56734=>array(-96.602484,48.770296),56735=>array(-96.635315,48.910175),56736=>array(-96.191476,47.708668),56737=>array(-96.036715,48.43447),56738=>array(-96.335704,48.334907),56741=>array(-94.853222,49.306868),56742=>array(-95.807021,47.928291),56744=>array(-97.12761,48.243805),56748=>array(-96.010269,47.921967),56750=>array(-96.294498,47.893024),56751=>array(-95.733307,48.809822),56754=>array(-96.188545,47.99911),56755=>array(-97.097235,48.970326),56756=>array(-95.538296,48.893305),56757=>array(-96.898134,48.478088),56758=>array(-96.51124,48.465369),56759=>array(-96.07009,48.554528),56760=>array(-96.453251,48.24357),56761=>array(-95.696207,48.602677),56762=>array(-96.73961,48.168749),56763=>array(-95.360862,48.815298),57001=>array(-96.637675,42.989202),57002=>array(-96.676931,44.296448),57003=>array(-96.755327,43.746313),57004=>array(-96.791217,43.079784),57005=>array(-96.585656,43.592068),57006=>array(-96.797514,44.315423),57010=>array(-96.816158,42.819184),57012=>array(-97.277198,43.594543),57013=>array(-96.617496,43.278376),57014=>array(-96.95635,43.111803),57015=>array(-96.980022,43.418384),57016=>array(-96.958995,43.899015),57017=>array(-96.849104,44.015156),57018=>array(-96.981006,43.797893),57020=>array(-96.820156,43.681278),57021=>array(-96.972194,43.264816),57022=>array(-96.717205,43.8409),57024=>array(-96.679219,43.988522),57025=>array(-96.697716,42.728403),57026=>array(-96.518396,44.259932),57027=>array(-96.517223,43.179998),57028=>array(-96.599811,44.061736),57029=>array(-97.484847,43.339062),57030=>array(-96.519561,43.738304),57031=>array(-97.185729,42.875321),57032=>array(-96.678132,43.424192),57033=>array(-96.960938,43.617972),57034=>array(-96.553807,43.11993),57035=>array(-97.080459,43.627175),57036=>array(-97.139059,43.278144),57037=>array(-97.249244,43.104561),57038=>array(-96.576625,42.585156),57039=>array(-96.874855,43.337838),57040=>array(-97.58735,43.061032),57041=>array(-96.867629,43.729774),57042=>array(-97.156681,43.986587),57043=>array(-97.310061,43.422611),57045=>array(-97.528384,43.205008),57046=>array(-97.306648,42.957636),57047=>array(-97.211956,43.52067),57048=>array(-97.200336,43.741984),57049=>array(-96.507606,42.531466),57050=>array(-97.012788,44.157204),57051=>array(-97.337907,44.232681),57052=>array(-97.707966,43.292356),57053=>array(-97.140286,43.410059),57054=>array(-97.25979,44.131488),57055=>array(-96.743898,43.66685),57057=>array(-96.95925,44.102232),57058=>array(-97.395155,43.73819),57059=>array(-97.764306,43.119205),57061=>array(-97.044011,44.242348),57062=>array(-97.945247,42.846199),57063=>array(-97.684565,42.930268),57064=>array(-96.873794,43.455933),57065=>array(-96.615579,43.904576),57066=>array(-97.869396,42.990046),57067=>array(-97.469006,43.045592),57068=>array(-96.495601,43.575015),57069=>array(-96.975173,42.843155),57070=>array(-97.173356,43.180067),57071=>array(-96.958351,44.272806),57072=>array(-97.188559,42.988671),57073=>array(-97.055057,43.005958),57075=>array(-96.959014,44.004375),57076=>array(-97.359727,43.971525),57077=>array(-96.756407,43.321853),57078=>array(-97.446689,42.915648),57103=>array(-96.690132,43.545833),57104=>array(-96.708645,43.604804),57105=>array(-96.735607,43.520296),57106=>array(-96.839962,43.507343),57107=>array(-96.820415,43.59762),57108=>array(-96.704983,43.479526),57110=>array(-96.642616,43.545488),57117=>array(-96.754971,43.531243),57197=>array(-96.738629,43.524568),57201=>array(-97.092757,44.936722),57212=>array(-97.139135,44.378729),57213=>array(-96.529494,44.553491),57214=>array(-97.204842,44.501979),57216=>array(-96.529779,45.30324),57217=>array(-97.677502,45.072481),57218=>array(-96.592103,44.652379),57219=>array(-97.796148,45.290641),57220=>array(-96.917466,44.467055),57221=>array(-97.456541,44.596631),57223=>array(-97.012493,44.71024),57224=>array(-97.134345,45.859161),57225=>array(-97.7284,44.888194),57226=>array(-96.714071,44.788157),57227=>array(-96.704786,45.36155),57231=>array(-97.57204,44.36152),57232=>array(-97.39261,45.623465),57233=>array(-97.398286,44.511948),57234=>array(-96.894291,44.610285),57235=>array(-97.295125,45.068355),57236=>array(-97.585622,44.985548),57237=>array(-96.500497,44.797699),57238=>array(-96.860868,44.873359),57239=>array(-97.299294,45.509211),57241=>array(-97.216193,44.695552),57242=>array(-97.365496,44.770719),57243=>array(-97.44284,44.91313),57245=>array(-96.91819,44.897581),57246=>array(-96.66698,45.054911),57247=>array(-97.437809,45.717409),57248=>array(-97.187953,44.583539),57249=>array(-97.360199,44.383725),57251=>array(-96.915377,45.283314),57252=>array(-96.612559,45.200406),57255=>array(-96.936649,45.868787),57256=>array(-97.195291,45.260899),57257=>array(-97.028157,45.497519),57258=>array(-97.922617,44.889599),57259=>array(-96.563488,45.002497),57260=>array(-96.719612,45.841733),57261=>array(-97.499694,45.529422),57262=>array(-97.070014,45.672913),57263=>array(-96.99594,45.142128),57264=>array(-96.823791,45.116757),57265=>array(-96.781562,44.992203),57266=>array(-97.095259,45.28044),57268=>array(-96.689414,44.567964),57269=>array(-96.814676,45.220983),57270=>array(-97.338627,45.841192),57271=>array(-97.522039,44.73938),57272=>array(-97.462871,45.101225),57273=>array(-97.280432,45.337132),57274=>array(-97.564541,45.30546),57276=>array(-96.613455,44.430861),57278=>array(-97.705276,44.638139),57279=>array(-96.876323,45.421222),57301=>array(-98.047697,43.713759),57311=>array(-97.763378,43.655651),57312=>array(-98.379249,44.207237),57313=>array(-98.37432,43.305031),57314=>array(-97.981288,44.046091),57315=>array(-98.040294,42.988388),57317=>array(-98.966447,43.143555),57319=>array(-97.480025,43.533018),57321=>array(-97.56002,43.870131),57322=>array(-97.974422,44.628064),57323=>array(-97.720279,44.146873),57324=>array(-98.054051,44.29843),57325=>array(-99.301892,43.752355),57328=>array(-98.439006,43.437622),57329=>array(-98.147336,42.97403),57330=>array(-98.156995,43.248016),57331=>array(-98.044848,43.474415),57332=>array(-97.656776,43.5505),57334=>array(-97.997122,43.549822),57335=>array(-98.783901,43.05369),57337=>array(-97.795813,44.011963),57339=>array(-99.417293,44.102176),57340=>array(-97.837547,43.795764),57341=>array(-99.117978,44.094667),57342=>array(-98.701381,43.244626),57344=>array(-98.653802,43.463754),57345=>array(-99.444401,44.578381),57346=>array(-99.600069,44.240731),57348=>array(-98.37222,44.625569),57349=>array(-97.5808,44.030097),57350=>array(-98.199291,44.404316),57353=>array(-97.842036,44.358421),57355=>array(-98.943362,43.780853),57356=>array(-98.529608,43.15817),57358=>array(-98.421921,44.07535),57359=>array(-98.182622,43.902872),57361=>array(-98.429216,42.996986),57362=>array(-99.074449,44.493857),57363=>array(-98.25552,43.680487),57364=>array(-98.606899,43.429099),57365=>array(-99.416428,43.811327),57366=>array(-97.946533,43.377168),57367=>array(-98.524701,43.061622),57368=>array(-98.472097,43.749509),57369=>array(-98.953012,43.420751),57370=>array(-99.165857,43.789461),57371=>array(-99.272207,44.413157),57373=>array(-98.872431,44.538356),57374=>array(-97.599126,43.753348),57375=>array(-98.48971,43.563945),57376=>array(-97.937265,43.217502),57379=>array(-98.557176,44.254665),57380=>array(-98.29855,43.030618),57381=>array(-98.737454,44.391041),57382=>array(-98.659699,44.059026),57383=>array(-98.73364,43.724481),57384=>array(-98.493066,44.419038),57385=>array(-98.286742,44.045304),57386=>array(-98.006176,44.505721),57401=>array(-98.53254,45.482335),57420=>array(-100.149046,45.29276),57421=>array(-97.907063,45.755478),57422=>array(-97.909471,45.419693),57424=>array(-98.564447,45.006471),57426=>array(-98.495591,45.737952),57427=>array(-98.318576,45.480547),57428=>array(-99.67822,45.452705),57429=>array(-98.297445,45.174757),57430=>array(-97.71958,45.812693),57432=>array(-98.031046,45.682867),57433=>array(-98.320765,45.638241),57434=>array(-98.072285,45.176247),57435=>array(-98.90894,45.179674),57436=>array(-98.088799,44.863789),57437=>array(-99.604081,45.788904),57438=>array(-99.158928,45.059381),57439=>array(-98.065112,45.331675),57440=>array(-98.271934,44.856969),57441=>array(-98.527902,45.829281),57442=>array(-100.158164,45.061754),57445=>array(-98.114967,45.465537),57446=>array(-98.15267,45.870828),57448=>array(-99.41133,45.63546),57449=>array(-98.176157,45.737408),57450=>array(-99.848392,45.225996),57451=>array(-98.956602,45.437401),57452=>array(-99.862852,45.529397),57454=>array(-97.783531,45.61024),57455=>array(-99.68147,45.018819),57456=>array(-98.980082,45.735597),57457=>array(-99.154299,45.877277),57460=>array(-98.670681,45.279575),57461=>array(-98.432019,45.15687),57465=>array(-98.687486,45.136035),57466=>array(-99.460633,45.223605),57467=>array(-99.176549,44.832072),57468=>array(-97.758142,45.499753),57469=>array(-98.571778,44.857384),57470=>array(-98.894286,44.883901),57471=>array(-99.318265,45.404536),57472=>array(-100.068105,45.435717),57473=>array(-99.499341,44.991457),57474=>array(-98.278733,45.292014),57475=>array(-99.624634,45.223553),57476=>array(-98.615226,44.713364),57477=>array(-98.162357,45.046943),57479=>array(-98.443214,45.302945),57481=>array(-98.669076,45.655751),57501=>array(-100.309041,44.527597),57520=>array(-100.193658,44.852798),57521=>array(-101.202163,43.804144),57522=>array(-99.994864,44.46807),57523=>array(-99.213765,43.233401),57528=>array(-99.761251,43.190776),57529=>array(-99.563794,43.230602),57531=>array(-100.485912,43.973671),57532=>array(-100.628221,44.40031),57533=>array(-99.424938,43.378934),57534=>array(-99.687364,43.570922),57536=>array(-99.76527,44.405385),57537=>array(-101.067304,44.578086),57538=>array(-99.142047,43.153994),57540=>array(-99.612595,44.517324),57541=>array(-99.883888,43.594019),57543=>array(-101.501212,43.774191),57544=>array(-99.9061,43.941236),57547=>array(-101.42219,43.473527),57548=>array(-99.660117,44.086805),57551=>array(-101.702079,43.175434),57552=>array(-101.19991,44.282982),57553=>array(-101.647601,44.472682),57555=>array(-100.611797,43.242096),57559=>array(-100.723479,43.936209),57560=>array(-101.190933,43.439227),57562=>array(-100.958429,43.897568),57563=>array(-100.365523,43.365383),57564=>array(-99.989662,44.729609),57566=>array(-101.09095,43.323502),57567=>array(-101.721691,44.097101),57568=>array(-100.077342,43.885649),57569=>array(-99.572854,43.856447),57570=>array(-100.830995,43.198189),57571=>array(-99.092505,43.085219),57572=>array(-101.069903,43.146539),57574=>array(-101.345928,43.10564),57576=>array(-100.296114,43.920919),57577=>array(-101.677216,43.52876),57579=>array(-100.786176,43.597198),57580=>array(-100.090107,43.289349),57584=>array(-100.070869,43.536198),57585=>array(-100.405433,43.539111),57601=>array(-100.54061,45.457862),57620=>array(-102.540212,45.377258),57621=>array(-101.072861,45.750092),57622=>array(-101.535499,44.665466),57623=>array(-101.685858,45.02981),57625=>array(-101.004447,44.955728),57626=>array(-102.21651,44.994647),57630=>array(-100.905544,45.43916),57631=>array(-100.28101,45.532933),57632=>array(-100.037727,45.834003),57633=>array(-101.44799,45.457211),57634=>array(-101.896411,45.752033),57636=>array(-101.43743,45.031827),57638=>array(-102.23206,45.869861),57639=>array(-100.755383,45.696189),57640=>array(-102.71762,45.789598),57641=>array(-101.317955,45.869353),57642=>array(-100.749546,45.811247),57644=>array(-102.046492,45.449229),57645=>array(-101.73929,45.980453),57646=>array(-100.08167,45.68242),57648=>array(-100.354491,45.910167),57649=>array(-102.857947,45.523816),57650=>array(-103.014362,45.847957),57651=>array(-103.148843,45.475472),57652=>array(-100.607935,45.205412),57656=>array(-101.059332,45.392991),57657=>array(-100.792161,45.518884),57658=>array(-100.494653,45.679845),57660=>array(-101.586365,45.797336),57661=>array(-100.960193,45.256752),57701=>array(-103.206866,44.145868),57702=>array(-103.420465,44.048273),57703=>array(-103.042628,44.004564),57706=>array(-103.09356,44.157189),57714=>array(-101.936856,43.301624),57716=>array(-102.207567,43.106936),57717=>array(-103.901961,44.9402),57718=>array(-103.368194,44.170732),57719=>array(-102.976094,44.232442),57720=>array(-103.657033,45.575865),57722=>array(-102.921098,43.456289),57724=>array(-104.023825,45.645373),57725=>array(-102.7919,43.932032),57730=>array(-103.649729,43.724138),57732=>array(-103.692542,44.201037),57735=>array(-103.84971,43.300919),57738=>array(-103.123928,43.6367),57741=>array(-103.466634,44.404969),57744=>array(-103.045941,43.782636),57745=>array(-103.778602,44.01924),57747=>array(-103.52724,43.384853),57748=>array(-102.04459,44.591039),57750=>array(-101.955547,43.593792),57751=>array(-103.453138,43.884533),57752=>array(-102.183721,43.460259),57754=>array(-103.887435,44.255588),57755=>array(-103.362052,45.84774),57756=>array(-102.49843,43.229698),57758=>array(-102.816181,44.909445),57759=>array(-103.559963,44.229188),57760=>array(-103.28694,45.012175),57761=>array(-102.740608,44.231205),57762=>array(-103.619692,44.753351),57763=>array(-103.251934,43.11135),57764=>array(-102.837949,43.183211),57766=>array(-103.197804,43.39762),57767=>array(-102.571112,44.136748),57769=>array(-103.286944,44.247073),57770=>array(-102.590242,43.059484),57772=>array(-102.588896,43.53255),57773=>array(-103.568147,43.592114),57775=>array(-102.02895,44.101964),57776=>array(-103.497547,45.263783),57779=>array(-103.755322,44.563773),57780=>array(-102.510542,43.780265),57782=>array(-103.140671,43.296596),57783=>array(-103.915361,44.467599),57785=>array(-103.2325,44.42566),57787=>array(-102.652557,44.685408),57788=>array(-103.206853,44.618348),57790=>array(-102.217278,44.082084),57791=>array(-102.44393,44.223162),57792=>array(-102.423902,44.536402),57793=>array(-103.57931,44.525591),57794=>array(-102.394843,43.124034),57799=>array(-103.872416,44.498707),58001=>array(-96.719993,46.445185),58002=>array(-97.397242,46.97109),58004=>array(-97.270723,47.026475),58005=>array(-96.950904,47.052877),58006=>array(-97.209796,47.101562),58007=>array(-97.468653,47.024361),58008=>array(-97.000547,46.309281),58009=>array(-97.246559,47.327689),58011=>array(-97.539887,46.91875),58012=>array(-97.168331,46.941686),58013=>array(-97.353266,46.057851),58015=>array(-96.816487,46.595255),58016=>array(-97.461755,47.367125),58017=>array(-97.851471,46.043361),58018=>array(-96.896504,46.435977),58021=>array(-97.083235,46.739076),58027=>array(-97.607916,46.633),58029=>array(-97.403783,47.119604),58030=>array(-96.670069,46.030059),58031=>array(-97.671491,46.767684),58032=>array(-97.642819,46.065094),58033=>array(-97.91956,46.4347),58035=>array(-97.420094,47.260723),58036=>array(-96.948134,47.155563),58038=>array(-96.995775,47.245107),58040=>array(-97.685,46.189495),58041=>array(-96.918364,46.047905),58042=>array(-96.956035,46.970891),58043=>array(-97.545003,45.97358),58045=>array(-97.016318,47.388882),58046=>array(-97.724586,47.328122),58047=>array(-96.872758,46.724262),58048=>array(-97.223803,47.198809),58049=>array(-98.008073,46.650738),58051=>array(-97.021501,46.636833),58052=>array(-97.272001,46.635532),58053=>array(-97.180528,46.052506),58054=>array(-97.668729,46.416881),58056=>array(-97.929394,47.231351),58057=>array(-97.257276,46.424475),58058=>array(-96.963366,46.182543),58059=>array(-97.125564,46.843963),58060=>array(-97.415599,46.264126),58061=>array(-96.902058,46.278946),58062=>array(-97.818823,46.637435),58063=>array(-97.797584,46.959034),58064=>array(-97.610872,47.144741),58065=>array(-97.760507,47.186168),58067=>array(-97.469354,46.070822),58068=>array(-97.395771,46.530291),58069=>array(-97.830088,46.247288),58071=>array(-97.676759,46.956401),58072=>array(-98.006833,46.925717),58075=>array(-96.730394,46.275536),58076=>array(-96.607584,46.272827),58077=>array(-96.97512,46.524837),58078=>array(-96.924088,46.8625),58079=>array(-97.324952,46.868242),58081=>array(-97.141395,46.310635),58102=>array(-96.834703,46.927094),58103=>array(-96.822078,46.856143),58104=>array(-96.839684,46.793238),58105=>array(-96.807848,46.895385),58201=>array(-97.141144,47.866638),58202=>array(-97.072208,47.920759),58203=>array(-97.16549,47.970477),58204=>array(-97.386797,47.955002),58205=>array(-97.378991,47.951474),58210=>array(-98.111589,48.405691),58212=>array(-98.000416,47.708541),58214=>array(-97.499701,47.924547),58216=>array(-97.43448,48.881885),58218=>array(-97.038395,47.593867),58219=>array(-96.878975,47.477626),58220=>array(-97.719638,48.796322),58222=>array(-97.678687,48.609949),58223=>array(-97.037889,47.505232),58224=>array(-97.943628,48.172338),58225=>array(-97.222779,48.611238),58227=>array(-97.892709,48.549096),58228=>array(-97.354638,47.880961),58229=>array(-98.244323,48.498485),58230=>array(-97.831611,47.474136),58231=>array(-97.824163,48.201306),58233=>array(-97.525719,48.226173),58235=>array(-97.474761,48.098989),58237=>array(-97.402876,48.414207),58238=>array(-97.392813,48.782789),58239=>array(-98.695066,48.922142),58240=>array(-97.487234,47.634161),58241=>array(-97.677426,48.698421),58243=>array(-97.680859,48.512705),58244=>array(-97.611693,48.144067),58249=>array(-98.326766,48.822776),58250=>array(-98.000815,48.274378),58251=>array(-97.700238,47.954294),58254=>array(-98.150008,47.774003),58256=>array(-97.200169,48.084025),58257=>array(-97.28183,47.497296),58258=>array(-97.351918,48.015382),58259=>array(-98.12823,48.025758),58260=>array(-98.024787,48.637588),58261=>array(-97.312762,48.244895),58262=>array(-97.876345,48.682182),58265=>array(-97.612143,48.956085),58266=>array(-97.849975,48.000939),58267=>array(-97.639177,47.752355),58269=>array(-98.176865,48.696182),58270=>array(-97.784084,48.393945),58271=>array(-97.289694,48.912895),58272=>array(-97.981833,48.016263),58273=>array(-97.668546,48.2961),58274=>array(-97.488549,47.491896),58275=>array(-97.121138,47.679374),58276=>array(-97.46035,48.638084),58277=>array(-97.82331,47.608381),58278=>array(-97.121538,47.770086),58281=>array(-98.616489,48.855839),58282=>array(-97.940624,48.912003),58301=>array(-98.871704,48.142106),58311=>array(-98.590163,48.6521),58316=>array(-99.776962,48.824301),58317=>array(-99.373909,48.605338),58318=>array(-100.398144,48.858254),58321=>array(-98.344818,48.200714),58323=>array(-98.885162,48.855224),58324=>array(-99.220944,48.479397),58325=>array(-99.148558,48.290313),58327=>array(-98.594378,48.100954),58329=>array(-100.079593,48.873307),58330=>array(-98.459621,48.449502),58331=>array(-99.088781,48.639292),58332=>array(-99.772971,48.044159),58335=>array(-99.021353,47.986582),58338=>array(-98.624443,48.537137),58339=>array(-99.436299,48.899531),58341=>array(-99.844409,47.782102),58343=>array(-99.729507,48.303796),58344=>array(-98.341509,48.027839),58345=>array(-98.366226,48.307009),58346=>array(-99.427696,48.287375),58348=>array(-99.52109,47.971665),58351=>array(-99.278079,48.099065),58352=>array(-98.872781,48.710574),58353=>array(-99.596632,48.634662),58355=>array(-98.36642,48.590751),58356=>array(-99.085157,47.678659),58357=>array(-99.238515,47.94846),58361=>array(-98.339226,47.752479),58362=>array(-99.085481,48.212202),58363=>array(-99.447307,48.755027),58365=>array(-99.252883,48.859376),58366=>array(-99.874028,48.653521),58367=>array(-99.580643,48.870402),58368=>array(-100.05322,48.260871),58369=>array(-99.797109,48.943639),58370=>array(-98.834887,47.985178),58372=>array(-98.996927,48.945191),58374=>array(-99.097658,47.839573),58377=>array(-98.872823,48.464438),58379=>array(-98.843555,47.905577),58380=>array(-98.501854,47.825153),58381=>array(-98.748768,47.825765),58382=>array(-98.778792,48.318151),58384=>array(-100.26556,48.595867),58385=>array(-99.656395,48.479811),58386=>array(-99.598337,48.305995),58401=>array(-98.766655,46.884369),58402=>array(-98.687205,46.880348),58405=>array(-98.699439,46.915167),58413=>array(-99.293167,46.035752),58415=>array(-98.489402,46.373335),58416=>array(-98.347888,47.528938),58418=>array(-99.638974,47.420589),58420=>array(-98.85844,47.061018),58421=>array(-99.076593,47.440419),58422=>array(-99.40523,47.600221),58423=>array(-99.836299,47.401106),58424=>array(-99.110117,46.887399),58425=>array(-98.1247,47.45637),58426=>array(-98.589253,47.218524),58428=>array(-99.779393,46.828271),58429=>array(-98.158296,47.190008),58430=>array(-100.256876,47.508825),58431=>array(-98.486606,46.510931),58433=>array(-98.71208,46.370064),58436=>array(-98.581639,46.089591),58438=>array(-99.602381,47.666874),58439=>array(-98.829165,45.975635),58440=>array(-99.163638,46.253311),58441=>array(-98.368493,46.175288),58442=>array(-99.179594,46.553679),58443=>array(-98.681116,47.449844),58444=>array(-100.129143,47.494062),58445=>array(-98.809454,47.5659),58448=>array(-98.225008,47.305957),58451=>array(-99.958447,47.44714),58452=>array(-98.231235,47.547759),58454=>array(-98.95332,46.588078),58455=>array(-98.766798,47.304908),58456=>array(-98.954289,46.265514),58458=>array(-98.293851,46.367931),58460=>array(-99.324558,46.301694),58461=>array(-98.194794,46.652585),58463=>array(-100.471014,47.493414),58464=>array(-98.565277,47.610726),58466=>array(-98.368908,46.623799),58467=>array(-99.330649,46.884858),58472=>array(-98.650249,46.638569),58474=>array(-98.127097,46.100294),58475=>array(-99.555396,47.179948),58476=>array(-99.011587,47.200511),58477=>array(-100.504652,47.218894),58478=>array(-99.749464,47.175493),58479=>array(-98.182702,47.092281),58480=>array(-98.259449,46.957653),58481=>array(-98.428684,46.927787),58482=>array(-99.899917,46.853459),58483=>array(-99.42977,46.646328),58484=>array(-98.485054,47.375996),58486=>array(-99.382027,47.39136),58487=>array(-99.605672,46.856767),58488=>array(-99.994035,47.176298),58490=>array(-98.065932,46.376985),58492=>array(-98.44132,47.156398),58494=>array(-100.262723,47.184778),58495=>array(-99.604874,46.277793),58496=>array(-99.328693,47.14646),58497=>array(-98.549987,46.765067),58501=>array(-100.700296,46.816035),58503=>array(-100.750302,46.90412),58504=>array(-100.678406,46.737571),58505=>array(-100.780917,46.820212),58520=>array(-101.576123,46.674204),58521=>array(-100.693945,47.008103),58523=>array(-101.779709,47.257221),58524=>array(-100.07366,46.600122),58528=>array(-100.636812,46.338619),58529=>array(-101.559699,46.295012),58530=>array(-101.14292,47.127782),58531=>array(-101.195631,47.567258),58532=>array(-100.108874,46.857611),58533=>array(-101.789702,46.405842),58535=>array(-101.247288,46.501789),58538=>array(-100.689563,46.109619),58540=>array(-101.727334,47.628881),58541=>array(-102.068222,47.366124),58542=>array(-100.009897,46.050849),58544=>array(-100.370811,46.512194),58545=>array(-101.591236,47.357925),58549=>array(-99.92971,46.479104),58552=>array(-100.28306,46.2472),58554=>array(-100.9353,46.742723),58558=>array(-100.488304,46.829735),58559=>array(-100.728214,47.489371),58560=>array(-100.265129,46.678439),58561=>array(-99.682891,46.48715),58562=>array(-101.996874,46.37735),58563=>array(-101.439257,46.898984),58564=>array(-101.344234,46.266095),58565=>array(-101.370899,47.493482),58566=>array(-100.925343,46.583219),58568=>array(-101.045286,46.087315),58569=>array(-101.19937,46.268099),58570=>array(-100.887669,46.381918),58571=>array(-101.397673,47.2795),58572=>array(-100.341305,46.857026),58573=>array(-100.201007,46.098273),58575=>array(-100.896029,47.567272),58576=>array(-101.214233,47.436908),58577=>array(-101.052285,47.317793),58579=>array(-100.738366,47.179421),58580=>array(-101.943318,47.267529),58581=>array(-99.774432,46.035178),58601=>array(-102.834258,46.916872),58620=>array(-103.330485,46.520262),58621=>array(-103.930449,47.088368),58622=>array(-103.263285,46.894005),58623=>array(-103.433731,46.187311),58625=>array(-102.199765,47.268133),58626=>array(-102.622965,47.383027),58627=>array(-103.299937,47.240135),58630=>array(-102.57856,46.944101),58631=>array(-101.800739,46.806565),58632=>array(-103.965986,46.665985),58634=>array(-103.316291,47.423095),58636=>array(-102.367171,47.379346),58638=>array(-102.045415,46.945999),58639=>array(-102.602641,46.094238),58640=>array(-102.908533,47.441538),58641=>array(-102.513912,46.667877),58642=>array(-102.840448,47.209459),58643=>array(-103.944785,46.330898),58645=>array(-103.55235,46.951266),58646=>array(-102.287643,46.392913),58647=>array(-102.936294,46.518902),58649=>array(-102.922871,46.126274),58650=>array(-102.582946,46.44305),58651=>array(-103.733341,46.255912),58652=>array(-102.241813,46.894071),58653=>array(-103.130557,46.097262),58654=>array(-103.79485,46.88723),58655=>array(-103.030395,46.781105),58656=>array(-102.458368,46.943037),58701=>array(-101.326016,48.144826),58702=>array(-101.293788,48.232139),58703=>array(-101.307237,48.334038),58704=>array(-101.320944,48.424722),58705=>array(-101.33391,48.422342),58707=>array(-101.30052,48.246218),58710=>array(-100.231091,47.868061),58711=>array(-101.28909,48.929575),58712=>array(-100.531684,47.970973),58713=>array(-100.581797,48.538378),58716=>array(-101.067845,47.804326),58718=>array(-101.803517,48.305559),58721=>array(-102.273464,48.80308),58722=>array(-101.501497,48.238173),58723=>array(-100.596246,47.745887),58725=>array(-101.680009,48.49549),58727=>array(-102.796832,48.839872),58730=>array(-103.316671,48.864883),58731=>array(-100.984013,48.436748),58733=>array(-101.587881,48.175009),58734=>array(-101.935295,48.513686),58735=>array(-101.48127,47.870209),58736=>array(-100.396626,47.930851),58737=>array(-102.382326,48.915978),58740=>array(-101.224182,48.468901),58741=>array(-100.830824,48.2768),58744=>array(-100.61532,48.116546),58746=>array(-102.094053,48.713443),58748=>array(-100.654837,48.681729),58750=>array(-101.397529,48.610954),58752=>array(-102.579963,48.829491),58755=>array(-102.951118,48.625886),58756=>array(-101.814643,47.970898),58757=>array(-102.555817,47.686282),58758=>array(-100.101707,47.782028),58759=>array(-101.238927,47.855616),58760=>array(-101.15762,48.6973),58761=>array(-101.534814,48.784372),58762=>array(-100.940087,48.673209),58763=>array(-102.564713,47.990944),58765=>array(-103.042817,48.873295),58768=>array(-101.003629,48.233235),58769=>array(-102.202714,48.319909),58770=>array(-102.169646,47.884344),58771=>array(-101.976214,48.088309),58772=>array(-102.622887,48.959569),58773=>array(-102.657837,48.58258),58775=>array(-101.861201,47.710059),58776=>array(-102.623232,48.247805),58778=>array(-100.934223,47.787886),58779=>array(-101.775409,47.869388),58781=>array(-101.132721,48.015761),58782=>array(-101.70467,48.944346),58783=>array(-100.76366,48.879354),58784=>array(-102.417701,48.36436),58785=>array(-101.089369,48.307789),58787=>array(-101.813659,48.756322),58788=>array(-100.467754,48.345799),58789=>array(-100.808895,48.553182),58790=>array(-100.947714,48.029571),58792=>array(-100.746785,47.971228),58793=>array(-101.049811,48.872191),58794=>array(-102.780037,48.268907),58795=>array(-103.156753,48.640375),58801=>array(-103.763084,48.21789),58830=>array(-103.461197,48.611872),58831=>array(-103.658527,47.799354),58833=>array(-103.510039,48.887118),58835=>array(-103.436929,47.767584),58838=>array(-103.900837,47.769991),58843=>array(-103.37749,48.23386),58844=>array(-103.749952,48.887526),58845=>array(-103.917535,48.641039),58847=>array(-102.907792,47.910892),58849=>array(-103.202925,48.317528),58852=>array(-102.946753,48.364287),58853=>array(-103.836881,48.07543),58854=>array(-103.15327,47.828352),58856=>array(-103.732864,48.595028),59001=>array(-109.532582,45.532893),59002=>array(-108.657558,46.008342),59003=>array(-106.202189,45.445763),59006=>array(-108.08888,45.92083),59007=>array(-109.129926,45.141007),59008=>array(-109.08775,45.061726),59010=>array(-107.286066,45.99271),59011=>array(-109.949163,45.924753),59012=>array(-106.439398,45.274847),59013=>array(-109.087117,45.456107),59014=>array(-108.759696,45.193946),59015=>array(-108.803789,46.054068),59016=>array(-106.947305,45.392677),59018=>array(-110.541821,45.852744),59019=>array(-109.217531,45.651783),59020=>array(-110.101355,45.107963),59022=>array(-107.287695,45.537869),59024=>array(-107.807114,46.278426),59025=>array(-106.633203,45.10718),59026=>array(-108.78437,45.485364),59027=>array(-110.912914,45.242152),59028=>array(-109.713875,45.302402),59029=>array(-108.79881,45.407971),59030=>array(-110.518994,45.104515),59031=>array(-107.414815,45.502431),59032=>array(-108.703075,47.024621),59033=>array(-109.701409,45.729478),59034=>array(-107.693463,45.697254),59035=>array(-107.963105,45.283),59036=>array(-109.933967,46.480275),59037=>array(-108.242236,45.823982),59038=>array(-107.207584,46.203126),59039=>array(-107.291122,46.686774),59041=>array(-108.982487,45.526812),59043=>array(-106.676381,45.550799),59044=>array(-108.728479,45.630153),59046=>array(-109.015696,46.398482),59047=>array(-110.571103,45.547286),59050=>array(-107.544498,45.236633),59052=>array(-110.14513,45.466295),59053=>array(-110.459635,46.46129),59054=>array(-107.748778,46.644536),59055=>array(-109.809893,46.108998),59057=>array(-108.933193,45.853502),59058=>array(-107.717565,47.147005),59059=>array(-108.072627,46.407918),59061=>array(-109.890082,45.266327),59062=>array(-106.1504,45.092944),59063=>array(-108.948235,45.669765),59064=>array(-107.977538,45.819184),59065=>array(-110.71508,45.271428),59066=>array(-108.510339,45.335866),59067=>array(-109.217637,46.000389),59068=>array(-109.446013,45.119299),59069=>array(-109.500979,45.820354),59070=>array(-109.186103,45.375314),59071=>array(-109.631058,45.245669),59072=>array(-108.545192,46.471295),59074=>array(-109.353209,46.36306),59075=>array(-107.88361,45.405332),59076=>array(-107.073958,46.27875),59077=>array(-107.600605,47.205086),59078=>array(-109.610551,46.333651),59079=>array(-108.363307,46.062118),59081=>array(-109.973519,45.00832),59082=>array(-110.225294,45.743009),59085=>array(-110.18523,46.331578),59086=>array(-110.561218,46.072243),59087=>array(-108.226575,47.141917),59088=>array(-108.093579,46.074337),59089=>array(-107.361533,45.083475),59101=>array(-108.390305,45.613054),59102=>array(-108.580206,45.775649),59105=>array(-108.497574,45.892816),59106=>array(-108.705501,45.813662),59201=>array(-105.699503,48.172933),59211=>array(-104.349863,48.698644),59212=>array(-104.143067,48.222386),59213=>array(-104.886609,48.189413),59214=>array(-105.993835,47.307279),59215=>array(-105.77482,47.518194),59217=>array(-104.249465,47.579319),59218=>array(-104.560133,48.082623),59219=>array(-104.219763,48.526096),59221=>array(-104.188313,47.934085),59222=>array(-105.116454,48.693491),59223=>array(-106.212668,47.833775),59225=>array(-105.975287,48.284384),59226=>array(-104.571021,48.352474),59230=>array(-106.83615,48.101697),59231=>array(-106.547859,48.398053),59240=>array(-106.235732,48.842166),59241=>array(-107.059858,48.477635),59242=>array(-104.450943,48.443672),59243=>array(-104.679209,47.757547),59244=>array(-106.306396,48.590447),59247=>array(-104.523506,48.516199),59248=>array(-106.299423,48.29158),59250=>array(-106.556891,48.874816),59252=>array(-104.816259,48.917904),59253=>array(-105.898705,48.701091),59254=>array(-104.607972,48.754335),59255=>array(-105.169231,48.244168),59256=>array(-104.563481,48.925113),59257=>array(-104.962457,48.751314),59258=>array(-104.691284,48.5847),59259=>array(-105.099851,47.680957),59260=>array(-106.087919,48.826953),59261=>array(-107.386829,48.573615),59262=>array(-104.497095,47.489619),59263=>array(-105.529249,48.788149),59270=>array(-104.086128,47.609455),59274=>array(-105.48479,47.821893),59275=>array(-104.199016,48.874467),59276=>array(-105.212453,48.952233),59301=>array(-105.759506,46.293338),59311=>array(-104.417202,45.171683),59312=>array(-106.214844,47.002377),59313=>array(-104.244522,46.309664),59314=>array(-105.374924,45.075613),59315=>array(-104.858271,47.4365),59317=>array(-105.488298,45.356538),59318=>array(-107.51385,47.501154),59322=>array(-106.686345,47.010502),59323=>array(-106.666467,45.98421),59324=>array(-104.54255,45.783736),59326=>array(-104.859402,46.770357),59327=>array(-106.682233,46.236772),59330=>array(-104.748781,47.098693),59332=>array(-104.8621,45.328163),59333=>array(-106.219986,46.277368),59336=>array(-105.022988,46.331998),59337=>array(-106.79841,47.384253),59338=>array(-105.640492,46.640459),59339=>array(-105.195851,47.27055),59343=>array(-105.465132,45.662588),59344=>array(-104.593818,46.398877),59347=>array(-106.319968,46.383891),59349=>array(-105.502227,46.890151),59351=>array(-105.749927,45.75235),59353=>array(-104.274466,46.962866),59354=>array(-104.300203,46.181923),59401=>array(-111.2755,47.511219),59404=>array(-111.32887,47.631766),59405=>array(-111.298533,47.319261),59410=>array(-112.635447,47.48688),59411=>array(-113.394345,48.862924),59412=>array(-110.88911,47.327271),59414=>array(-111.259323,47.528099),59416=>array(-111.492748,48.037342),59417=>array(-113.129197,48.701391),59418=>array(-109.920424,46.799504),59419=>array(-112.41701,47.983733),59420=>array(-111.003826,47.877491),59421=>array(-111.73737,47.19607),59422=>array(-112.473813,47.813941),59424=>array(-110.107221,47.352939),59425=>array(-111.898534,48.187188),59427=>array(-112.53309,48.77023),59430=>array(-109.828966,47.428095),59432=>array(-112.411284,48.168933),59433=>array(-111.69203,47.883621),59434=>array(-113.363518,48.479489),59436=>array(-112.04732,47.612001),59440=>array(-111.15854,47.716021),59441=>array(-108.983837,46.860923),59442=>array(-110.644944,47.894607),59443=>array(-111.828933,47.563934),59444=>array(-111.377291,48.727062),59446=>array(-110.159518,47.6184),59447=>array(-110.473317,47.264849),59448=>array(-112.781368,48.267024),59450=>array(-110.742839,47.552525),59451=>array(-109.389662,47.389175),59452=>array(-110.106626,46.861898),59453=>array(-109.652844,46.638569),59454=>array(-112.005415,48.72252),59456=>array(-111.36167,48.27015),59457=>array(-109.310721,47.139997),59460=>array(-110.504941,48.08457),59461=>array(-111.201456,48.489338),59462=>array(-109.891841,47.122564),59463=>array(-110.830833,47.035641),59464=>array(-109.655409,46.907111),59465=>array(-110.720273,46.890345),59466=>array(-111.70105,48.768832),59467=>array(-112.601298,48.067356),59468=>array(-111.62773,47.705609),59469=>array(-110.701673,47.201398),59471=>array(-108.772077,47.426655),59472=>array(-111.159034,47.396634),59474=>array(-111.72954,48.508807),59477=>array(-111.916558,47.450159),59479=>array(-110.30532,47.032558),59480=>array(-111.229206,47.156478),59482=>array(-111.912019,48.869875),59483=>array(-111.70137,47.453014),59484=>array(-111.658692,48.967184),59485=>array(-111.572195,47.401699),59486=>array(-112.352072,48.328011),59487=>array(-111.638487,47.587197),59489=>array(-109.229309,47.624548),59501=>array(-109.78113,48.689862),59520=>array(-109.910509,48.025105),59521=>array(-109.918262,48.298777),59522=>array(-111.005156,48.550782),59523=>array(-109.238565,48.531584),59524=>array(-108.337007,48.229062),59525=>array(-110.302843,48.689648),59526=>array(-108.718051,48.440569),59527=>array(-108.752914,48.03336),59528=>array(-110.408743,48.576175),59529=>array(-108.631789,48.824522),59530=>array(-110.717397,48.631778),59531=>array(-110.801412,48.788389),59532=>array(-110.105784,48.578152),59535=>array(-109.291498,47.980497),59537=>array(-108.056377,48.829781),59538=>array(-107.84552,48.112019),59540=>array(-110.564262,48.595081),59542=>array(-108.379302,48.793007),59544=>array(-107.557123,48.805309),59545=>array(-111.16259,48.938962),59546=>array(-108.592475,47.751189),59547=>array(-109.030355,48.661556),59601=>array(-112.21037,46.527398),59602=>array(-111.905529,46.739365),59631=>array(-112.429775,46.318339),59632=>array(-112.020452,46.199908),59633=>array(-112.342933,46.818845),59634=>array(-111.947796,46.453506),59635=>array(-111.825982,46.565126),59636=>array(-112.109921,46.619729),59638=>array(-111.967499,46.360758),59639=>array(-112.692961,47.07614),59640=>array(-112.299386,46.736116),59642=>array(-110.718587,46.283477),59643=>array(-111.589827,46.172521),59644=>array(-111.415948,46.428793),59645=>array(-111.054661,46.687671),59647=>array(-111.652939,46.491037),59648=>array(-112.127867,47.07724),59701=>array(-112.47572,46.035043),59703=>array(-112.537462,46.045687),59710=>array(-112.067993,45.06535),59711=>array(-113.139108,46.099059),59713=>array(-112.561064,46.700778),59714=>array(-111.129807,45.980279),59715=>array(-110.898798,45.82641),59716=>array(-111.489175,45.067125),59718=>array(-111.118089,45.576265),59720=>array(-111.723513,44.85875),59721=>array(-111.837159,45.883065),59722=>array(-112.772501,46.366483),59724=>array(-112.762062,44.696254),59725=>array(-112.821469,45.098018),59727=>array(-112.837769,45.801675),59728=>array(-112.434846,46.508907),59729=>array(-111.649073,45.29372),59730=>array(-111.135185,45.274465),59731=>array(-112.779623,46.5822),59732=>array(-112.727015,45.48522),59733=>array(-112.941615,46.492252),59735=>array(-111.869264,45.651217),59736=>array(-113.373845,45.320646),59739=>array(-112.17207,44.635875),59740=>array(-111.827844,45.482937),59741=>array(-111.368344,45.769824),59743=>array(-112.680338,45.68041),59745=>array(-111.614817,45.595197),59746=>array(-113.06207,45.386453),59747=>array(-111.923859,45.735177),59748=>array(-112.699236,46.046682),59749=>array(-112.08526,45.451603),59750=>array(-112.757232,45.948191),59751=>array(-112.436317,45.704776),59752=>array(-111.503941,45.946381),59754=>array(-112.326386,45.456857),59755=>array(-111.917328,45.319288),59756=>array(-112.828004,46.179849),59758=>array(-111.182902,44.741942),59759=>array(-112.191421,45.851618),59760=>array(-111.632061,45.766631),59761=>array(-113.534189,45.642317),59762=>array(-113.030793,45.602186),59801=>array(-114.014338,46.856398),59802=>array(-113.919148,46.903865),59803=>array(-113.950416,46.796608),59804=>array(-114.233812,46.875763),59808=>array(-114.086201,46.980859),59820=>array(-114.625586,46.898852),59821=>array(-114.077435,47.173341),59823=>array(-113.577725,46.919806),59824=>array(-114.203035,47.422742),59825=>array(-113.735591,46.614276),59826=>array(-113.792237,47.37392),59827=>array(-114.004111,45.885625),59828=>array(-113.97538,46.331172),59829=>array(-114.295604,45.776417),59830=>array(-115.343643,47.424528),59831=>array(-114.368312,47.26012),59832=>array(-113.252857,46.688956),59833=>array(-114.062364,46.655485),59834=>array(-114.221653,47.080954),59837=>array(-113.255399,46.540302),59840=>array(-114.193689,46.185493),59841=>array(-114.222998,46.334211),59842=>array(-115.437448,47.329951),59843=>array(-112.965761,46.832595),59844=>array(-115.974258,48.058227),59845=>array(-114.555981,47.690337),59846=>array(-114.513148,47.15181),59847=>array(-114.460596,46.702089),59848=>array(-114.693294,47.699486),59851=>array(-113.876537,46.871544),59853=>array(-115.790724,48.042017),59854=>array(-113.087968,47.028464),59855=>array(-114.118589,47.60551),59856=>array(-114.748394,47.314176),59858=>array(-113.4674,46.285772),59859=>array(-114.826544,47.535214),59860=>array(-114.17282,47.706523),59863=>array(-114.182539,47.300226),59864=>array(-114.109302,47.529251),59865=>array(-114.010198,47.330512),59866=>array(-115.158561,47.327042),59867=>array(-115.611979,47.440003),59868=>array(-113.506003,47.211792),59870=>array(-114.06345,46.516308),59871=>array(-113.819335,45.870728),59872=>array(-114.90092,47.110018),59873=>array(-115.297327,47.668305),59874=>array(-115.623421,47.79941),59875=>array(-114.314609,46.419841),59901=>array(-114.385053,48.229649),59910=>array(-114.298852,47.795266),59911=>array(-113.740522,47.738441),59912=>array(-114.154362,48.408215),59913=>array(-113.951352,48.440278),59914=>array(-114.281831,47.858197),59915=>array(-114.4052,47.848129),59916=>array(-113.381612,48.256533),59917=>array(-114.876902,48.936035),59918=>array(-114.859061,48.768101),59919=>array(-113.23959,47.958549),59920=>array(-114.545855,48.053743),59922=>array(-114.187522,47.996638),59923=>array(-115.392222,48.226144),59925=>array(-114.833941,48.048355),59926=>array(-113.997993,48.352716),59927=>array(-114.711833,48.592348),59928=>array(-114.45834,48.778144),59929=>array(-114.369341,47.927434),59930=>array(-115.133187,48.866733),59931=>array(-114.174975,47.914632),59932=>array(-114.192423,48.057999),59933=>array(-114.772578,48.682382),59934=>array(-114.8983,48.600295),59935=>array(-115.832885,48.650377),59936=>array(-113.807633,48.626399),59937=>array(-114.532766,48.406092),60002=>array(-88.083818,42.471077),60004=>array(-87.979542,42.11278),60005=>array(-87.985462,42.06449),60007=>array(-87.99736,42.00865),60008=>array(-88.016221,42.069786),60010=>array(-88.165268,42.146794),60012=>array(-88.314084,42.272492),60013=>array(-88.235532,42.223188),60014=>array(-88.327449,42.232414),60015=>array(-87.878173,42.173809),60016=>array(-87.895,42.04958),60018=>array(-87.911763,41.979388),60020=>array(-88.173346,42.389054),60021=>array(-88.217108,42.194697),60022=>array(-87.761882,42.135423),60025=>array(-87.821026,42.075201),60026=>array(-87.837445,42.092234),60029=>array(-87.778339,42.059253),60030=>array(-88.044326,42.337078),60031=>array(-87.939353,42.373574),60033=>array(-88.608011,42.424786),60034=>array(-88.419695,42.456318),60035=>array(-87.805939,42.185968),60040=>array(-87.813102,42.206369),60041=>array(-88.15112,42.364552),60042=>array(-88.196627,42.278206),60043=>array(-87.714588,42.088859),60044=>array(-87.862297,42.284408),60045=>array(-87.864777,42.235997),60046=>array(-88.059119,42.416323),60047=>array(-88.044208,42.203134),60048=>array(-87.950611,42.295408),60050=>array(-88.29518,42.331147),60051=>array(-88.228663,42.355462),60053=>array(-87.788949,42.042336),60056=>array(-87.934719,42.067166),60060=>array(-88.039275,42.270156),60061=>array(-87.959135,42.234909),60062=>array(-87.846704,42.126511),60064=>array(-87.856704,42.324027),60067=>array(-88.064362,42.106323),60068=>array(-87.843434,42.011762),60069=>array(-87.923934,42.196156),60070=>array(-87.928972,42.103663),60071=>array(-88.31593,42.468058),60072=>array(-88.305871,42.406697),60073=>array(-88.109581,42.348824),60074=>array(-88.026329,42.131462),60076=>array(-87.729928,42.035259),60077=>array(-87.757186,42.034751),60081=>array(-88.225409,42.451014),60083=>array(-87.941889,42.436403),60084=>array(-88.140911,42.269669),60085=>array(-87.867656,42.352097),60087=>array(-87.850836,42.403085),60088=>array(-87.844061,42.309632),60089=>array(-87.960653,42.167465),60090=>array(-87.921102,42.129419),60091=>array(-87.720581,42.078067),60093=>array(-87.756292,42.106708),60096=>array(-87.824805,42.479722),60097=>array(-88.371039,42.396954),60098=>array(-88.456071,42.326227),60099=>array(-87.864977,42.459907),60101=>array(-88.01305,41.93106),60102=>array(-88.308625,42.164741),60103=>array(-88.203407,41.980446),60104=>array(-87.87643,41.882845),60106=>array(-87.941835,41.959701),60107=>array(-88.177771,42.020586),60108=>array(-88.091865,41.950022),60109=>array(-88.54591,42.049789),60110=>array(-88.291866,42.114687),60111=>array(-88.805358,42.009497),60112=>array(-88.690186,41.924797),60113=>array(-88.965872,41.932247),60115=>array(-88.759253,41.901264),60118=>array(-88.304394,42.106199),60119=>array(-88.47645,41.851532),60120=>array(-88.238396,42.034492),60123=>array(-88.311296,42.040644),60124=>array(-88.400686,42.020169),60126=>array(-87.94124,41.896843),60129=>array(-88.974996,42.008121),60130=>array(-87.817389,41.86644),60131=>array(-87.884263,41.938755),60133=>array(-88.14259,41.977726),60134=>array(-88.342066,41.878343),60135=>array(-88.670862,42.112495),60136=>array(-88.380573,42.105485),60137=>array(-88.061479,41.865213),60139=>array(-88.078095,41.918877),60140=>array(-88.515442,42.080051),60141=>array(-87.837993,41.857831),60142=>array(-88.444664,42.173997),60143=>array(-88.022774,41.97417),60144=>array(-88.520644,41.835957),60145=>array(-88.773824,42.084558),60146=>array(-88.874353,42.100452),60148=>array(-88.020766,41.873571),60150=>array(-88.894473,41.925825),60151=>array(-88.574468,41.918475),60152=>array(-88.625522,42.237792),60153=>array(-87.843251,41.879283),60154=>array(-87.891643,41.847471),60155=>array(-87.856225,41.857696),60156=>array(-88.320768,42.203618),60157=>array(-88.056122,41.9753),60160=>array(-87.860665,41.904144),60162=>array(-87.902188,41.867533),60163=>array(-87.909048,41.88883),60164=>array(-87.900698,41.917512),60165=>array(-87.880713,41.903215),60169=>array(-88.116615,42.05087),60171=>array(-87.838372,41.925046),60172=>array(-88.089628,41.97985),60173=>array(-88.055522,42.051556),60174=>array(-88.298737,41.930757),60175=>array(-88.388701,41.948188),60176=>array(-87.868886,41.958125),60177=>array(-88.310167,41.988481),60178=>array(-88.670669,42.006791),60180=>array(-88.524527,42.225262),60181=>array(-87.976328,41.876897),60184=>array(-88.25317,41.951502),60185=>array(-88.211014,41.896691),60187=>array(-88.112442,41.87272),60188=>array(-88.129434,41.915737),60189=>array(-88.117716,41.839981),60190=>array(-88.157034,41.871796),60191=>array(-87.980851,41.966306),60192=>array(-88.203662,42.063272),60193=>array(-88.096644,42.009666),60194=>array(-88.110285,42.03482),60195=>array(-88.086284,42.074962),60201=>array(-87.69224,42.05614),60202=>array(-87.685549,42.030355),60203=>array(-87.717453,42.049045),60301=>array(-87.798933,41.888545),60302=>array(-87.789713,41.894611),60304=>array(-87.789483,41.872389),60305=>array(-87.819064,41.894875),60401=>array(-87.6164,41.343959),60402=>array(-87.791373,41.835216),60403=>array(-88.134185,41.553739),60404=>array(-88.223977,41.513049),60406=>array(-87.681952,41.654945),60407=>array(-88.261302,41.234907),60408=>array(-88.215536,41.263739),60409=>array(-87.552122,41.613641),60410=>array(-88.201907,41.4236),60411=>array(-87.590314,41.508774),60415=>array(-87.77883,41.702948),60416=>array(-88.283101,41.293908),60417=>array(-87.586149,41.427585),60419=>array(-87.59949,41.629147),60420=>array(-88.41697,41.088287),60421=>array(-88.09971,41.431182),60422=>array(-87.684139,41.536964),60423=>array(-87.832416,41.477368),60424=>array(-88.327716,41.164148),60425=>array(-87.611726,41.545576),60426=>array(-87.653394,41.610343),60428=>array(-87.690565,41.5998),60429=>array(-87.683706,41.574029),60430=>array(-87.664442,41.55888),60431=>array(-88.180211,41.509668),60432=>array(-88.034728,41.541747),60433=>array(-88.043681,41.499502),60435=>array(-88.128928,41.54859),60436=>array(-88.129295,41.486888),60437=>array(-88.560435,41.162929),60438=>array(-87.550204,41.566242),60439=>array(-87.98177,41.676397),60440=>array(-88.075006,41.7006),60441=>array(-88.050043,41.592639),60442=>array(-87.963468,41.392698),60443=>array(-87.748201,41.502184),60444=>array(-88.402732,41.243115),60445=>array(-87.736395,41.63439),60446=>array(-88.1062,41.632017),60447=>array(-88.322166,41.487239),60448=>array(-87.892451,41.537785),60449=>array(-87.778882,41.417545),60450=>array(-88.434609,41.366374),60451=>array(-87.96109,41.507651),60452=>array(-87.75349,41.608007),60453=>array(-87.75256,41.713436),60455=>array(-87.808642,41.742076),60456=>array(-87.731134,41.731248),60457=>array(-87.828043,41.724664),60458=>array(-87.826946,41.753399),60459=>array(-87.768577,41.744431),60460=>array(-88.536714,40.998479),60461=>array(-87.700733,41.522116),60462=>array(-87.83293,41.625307),60463=>array(-87.789969,41.662446),60464=>array(-87.860756,41.66284),60465=>array(-87.829143,41.698023),60466=>array(-87.683188,41.477816),60467=>array(-87.889096,41.601621),60468=>array(-87.810291,41.335283),60469=>array(-87.687037,41.628359),60470=>array(-88.641026,41.16897),60471=>array(-87.734059,41.478971),60472=>array(-87.708082,41.643075),60473=>array(-87.59915,41.597379),60474=>array(-88.266368,41.180025),60475=>array(-87.627508,41.47254),60476=>array(-87.601707,41.569482),60477=>array(-87.78925,41.572143),60478=>array(-87.725409,41.563453),60479=>array(-88.526396,41.232384),60480=>array(-87.88131,41.729244),60481=>array(-88.114298,41.285227),60482=>array(-87.789946,41.687843),60484=>array(-87.708354,41.443615),60487=>array(-87.834416,41.56273),60490=>array(-88.145399,41.66932),60491=>array(-87.962887,41.602549),60501=>array(-87.823462,41.780204),60502=>array(-88.259738,41.790651),60503=>array(-88.25518,41.712127),60504=>array(-88.238622,41.747452),60505=>array(-88.294658,41.764527),60506=>array(-88.362227,41.765385),60510=>array(-88.306602,41.841141),60511=>array(-88.551993,41.758993),60512=>array(-88.439805,41.701578),60513=>array(-87.847546,41.825059),60514=>array(-87.962155,41.795689),60515=>array(-88.022796,41.810554),60516=>array(-88.013394,41.761302),60517=>array(-88.042149,41.740329),60518=>array(-88.919706,41.598864),60519=>array(-88.24261,41.777821),60520=>array(-88.667548,41.787267),60521=>array(-87.928172,41.800683),60523=>array(-87.953472,41.83661),60525=>array(-87.868952,41.78443),60526=>array(-87.873995,41.831794),60527=>array(-87.93236,41.742624),60530=>array(-88.95298,41.796909),60531=>array(-88.77964,41.617322),60532=>array(-88.083984,41.789443),60534=>array(-87.82189,41.813241),60536=>array(-88.549957,41.597542),60537=>array(-88.604224,41.560516),60538=>array(-88.338195,41.726871),60539=>array(-88.336209,41.82724),60540=>array(-88.145428,41.76467),60541=>array(-88.532418,41.513357),60542=>array(-88.352556,41.809609),60543=>array(-88.317818,41.664136),60544=>array(-88.218719,41.613637),60545=>array(-88.532995,41.679761),60546=>array(-87.821859,41.837923),60548=>array(-88.638131,41.649149),60549=>array(-88.739635,41.502537),60550=>array(-88.863296,41.781386),60551=>array(-88.687688,41.524826),60552=>array(-88.706507,41.666888),60553=>array(-89.033728,41.82706),60554=>array(-88.457062,41.776684),60555=>array(-88.180773,41.822167),60556=>array(-88.771142,41.762918),60557=>array(-88.760078,41.448102),60558=>array(-87.901039,41.805603),60559=>array(-87.97286,41.794371),60560=>array(-88.429346,41.60822),60561=>array(-87.981494,41.745663),60563=>array(-88.204404,41.789996),60564=>array(-88.19482,41.70743),60565=>array(-88.124336,41.730729),60585=>array(-88.225243,41.657058),60586=>array(-88.237756,41.571405),60601=>array(-87.622129,41.88531),60602=>array(-87.629149,41.883073),60603=>array(-87.625509,41.880188),60604=>array(-87.628461,41.878095),60605=>array(-87.617228,41.867566),60606=>array(-87.637349,41.882066),60607=>array(-87.651596,41.874932),60608=>array(-87.672388,41.846223),60609=>array(-87.656935,41.81268),60610=>array(-87.631939,41.906844),60611=>array(-87.613775,41.8957),60612=>array(-87.687749,41.88032),60613=>array(-87.654272,41.956949),60614=>array(-87.649577,41.922714),60615=>array(-87.596288,41.801647),60616=>array(-87.624032,41.844883),60617=>array(-87.552739,41.718197),60618=>array(-87.702548,41.946962),60619=>array(-87.605526,41.74369),60620=>array(-87.652558,41.740497),60621=>array(-87.639571,41.776382),60622=>array(-87.683337,41.902172),60623=>array(-87.717661,41.848897),60624=>array(-87.724444,41.880504),60625=>array(-87.700351,41.973292),60626=>array(-87.667095,42.010019),60628=>array(-87.615773,41.690875),60629=>array(-87.711496,41.775868),60630=>array(-87.756569,41.972071),60631=>array(-87.813003,41.994855),60632=>array(-87.713252,41.810166),60633=>array(-87.56147,41.663809),60634=>array(-87.806117,41.946189),60636=>array(-87.669064,41.775739),60637=>array(-87.599876,41.781621),60638=>array(-87.770534,41.781442),60639=>array(-87.756056,41.920553),60640=>array(-87.662604,41.972872),60641=>array(-87.746787,41.946606),60642=>array(-87.658544,41.902042),60643=>array(-87.663267,41.700273),60644=>array(-87.756373,41.880084),60645=>array(-87.694735,42.008558),60646=>array(-87.759627,41.993019),60647=>array(-87.701028,41.921215),60649=>array(-87.565879,41.76342),60651=>array(-87.74085,41.902095),60652=>array(-87.714807,41.74794),60653=>array(-87.605984,41.819962),60654=>array(-87.637271,41.892289),60655=>array(-87.703779,41.694781),60656=>array(-87.827131,41.97428),60657=>array(-87.646857,41.940293),60659=>array(-87.703986,41.991488),60660=>array(-87.663076,41.99111),60661=>array(-87.644098,41.883026),60706=>array(-87.816242,41.964257),60707=>array(-87.807282,41.921854),60712=>array(-87.733239,42.005432),60714=>array(-87.81096,42.028055),60803=>array(-87.735958,41.673552),60804=>array(-87.75987,41.838036),60805=>array(-87.702442,41.722005),60827=>array(-87.633572,41.649434),60901=>array(-87.897917,41.109505),60910=>array(-87.80953,41.080546),60911=>array(-87.976584,40.880243),60912=>array(-87.603476,40.973619),60913=>array(-88.061778,41.146985),60914=>array(-87.861802,41.187368),60915=>array(-87.861046,41.146304),60917=>array(-88.186315,41.047493),60918=>array(-88.02567,40.59497),60919=>array(-88.237518,40.987875),60920=>array(-88.30497,41.029257),60921=>array(-88.297018,40.731456),60922=>array(-87.917188,41.003226),60924=>array(-87.886524,40.551009),60926=>array(-87.823657,40.566351),60927=>array(-87.972776,40.938489),60928=>array(-87.849011,40.74166),60929=>array(-88.289163,40.874974),60930=>array(-88.002574,40.829913),60931=>array(-87.588141,40.889327),60932=>array(-87.805561,40.463312),60933=>array(-88.271912,40.464728),60934=>array(-88.353047,40.958061),60935=>array(-88.175861,41.170447),60936=>array(-88.351997,40.467849),60938=>array(-87.98826,40.773028),60940=>array(-87.642858,41.249777),60941=>array(-88.082084,41.041988),60942=>array(-87.661377,40.46538),60945=>array(-87.584213,40.828189),60946=>array(-88.202897,40.916505),60948=>array(-88.081061,40.525039),60949=>array(-88.105151,40.378337),60950=>array(-87.884593,41.252784),60951=>array(-87.755127,40.914602),60952=>array(-88.250366,40.562795),60953=>array(-87.688641,40.629577),60954=>array(-87.622516,41.147708),60955=>array(-87.969261,40.699506),60957=>array(-88.13589,40.443183),60958=>array(-87.591359,41.064833),60959=>array(-88.181996,40.789695),60960=>array(-87.890723,40.438957),60961=>array(-88.221504,41.109567),60962=>array(-88.187136,40.626121),60963=>array(-87.648421,40.366679),60964=>array(-87.744203,41.038816),60966=>array(-87.583223,40.751503),60968=>array(-88.119538,40.672352),60969=>array(-88.149737,41.110975),60970=>array(-87.734726,40.794942),60973=>array(-87.663146,40.541685),60974=>array(-87.733847,40.719013),61001=>array(-90.110232,42.465816),61006=>array(-89.202103,41.861743),61007=>array(-89.589505,42.197755),61008=>array(-88.84113,42.245919),61010=>array(-89.266354,42.134991),61011=>array(-88.897904,42.392526),61012=>array(-88.764558,42.401445),61013=>array(-89.639278,42.372123),61014=>array(-89.884447,41.974687),61015=>array(-89.197077,41.996752),61016=>array(-88.947723,42.197297),61018=>array(-89.555222,42.415263),61019=>array(-89.410047,42.439512),61020=>array(-89.098207,42.110183),61021=>array(-89.479188,41.827392),61024=>array(-89.297114,42.436415),61025=>array(-90.55626,42.470902),61027=>array(-89.757279,42.330909),61028=>array(-90.175881,42.298465),61030=>array(-89.591624,42.119648),61031=>array(-89.311588,41.832071),61032=>array(-89.636784,42.318004),61036=>array(-90.377097,42.413614),61037=>array(-89.760294,41.789331),61038=>array(-88.737964,42.265818),61039=>array(-89.467558,42.208868),61041=>array(-90.311245,42.273156),61042=>array(-89.562791,41.687626),61043=>array(-89.105241,42.056438),61044=>array(-89.915092,42.318779),61046=>array(-89.811739,42.104394),61047=>array(-89.395916,42.153152),61048=>array(-89.841231,42.382637),61049=>array(-89.008914,42.049626),61050=>array(-89.734143,42.440288),61051=>array(-89.754875,41.982781),61052=>array(-88.999555,42.111372),61053=>array(-89.983427,42.120761),61054=>array(-89.449449,42.054974),61057=>array(-89.382046,41.8292),61059=>array(-89.9402,42.453149),61060=>array(-89.621909,42.478161),61061=>array(-89.341656,41.997917),61062=>array(-89.835749,42.250635),61063=>array(-89.340658,42.319493),61064=>array(-89.582338,41.987852),61065=>array(-88.836952,42.400588),61067=>array(-89.478928,42.305046),61068=>array(-89.060013,41.945817),61070=>array(-89.473074,42.416818),61071=>array(-89.698867,41.724673),61072=>array(-89.13849,42.442353),61073=>array(-88.993849,42.423717),61074=>array(-90.120321,42.125818),61075=>array(-90.258941,42.464449),61077=>array(-89.357813,42.238138),61078=>array(-89.729005,42.165921),61079=>array(-89.216208,42.437245),61080=>array(-88.988025,42.482064),61081=>array(-89.735295,41.843847),61084=>array(-89.185652,42.124022),61085=>array(-90.032187,42.34181),61087=>array(-89.992631,42.480217),61088=>array(-89.262692,42.268117),61089=>array(-89.819325,42.473424),61091=>array(-89.52769,41.906878),61101=>array(-89.146087,42.346079),61102=>array(-89.162524,42.228769),61103=>array(-89.086492,42.340261),61104=>array(-89.079945,42.25172),61107=>array(-89.001692,42.28529),61108=>array(-89.002129,42.257371),61109=>array(-89.055756,42.191304),61111=>array(-89.002745,42.335503),61112=>array(-88.975184,42.241981),61114=>array(-88.990894,42.306605),61115=>array(-89.027467,42.364306),61201=>array(-90.575628,41.477559),61230=>array(-90.213132,41.734087),61231=>array(-90.718219,41.211487),61232=>array(-90.732438,41.430737),61234=>array(-89.914339,41.417963),61235=>array(-90.023559,41.401294),61236=>array(-90.367807,41.515956),61238=>array(-90.172661,41.282483),61239=>array(-90.383246,41.480572),61240=>array(-90.428608,41.421158),61241=>array(-90.321158,41.488588),61242=>array(-90.285148,41.708009),61243=>array(-89.682944,41.618771),61244=>array(-90.390822,41.522559),61250=>array(-90.112419,41.655926),61251=>array(-90.075699,41.730595),61252=>array(-90.125373,41.83691),61254=>array(-90.14981,41.467196),61256=>array(-90.407493,41.547833),61257=>array(-90.221845,41.593358),61258=>array(-89.91401,41.521564),61259=>array(-90.954365,41.392567),61260=>array(-90.880521,41.245974),61261=>array(-89.91546,41.726285),61262=>array(-90.348286,41.276069),61263=>array(-90.60473,41.258847),61264=>array(-90.594859,41.40222),61265=>array(-90.493492,41.482387),61270=>array(-89.963451,41.826598),61272=>array(-91.004598,41.253608),61273=>array(-90.398881,41.362901),61274=>array(-90.276974,41.368573),61275=>array(-90.307048,41.605575),61276=>array(-90.589916,41.304077),61277=>array(-89.930578,41.613582),61278=>array(-90.336732,41.582025),61279=>array(-90.726796,41.320528),61281=>array(-90.520144,41.29978),61282=>array(-90.412989,41.495554),61283=>array(-89.786563,41.591859),61284=>array(-90.751797,41.394212),61285=>array(-90.05832,41.985776),61301=>array(-89.082214,41.401096),61310=>array(-89.356823,41.701366),61311=>array(-88.860016,41.037692),61312=>array(-89.234905,41.436355),61313=>array(-88.668671,41.073694),61314=>array(-89.678495,41.296481),61315=>array(-89.364517,41.287804),61316=>array(-89.124987,41.259082),61317=>array(-89.208916,41.431454),61318=>array(-89.078271,41.711285),61319=>array(-88.742318,41.018416),61320=>array(-89.170456,41.35468),61321=>array(-88.973147,40.969276),61322=>array(-89.31759,41.314131),61323=>array(-89.396789,41.433059),61324=>array(-89.413892,41.769914),61325=>array(-88.809633,41.234953),61326=>array(-89.231034,41.245918),61327=>array(-89.311467,41.22671),61328=>array(-89.459257,41.499544),61329=>array(-89.180739,41.375034),61330=>array(-89.267012,41.536068),61331=>array(-89.277542,41.747703),61332=>array(-88.988778,41.188769),61333=>array(-88.888154,40.989245),61334=>array(-89.098451,41.145113),61335=>array(-89.218354,41.165748),61336=>array(-89.231916,41.112606),61337=>array(-89.32843,41.436413),61338=>array(-89.676107,41.458737),61340=>array(-89.250157,41.26125),61341=>array(-88.693281,41.352042),61342=>array(-89.08427,41.543343),61344=>array(-89.839694,41.411154),61345=>array(-89.794395,41.280245),61346=>array(-89.718402,41.51119),61348=>array(-89.035197,41.285723),61349=>array(-89.442299,41.544823),61350=>array(-88.865134,41.372048),61353=>array(-88.991053,41.704316),61354=>array(-89.143248,41.327928),61356=>array(-89.433868,41.39479),61358=>array(-89.044023,40.978724),61359=>array(-89.271459,41.362452),61360=>array(-88.600572,41.328218),61361=>array(-89.756154,41.413064),61362=>array(-89.23322,41.358708),61363=>array(-89.182339,41.254185),61364=>array(-88.841565,41.128078),61367=>array(-89.259488,41.621412),61368=>array(-89.521296,41.264642),61369=>array(-89.155061,40.984046),61370=>array(-89.038477,41.199778),61372=>array(-89.078018,41.4649),61373=>array(-88.995936,41.407228),61374=>array(-89.358725,41.547712),61375=>array(-89.244454,41.033889),61376=>array(-89.613262,41.545347),61377=>array(-89.034038,41.061382),61378=>array(-89.155402,41.722671),61379=>array(-89.60698,41.390795),61401=>array(-90.385282,40.944559),61410=>array(-90.396007,40.796475),61411=>array(-90.502128,40.400982),61412=>array(-90.579715,41.078398),61413=>array(-90.368905,41.190597),61414=>array(-90.155739,41.12468),61415=>array(-90.43127,40.65631),61416=>array(-90.562897,40.499397),61417=>array(-90.53832,40.774174),61418=>array(-90.862586,40.850174),61419=>array(-90.11746,41.199461),61420=>array(-90.86664,40.547722),61421=>array(-89.647935,41.187539),61422=>array(-90.532761,40.551362),61423=>array(-90.501204,40.886282),61424=>array(-89.634994,41.076767),61425=>array(-91.04015,40.759242),61426=>array(-89.70698,41.119997),61427=>array(-90.183878,40.508521),61428=>array(-90.107135,40.943829),61430=>array(-90.311209,40.939231),61431=>array(-90.276497,40.608009),61432=>array(-90.153167,40.648385),61433=>array(-90.168989,40.554375),61434=>array(-90.038516,41.183981),61435=>array(-90.544946,40.975148),61436=>array(-90.223174,40.860149),61437=>array(-90.987759,40.848791),61438=>array(-90.651654,40.582743),61439=>array(-90.357059,41.028419),61440=>array(-90.598626,40.305582),61441=>array(-90.277187,40.338564),61442=>array(-90.921684,41.108865),61443=>array(-89.944897,41.263671),61447=>array(-90.753342,40.867312),61448=>array(-90.246813,40.93362),61449=>array(-89.979463,41.091504),61450=>array(-90.979104,40.578637),61451=>array(-89.939478,40.938697),61452=>array(-90.660627,40.23619),61453=>array(-90.764135,41.012202),61454=>array(-91.039891,40.68193),61455=>array(-90.646505,40.439873),61458=>array(-90.183139,40.782252),61459=>array(-90.419564,40.510245),61460=>array(-90.829174,40.716661),61462=>array(-90.644346,40.923249),61465=>array(-90.479667,41.210673),61466=>array(-90.479663,41.110013),61467=>array(-90.240813,41.076367),61468=>array(-90.38778,41.257745),61469=>array(-90.908236,40.955988),61470=>array(-90.50484,40.603863),61471=>array(-90.834837,40.69748),61472=>array(-90.382867,41.102149),61473=>array(-90.640428,40.707687),61474=>array(-90.380402,40.736456),61475=>array(-90.753451,40.597924),61476=>array(-90.83394,41.099146),61477=>array(-90.310552,40.495994),61478=>array(-90.760645,40.757855),61479=>array(-89.644768,41.00479),61480=>array(-90.913356,40.727421),61482=>array(-90.408345,40.384239),61483=>array(-89.881372,41.08483),61484=>array(-90.43579,40.295816),61485=>array(-90.102912,41.021282),61486=>array(-90.57787,41.195016),61488=>array(-90.31832,41.032239),61489=>array(-90.033162,40.930858),61490=>array(-90.258712,41.185531),61491=>array(-89.730734,41.054464),61501=>array(-90.311915,40.228366),61516=>array(-89.135201,40.858083),61517=>array(-89.844868,40.828366),61519=>array(-90.088956,40.46007),61520=>array(-90.023221,40.539026),61523=>array(-89.53777,40.91193),61524=>array(-90.034735,40.491321),61525=>array(-89.669078,40.84848),61526=>array(-89.619957,40.922901),61528=>array(-89.722961,40.778955),61529=>array(-89.937608,40.782018),61530=>array(-89.260105,40.71437),61531=>array(-90.036794,40.682505),61532=>array(-89.818789,40.339487),61533=>array(-89.842499,40.586374),61534=>array(-89.666079,40.414441),61535=>array(-89.516102,40.578709),61536=>array(-89.793782,40.689425),61537=>array(-89.471462,41.1192),61539=>array(-89.762073,40.556403),61540=>array(-89.366597,41.0146),61541=>array(-89.234952,40.980378),61542=>array(-90.130236,40.389729),61543=>array(-89.974552,40.412512),61544=>array(-90.235793,40.693648),61545=>array(-89.353494,40.87071),61546=>array(-89.809589,40.448338),61547=>array(-89.720918,40.580832),61548=>array(-89.412699,40.808363),61550=>array(-89.441854,40.610249),61552=>array(-89.565655,40.817632),61553=>array(-90.032265,40.625932),61554=>array(-89.61832,40.539343),61559=>array(-89.779203,40.919018),61560=>array(-89.41979,41.187262),61561=>array(-89.200895,40.803036),61562=>array(-89.501542,40.880395),61563=>array(-90.054216,40.492024),61564=>array(-89.653494,40.493466),61565=>array(-89.505036,41.038714),61567=>array(-89.896566,40.358139),61568=>array(-89.48222,40.511627),61569=>array(-89.900619,40.683232),61570=>array(-89.325733,40.921072),61571=>array(-89.417889,40.704146),61572=>array(-90.044471,40.80317),61602=>array(-89.608587,40.674568),61603=>array(-89.576722,40.712882),61604=>array(-89.653624,40.705729),61605=>array(-89.633346,40.676541),61606=>array(-89.611514,40.699807),61607=>array(-89.685132,40.627135),61610=>array(-89.59956,40.642116),61611=>array(-89.535816,40.713236),61614=>array(-89.604123,40.759136),61615=>array(-89.686781,40.737893),61616=>array(-89.571641,40.746726),61625=>array(-89.612699,40.697618),61701=>array(-88.992995,40.476771),61704=>array(-88.944538,40.471127),61705=>array(-88.897098,40.413575),61720=>array(-88.514468,40.55467),61721=>array(-89.323483,40.350757),61722=>array(-88.63237,40.418661),61723=>array(-89.276542,40.264664),61724=>array(-88.530877,40.329508),61725=>array(-89.122717,40.610446),61726=>array(-88.692315,40.738395),61727=>array(-88.96116,40.142419),61728=>array(-88.627336,40.571735),61729=>array(-89.221289,40.628647),61730=>array(-88.729413,40.532486),61731=>array(-88.485525,40.613947),61732=>array(-89.20859,40.529527),61733=>array(-89.336899,40.618858),61734=>array(-89.512608,40.375995),61735=>array(-88.814798,40.200639),61736=>array(-88.840561,40.40231),61737=>array(-88.745295,40.464516),61738=>array(-89.029986,40.744984),61739=>array(-88.520725,40.732942),61740=>array(-88.861634,40.884263),61741=>array(-88.40427,40.759435),61742=>array(-89.270049,40.635557),61743=>array(-88.781679,40.875664),61744=>array(-88.887112,40.739971),61745=>array(-88.970354,40.326135),61747=>array(-89.43548,40.416219),61748=>array(-88.991155,40.619486),61749=>array(-89.116222,40.092849),61750=>array(-88.85965,40.123545),61751=>array(-89.299252,40.214556),61752=>array(-88.754301,40.339682),61753=>array(-88.788001,40.629725),61754=>array(-89.18183,40.333729),61755=>array(-89.337173,40.528022),61756=>array(-88.973447,40.031242),61759=>array(-89.334895,40.437333),61760=>array(-89.021795,40.879243),61761=>array(-88.958937,40.529083),61764=>array(-88.628136,40.882442),61769=>array(-88.399364,40.882009),61770=>array(-88.525267,40.442966),61771=>array(-89.131374,40.702016),61772=>array(-89.065969,40.381256),61773=>array(-88.383439,40.57162),61774=>array(-89.203945,40.430677),61775=>array(-88.375962,40.653696),61776=>array(-88.87449,40.566516),61777=>array(-88.945663,40.244063),61778=>array(-89.091171,40.232881),61801=>array(-88.211024,40.108966),61802=>array(-88.15677,40.131498),61810=>array(-87.914791,39.916122),61811=>array(-87.622848,40.292742),61812=>array(-87.911218,40.226685),61813=>array(-88.565701,39.91075),61814=>array(-87.572471,40.230607),61815=>array(-88.376547,40.110752),61816=>array(-88.001216,39.922809),61817=>array(-87.716283,40.035275),61818=>array(-88.716505,39.886708),61820=>array(-88.244266,40.10789),61821=>array(-88.274903,40.109646),61822=>array(-88.305307,40.136481),61830=>array(-88.716508,40.033078),61831=>array(-87.79207,40.22509),61832=>array(-87.636466,40.136234),61833=>array(-87.64422,40.099747),61834=>array(-87.673298,40.152546),61839=>array(-88.629166,40.137717),61840=>array(-88.300263,40.298873),61841=>array(-87.816871,40.020594),61842=>array(-88.665395,40.238677),61843=>array(-88.375163,40.314162),61844=>array(-87.868799,40.14108),61845=>array(-88.396814,40.373621),61846=>array(-87.607538,39.977252),61847=>array(-88.011235,40.319307),61848=>array(-87.702771,40.30806),61849=>array(-87.96737,40.014226),61850=>array(-87.739797,39.931734),61851=>array(-88.434724,39.96082),61852=>array(-88.075799,39.903152),61853=>array(-88.421171,40.214956),61854=>array(-88.529328,40.199872),61855=>array(-88.660929,39.922139),61856=>array(-88.580103,40.026695),61857=>array(-87.84228,40.116554),61858=>array(-87.761877,40.134258),61859=>array(-87.962905,40.150428),61862=>array(-87.958606,40.306027),61863=>array(-88.278472,39.905255),61864=>array(-88.152723,39.975064),61865=>array(-87.802464,40.304925),61866=>array(-88.154549,40.312587),61870=>array(-87.618389,39.897549),61871=>array(-87.968042,40.190222),61872=>array(-88.37811,39.945376),61873=>array(-88.039122,40.133896),61874=>array(-88.259444,40.045756),61875=>array(-88.41642,40.103485),61876=>array(-87.839529,39.902767),61877=>array(-88.081601,39.989192),61878=>array(-88.145453,40.242651),61880=>array(-88.248906,39.973795),61882=>array(-88.754729,40.10623),61883=>array(-87.641523,40.037393),61884=>array(-88.477814,40.08916),61910=>array(-88.299912,39.675509),61911=>array(-88.469322,39.700938),61912=>array(-88.03971,39.521951),61913=>array(-88.46609,39.827555),61914=>array(-88.762449,39.630343),61917=>array(-87.897725,39.7142),61919=>array(-88.13777,39.784439),61920=>array(-88.154193,39.512041),61924=>array(-87.663216,39.786199),61925=>array(-88.840528,39.719105),61928=>array(-88.501263,39.451216),61929=>array(-88.625797,39.824789),61930=>array(-88.130478,39.680887),61931=>array(-88.349775,39.586339),61932=>array(-87.879047,39.803595),61933=>array(-87.926758,39.546695),61936=>array(-88.730259,39.801351),61937=>array(-88.654821,39.741355),61938=>array(-88.374771,39.484141),61940=>array(-87.818525,39.807701),61941=>array(-88.07294,39.804067),61942=>array(-88.003205,39.814412),61943=>array(-88.03085,39.673103),61944=>array(-87.700643,39.600845),61949=>array(-87.873648,39.633642),61951=>array(-88.59028,39.595754),61953=>array(-88.291339,39.803409),61955=>array(-87.591665,39.582172),61956=>array(-88.135009,39.85819),61957=>array(-88.615209,39.440561),62001=>array(-89.745001,38.881403),62002=>array(-90.124504,38.939532),62006=>array(-90.669715,39.053054),62009=>array(-89.798118,39.091549),62010=>array(-90.045305,38.921117),62011=>array(-89.216001,39.126511),62012=>array(-90.1482,39.044749),62013=>array(-90.573646,38.956413),62014=>array(-89.951132,39.043376),62015=>array(-89.544038,39.221451),62016=>array(-90.431767,39.295025),62017=>array(-89.368619,39.065099),62018=>array(-90.08132,38.907779),62019=>array(-89.442402,39.017263),62021=>array(-89.971728,38.984867),62022=>array(-90.326185,39.003162),62023=>array(-89.787059,39.112293),62024=>array(-90.073363,38.875659),62025=>array(-89.932326,38.831391),62027=>array(-90.562735,39.249602),62028=>array(-90.354956,38.95823),62030=>array(-90.164239,39.154621),62031=>array(-90.53693,39.111496),62032=>array(-89.288514,39.115639),62033=>array(-89.839885,39.136567),62034=>array(-89.972284,38.754871),62035=>array(-90.240063,38.964906),62036=>array(-90.589735,38.918311),62037=>array(-90.465642,39.010404),62040=>array(-90.111791,38.725838),62044=>array(-90.22155,39.363052),62045=>array(-90.690137,39.264194),62046=>array(-89.846171,38.889834),62047=>array(-90.626199,39.122744),62048=>array(-90.091714,38.801357),62049=>array(-89.481382,39.131717),62050=>array(-90.54472,39.440017),62051=>array(-89.403275,39.20165),62052=>array(-90.321217,39.110571),62053=>array(-90.66542,39.319254),62054=>array(-90.339427,39.204343),62056=>array(-89.67197,39.179457),62058=>array(-89.769571,38.971118),62059=>array(-90.165046,38.656488),62060=>array(-90.142429,38.681906),62061=>array(-89.779093,38.789567),62062=>array(-89.961315,38.725931),62063=>array(-90.149764,39.198422),62065=>array(-90.632707,39.22609),62067=>array(-89.982053,38.929602),62069=>array(-89.739298,39.089106),62070=>array(-90.732493,39.296898),62074=>array(-89.689742,38.955),62075=>array(-89.296245,39.302262),62076=>array(-89.219136,39.343372),62077=>array(-89.522448,39.029185),62078=>array(-90.486079,39.47863),62079=>array(-90.143849,39.110499),62080=>array(-89.10422,39.137908),62081=>array(-90.225,39.264927),62082=>array(-90.317508,39.489989),62083=>array(-89.201432,39.354451),62084=>array(-90.063668,38.838368),62085=>array(-89.8045,39.081894),62086=>array(-89.579837,38.980771),62087=>array(-90.065488,38.817014),62088=>array(-89.799816,39.01243),62089=>array(-89.495141,39.129585),62090=>array(-90.16963,38.670356),62091=>array(-89.610567,39.056246),62092=>array(-90.431226,39.418572),62093=>array(-89.853922,39.066361),62094=>array(-89.34987,39.245549),62095=>array(-90.069002,38.861343),62097=>array(-89.852627,38.936656),62098=>array(-90.304622,39.386098),62201=>array(-90.140016,38.644405),62203=>array(-90.077337,38.599955),62204=>array(-90.090166,38.633745),62205=>array(-90.122803,38.609757),62206=>array(-90.166652,38.572342),62207=>array(-90.123247,38.582466),62208=>array(-90.005138,38.595079),62214=>array(-89.603629,38.376408),62215=>array(-89.608827,38.508311),62216=>array(-89.601788,38.618617),62217=>array(-89.853507,38.175668),62218=>array(-89.473788,38.522191),62219=>array(-89.431899,38.605786),62220=>array(-89.998032,38.478277),62221=>array(-89.905289,38.512111),62223=>array(-90.059457,38.535957),62225=>array(-89.852114,38.542964),62226=>array(-89.999588,38.535124),62230=>array(-89.531014,38.635081),62231=>array(-89.319337,38.612258),62232=>array(-89.999928,38.6315),62233=>array(-89.788551,37.942252),62234=>array(-89.982058,38.683215),62236=>array(-90.216606,38.436908),62237=>array(-89.56847,38.186721),62238=>array(-89.532296,38.038556),62239=>array(-90.161471,38.535176),62240=>array(-90.176557,38.501857),62241=>array(-89.893673,38.011291),62242=>array(-89.946871,38.098153),62243=>array(-89.889488,38.420129),62244=>array(-90.198775,38.195693),62245=>array(-89.562816,38.545339),62246=>array(-89.427497,38.890364),62248=>array(-89.9964,38.303038),62249=>array(-89.667278,38.754556),62250=>array(-89.26611,38.540795),62253=>array(-89.300082,38.777731),62254=>array(-89.823248,38.609042),62255=>array(-89.783121,38.313204),62257=>array(-89.728709,38.284874),62258=>array(-89.782081,38.460897),62260=>array(-90.1007,38.460653),62261=>array(-90.000394,37.997579),62262=>array(-89.282715,38.940678),62263=>array(-89.410588,38.326439),62264=>array(-89.903533,38.318803),62265=>array(-89.673407,38.499764),62266=>array(-89.677069,38.486685),62268=>array(-89.530213,38.275671),62269=>array(-89.915479,38.600069),62271=>array(-89.519128,38.450127),62272=>array(-89.597916,37.986664),62273=>array(-89.583856,38.786795),62274=>array(-89.413973,38.10003),62275=>array(-89.551148,38.809868),62277=>array(-90.112311,38.09711),62278=>array(-89.992598,38.207527),62279=>array(-90.135778,38.150859),62280=>array(-89.647988,37.846636),62281=>array(-89.779338,38.706901),62282=>array(-89.718104,38.363067),62284=>array(-89.313988,38.881265),62285=>array(-90.010301,38.389752),62286=>array(-89.715824,38.11859),62288=>array(-89.687262,37.988592),62289=>array(-89.751472,38.596911),62292=>array(-89.676629,38.211313),62293=>array(-89.697198,38.619267),62294=>array(-89.868492,38.702392),62295=>array(-90.323662,38.283878),62297=>array(-89.806332,38.052121),62298=>array(-90.149848,38.311831),62301=>array(-91.385695,39.931138),62305=>array(-91.343825,39.928206),62311=>array(-90.930892,40.209847),62312=>array(-91.024237,39.707353),62313=>array(-91.228289,40.317726),62314=>array(-90.891698,39.767988),62316=>array(-91.053025,40.235474),62319=>array(-90.731284,40.152482),62320=>array(-91.082819,40.030377),62321=>array(-91.105551,40.411428),62323=>array(-90.687395,39.797568),62324=>array(-90.966328,39.998277),62325=>array(-91.162046,40.045624),62326=>array(-90.809095,40.416736),62330=>array(-91.125784,40.571437),62334=>array(-91.233644,40.388846),62336=>array(-91.171385,40.468065),62338=>array(-91.238047,39.987974),62339=>array(-91.038183,40.128568),62340=>array(-90.728245,39.73477),62341=>array(-91.295738,40.426611),62343=>array(-91.245869,39.697869),62344=>array(-90.831101,40.168894),62345=>array(-91.127325,39.704319),62346=>array(-90.951257,40.150624),62347=>array(-91.088955,39.870093),62348=>array(-91.367322,40.187557),62349=>array(-91.190106,40.170391),62351=>array(-91.268867,40.113608),62352=>array(-90.650116,39.564547),62353=>array(-90.756355,39.967744),62354=>array(-91.337591,40.52634),62355=>array(-90.778624,39.412245),62356=>array(-91.076672,39.58968),62357=>array(-90.867226,39.688071),62358=>array(-91.25347,40.587585),62359=>array(-91.201455,40.03388),62360=>array(-91.263432,39.816263),62361=>array(-90.645467,39.480283),62362=>array(-90.747127,39.782328),62363=>array(-90.769665,39.590496),62365=>array(-91.165124,39.796403),62366=>array(-90.901821,39.472086),62367=>array(-90.874264,40.299312),62370=>array(-91.007228,39.517293),62373=>array(-91.339323,40.241879),62374=>array(-90.912064,40.408924),62375=>array(-90.86852,40.006342),62376=>array(-91.434891,40.120548),62378=>array(-90.634784,39.905859),62379=>array(-91.403355,40.283497),62380=>array(-91.190901,40.23823),62401=>array(-88.562385,39.118722),62410=>array(-87.733213,38.5388),62411=>array(-88.733649,39.071264),62413=>array(-87.837748,39.138799),62414=>array(-88.826356,39.174413),62417=>array(-87.766379,38.707439),62418=>array(-88.973917,39.022253),62419=>array(-87.989672,38.610736),62420=>array(-87.998545,39.287033),62421=>array(-87.94353,38.75353),62422=>array(-88.883247,39.238796),62423=>array(-87.57989,39.462687),62424=>array(-88.420192,38.991159),62425=>array(-88.092198,38.830094),62426=>array(-88.664028,38.892302),62427=>array(-87.649864,38.873127),62428=>array(-88.136713,39.262654),62431=>array(-88.988744,39.22817),62432=>array(-88.139823,39.135473),62433=>array(-87.715756,39.106742),62434=>array(-88.321609,38.842186),62436=>array(-88.252556,39.179864),62438=>array(-88.869227,39.321114),62439=>array(-87.639699,38.744062),62440=>array(-88.267884,39.395491),62441=>array(-87.697612,39.397619),62442=>array(-87.85838,39.311623),62443=>array(-88.627068,38.954328),62444=>array(-88.7393,39.276544),62445=>array(-88.321348,39.169156),62446=>array(-88.213291,38.502952),62447=>array(-88.448275,39.314746),62448=>array(-88.179181,38.968356),62449=>array(-87.914352,39.006223),62450=>array(-88.089183,38.713182),62451=>array(-87.611121,38.971177),62452=>array(-88.015156,38.589885),62454=>array(-87.755852,38.999665),62458=>array(-88.851563,39.02478),62459=>array(-88.027785,38.930022),62460=>array(-87.717505,38.601727),62461=>array(-88.683234,39.196877),62462=>array(-88.460632,39.236991),62463=>array(-88.605375,39.276648),62465=>array(-88.640463,39.34939),62466=>array(-87.852631,38.728411),62467=>array(-88.435002,39.131186),62468=>array(-88.270309,39.276946),62469=>array(-88.333828,39.351236),62471=>array(-89.13013,38.946168),62473=>array(-88.56779,39.02157),62474=>array(-88.000675,39.423611),62475=>array(-88.04692,38.889901),62476=>array(-88.006982,38.535112),62477=>array(-87.643438,39.233553),62478=>array(-87.743616,39.179972),62479=>array(-88.306897,39.037041),62480=>array(-87.999575,38.997392),62481=>array(-88.022012,39.127228),62501=>array(-88.805357,39.941961),62510=>array(-89.028916,39.530665),62512=>array(-89.209159,40.147136),62513=>array(-89.150811,39.721984),62514=>array(-89.050691,39.762441),62515=>array(-89.378281,39.860416),62517=>array(-89.425262,39.591653),62518=>array(-89.191409,40.054193),62519=>array(-89.39532,39.928796),62520=>array(-89.455965,39.818055),62521=>array(-88.926317,39.81707),62522=>array(-89.0478,39.827583),62523=>array(-88.952216,39.844096),62526=>array(-88.989475,39.901937),62530=>array(-89.675123,39.560286),62531=>array(-89.37756,39.674378),62532=>array(-88.989322,39.763355),62533=>array(-89.615992,39.446936),62534=>array(-88.800594,39.529684),62535=>array(-88.969078,39.924757),62536=>array(-89.652328,39.629076),62537=>array(-89.09476,39.853267),62538=>array(-89.519915,39.356412),62539=>array(-89.251291,39.86603),62540=>array(-89.417493,39.583957),62541=>array(-89.355146,39.965366),62543=>array(-89.152233,39.971422),62544=>array(-88.96784,39.706412),62545=>array(-89.388304,39.756717),62546=>array(-89.445923,39.431455),62547=>array(-89.242253,39.770482),62548=>array(-89.283539,39.981254),62549=>array(-88.867155,39.771029),62550=>array(-88.989628,39.617876),62551=>array(-89.158927,39.855374),62553=>array(-89.107186,39.266267),62554=>array(-88.882262,39.944478),62555=>array(-89.210466,39.46298),62556=>array(-89.375213,39.474974),62557=>array(-89.104534,39.396869),62558=>array(-89.549853,39.586712),62560=>array(-89.602818,39.29863),62561=>array(-89.501913,39.863895),62563=>array(-89.496253,39.719264),62565=>array(-88.804095,39.411777),62567=>array(-89.18985,39.645213),62568=>array(-89.289158,39.561004),62570=>array(-89.448004,39.588581),62571=>array(-88.960225,39.381008),62572=>array(-89.701524,39.360937),62573=>array(-89.074133,39.945409),62601=>array(-90.039255,39.749094),62610=>array(-90.434858,39.558844),62611=>array(-90.398177,39.884116),62612=>array(-90.063158,39.896048),62613=>array(-89.665941,39.997432),62615=>array(-89.757381,39.585061),62617=>array(-90.16989,40.156822),62618=>array(-90.402049,39.982598),62621=>array(-90.52058,39.72672),62622=>array(-90.353449,39.978177),62624=>array(-90.363732,40.156569),62625=>array(-89.687708,39.910073),62626=>array(-89.883939,39.282802),62627=>array(-90.111077,40.059128),62628=>array(-90.403198,39.779463),62629=>array(-89.711833,39.679778),62630=>array(-90.091111,39.255117),62631=>array(-90.354199,39.827417),62633=>array(-89.866296,40.224979),62634=>array(-89.454534,40.011799),62635=>array(-89.471453,40.296711),62638=>array(-90.081236,39.609301),62639=>array(-90.486012,40.03767),62640=>array(-89.804994,39.42826),62642=>array(-89.724017,40.09275),62643=>array(-89.451703,40.242994),62644=>array(-90.054538,40.287943),62649=>array(-90.070237,39.357528),62650=>array(-90.223047,39.734542),62655=>array(-89.986537,40.169931),62656=>array(-89.371647,40.139942),62661=>array(-89.826988,39.668014),62663=>array(-90.328759,39.540551),62664=>array(-89.724144,40.212562),62665=>array(-90.529555,39.816949),62666=>array(-89.543875,40.086111),62667=>array(-89.992297,39.487765),62668=>array(-90.234163,39.572356),62670=>array(-89.89172,39.742911),62671=>array(-89.558457,40.17288),62672=>array(-89.804455,39.398009),62673=>array(-89.978692,40.085541),62674=>array(-90.028506,39.441651),62675=>array(-89.847921,40.036029),62677=>array(-89.883032,39.850588),62681=>array(-90.550562,40.135355),62682=>array(-89.630971,40.298725),62684=>array(-89.587161,39.909423),62685=>array(-90.002766,39.139883),62688=>array(-89.923096,39.945973),62689=>array(-89.761852,39.533671),62690=>array(-89.762809,39.505912),62691=>array(-90.210428,39.958257),62692=>array(-89.939137,39.58352),62693=>array(-89.516172,39.958048),62694=>array(-90.477118,39.62278),62695=>array(-90.22365,39.627088),62701=>array(-89.648801,39.800697),62702=>array(-89.641927,39.824137),62703=>array(-89.629884,39.762449),62704=>array(-89.68384,39.773498),62707=>array(-89.650389,39.854932),62711=>array(-89.729326,39.765466),62712=>array(-89.579701,39.753814),62801=>array(-89.141837,38.512863),62803=>array(-89.295029,38.453336),62806=>array(-88.077254,38.382053),62807=>array(-88.940675,38.744774),62808=>array(-89.188699,38.30618),62809=>array(-88.294663,38.270745),62810=>array(-88.752318,38.201276),62811=>array(-87.905586,38.38297),62812=>array(-88.916035,37.99734),62814=>array(-88.731915,38.378397),62815=>array(-87.96644,38.458352),62816=>array(-88.922922,38.189765),62817=>array(-88.476107,37.954474),62818=>array(-87.965346,38.383278),62819=>array(-89.016586,37.977311),62820=>array(-88.237445,38.242402),62821=>array(-88.129673,38.071022),62822=>array(-89.056451,37.977539),62823=>array(-88.442514,38.530774),62824=>array(-88.341669,38.669452),62825=>array(-89.068659,37.998887),62827=>array(-88.0479,38.17279),62828=>array(-88.601621,38.194537),62829=>array(-88.48954,37.973558),62830=>array(-88.967632,38.443409),62831=>array(-89.222732,38.234969),62832=>array(-89.24891,38.011822),62833=>array(-88.164177,38.361723),62835=>array(-88.321638,38.106048),62836=>array(-88.805455,38.094569),62837=>array(-88.352856,38.360406),62838=>array(-88.751389,38.873738),62839=>array(-88.500905,38.665804),62841=>array(-89.000174,37.859261),62842=>array(-88.371044,38.467672),62843=>array(-88.199061,38.38221),62844=>array(-88.043467,38.262729),62846=>array(-88.866853,38.145206),62848=>array(-89.166528,38.435397),62849=>array(-88.773698,38.58494),62850=>array(-88.59482,38.494727),62851=>array(-88.659979,38.427596),62852=>array(-87.866785,38.350223),62853=>array(-88.912193,38.516107),62854=>array(-88.801043,38.769938),62856=>array(-88.838457,37.956409),62858=>array(-88.49295,38.811813),62859=>array(-88.532699,38.081344),62860=>array(-88.731934,38.041367),62861=>array(-88.013891,38.029945),62862=>array(-88.299332,38.219101),62863=>array(-87.859872,38.415834),62864=>array(-88.902519,38.330493),62865=>array(-89.080092,37.972104),62867=>array(-88.098946,37.912266),62868=>array(-88.228125,38.67771),62869=>array(-88.280867,37.962444),62870=>array(-89.053057,38.635153),62871=>array(-88.272861,37.875359),62872=>array(-88.809436,38.268058),62874=>array(-88.976028,37.918705),62875=>array(-89.121198,38.755452),62876=>array(-89.195732,38.276413),62877=>array(-89.211193,38.392808),62878=>array(-88.507898,38.574513),62879=>array(-88.360495,38.764906),62880=>array(-88.884389,38.866987),62881=>array(-88.927356,38.635332),62882=>array(-89.118646,38.636254),62883=>array(-89.120371,38.168415),62884=>array(-89.056171,38.083366),62885=>array(-89.054212,38.859059),62886=>array(-88.539227,38.380898),62887=>array(-88.36196,38.184525),62888=>array(-89.234469,38.130976),62889=>array(-88.823598,38.456539),62890=>array(-88.737966,37.906205),62891=>array(-89.042451,38.015023),62892=>array(-89.075972,38.808355),62893=>array(-89.030168,38.46581),62894=>array(-89.036709,38.20852),62895=>array(-88.555138,38.305545),62896=>array(-88.915973,37.890492),62897=>array(-88.898862,38.094608),62898=>array(-89.060166,38.350379),62899=>array(-88.642463,38.61889),62901=>array(-89.209109,37.739004),62902=>array(-89.117546,37.662587),62903=>array(-89.276234,37.674118),62905=>array(-89.367195,37.557561),62906=>array(-89.17253,37.462109),62907=>array(-89.49745,37.872468),62908=>array(-88.864901,37.310226),62910=>array(-88.534459,37.153109),62912=>array(-89.032407,37.476199),62914=>array(-89.218249,37.061169),62915=>array(-89.119606,37.783608),62916=>array(-89.568714,37.930677),62917=>array(-88.651628,37.693416),62918=>array(-89.088131,37.789529),62919=>array(-88.138368,37.524023),62920=>array(-89.237778,37.550074),62921=>array(-89.084262,37.801912),62922=>array(-88.814807,37.620754),62923=>array(-89.016004,37.346432),62924=>array(-89.198023,37.823),62926=>array(-89.131409,37.366678),62927=>array(-89.242307,37.934662),62928=>array(-88.575321,37.482396),62930=>array(-88.441065,37.837779),62931=>array(-88.292023,37.52143),62932=>array(-89.218748,37.902218),62933=>array(-89.025656,37.772371),62934=>array(-88.358633,37.707239),62935=>array(-88.634847,37.839547),62938=>array(-88.53942,37.381459),62939=>array(-88.981647,37.551161),62940=>array(-89.471814,37.738486),62941=>array(-88.986107,37.239258),62942=>array(-89.47287,37.649362),62943=>array(-88.750384,37.357564),62946=>array(-88.538845,37.709862),62947=>array(-88.454428,37.528409),62948=>array(-89.030678,37.817138),62949=>array(-89.144607,37.827923),62950=>array(-89.560711,37.746447),62951=>array(-88.929329,37.823971),62952=>array(-89.341001,37.40957),62953=>array(-88.849519,37.209471),62954=>array(-88.279548,37.692088),62956=>array(-88.938359,37.279795),62957=>array(-89.426131,37.312496),62958=>array(-89.230987,37.630995),62959=>array(-88.91035,37.716831),62960=>array(-88.709403,37.225299),62961=>array(-89.255225,37.338248),62962=>array(-89.335889,37.07536),62963=>array(-89.164912,37.096507),62964=>array(-89.217003,37.127788),62965=>array(-88.520616,37.767319),62966=>array(-89.350979,37.775136),62967=>array(-88.745771,37.583822),62969=>array(-89.342299,37.154393),62970=>array(-89.091093,37.224577),62972=>array(-88.791037,37.542288),62974=>array(-88.782992,37.781202),62975=>array(-89.387589,37.633773),62976=>array(-89.204377,37.221663),62977=>array(-88.545923,37.851778),62979=>array(-88.191116,37.822108),62982=>array(-88.36538,37.424775),62983=>array(-89.121219,37.902971),62984=>array(-88.154928,37.712002),62985=>array(-88.685445,37.458595),62987=>array(-88.651906,37.618469),62988=>array(-89.294678,37.251285),62990=>array(-89.398842,37.228582),62992=>array(-89.165805,37.280117),62994=>array(-89.342358,37.906728),62995=>array(-88.869433,37.437644),62996=>array(-89.151028,37.157531),62997=>array(-89.590443,37.982278),62998=>array(-89.458153,37.51207),62999=>array(-89.047542,37.889816),63005=>array(-90.651407,38.644214),63010=>array(-90.3921,38.430371),63011=>array(-90.559271,38.603679),63012=>array(-90.453851,38.331675),63013=>array(-91.161511,38.415083),63014=>array(-91.313445,38.651805),63015=>array(-90.759427,38.405785),63016=>array(-90.634964,38.352457),63017=>array(-90.531216,38.651309),63019=>array(-90.376992,38.226362),63020=>array(-90.565549,38.100971),63021=>array(-90.545689,38.56984),63023=>array(-90.698745,38.270192),63025=>array(-90.620136,38.487575),63026=>array(-90.460968,38.503348),63028=>array(-90.392182,38.137919),63030=>array(-90.746292,38.124692),63031=>array(-90.353928,38.813468),63033=>array(-90.27468,38.799723),63034=>array(-90.288423,38.848304),63036=>array(-90.371764,37.976428),63037=>array(-91.301865,38.431389),63038=>array(-90.667758,38.577047),63039=>array(-90.839295,38.494496),63040=>array(-90.635031,38.57295),63041=>array(-90.787529,38.260132),63042=>array(-90.383731,38.78413),63043=>array(-90.461383,38.729739),63044=>array(-90.430046,38.772791),63045=>array(-90.463466,38.769205),63047=>array(-90.487417,38.195501),63048=>array(-90.39313,38.257558),63049=>array(-90.530835,38.481277),63050=>array(-90.577992,38.254768),63051=>array(-90.576636,38.377768),63052=>array(-90.436886,38.388903),63053=>array(-90.363927,38.366588),63055=>array(-90.824413,38.527091),63056=>array(-91.214849,38.400027),63057=>array(-90.405572,38.3433),63060=>array(-90.874969,38.257794),63061=>array(-90.812221,38.272892),63068=>array(-91.244062,38.565884),63069=>array(-90.732019,38.490835),63070=>array(-90.429113,38.288429),63071=>array(-90.831807,38.147628),63072=>array(-90.812533,38.36927),63073=>array(-90.779293,38.589752),63074=>array(-90.388703,38.726499),63077=>array(-90.984475,38.329075),63079=>array(-91.099799,38.260582),63080=>array(-91.077001,38.194674),63084=>array(-91.019289,38.4219),63087=>array(-90.451539,38.013279),63088=>array(-90.499888,38.54962),63089=>array(-90.889554,38.458271),63090=>array(-91.04884,38.535239),63091=>array(-91.393223,38.371663),63101=>array(-90.19261,38.631558),63102=>array(-90.187001,38.635181),63103=>array(-90.216863,38.629712),63104=>array(-90.214086,38.611126),63105=>array(-90.328202,38.644308),63106=>array(-90.208316,38.644397),63107=>array(-90.212106,38.663921),63108=>array(-90.253417,38.644803),63109=>array(-90.294432,38.584601),63110=>array(-90.266998,38.625794),63111=>array(-90.250008,38.558084),63112=>array(-90.28267,38.658933),63113=>array(-90.247592,38.658004),63114=>array(-90.363674,38.702256),63115=>array(-90.239975,38.682188),63116=>array(-90.264108,38.580814),63117=>array(-90.330852,38.630765),63118=>array(-90.226241,38.59244),63119=>array(-90.351341,38.58845),63120=>array(-90.262089,38.690576),63121=>array(-90.301334,38.707193),63122=>array(-90.417981,38.58119),63123=>array(-90.328109,38.547432),63124=>array(-90.380268,38.638103),63125=>array(-90.293514,38.518452),63126=>array(-90.378592,38.549656),63127=>array(-90.416839,38.533282),63128=>array(-90.386513,38.492427),63129=>array(-90.316502,38.458622),63130=>array(-90.325307,38.665066),63131=>array(-90.44419,38.617395),63132=>array(-90.377994,38.676026),63133=>array(-90.305992,38.680914),63134=>array(-90.346991,38.740708),63135=>array(-90.298718,38.749681),63136=>array(-90.259779,38.743306),63137=>array(-90.211685,38.750472),63138=>array(-90.192397,38.801051),63139=>array(-90.291723,38.610412),63140=>array(-90.323063,38.738381),63141=>array(-90.458203,38.658277),63143=>array(-90.321432,38.611729),63144=>array(-90.347719,38.619024),63146=>array(-90.474667,38.697686),63147=>array(-90.216219,38.694017),63155=>array(-90.205457,38.627871),63301=>array(-90.463316,38.858035),63303=>array(-90.543744,38.739882),63304=>array(-90.667522,38.703508),63330=>array(-90.80427,39.271336),63332=>array(-90.893983,38.596917),63333=>array(-91.309018,39.033743),63334=>array(-91.188309,39.297583),63336=>array(-90.933413,39.332791),63339=>array(-91.371349,39.344378),63341=>array(-90.815888,38.670825),63343=>array(-90.828184,39.154813),63344=>array(-91.003976,39.236864),63345=>array(-91.569141,39.277056),63347=>array(-90.766733,39.069871),63348=>array(-90.945226,38.785461),63349=>array(-91.150965,38.974386),63350=>array(-91.361708,38.901096),63351=>array(-91.312739,38.862373),63352=>array(-91.658947,39.247787),63353=>array(-91.113225,39.454496),63357=>array(-91.086905,38.661018),63359=>array(-91.356191,39.151211),63361=>array(-91.552972,38.965146),63362=>array(-90.869845,38.9228),63363=>array(-91.454906,38.883906),63366=>array(-90.725492,38.857443),63367=>array(-90.795044,38.774327),63368=>array(-90.729626,38.75129),63369=>array(-90.763296,38.935145),63370=>array(-91.240463,39.09151),63373=>array(-90.385407,38.929574),63376=>array(-90.60754,38.798905),63377=>array(-91.10339,39.110313),63379=>array(-90.995709,39.000905),63381=>array(-91.253305,38.986402),63382=>array(-91.495927,39.305387),63383=>array(-91.193705,38.804365),63384=>array(-91.553592,39.092528),63385=>array(-90.857261,38.796993),63386=>array(-90.219634,38.870227),63387=>array(-91.016734,39.183555),63388=>array(-91.757122,38.875111),63389=>array(-90.77411,39.010559),63390=>array(-91.040068,38.803397),63401=>array(-91.456616,39.690673),63430=>array(-91.542638,40.390626),63431=>array(-92.31396,39.740221),63432=>array(-91.993928,40.497239),63433=>array(-91.131243,39.534181),63434=>array(-91.947197,39.90673),63435=>array(-91.58368,40.199137),63436=>array(-91.55251,39.505732),63437=>array(-92.220654,39.728217),63438=>array(-91.687967,39.968514),63439=>array(-91.860563,39.801934),63440=>array(-91.758834,39.987475),63441=>array(-91.312032,39.480325),63443=>array(-91.882487,39.66852),63445=>array(-91.732212,40.395662),63446=>array(-91.987206,40.130413),63447=>array(-91.9034,40.097022),63448=>array(-91.557038,40.024661),63450=>array(-92.15026,39.668909),63451=>array(-92.205892,39.903783),63452=>array(-91.790052,40.09313),63453=>array(-91.867256,40.510756),63454=>array(-91.650377,39.922981),63456=>array(-91.728331,39.65647),63457=>array(-91.711889,40.16585),63458=>array(-92.019907,39.992451),63459=>array(-91.369252,39.579374),63460=>array(-92.207897,39.999269),63461=>array(-91.568927,39.790542),63462=>array(-91.70113,39.419207),63463=>array(-91.780965,39.851438),63464=>array(-92.083595,39.980885),63465=>array(-91.679549,40.527638),63467=>array(-91.270667,39.648597),63468=>array(-92.014629,39.684064),63469=>array(-92.041218,39.825851),63471=>array(-91.487808,39.907238),63472=>array(-91.585849,40.404428),63473=>array(-91.783858,40.246853),63474=>array(-91.893573,40.349765),63501=>array(-92.59121,40.166289),63530=>array(-92.455054,39.90762),63531=>array(-92.241036,40.300263),63532=>array(-92.572883,39.760888),63533=>array(-92.392226,40.199773),63534=>array(-92.648407,39.737309),63535=>array(-92.664954,40.559957),63536=>array(-92.355927,40.485291),63537=>array(-92.153575,40.149926),63538=>array(-92.679871,39.953937),63539=>array(-92.75121,39.926222),63540=>array(-92.406887,40.105389),63541=>array(-92.627042,40.50417),63543=>array(-92.014125,40.35242),63544=>array(-92.840197,40.245752),63545=>array(-92.964521,40.272236),63546=>array(-92.510989,40.337736),63547=>array(-92.297714,40.135832),63548=>array(-92.48916,40.536366),63549=>array(-92.486226,40.018755),63551=>array(-92.735589,40.500565),63552=>array(-92.43653,39.763163),63555=>array(-92.193179,40.486404),63556=>array(-93.12729,40.182985),63557=>array(-92.878772,39.970985),63558=>array(-92.751105,39.749446),63559=>array(-92.751687,40.219823),63560=>array(-93.120409,40.359626),63561=>array(-92.540863,40.419561),63563=>array(-92.065941,40.304552),63565=>array(-92.947276,40.48062),63566=>array(-92.925622,40.043275),63567=>array(-92.719744,40.418795),63601=>array(-90.546492,37.824454),63620=>array(-90.651946,37.381731),63621=>array(-90.61024,37.478367),63622=>array(-90.907454,37.791016),63623=>array(-90.88259,37.685055),63624=>array(-90.63404,37.755509),63625=>array(-90.971768,37.554897),63626=>array(-90.68653,38.069983),63627=>array(-90.25961,38.049222),63628=>array(-90.524737,37.945701),63629=>array(-91.236844,37.408644),63630=>array(-90.717491,38.029601),63631=>array(-90.788037,37.754571),63633=>array(-91.02046,37.443467),63636=>array(-90.575534,37.293641),63637=>array(-90.518346,37.712286),63638=>array(-91.018862,37.215017),63640=>array(-90.380562,37.754674),63645=>array(-90.341803,37.538676),63648=>array(-90.695642,37.825109),63650=>array(-90.609439,37.623377),63653=>array(-90.59159,37.860286),63654=>array(-90.857827,37.487529),63655=>array(-90.189106,37.390559),63656=>array(-90.797305,37.593225),63660=>array(-90.688778,37.909248),63662=>array(-90.050025,37.532424),63663=>array(-90.64731,37.626203),63664=>array(-90.927571,37.899827),63665=>array(-90.843921,37.292843),63666=>array(-91.055857,37.402982),63670=>array(-90.18117,37.89018),63673=>array(-89.991058,37.841831),63674=>array(-90.659306,38.036656),63675=>array(-90.694829,37.314478),63701=>array(-89.574605,37.335289),63703=>array(-89.539808,37.272313),63730=>array(-89.917161,37.098288),63732=>array(-89.57593,37.594135),63735=>array(-89.775684,36.977711),63736=>array(-89.5103,37.09318),63738=>array(-89.95723,37.08984),63739=>array(-89.800258,37.35855),63740=>array(-89.680721,37.175369),63742=>array(-89.446141,37.158665),63743=>array(-89.816136,37.521279),63744=>array(-89.738256,37.196001),63745=>array(-89.690157,37.239802),63746=>array(-89.694828,37.707841),63747=>array(-89.799679,37.556375),63748=>array(-89.626315,37.668926),63750=>array(-90.202737,37.152126),63751=>array(-90.128182,37.275815),63755=>array(-89.638598,37.437854),63758=>array(-89.555945,37.187019),63760=>array(-89.898893,37.242787),63763=>array(-90.175609,37.064462),63764=>array(-89.990229,37.319764),63766=>array(-89.83688,37.430896),63767=>array(-89.611202,37.046217),63769=>array(-89.736581,37.522403),63770=>array(-89.703017,37.597515),63771=>array(-89.703733,37.071612),63774=>array(-89.764251,37.089468),63775=>array(-89.877614,37.711324),63780=>array(-89.514476,37.188716),63781=>array(-89.928357,37.538453),63782=>array(-90.035305,37.122136),63783=>array(-89.679848,37.607268),63784=>array(-89.69155,36.984534),63785=>array(-89.822213,37.266837),63787=>array(-90.133126,37.121087),63801=>array(-89.617923,36.904787),63820=>array(-89.325574,36.824262),63821=>array(-90.23911,36.047674),63822=>array(-89.998831,36.665946),63823=>array(-89.460378,36.895007),63824=>array(-89.526686,37.004918),63825=>array(-89.94574,36.931693),63826=>array(-89.841743,36.170362),63827=>array(-89.887342,36.256012),63828=>array(-89.691841,36.750369),63829=>array(-90.308867,36.03551),63830=>array(-89.68954,36.132049),63833=>array(-89.730765,36.650344),63834=>array(-89.274233,36.914293),63837=>array(-89.992151,36.461978),63839=>array(-89.813578,36.044736),63841=>array(-89.984451,36.771316),63845=>array(-89.324393,36.712948),63846=>array(-89.799442,36.826242),63847=>array(-90.038933,36.43995),63848=>array(-89.906147,36.444495),63849=>array(-89.978779,36.138609),63851=>array(-89.717229,36.259153),63852=>array(-90.015764,36.369145),63853=>array(-89.870321,36.06474),63855=>array(-90.056809,36.069107),63857=>array(-90.04576,36.224266),63860=>array(-89.594665,36.652181),63862=>array(-89.641714,36.614001),63863=>array(-89.976765,36.564889),63866=>array(-89.605643,36.528537),63867=>array(-89.551881,36.732716),63868=>array(-89.69343,36.849167),63869=>array(-89.482225,36.597025),63870=>array(-89.857202,36.621139),63873=>array(-89.671168,36.422873),63874=>array(-89.822657,36.542998),63876=>array(-90.17031,36.132276),63877=>array(-89.858336,36.075721),63878=>array(-89.822358,36.503021),63879=>array(-89.812721,36.359516),63880=>array(-90.023873,36.326036),63882=>array(-89.222715,36.915279),63901=>array(-90.460565,36.760331),63902=>array(-90.427107,36.76762),63932=>array(-90.255782,36.683242),63933=>array(-90.106956,36.528179),63934=>array(-90.368652,37.198621),63935=>array(-90.921484,36.675361),63936=>array(-90.129028,36.808925),63937=>array(-90.784031,36.935121),63939=>array(-90.673446,36.651332),63940=>array(-90.227674,36.768003),63941=>array(-91.159046,36.885592),63942=>array(-91.074481,36.554374),63943=>array(-90.788984,36.827168),63944=>array(-90.359498,37.113156),63945=>array(-90.54274,36.632973),63951=>array(-90.257876,37.114876),63952=>array(-90.642044,37.010062),63953=>array(-90.637706,36.587245),63954=>array(-90.471256,36.557494),63955=>array(-90.680881,36.603559),63956=>array(-90.521728,37.213951),63957=>array(-90.648266,37.12298),63960=>array(-90.131465,36.95694),63961=>array(-90.277076,36.567208),63962=>array(-90.281507,36.844028),63964=>array(-90.414973,37.262947),63965=>array(-91.021293,36.96517),63966=>array(-90.264717,36.979507),63967=>array(-90.485325,36.940696),64001=>array(-93.540908,39.114216),64011=>array(-94.067926,38.959756),64012=>array(-94.543625,38.789354),64014=>array(-94.255136,39.00676),64015=>array(-94.312605,39.015059),64016=>array(-94.215755,39.119616),64017=>array(-94.024205,39.19562),64018=>array(-94.721261,39.454719),64019=>array(-93.865281,38.777542),64020=>array(-93.599784,38.967425),64021=>array(-93.619004,39.10449),64022=>array(-93.671804,39.194364),64024=>array(-94.226953,39.327618),64029=>array(-94.212799,39.005687),64030=>array(-94.522744,38.881359),64034=>array(-94.297554,38.858551),64035=>array(-93.812219,39.290513),64036=>array(-93.936807,39.193758),64037=>array(-93.732709,39.054863),64040=>array(-93.98766,38.72376),64048=>array(-94.363579,39.437763),64050=>array(-94.410525,39.115913),64052=>array(-94.450236,39.073415),64053=>array(-94.465282,39.109351),64054=>array(-94.439036,39.110355),64055=>array(-94.397998,39.050847),64056=>array(-94.319802,39.113308),64057=>array(-94.319308,39.071957),64058=>array(-94.31356,39.173856),64060=>array(-94.364835,39.368913),64061=>array(-94.084862,38.783394),64062=>array(-94.163205,39.455731),64063=>array(-94.351673,38.911994),64064=>array(-94.34522,38.974502),64065=>array(-94.404843,38.954778),64066=>array(-94.125836,39.135995),64067=>array(-93.830311,39.154878),64068=>array(-94.389653,39.258315),64070=>array(-94.14889,38.886623),64071=>array(-93.831717,39.027828),64072=>array(-94.293788,39.242067),64074=>array(-94.071296,39.083651),64075=>array(-94.145243,38.999815),64076=>array(-93.948056,38.983162),64077=>array(-94.139126,39.224578),64078=>array(-94.458131,38.702692),64079=>array(-94.793687,39.359124),64080=>array(-94.26041,38.764209),64081=>array(-94.403932,38.907046),64082=>array(-94.40832,38.862111),64083=>array(-94.445534,38.797393),64084=>array(-94.066883,39.384345),64085=>array(-93.945283,39.334841),64086=>array(-94.272385,38.899171),64088=>array(-94.181903,39.151558),64089=>array(-94.560817,39.393806),64090=>array(-94.163578,38.759359),64092=>array(-94.811119,39.217578),64093=>array(-93.731782,38.796393),64096=>array(-93.552504,39.208822),64097=>array(-93.984271,39.104909),64098=>array(-94.891475,39.468076),64101=>array(-94.600614,39.103463),64102=>array(-94.604041,39.093844),64105=>array(-94.590375,39.104725),64106=>array(-94.572176,39.104839),64108=>array(-94.58647,39.084895),64109=>array(-94.566343,39.065794),64110=>array(-94.572806,39.034503),64111=>array(-94.593879,39.05758),64112=>array(-94.59519,39.035975),64113=>array(-94.595652,39.014065),64114=>array(-94.598599,38.957802),64116=>array(-94.575242,39.148811),64117=>array(-94.522657,39.164449),64118=>array(-94.572366,39.212744),64119=>array(-94.514665,39.209967),64120=>array(-94.514957,39.135007),64123=>array(-94.523234,39.114346),64124=>array(-94.539212,39.107225),64125=>array(-94.494153,39.106463),64126=>array(-94.495978,39.091093),64127=>array(-94.538537,39.089138),64128=>array(-94.534623,39.065566),64129=>array(-94.491958,39.047897),64130=>array(-94.540754,39.033683),64131=>array(-94.585011,38.936041),64132=>array(-94.542261,38.988304),64133=>array(-94.455876,39.013941),64134=>array(-94.487626,38.928039),64136=>array(-94.405845,39.012767),64137=>array(-94.542668,38.93536),64138=>array(-94.467927,38.967119),64139=>array(-94.416366,38.968342),64145=>array(-94.59402,38.873529),64146=>array(-94.572741,38.883038),64147=>array(-94.55049,38.852723),64149=>array(-94.468876,38.861907),64150=>array(-94.632534,39.172196),64151=>array(-94.630168,39.214394),64152=>array(-94.72473,39.219074),64153=>array(-94.726643,39.274581),64154=>array(-94.637094,39.28023),64155=>array(-94.580082,39.27241),64156=>array(-94.519995,39.273306),64157=>array(-94.483504,39.279003),64158=>array(-94.485477,39.234315),64161=>array(-94.45078,39.158486),64163=>array(-94.688186,39.344561),64164=>array(-94.627074,39.329423),64165=>array(-94.576341,39.321429),64166=>array(-94.523143,39.322071),64167=>array(-94.487141,39.320589),64192=>array(-94.522029,38.960455),64401=>array(-94.715618,39.633348),64402=>array(-94.327329,40.257169),64420=>array(-94.288679,40.48534),64421=>array(-94.935909,39.912325),64422=>array(-94.498907,39.885929),64423=>array(-94.851656,40.192871),64424=>array(-94.036075,40.261889),64426=>array(-93.859518,40.52171),64427=>array(-94.833155,40.111362),64428=>array(-95.093894,40.43661),64429=>array(-94.225807,39.736726),64430=>array(-94.565539,39.83899),64431=>array(-94.996257,40.528193),64432=>array(-94.668692,40.263494),64433=>array(-94.678085,40.23868),64434=>array(-94.733515,40.261855),64436=>array(-94.691859,39.857727),64437=>array(-95.347485,40.122385),64438=>array(-94.413766,40.158583),64439=>array(-94.753373,39.524413),64440=>array(-94.910338,39.585134),64441=>array(-94.2713,40.392917),64442=>array(-94.011464,40.489895),64443=>array(-94.653163,39.742886),64444=>array(-94.648013,39.485433),64445=>array(-95.149108,40.540243),64446=>array(-95.422168,40.316786),64448=>array(-94.822765,39.596748),64449=>array(-94.978475,40.0412),64451=>array(-95.193705,40.001495),64453=>array(-94.480161,40.345019),64454=>array(-94.592553,39.5965),64455=>array(-95.00499,40.180566),64456=>array(-94.39108,40.493138),64457=>array(-94.682355,40.162713),64458=>array(-94.145198,40.514955),64459=>array(-94.649389,39.928943),64461=>array(-94.80719,40.521587),64463=>array(-94.482585,40.062598),64465=>array(-94.287621,39.549898),64466=>array(-95.106267,40.16622),64467=>array(-94.162947,40.401658),64468=>array(-94.881028,40.343552),64469=>array(-94.365018,39.918689),64470=>array(-95.229189,40.160107),64471=>array(-94.192879,40.253201),64473=>array(-95.076209,39.979261),64474=>array(-94.379595,39.755309),64475=>array(-94.623615,40.436279),64476=>array(-94.83059,40.452969),64477=>array(-94.452827,39.575558),64479=>array(-94.647005,40.333987),64480=>array(-94.705477,40.054115),64481=>array(-93.887733,40.353947),64482=>array(-95.546378,40.46497),64483=>array(-94.839109,40.038891),64484=>array(-95.017149,39.5612),64485=>array(-94.818163,39.949977),64486=>array(-94.624411,40.530389),64487=>array(-95.095911,40.300935),64489=>array(-94.547271,40.236887),64490=>array(-94.514713,39.731215),64491=>array(-95.358054,40.446045),64492=>array(-94.532644,39.470667),64493=>array(-94.318186,39.635053),64494=>array(-94.609608,39.989408),64496=>array(-95.645934,40.481159),64497=>array(-94.219852,39.930459),64498=>array(-95.321933,40.539605),64499=>array(-94.43979,40.393864),64501=>array(-94.844432,39.765442),64503=>array(-94.843728,39.748884),64504=>array(-94.905924,39.691247),64505=>array(-94.823908,39.84678),64506=>array(-94.803312,39.789915),64507=>array(-94.763541,39.728509),64601=>array(-93.579097,39.805381),64620=>array(-94.089951,39.894531),64622=>array(-93.542717,39.49255),64623=>array(-93.333742,39.469599),64624=>array(-93.784471,39.562364),64625=>array(-93.802883,39.744043),64628=>array(-93.041516,39.796166),64630=>array(-93.156662,40.037692),64631=>array(-92.866091,39.82425),64632=>array(-93.766788,40.468986),64633=>array(-93.484492,39.356863),64635=>array(-93.433845,39.95278),64636=>array(-93.980463,40.110098),64637=>array(-93.915091,39.557997),64638=>array(-93.620136,39.617643),64639=>array(-93.222763,39.391732),64640=>array(-93.935107,39.895648),64641=>array(-93.399564,40.175889),64642=>array(-93.836449,40.170792),64643=>array(-93.369158,39.613045),64644=>array(-93.975183,39.735438),64645=>array(-93.32232,40.30007),64646=>array(-93.309021,40.099034),64647=>array(-93.984725,40.031136),64648=>array(-93.802749,39.989061),64649=>array(-94.08639,39.773347),64650=>array(-94.071505,39.635657),64651=>array(-93.185672,39.766804),64652=>array(-93.418192,40.021508),64653=>array(-93.212092,39.897256),64654=>array(-93.773159,39.840341),64655=>array(-93.257493,40.44653),64656=>array(-93.692789,39.67691),64657=>array(-94.223765,40.129094),64658=>array(-92.917299,39.662965),64659=>array(-93.298635,39.784623),64660=>array(-93.098666,39.564517),64661=>array(-93.517049,40.536314),64664=>array(-93.651288,39.749706),64667=>array(-93.331269,40.385743),64668=>array(-93.704415,39.355068),64670=>array(-94.141692,40.047765),64671=>array(-94.050775,39.531881),64672=>array(-93.255082,40.544835),64673=>array(-93.586901,40.374309),64674=>array(-93.137733,39.962633),64676=>array(-93.058469,39.638456),64679=>array(-93.580329,40.237511),64681=>array(-93.230453,39.645516),64682=>array(-93.490551,39.550123),64683=>array(-93.60104,40.078396),64686=>array(-93.624336,39.748959),64688=>array(-93.37506,39.817132),64689=>array(-94.150128,39.872556),64701=>array(-94.329255,38.624513),64720=>array(-94.343478,38.404674),64722=>array(-94.542511,38.278074),64723=>array(-94.559592,38.361639),64724=>array(-94.006638,38.15321),64725=>array(-94.372655,38.490658),64726=>array(-93.921941,38.527153),64728=>array(-94.523816,37.703047),64730=>array(-94.300276,38.259262),64733=>array(-93.827198,38.584819),64734=>array(-94.559334,38.654734),64735=>array(-93.743646,38.367806),64738=>array(-93.651689,37.901664),64739=>array(-94.096624,38.51128),64740=>array(-93.703771,38.226188),64741=>array(-94.562345,37.818234),64742=>array(-94.541195,38.508095),64743=>array(-94.232284,38.668454),64744=>array(-93.978926,37.848197),64745=>array(-94.497226,38.171889),64746=>array(-94.496698,38.6021),64747=>array(-94.182182,38.578826),64748=>array(-94.090739,37.359673),64750=>array(-94.101696,37.940899),64752=>array(-94.563468,38.065018),64755=>array(-94.308691,37.337416),64756=>array(-94.01549,37.619045),64759=>array(-94.25704,37.52122),64761=>array(-93.683114,38.601551),64762=>array(-94.501483,37.546659),64763=>array(-93.701939,38.143551),64765=>array(-94.443796,37.995885),64767=>array(-94.201452,37.737357),64769=>array(-94.568309,37.480688),64770=>array(-93.989537,38.281457),64771=>array(-94.470296,37.750223),64772=>array(-94.334697,37.832567),64776=>array(-93.66347,38.048385),64778=>array(-94.479382,37.919357),64779=>array(-94.396212,38.092018),64780=>array(-94.046961,38.059202),64781=>array(-93.812591,37.981517),64783=>array(-94.1094,38.005239),64784=>array(-94.234169,37.664651),64788=>array(-94.019548,38.423906),64790=>array(-94.220647,37.927026),64801=>array(-94.496221,37.109783),64804=>array(-94.50942,37.022425),64830=>array(-94.41037,37.231391),64831=>array(-94.455992,36.656869),64832=>array(-94.573598,37.340209),64833=>array(-94.129842,37.19381),64834=>array(-94.573612,37.187875),64835=>array(-94.437484,37.148444),64836=>array(-94.279255,37.189255),64840=>array(-94.336063,37.01657),64841=>array(-94.416752,37.078348),64842=>array(-94.105994,36.789007),64843=>array(-94.443926,36.733895),64844=>array(-94.238563,36.916226),64847=>array(-94.440999,36.593982),64848=>array(-93.989626,37.171779),64849=>array(-94.444881,37.254904),64850=>array(-94.401672,36.860531),64854=>array(-94.455884,36.545988),64855=>array(-94.48532,37.295478),64856=>array(-94.269907,36.565948),64857=>array(-94.438585,37.245854),64858=>array(-94.530495,36.901178),64859=>array(-94.137989,37.162761),64861=>array(-94.154072,36.695352),64862=>array(-94.119523,37.100665),64863=>array(-94.58334,36.559367),64865=>array(-94.581306,36.842677),64866=>array(-94.156423,36.869577),64867=>array(-94.235106,36.728044),64870=>array(-94.477775,37.182917),64873=>array(-94.045714,37.013395),64874=>array(-94.054314,36.758474),65001=>array(-92.010272,38.29023),65010=>array(-92.237172,38.793269),65011=>array(-92.713345,38.389067),65013=>array(-91.762257,38.284774),65014=>array(-91.631137,38.316176),65016=>array(-91.933877,38.560079),65017=>array(-92.494503,38.092307),65018=>array(-92.563615,38.620197),65020=>array(-92.780644,38.006239),65023=>array(-92.396296,38.653901),65024=>array(-91.756356,38.619249),65025=>array(-92.69002,38.675948),65026=>array(-92.564791,38.324361),65032=>array(-92.378378,38.346567),65034=>array(-92.818106,38.559677),65035=>array(-91.946963,38.363815),65037=>array(-92.849146,38.243419),65039=>array(-92.296622,38.711084),65040=>array(-92.284439,38.34824),65041=>array(-91.489763,38.632996),65043=>array(-92.102764,38.623449),65046=>array(-92.488423,38.786494),65047=>array(-92.578409,38.15097),65048=>array(-92.040605,38.37312),65049=>array(-92.674809,38.1995),65050=>array(-92.687801,38.543645),65051=>array(-91.797166,38.469165),65052=>array(-92.61734,38.083492),65053=>array(-92.378964,38.527054),65054=>array(-91.949439,38.488994),65058=>array(-92.127853,38.249621),65059=>array(-91.867637,38.700661),65061=>array(-91.63551,38.599503),65062=>array(-91.659235,38.504042),65063=>array(-92.087607,38.72126),65064=>array(-92.471423,38.402845),65065=>array(-92.662853,38.134934),65066=>array(-91.484846,38.349483),65067=>array(-91.703149,38.766201),65068=>array(-92.614762,38.825749),65069=>array(-91.589785,38.753012),65072=>array(-92.72935,38.266773),65074=>array(-92.468144,38.484301),65075=>array(-92.25752,38.250489),65076=>array(-92.194056,38.379486),65077=>array(-91.812579,38.772199),65078=>array(-93.022188,38.389492),65079=>array(-92.748302,38.150286),65080=>array(-91.978927,38.636261),65081=>array(-92.782268,38.644434),65082=>array(-92.421422,38.219313),65083=>array(-92.440994,38.140911),65084=>array(-92.856128,38.43424),65085=>array(-92.084526,38.397651),65101=>array(-92.134532,38.495766),65109=>array(-92.277944,38.57416),65201=>array(-92.238425,38.900944),65202=>array(-92.296535,39.02037),65203=>array(-92.398565,38.884324),65215=>array(-92.32085,38.953173),65230=>array(-92.702593,39.290548),65231=>array(-91.897785,39.01654),65232=>array(-91.756,39.160695),65233=>array(-92.728078,38.917096),65236=>array(-93.065958,39.440542),65237=>array(-92.793644,38.766639),65239=>array(-92.432043,39.53352),65240=>array(-92.125561,39.220638),65243=>array(-92.354421,39.268429),65244=>array(-92.659485,39.4848),65246=>array(-92.996616,39.378901),65247=>array(-92.470615,39.635059),65248=>array(-92.660133,39.138606),65250=>array(-92.840101,39.0301),65251=>array(-91.977132,38.841849),65254=>array(-92.853371,39.210375),65255=>array(-92.218393,39.102561),65256=>array(-92.456477,39.120991),65257=>array(-92.533811,39.287086),65258=>array(-92.135201,39.520236),65259=>array(-92.569715,39.476712),65260=>array(-92.385861,39.580629),65261=>array(-92.933433,39.475211),65262=>array(-91.955313,38.960143),65263=>array(-92.220167,39.461874),65264=>array(-91.68564,39.088314),65265=>array(-91.885371,39.203373),65270=>array(-92.39495,39.413639),65274=>array(-92.686203,39.015799),65275=>array(-91.994965,39.453066),65276=>array(-92.952563,38.849568),65278=>array(-92.410624,39.341583),65279=>array(-92.52849,39.001389),65280=>array(-91.736982,39.242871),65281=>array(-92.798834,39.46824),65282=>array(-91.822967,39.387929),65283=>array(-91.827525,39.509271),65284=>array(-92.293325,39.20641),65285=>array(-91.999838,39.271734),65286=>array(-93.220334,39.507568),65287=>array(-92.530138,38.886302),65301=>array(-93.225707,38.698269),65305=>array(-93.553162,38.733096),65320=>array(-92.947247,39.07),65321=>array(-93.46863,39.092622),65322=>array(-92.951995,38.982087),65323=>array(-93.617513,38.443904),65324=>array(-93.029914,38.126812),65325=>array(-93.189165,38.439774),65326=>array(-93.13917,38.16584),65327=>array(-93.495313,38.973973),65329=>array(-92.966698,38.621034),65330=>array(-92.952862,39.217726),65332=>array(-93.414805,38.624224),65333=>array(-93.319941,38.900768),65334=>array(-93.226858,38.84531),65335=>array(-93.342103,38.504713),65336=>array(-93.575353,38.792708),65337=>array(-93.431379,38.794493),65338=>array(-93.279912,38.363547),65339=>array(-93.374737,39.195918),65340=>array(-93.182975,39.09086),65344=>array(-93.192186,39.313866),65345=>array(-93.126897,38.537892),65347=>array(-93.04025,38.988926),65348=>array(-92.974231,38.714024),65349=>array(-93.045452,39.230471),65350=>array(-93.090672,38.64597),65351=>array(-93.381217,38.994268),65354=>array(-92.876448,38.653942),65355=>array(-93.366948,38.219545),65360=>array(-93.517553,38.516411),65401=>array(-91.768578,37.900035),65436=>array(-91.96361,37.623801),65438=>array(-91.501101,36.931336),65439=>array(-91.070009,37.655276),65440=>array(-91.172728,37.619926),65441=>array(-91.159022,38.09638),65443=>array(-92.094622,38.131683),65444=>array(-92.057206,37.379114),65446=>array(-91.28134,37.777805),65449=>array(-91.494674,37.852033),65452=>array(-92.266127,37.96689),65453=>array(-91.439811,38.106493),65456=>array(-91.18978,37.784607),65457=>array(-92.059538,37.81011),65459=>array(-92.096732,38.02972),65461=>array(-92.043738,37.676732),65462=>array(-91.848757,37.683375),65463=>array(-92.784345,37.853617),65464=>array(-91.899782,37.186578),65466=>array(-91.348447,37.205455),65468=>array(-91.790223,37.249928),65470=>array(-92.401801,37.547434),65473=>array(-92.154489,37.706433),65479=>array(-91.636139,37.342026),65483=>array(-91.955093,37.298969),65484=>array(-92.227015,37.356223),65486=>array(-92.328061,38.108287),65501=>array(-91.566241,37.462127),65529=>array(-92.01004,37.929166),65534=>array(-92.28428,37.690279),65535=>array(-91.274154,38.070003),65536=>array(-92.644482,37.687697),65541=>array(-91.772205,37.651862),65542=>array(-91.883745,37.495709),65543=>array(-92.289349,37.46187),65548=>array(-91.712657,37.013085),65550=>array(-91.95454,37.822689),65552=>array(-92.16588,37.535168),65555=>array(-91.767023,37.367583),65556=>array(-92.408789,37.835406),65557=>array(-92.100972,37.509813),65559=>array(-91.610098,38.024853),65560=>array(-91.503902,37.596621),65564=>array(-91.968826,37.227369),65565=>array(-91.242232,37.893625),65566=>array(-91.126642,37.720734),65567=>array(-92.535705,37.865133),65570=>array(-92.094798,37.452634),65571=>array(-91.62303,37.186248),65580=>array(-91.789799,38.116494),65582=>array(-91.923639,38.196054),65583=>array(-92.255536,37.82273),65584=>array(-92.131212,37.828203),65586=>array(-91.431656,37.849588),65588=>array(-91.272971,36.981751),65589=>array(-91.838239,37.245475),65590=>array(-92.951287,37.606148),65591=>array(-92.640747,37.938453),65601=>array(-93.588004,37.539862),65603=>array(-93.86523,37.556769),65604=>array(-93.598471,37.269914),65605=>array(-93.654747,36.771716),65606=>array(-91.359397,36.697257),65608=>array(-92.677621,36.898747),65609=>array(-92.151703,36.542528),65610=>array(-93.530942,37.030759),65611=>array(-93.372149,36.549846),65612=>array(-93.540109,37.215241),65613=>array(-93.396427,37.636902),65614=>array(-92.909237,36.754466),65616=>array(-93.248879,36.669373),65617=>array(-93.336027,37.438072),65618=>array(-92.359711,36.733139),65619=>array(-93.394691,37.121719),65620=>array(-92.944583,37.022629),65622=>array(-93.103604,37.633024),65623=>array(-93.906409,36.748816),65624=>array(-93.566299,36.730202),65625=>array(-93.816497,36.674069),65626=>array(-92.130859,36.594943),65627=>array(-93.030872,36.56469),65629=>array(-93.000589,36.891489),65630=>array(-93.21365,36.832959),65631=>array(-93.423999,37.000699),65632=>array(-92.80993,37.497907),65633=>array(-93.534748,36.894781),65634=>array(-93.194616,38.015397),65635=>array(-93.717143,37.531741),65637=>array(-92.200166,36.759338),65638=>array(-92.322251,36.838205),65640=>array(-93.566848,37.698467),65641=>array(-93.769176,36.543773),65644=>array(-93.038245,37.510937),65646=>array(-93.703246,37.333448),65647=>array(-94.007438,36.692553),65648=>array(-93.167091,37.408853),65649=>array(-93.623215,37.617274),65650=>array(-93.441928,37.813994),65652=>array(-92.948822,37.133949),65653=>array(-93.140383,36.84083),65654=>array(-93.909637,37.022203),65655=>array(-92.425548,36.595898),65656=>array(-93.46783,36.793766),65657=>array(-93.007524,36.838309),65658=>array(-93.637963,36.540154),65660=>array(-92.273898,37.334212),65661=>array(-93.825199,37.467688),65662=>array(-92.570452,37.446733),65663=>array(-93.246727,37.623371),65664=>array(-93.615151,37.198055),65667=>array(-92.514047,37.308459),65668=>array(-93.290503,37.93123),65669=>array(-93.302603,36.911907),65672=>array(-93.219488,36.560354),65674=>array(-93.607277,37.785786),65676=>array(-92.61594,36.57217),65679=>array(-93.095925,36.579445),65680=>array(-93.003455,36.653164),65681=>array(-93.461857,36.550848),65682=>array(-93.961715,37.411878),65685=>array(-93.166953,37.7523),65686=>array(-93.436156,36.622117),65689=>array(-92.092904,37.144416),65690=>array(-91.279346,36.58909),65692=>array(-91.631413,36.627591),65702=>array(-92.494058,37.07202),65704=>array(-92.586107,37.12762),65705=>array(-93.621572,36.988526),65706=>array(-92.898635,37.32282),65707=>array(-93.843315,37.233674),65708=>array(-93.911536,36.902894),65710=>array(-93.421088,37.485556),65711=>array(-92.275679,37.176383),65712=>array(-93.800291,37.110674),65713=>array(-92.746951,37.404644),65714=>array(-93.320282,37.038095),65715=>array(-92.574001,36.731375),65717=>array(-92.416048,37.06044),65720=>array(-92.950037,36.940563),65721=>array(-93.209226,36.982818),65722=>array(-92.805465,37.582915),65723=>array(-94.04032,36.958625),65724=>array(-93.313311,37.84443),65725=>array(-93.28816,37.433273),65727=>array(-93.294846,37.755095),65728=>array(-93.345561,36.871381),65729=>array(-92.592739,36.51396),65730=>array(-94.177289,36.623694),65731=>array(-93.126038,36.653342),65732=>array(-93.161545,37.941693),65733=>array(-92.849419,36.527116),65734=>array(-93.941817,36.795214),65735=>array(-93.458727,38.03992),65737=>array(-93.360672,36.714025),65738=>array(-93.506398,37.13928),65739=>array(-93.274159,36.510959),65740=>array(-93.163478,36.713574),65742=>array(-93.079797,37.124614),65744=>array(-92.897552,36.622787),65745=>array(-93.970641,36.530708),65746=>array(-92.778195,37.14619),65747=>array(-93.580084,36.600861),65752=>array(-93.830886,37.327705),65753=>array(-93.046087,37.002844),65754=>array(-93.281437,36.836654),65755=>array(-92.626445,36.814669),65756=>array(-93.973906,37.098035),65757=>array(-93.09894,37.282848),65759=>array(-93.068019,36.762545),65760=>array(-92.281329,36.634217),65761=>array(-92.724984,36.576449),65762=>array(-92.651285,36.684886),65764=>array(-92.948688,37.814523),65766=>array(-92.268221,36.536157),65767=>array(-93.155931,37.852256),65768=>array(-92.270035,36.919435),65769=>array(-93.799405,36.919096),65770=>array(-93.548226,37.422627),65771=>array(-93.20642,36.772472),65772=>array(-94.023207,36.598992),65773=>array(-92.501811,36.762508),65774=>array(-93.489344,37.930273),65775=>array(-91.858053,36.700074),65777=>array(-91.997786,36.525746),65778=>array(-91.269785,36.529757),65779=>array(-93.378863,37.977567),65781=>array(-93.417569,37.355541),65783=>array(-92.933321,37.71457),65784=>array(-92.313911,36.679888),65785=>array(-93.825054,37.708475),65786=>array(-92.962723,37.96578),65787=>array(-92.883347,38.070593),65788=>array(-91.694945,36.806689),65789=>array(-91.873714,36.862869),65790=>array(-92.10954,36.703024),65791=>array(-91.497595,36.579764),65793=>array(-91.971986,36.991559),65802=>array(-93.354612,37.20745),65803=>array(-93.289599,37.28314),65804=>array(-93.252749,37.149307),65806=>array(-93.299157,37.205585),65807=>array(-93.325004,37.165185),65809=>array(-93.182484,37.166589),65810=>array(-93.309929,37.119534),66002=>array(-95.137635,39.538742),66006=>array(-95.23267,38.804266),66007=>array(-94.94165,39.15622),66008=>array(-95.176504,39.718049),66010=>array(-94.97917,38.088217),66012=>array(-94.919276,39.065593),66013=>array(-94.695551,38.730666),66014=>array(-94.987105,38.228845),66015=>array(-95.413199,38.074849),66016=>array(-95.231745,39.475168),66017=>array(-95.273961,39.703716),66018=>array(-94.964154,38.962643),66019=>array(-95.003284,38.94544),66020=>array(-95.116107,39.339341),66021=>array(-95.0144,38.76628),66023=>array(-95.392403,39.512289),66024=>array(-94.881614,39.736988),66025=>array(-95.08334,38.891903),66026=>array(-94.864355,38.396304),66027=>array(-94.911426,39.368618),66030=>array(-94.940266,38.815137),66031=>array(-94.890084,38.832069),66032=>array(-95.278214,38.286777),66033=>array(-95.122267,38.363289),66035=>array(-95.253591,39.870996),66039=>array(-95.164855,38.104411),66040=>array(-94.747904,38.354528),66041=>array(-95.307974,39.600303),66042=>array(-95.079886,38.422786),66043=>array(-94.882513,39.251199),66044=>array(-95.208909,39.023294),66045=>array(-95.247749,38.958845),66046=>array(-95.209753,38.904524),66047=>array(-95.346521,38.892426),66048=>array(-94.995995,39.28233),66049=>array(-95.344139,38.978105),66050=>array(-95.442516,39.011834),66052=>array(-95.048266,39.015766),66053=>array(-94.668065,38.581078),66054=>array(-95.198043,39.206136),66056=>array(-94.844282,38.151453),66058=>array(-95.520384,39.541067),66060=>array(-95.33223,39.418161),66061=>array(-94.879975,38.893764),66062=>array(-94.778679,38.835366),66064=>array(-94.988936,38.480714),66066=>array(-95.330593,39.203002),66067=>array(-95.276284,38.623617),66070=>array(-95.450917,39.20569),66071=>array(-94.864562,38.573078),66072=>array(-94.963963,38.309431),66073=>array(-95.368342,39.082417),66075=>array(-94.693412,38.200521),66076=>array(-95.443013,38.632455),66078=>array(-95.259302,38.48544),66079=>array(-95.108134,38.542467),66080=>array(-95.260197,38.40697),66083=>array(-94.831552,38.730587),66085=>array(-94.656684,38.798768),66086=>array(-95.08123,39.119526),66087=>array(-95.122122,39.802081),66088=>array(-95.461198,39.339329),66090=>array(-94.973467,39.788124),66091=>array(-95.312532,38.178278),66092=>array(-95.097953,38.7015),66093=>array(-95.494138,38.20781),66094=>array(-95.34244,39.951286),66095=>array(-95.438861,38.441094),66097=>array(-95.246083,39.328599),66101=>array(-94.625983,39.118982),66102=>array(-94.692538,39.108964),66103=>array(-94.626797,39.060338),66104=>array(-94.689501,39.150204),66105=>array(-94.638934,39.087011),66106=>array(-94.702613,39.069454),66109=>array(-94.829341,39.165351),66111=>array(-94.789981,39.08401),66112=>array(-94.773577,39.11452),66115=>array(-94.605084,39.148258),66118=>array(-94.613129,39.103981),66202=>array(-94.669466,39.02315),66203=>array(-94.705787,39.020331),66204=>array(-94.678214,38.990381),66205=>array(-94.630762,39.031176),66206=>array(-94.620277,38.960717),66207=>array(-94.643247,38.955644),66208=>array(-94.628568,38.998262),66209=>array(-94.638358,38.8996),66210=>array(-94.704655,38.921707),66211=>array(-94.636336,38.923059),66212=>array(-94.679875,38.955565),66213=>array(-94.708219,38.898859),66214=>array(-94.714087,38.967425),66215=>array(-94.744269,38.957701),66216=>array(-94.741577,39.013774),66217=>array(-94.782287,39.009521),66218=>array(-94.818803,39.02069),66219=>array(-94.77622,38.952366),66220=>array(-94.819584,38.961714),66221=>array(-94.708502,38.863662),66223=>array(-94.668479,38.863482),66224=>array(-94.626804,38.863539),66226=>array(-94.859095,39.030902),66227=>array(-94.874826,38.972676),66401=>array(-96.309695,38.932251),66402=>array(-95.84327,38.914),66403=>array(-96.285893,39.893573),66404=>array(-96.173343,39.878146),66406=>array(-96.420729,39.894106),66407=>array(-96.198795,39.228519),66408=>array(-95.969994,39.959454),66409=>array(-95.55964,38.924185),66411=>array(-96.628455,39.64546),66412=>array(-96.777462,39.90763),66413=>array(-95.880727,38.768874),66414=>array(-95.688649,38.830304),66415=>array(-96.147458,39.688276),66416=>array(-95.86324,39.525706),66417=>array(-96.044857,39.656559),66418=>array(-95.933586,39.279496),66419=>array(-95.598882,39.360679),66422=>array(-96.085516,39.336294),66423=>array(-96.232746,38.801294),66424=>array(-95.404063,39.674689),66425=>array(-95.738422,39.816196),66427=>array(-96.438829,39.661283),66428=>array(-95.931359,39.676115),66429=>array(-95.534186,39.09377),66431=>array(-96.003769,38.802909),66432=>array(-96.066716,39.489763),66434=>array(-95.549365,39.861691),66436=>array(-95.698276,39.467881),66438=>array(-96.492864,39.854484),66439=>array(-95.540086,39.656331),66440=>array(-95.676822,39.268181),66441=>array(-96.803088,38.97352),66442=>array(-96.790133,39.091847),66449=>array(-96.856465,39.390138),66451=>array(-95.672323,38.614716),66501=>array(-96.237446,39.05381),66502=>array(-96.521914,39.157803),66503=>array(-96.692192,39.265057),66506=>array(-96.581571,39.19586),66507=>array(-96.06796,39.045162),66508=>array(-96.630811,39.855917),66509=>array(-95.780372,39.340866),66510=>array(-95.610199,38.499626),66512=>array(-95.545107,39.19917),66514=>array(-96.875603,39.126223),66515=>array(-95.703732,39.936244),66516=>array(-95.720734,39.627947),66517=>array(-96.706605,39.113132),66518=>array(-96.550756,39.965606),66520=>array(-96.617663,39.418894),66521=>array(-96.218995,39.480218),66522=>array(-95.941994,39.868546),66523=>array(-95.839913,38.610562),66524=>array(-95.506081,38.790944),66526=>array(-96.154801,39.065509),66527=>array(-95.67371,39.745394),66528=>array(-95.535308,38.597755),66531=>array(-96.821533,39.310997),66532=>array(-95.377943,39.821429),66533=>array(-95.947495,39.163187),66534=>array(-95.837144,39.88436),66535=>array(-96.433702,39.26703),66536=>array(-96.080292,39.225094),66537=>array(-95.719623,38.751242),66538=>array(-96.044691,39.850557),66539=>array(-95.84039,39.141967),66540=>array(-95.976268,39.490516),66541=>array(-96.366926,39.974736),66542=>array(-95.544771,39.010744),66543=>array(-95.592811,38.644955),66544=>array(-96.280047,39.692051),66546=>array(-95.721038,38.895461),66547=>array(-96.295611,39.231558),66548=>array(-96.761417,39.677943),66549=>array(-96.415466,39.427677),66550=>array(-95.820665,39.655442),66552=>array(-95.624167,39.593892),66554=>array(-96.790528,39.494814),66603=>array(-95.67616,39.057894),66604=>array(-95.726188,39.039022),66605=>array(-95.634774,39.011911),66606=>array(-95.71987,39.061436),66607=>array(-95.636364,39.04258),66608=>array(-95.663226,39.079611),66609=>array(-95.660737,38.978236),66610=>array(-95.844565,38.976726),66611=>array(-95.696387,39.018756),66612=>array(-95.680471,39.040436),66614=>array(-95.852479,39.010366),66615=>array(-95.897866,39.050826),66616=>array(-95.623407,39.068476),66617=>array(-95.623239,39.134832),66618=>array(-95.748267,39.139508),66619=>array(-95.688062,38.947635),66621=>array(-95.701543,39.033321),66622=>array(-95.72227,39.025896),66701=>array(-94.762136,37.822015),66710=>array(-95.624072,37.552628),66711=>array(-94.685001,37.637096),66712=>array(-94.714519,37.564876),66713=>array(-94.785294,37.040492),66714=>array(-95.698621,37.636602),66716=>array(-95.036782,37.94802),66717=>array(-95.696902,37.69586),66720=>array(-95.45719,37.64833),66724=>array(-94.857052,37.350289),66725=>array(-94.895319,37.156583),66728=>array(-94.704071,37.171277),66732=>array(-95.187002,37.799187),66733=>array(-95.254823,37.596759),66734=>array(-94.830183,37.618089),66735=>array(-94.708564,37.523161),66736=>array(-95.861095,37.551477),66738=>array(-94.723389,38.013735),66739=>array(-94.655261,37.12578),66740=>array(-95.364186,37.479551),66741=>array(-94.656007,37.71914),66743=>array(-94.893692,37.503998),66746=>array(-94.954136,37.668111),66748=>array(-95.441606,37.795954),66749=>array(-95.406943,37.935949),66751=>array(-95.289784,37.943731),66753=>array(-95.011049,37.362055),66754=>array(-94.885623,38.004862),66755=>array(-95.179278,37.928862),66756=>array(-94.659149,37.54483),66757=>array(-95.695818,37.417206),66758=>array(-95.58695,38.01599),66760=>array(-94.624352,37.348316),66761=>array(-95.569215,37.91826),66762=>array(-94.710469,37.393869),66763=>array(-94.69781,37.46315),66767=>array(-94.703031,38.073554),66769=>array(-94.889957,37.856527),66770=>array(-94.715342,37.080735),66771=>array(-95.145995,37.487563),66772=>array(-95.206284,37.754519),66773=>array(-94.806572,37.272257),66775=>array(-95.148771,37.701935),66776=>array(-95.489391,37.462882),66777=>array(-95.972096,37.799903),66778=>array(-94.840857,37.000499),66779=>array(-94.991966,37.825646),66780=>array(-95.056933,37.621728),66781=>array(-94.733491,37.288583),66782=>array(-94.926319,37.285017),66783=>array(-95.737014,37.874461),66801=>array(-96.218187,38.413743),66830=>array(-96.08742,38.60242),66833=>array(-96.195012,38.695591),66834=>array(-96.437347,38.861969),66835=>array(-96.258153,38.543253),66838=>array(-96.800981,38.555305),66839=>array(-95.748127,38.217399),66840=>array(-96.879024,38.065599),66842=>array(-96.651497,38.009995),66843=>array(-96.740487,38.222479),66845=>array(-96.508392,38.298731),66846=>array(-96.470435,38.64747),66849=>array(-96.589623,38.877492),66850=>array(-96.744392,38.433969),66851=>array(-96.918638,38.217863),66852=>array(-95.895613,38.06437),66853=>array(-96.235303,38.001895),66854=>array(-95.979552,38.250808),66856=>array(-95.811788,38.397806),66857=>array(-95.633116,38.096342),66858=>array(-96.932543,38.480437),66859=>array(-96.96242,38.556181),66860=>array(-96.165629,38.12728),66861=>array(-97.008508,38.367759),66862=>array(-96.556128,38.154999),66863=>array(-96.081781,37.832866),66864=>array(-95.981495,38.354887),66865=>array(-96.293207,38.223476),66866=>array(-97.107439,38.173042),66868=>array(-95.979419,38.544773),66869=>array(-96.516685,38.463875),66870=>array(-96.029569,37.944163),66871=>array(-95.610225,38.362643),66872=>array(-96.768749,38.790751),66873=>array(-96.679596,38.618816),66901=>array(-97.638951,39.560035),66930=>array(-97.479485,39.706683),66932=>array(-98.930885,39.779487),66933=>array(-96.872319,39.675419),66935=>array(-97.631694,39.840598),66936=>array(-98.316114,39.921187),66937=>array(-97.270636,39.587719),66938=>array(-97.413988,39.574462),66939=>array(-97.90429,39.85286),66940=>array(-97.448891,39.807788),66941=>array(-98.438848,39.835576),66942=>array(-98.000706,39.805279),66943=>array(-96.966281,39.671811),66944=>array(-97.303062,39.839676),66945=>array(-96.878258,39.887172),66946=>array(-97.004607,39.966411),66948=>array(-97.852349,39.59825),66949=>array(-98.186309,39.64357),66951=>array(-99.019698,39.850601),66952=>array(-98.604785,39.835805),66953=>array(-97.106623,39.690191),66955=>array(-97.297736,39.96787),66956=>array(-98.227649,39.794314),66958=>array(-97.177186,39.889446),66959=>array(-97.529645,39.923008),66960=>array(-97.434754,39.936764),66962=>array(-97.114331,39.599322),66963=>array(-97.999399,39.636931),66964=>array(-97.804925,39.941213),66966=>array(-97.766299,39.775329),66967=>array(-98.794227,39.819725),66968=>array(-97.065893,39.824736),66970=>array(-98.034453,39.948228),67001=>array(-97.629161,37.758455),67002=>array(-97.108354,37.699294),67003=>array(-98.073777,37.099126),67004=>array(-97.753071,37.278725),67005=>array(-96.995733,37.065173),67008=>array(-96.779441,37.486787),67009=>array(-98.266833,37.218022),67010=>array(-96.976424,37.664428),67012=>array(-96.54655,37.673665),67013=>array(-97.26822,37.381869),67016=>array(-97.514822,37.886791),67017=>array(-97.111635,37.826286),67018=>array(-97.85904,37.072631),67019=>array(-96.777587,37.30657),67020=>array(-97.670641,38.007923),67021=>array(-98.91531,37.778497),67022=>array(-97.632662,37.076549),67023=>array(-96.592204,37.346116),67024=>array(-96.48633,37.110747),67025=>array(-97.785091,37.643002),67026=>array(-97.494299,37.51087),67028=>array(-98.936392,37.458774),67029=>array(-99.279961,37.171432),67030=>array(-97.54681,37.785616),67031=>array(-97.639518,37.399302),67035=>array(-98.387334,37.649234),67036=>array(-97.876668,37.297567),67037=>array(-97.217333,37.571767),67038=>array(-96.723843,37.10179),67039=>array(-96.97429,37.527668),67041=>array(-97.129971,38.054139),67042=>array(-96.780718,37.857264),67045=>array(-96.345282,37.866145),67047=>array(-96.056963,37.628305),67049=>array(-97.846362,37.177439),67050=>array(-97.675588,37.674351),67051=>array(-97.196565,37.089302),67052=>array(-97.575586,37.657709),67053=>array(-97.346339,38.246815),67054=>array(-99.316072,37.57504),67055=>array(-97.197687,37.790028),67056=>array(-97.525412,38.021951),67057=>array(-98.779531,37.071203),67058=>array(-98.061352,37.317916),67059=>array(-99.097274,37.636944),67060=>array(-97.363698,37.542973),67061=>array(-98.381734,37.092794),67062=>array(-97.437098,38.145186),67063=>array(-97.233749,38.340735),67065=>array(-98.516204,37.464925),67066=>array(-98.766895,37.769997),67067=>array(-97.274036,37.793161),67068=>array(-98.105834,37.617195),67070=>array(-98.525994,37.079078),67071=>array(-98.882142,37.262719),67072=>array(-96.611371,37.544533),67073=>array(-97.328482,38.383819),67074=>array(-96.723859,37.670731),67101=>array(-97.464268,37.785255),67103=>array(-97.560608,37.26632),67104=>array(-98.664433,37.265078),67105=>array(-97.67578,37.233364),67106=>array(-97.757279,37.467123),67107=>array(-97.547655,38.194214),67108=>array(-97.685161,37.812835),67109=>array(-99.485817,37.561275),67110=>array(-97.226554,37.465896),67111=>array(-97.936927,37.614563),67112=>array(-98.419349,37.467197),67114=>array(-97.289251,38.07562),67117=>array(-97.346242,38.074214),67118=>array(-97.854212,37.481665),67119=>array(-97.195177,37.238853),67120=>array(-97.373531,37.469282),67122=>array(-96.428116,37.619001),67123=>array(-96.996749,37.948534),67124=>array(-98.773642,37.634439),67127=>array(-99.487114,37.16482),67131=>array(-96.955448,37.42697),67132=>array(-96.584695,37.850881),67133=>array(-97.107428,37.569962),67134=>array(-98.675037,37.490343),67135=>array(-97.460022,37.917958),67137=>array(-96.221972,37.633843),67138=>array(-98.415842,37.276388),67140=>array(-97.356496,37.079302),67142=>array(-98.11362,37.452585),67143=>array(-98.963403,37.341823),67144=>array(-97.003301,37.81917),67146=>array(-97.104645,37.384484),67147=>array(-97.312763,37.860576),67149=>array(-97.629512,37.540156),67150=>array(-98.222462,37.007406),67151=>array(-97.257065,38.142146),67152=>array(-97.413396,37.260289),67154=>array(-97.125224,37.978385),67155=>array(-99.137561,37.274948),67156=>array(-96.961559,37.255658),67159=>array(-98.309908,37.42627),67202=>array(-97.33492,37.686984),67203=>array(-97.365701,37.700763),67204=>array(-97.360492,37.767146),67205=>array(-97.423461,37.749473),67206=>array(-97.225463,37.704071),67207=>array(-97.227205,37.665576),67208=>array(-97.279266,37.703847),67209=>array(-97.428543,37.651239),67210=>array(-97.246498,37.63026),67211=>array(-97.317453,37.66688),67212=>array(-97.438899,37.702404),67213=>array(-97.364194,37.667476),67214=>array(-97.31775,37.707178),67215=>array(-97.420717,37.61556),67216=>array(-97.312708,37.611061),67217=>array(-97.362465,37.618074),67218=>array(-97.280418,37.668511),67219=>array(-97.318704,37.771477),67220=>array(-97.278361,37.751156),67223=>array(-97.495544,37.742432),67226=>array(-97.213035,37.773213),67227=>array(-97.499679,37.628186),67228=>array(-97.169689,37.769004),67230=>array(-97.171336,37.687431),67232=>array(-97.170212,37.636292),67235=>array(-97.500046,37.688993),67260=>array(-97.293576,37.719376),67301=>array(-95.756081,37.20823),67330=>array(-95.309148,37.158055),67332=>array(-95.236567,37.043368),67333=>array(-95.882452,37.045391),67334=>array(-96.177144,37.023897),67335=>array(-95.527461,37.275391),67336=>array(-95.064296,37.095595),67337=>array(-95.598198,37.053665),67340=>array(-95.713117,37.059602),67341=>array(-95.428356,37.34437),67342=>array(-95.357301,37.059534),67344=>array(-95.953857,37.287471),67345=>array(-96.199264,37.37762),67346=>array(-96.43469,37.324395),67347=>array(-95.951539,37.154406),67349=>array(-96.297916,37.494403),67351=>array(-95.568937,37.143556),67352=>array(-96.022826,37.407194),67353=>array(-96.317193,37.308381),67354=>array(-95.409185,37.20944),67355=>array(-96.010838,37.046836),67356=>array(-95.145772,37.176257),67357=>array(-95.261617,37.345929),67360=>array(-96.106561,37.038024),67361=>array(-96.217607,37.137644),67363=>array(-95.723052,37.339471),67364=>array(-95.810429,37.060387),67401=>array(-97.654491,38.831846),67410=>array(-97.21909,38.956476),67416=>array(-97.58212,38.673059),67417=>array(-97.545188,39.444585),67418=>array(-98.046452,39.174886),67420=>array(-98.085468,39.400935),67422=>array(-97.585249,39.021084),67423=>array(-97.975323,38.95123),67425=>array(-97.919607,38.785097),67427=>array(-98.399346,38.498461),67428=>array(-97.417862,38.369631),67430=>array(-98.424914,39.531091),67431=>array(-97.012425,38.951046),67432=>array(-97.193388,39.329343),67436=>array(-97.73581,39.269705),67437=>array(-98.555646,39.515079),67438=>array(-97.283406,38.495918),67439=>array(-98.220447,38.749782),67441=>array(-97.105222,38.880034),67442=>array(-97.772084,38.6559),67443=>array(-97.525768,38.380616),67444=>array(-98.136257,38.544862),67445=>array(-97.824145,39.371393),67446=>array(-98.305489,39.473766),67447=>array(-96.972954,39.485459),67448=>array(-97.412961,38.649547),67449=>array(-96.893941,38.676644),67450=>array(-98.451374,38.615016),67451=>array(-97.12158,38.703171),67452=>array(-98.371607,39.240071),67454=>array(-98.112105,38.69884),67455=>array(-98.165407,39.020478),67456=>array(-97.675387,38.600676),67457=>array(-97.992841,38.393628),67458=>array(-97.304396,39.170754),67459=>array(-98.340484,38.600789),67460=>array(-97.699453,38.382552),67464=>array(-97.897144,38.559244),67466=>array(-97.472357,39.327815),67467=>array(-97.69582,39.142355),67468=>array(-97.257263,39.459493),67470=>array(-97.507598,38.922632),67473=>array(-98.740576,39.378744),67474=>array(-98.71694,39.576622),67475=>array(-97.054948,38.590043),67478=>array(-97.938827,39.386063),67480=>array(-97.402962,38.965482),67481=>array(-98.380935,39.01275),67482=>array(-97.259713,39.026891),67483=>array(-97.203516,38.556735),67484=>array(-97.8453,38.993508),67485=>array(-98.50191,39.283399),67487=>array(-97.071219,39.179061),67490=>array(-98.439661,38.788536),67491=>array(-97.902441,38.387496),67492=>array(-96.962784,38.809283),67501=>array(-97.926452,37.977493),67502=>array(-97.929949,38.126736),67505=>array(-97.9458,38.031355),67510=>array(-98.206324,38.006359),67511=>array(-99.047255,38.432498),67512=>array(-98.335159,38.224569),67513=>array(-99.538302,38.445112),67514=>array(-98.202381,37.861953),67515=>array(-100.068657,38.624639),67516=>array(-99.68682,38.385737),67518=>array(-100.167102,38.41459),67519=>array(-99.091082,37.930345),67520=>array(-99.187712,38.589677),67521=>array(-99.712902,38.628167),67522=>array(-97.747612,38.122196),67523=>array(-99.544182,38.199262),67524=>array(-98.378618,38.369422),67525=>array(-98.563033,38.572533),67526=>array(-98.544743,38.332756),67529=>array(-99.254382,38.076234),67530=>array(-98.794484,38.352059),67543=>array(-97.799264,37.87804),67544=>array(-98.759205,38.586791),67545=>array(-98.610758,38.165916),67546=>array(-97.818712,38.236266),67547=>array(-99.455866,37.930565),67548=>array(-99.344998,38.589785),67550=>array(-99.12459,38.185383),67552=>array(-99.22843,37.866129),67553=>array(-99.308357,38.669467),67554=>array(-98.195208,38.372211),67556=>array(-99.523571,38.616492),67557=>array(-98.958462,37.934601),67559=>array(-99.454502,38.385868),67560=>array(-99.939209,38.399335),67561=>array(-98.096853,38.109017),67563=>array(-99.556354,37.844005),67564=>array(-98.930946,38.531104),67565=>array(-99.044062,38.600591),67566=>array(-98.097399,37.933172),67567=>array(-98.979093,38.272185),67568=>array(-98.316595,38.006314),67570=>array(-97.964176,37.787407),67572=>array(-99.907938,38.689492),67573=>array(-98.423563,38.264697),67574=>array(-99.384908,38.225884),67575=>array(-99.257638,38.41194),67576=>array(-98.795217,38.035977),67578=>array(-98.574156,37.991416),67579=>array(-98.235601,38.188579),67581=>array(-98.408746,37.977536),67583=>array(-98.475,37.799431),67584=>array(-100.163316,38.682589),67601=>array(-99.349544,38.876881),67621=>array(-99.132679,39.821165),67622=>array(-99.735065,39.895868),67623=>array(-98.954264,39.444471),67625=>array(-99.685595,39.389004),67626=>array(-98.716958,38.881563),67628=>array(-99.001622,39.627384),67629=>array(-100.199353,39.699951),67631=>array(-100.081392,39.009136),67632=>array(-99.580695,39.343605),67634=>array(-98.608832,38.819004),67635=>array(-100.433582,39.590217),67637=>array(-99.60533,38.938377),67638=>array(-98.854602,39.614201),67639=>array(-99.308434,39.636857),67640=>array(-99.049114,38.914134),67642=>array(-99.844495,39.359078),67643=>array(-100.304033,39.677205),67644=>array(-99.157743,39.643724),67645=>array(-99.873738,39.590207),67646=>array(-99.577449,39.638451),67647=>array(-99.544883,39.934554),67648=>array(-98.580363,39.087252),67649=>array(-98.679981,39.126972),67650=>array(-100.102673,39.37267),67651=>array(-99.052635,39.212864),67653=>array(-100.208054,39.9067),67654=>array(-99.949132,39.823962),67656=>array(-99.750361,38.989343),67657=>array(-99.616784,39.202293),67658=>array(-98.947717,39.103062),67659=>array(-100.005362,39.322801),67660=>array(-99.156555,38.718247),67661=>array(-99.318975,39.820881),67663=>array(-99.354247,39.212793),67664=>array(-99.583409,39.818227),67665=>array(-98.88253,38.849085),67667=>array(-99.332501,38.71313),67669=>array(-99.34415,39.458229),67671=>array(-99.134667,38.84716),67672=>array(-99.912006,39.008413),67673=>array(-98.818662,39.152204),67674=>array(-99.068721,38.863858),67675=>array(-99.090258,39.446185),67701=>array(-101.061478,39.395154),67730=>array(-101.111247,39.808975),67731=>array(-101.537324,39.765919),67732=>array(-101.343783,39.42472),67733=>array(-101.512704,39.319367),67734=>array(-100.895989,39.523518),67735=>array(-101.753217,39.344787),67736=>array(-100.479471,38.851088),67737=>array(-100.478093,39.129483),67738=>array(-100.63941,38.982284),67739=>array(-100.812798,39.878434),67740=>array(-100.368493,39.374969),67741=>array(-101.994659,39.402735),67743=>array(-101.247184,39.372796),67744=>array(-100.939843,39.84399),67745=>array(-101.345391,39.807589),67747=>array(-101.065079,39.04201),67748=>array(-100.85985,39.039785),67749=>array(-100.562519,39.834858),67751=>array(-100.345765,39.12565),67752=>array(-100.251374,38.994968),67753=>array(-100.747899,39.432606),67756=>array(-101.836735,39.797204),67757=>array(-100.617249,39.552908),67758=>array(-101.764693,38.856062),67761=>array(-101.531917,38.969188),67762=>array(-101.975293,38.905865),67764=>array(-101.209985,38.926382),67801=>array(-100.057186,37.723603),67831=>array(-99.79598,37.185621),67834=>array(-99.633312,37.519051),67835=>array(-100.325941,37.966772),67836=>array(-102.008235,38.020556),67837=>array(-100.675137,37.554824),67838=>array(-101.12774,38.084106),67839=>array(-100.441624,38.470501),67840=>array(-100.043728,37.057346),67841=>array(-100.2425,37.634648),67842=>array(-99.769712,37.561138),67843=>array(-99.936956,37.730266),67844=>array(-100.194588,37.38586),67846=>array(-100.768068,38.034156),67849=>array(-99.708571,38.151242),67850=>array(-100.614162,38.586731),67851=>array(-101.021258,38.068425),67853=>array(-100.528171,37.885578),67854=>array(-100.017067,38.104952),67855=>array(-101.685232,37.551783),67857=>array(-101.555227,37.980694),67859=>array(-100.770115,37.235172),67860=>array(-101.307036,38.008385),67861=>array(-101.382987,38.470438),67862=>array(-101.948962,37.552511),67863=>array(-101.216506,38.573114),67864=>array(-100.31727,37.176517),67865=>array(-99.96837,37.435511),67867=>array(-100.463734,37.570246),67868=>array(-100.708784,37.821113),67869=>array(-100.566487,37.236184),67870=>array(-101.003499,37.522178),67871=>array(-100.888344,38.511485),67876=>array(-99.743464,37.862844),67877=>array(-100.843926,37.554925),67878=>array(-101.828261,38.028056),67879=>array(-101.805984,38.480408),67880=>array(-101.313039,37.583432),67882=>array(-99.879885,37.804181),67901=>array(-100.913292,37.097799),67950=>array(-101.867879,37.046857),67951=>array(-101.349103,37.160599),67952=>array(-101.149465,37.292954),67953=>array(-101.890965,37.250679),67954=>array(-101.641311,37.20887),68001=>array(-96.960029,41.331136),68002=>array(-96.337716,41.499022),68003=>array(-96.382497,41.081263),68004=>array(-96.623048,42.009736),68005=>array(-95.892969,41.142686),68007=>array(-96.190097,41.367445),68008=>array(-96.162811,41.546712),68010=>array(-96.132638,41.255102),68014=>array(-96.961996,41.282025),68015=>array(-96.643418,41.38558),68016=>array(-96.105394,41.041448),68017=>array(-96.657761,41.053678),68018=>array(-96.615195,41.302097),68019=>array(-96.375352,41.781019),68020=>array(-96.264175,41.971179),68022=>array(-96.246536,41.278064),68023=>array(-96.016389,41.447225),68025=>array(-96.48788,41.437235),68028=>array(-96.258314,41.105185),68029=>array(-96.273537,41.657003),68030=>array(-96.455432,42.322905),68031=>array(-96.525171,41.640586),68033=>array(-96.511022,41.124967),68034=>array(-96.225269,41.459558),68036=>array(-96.952344,41.387378),68037=>array(-96.130047,40.983506),68038=>array(-96.452756,41.947113),68039=>array(-96.345452,42.116251),68040=>array(-96.734999,41.283485),68041=>array(-96.493389,41.241423),68042=>array(-96.437726,41.098862),68044=>array(-96.442191,41.551677),68045=>array(-96.492473,41.825554),68046=>array(-96.052767,41.12182),68047=>array(-96.733089,42.111188),68048=>array(-95.942013,40.98408),68050=>array(-96.842321,41.300053),68055=>array(-96.47219,42.054161),68057=>array(-96.723527,41.66187),68058=>array(-96.244785,41.005824),68059=>array(-96.158755,41.06445),68061=>array(-96.20783,41.793192),68062=>array(-96.67751,42.198845),68063=>array(-96.497082,41.73532),68064=>array(-96.357708,41.355752),68065=>array(-96.839466,41.068901),68066=>array(-96.627933,41.186819),68067=>array(-96.482508,42.160437),68068=>array(-96.208503,41.397892),68069=>array(-96.315939,41.241065),68070=>array(-96.800948,41.196681),68071=>array(-96.471415,42.236097),68072=>array(-96.504788,41.609181),68073=>array(-96.415363,41.256126),68102=>array(-95.933854,41.262129),68104=>array(-96.002289,41.295431),68105=>array(-95.96366,41.240737),68106=>array(-96.002274,41.238785),68107=>array(-95.953445,41.208271),68108=>array(-95.930102,41.237553),68110=>array(-95.892521,41.302503),68111=>array(-95.964916,41.295458),68112=>array(-95.959052,41.374859),68113=>array(-95.906496,41.117846),68114=>array(-96.050513,41.263205),68116=>array(-96.167128,41.298964),68117=>array(-96.000564,41.20713),68118=>array(-96.179006,41.263857),68122=>array(-96.049201,41.372501),68123=>array(-95.943504,41.101821),68124=>array(-96.051334,41.235473),68127=>array(-96.04976,41.20561),68128=>array(-96.065315,41.182074),68130=>array(-96.195354,41.235704),68131=>array(-95.96448,41.264566),68132=>array(-96.001137,41.262331),68133=>array(-95.995482,41.112563),68134=>array(-96.048846,41.301477),68135=>array(-96.193646,41.207379),68136=>array(-96.186946,41.168702),68137=>array(-96.118601,41.205825),68138=>array(-96.127966,41.155995),68142=>array(-96.10708,41.371146),68144=>array(-96.11845,41.234983),68147=>array(-95.959746,41.173061),68152=>array(-95.999998,41.368529),68154=>array(-96.114445,41.265139),68157=>array(-95.993951,41.178455),68164=>array(-96.106748,41.296881),68178=>array(-95.947658,41.265696),68301=>array(-96.53246,40.458675),68303=>array(-97.428607,40.268358),68304=>array(-96.397869,40.878837),68305=>array(-95.864617,40.368597),68307=>array(-96.131003,40.788873),68309=>array(-96.567159,40.055767),68310=>array(-96.74949,40.249821),68313=>array(-97.271315,40.783683),68314=>array(-97.035931,41.011259),68315=>array(-97.544115,40.252618),68316=>array(-97.6264,41.024569),68317=>array(-96.507292,40.671741),68318=>array(-96.637561,40.150996),68319=>array(-97.75971,40.937755),68320=>array(-95.939002,40.487145),68321=>array(-95.68827,40.389213),68322=>array(-97.549592,40.342479),68323=>array(-96.382238,40.14265),68324=>array(-96.292163,40.560049),68325=>array(-97.753101,40.024095),68326=>array(-97.684246,40.283408),68327=>array(-97.624004,40.024106),68328=>array(-96.835829,40.485026),68329=>array(-96.169239,40.497921),68331=>array(-96.714782,40.472865),68332=>array(-96.400251,40.315108),68333=>array(-96.949812,40.622183),68335=>array(-97.804048,40.274892),68336=>array(-96.690917,40.965855),68337=>array(-95.831894,40.098408),68338=>array(-97.264952,40.31391),68339=>array(-96.870103,40.732053),68340=>array(-97.755279,40.125343),68341=>array(-96.920261,40.381113),68342=>array(-96.946317,40.097171),68343=>array(-97.132103,40.618234),68344=>array(-96.399847,40.566742),68345=>array(-96.024862,40.040583),68346=>array(-96.025186,40.657703),68347=>array(-96.425835,40.804571),68348=>array(-96.132908,40.310315),68349=>array(-96.296896,40.83163),68350=>array(-97.069689,40.041679),68351=>array(-97.434635,40.661361),68352=>array(-97.229238,40.142403),68354=>array(-97.577161,40.638978),68355=>array(-95.567883,40.109001),68357=>array(-96.547756,40.312925),68358=>array(-96.608292,40.531423),68359=>array(-97.284829,40.631292),68360=>array(-96.956412,40.950556),68361=>array(-97.598807,40.512146),68362=>array(-97.441445,40.15225),68364=>array(-97.218787,40.832667),68365=>array(-97.718432,40.604554),68366=>array(-96.434942,40.974112),68367=>array(-97.39684,41.039521),68368=>array(-96.822721,40.557745),68370=>array(-97.547632,40.139642),68371=>array(-97.79014,40.771376),68372=>array(-96.60548,40.608346),68375=>array(-97.456145,40.033188),68376=>array(-95.945332,40.174357),68377=>array(-97.0191,40.213937),68378=>array(-96.018413,40.385989),68379=>array(-95.867366,40.519885),68380=>array(-96.384102,40.243149),68381=>array(-96.480625,40.076649),68382=>array(-96.02406,40.597299),68401=>array(-97.59113,40.7386),68402=>array(-96.857212,40.907803),68403=>array(-96.168023,40.920637),68404=>array(-96.752842,40.613627),68405=>array(-97.073498,40.76205),68406=>array(-97.385641,40.500089),68407=>array(-96.266964,40.9167),68409=>array(-95.95418,40.907713),68410=>array(-95.883057,40.634941),68413=>array(-96.012639,40.838846),68414=>array(-95.665835,40.308102),68415=>array(-96.821216,40.069634),68416=>array(-97.459542,40.4103),68417=>array(-96.094147,40.733168),68418=>array(-96.403382,40.687767),68419=>array(-96.511171,40.599806),68420=>array(-96.209452,40.09297),68421=>array(-95.743549,40.493981),68422=>array(-96.694709,40.388735),68423=>array(-96.95745,40.807477),68424=>array(-97.016261,40.299195),68428=>array(-96.793115,40.964424),68430=>array(-96.663354,40.668621),68431=>array(-95.438183,40.067562),68433=>array(-95.738532,40.053339),68434=>array(-97.116949,40.909586),68436=>array(-97.738261,40.43026),68437=>array(-95.64395,40.226069),68438=>array(-96.744615,40.626605),68439=>array(-97.205463,40.995896),68440=>array(-97.001788,40.060556),68441=>array(-96.240128,40.222441),68442=>array(-95.773233,40.238673),68443=>array(-96.350076,40.447459),68444=>array(-97.57708,40.411381),68445=>array(-97.079163,40.389231),68446=>array(-96.175404,40.653402),68447=>array(-96.072644,40.208885),68448=>array(-96.024165,40.557858),68450=>array(-96.229749,40.363539),68452=>array(-97.852288,40.394441),68453=>array(-97.325813,40.412994),68454=>array(-96.288481,40.691824),68455=>array(-95.897286,40.820047),68456=>array(-97.320861,40.909053),68457=>array(-95.699364,40.153193),68458=>array(-96.509005,40.227499),68460=>array(-97.43514,40.890741),68461=>array(-96.511432,40.762334),68462=>array(-96.519659,40.952129),68463=>array(-96.129031,40.875803),68464=>array(-97.206836,40.428738),68465=>array(-97.022227,40.486338),68466=>array(-96.642831,40.066854),68467=>array(-97.595637,40.866364),68502=>array(-96.698002,40.78581),68503=>array(-96.67404,40.824554),68504=>array(-96.660184,40.854478),68505=>array(-96.619262,40.824839),68506=>array(-96.632223,40.783655),68507=>array(-96.614848,40.858885),68508=>array(-96.703937,40.818272),68510=>array(-96.635703,40.806237),68512=>array(-96.707513,40.738801),68514=>array(-96.653112,40.921979),68516=>array(-96.64279,40.735276),68517=>array(-96.61502,40.936247),68520=>array(-96.552282,40.799995),68521=>array(-96.705455,40.868266),68522=>array(-96.762488,40.790111),68523=>array(-96.758183,40.735633),68524=>array(-96.787442,40.907023),68526=>array(-96.582101,40.729968),68527=>array(-96.524224,40.847113),68528=>array(-96.830216,40.820839),68531=>array(-96.723224,40.901432),68532=>array(-96.842655,40.792052),68601=>array(-97.398273,41.4545),68620=>array(-98.074478,41.7452),68621=>array(-96.639488,41.492162),68622=>array(-98.625436,41.94897),68623=>array(-98.151971,41.441473),68624=>array(-97.229358,41.345613),68626=>array(-96.992008,41.169497),68627=>array(-98.174381,41.55901),68628=>array(-97.836915,41.22762),68629=>array(-97.132617,41.719653),68631=>array(-97.34463,41.692093),68632=>array(-97.131198,41.246154),68633=>array(-96.896404,41.706202),68634=>array(-97.493069,41.389898),68635=>array(-97.015909,41.083416),68636=>array(-98.152606,42.009224),68637=>array(-98.721803,41.881019),68638=>array(-97.992939,41.375492),68640=>array(-97.785881,41.460369),68641=>array(-97.015265,41.73567),68642=>array(-97.513932,41.689215),68643=>array(-97.263334,41.705976),68644=>array(-97.670015,41.704257),68647=>array(-97.62834,41.518774),68648=>array(-96.800326,41.400719),68649=>array(-96.785365,41.505048),68651=>array(-97.570129,41.228224),68652=>array(-98.044181,41.861404),68653=>array(-97.485954,41.558235),68654=>array(-97.779132,41.067027),68655=>array(-98.242514,41.655561),68658=>array(-97.291232,41.197668),68659=>array(-96.935406,41.545943),68660=>array(-97.869571,41.572817),68661=>array(-97.088623,41.492505),68662=>array(-97.417564,41.210704),68663=>array(-97.685134,41.319184),68664=>array(-96.786542,41.704011),68665=>array(-98.392246,41.769883),68666=>array(-97.611211,41.110595),68667=>array(-97.304753,41.109766),68669=>array(-97.236898,41.079231),68701=>array(-97.442988,42.019977),68710=>array(-96.859268,42.441865),68711=>array(-99.040962,42.198074),68713=>array(-98.959566,42.54015),68714=>array(-99.495233,42.431105),68715=>array(-97.609897,41.963891),68716=>array(-96.822632,41.926838),68717=>array(-97.222971,42.38787),68718=>array(-97.692958,42.668353),68719=>array(-98.560153,42.954456),68720=>array(-98.01466,42.344997),68722=>array(-98.869016,42.929935),68723=>array(-97.20824,42.282752),68724=>array(-97.894007,42.638007),68725=>array(-98.777902,42.197414),68726=>array(-98.21011,42.184661),68727=>array(-97.202478,42.515296),68728=>array(-96.94712,42.375131),68729=>array(-97.905075,42.471872),68730=>array(-97.534632,42.767263),68731=>array(-96.472928,42.404578),68732=>array(-96.978733,42.493826),68733=>array(-96.72518,42.285116),68734=>array(-98.803963,42.458508),68735=>array(-98.466036,42.13952),68736=>array(-97.367806,42.735371),68739=>array(-97.269952,42.625997),68740=>array(-97.29617,42.152347),68741=>array(-96.594478,42.343022),68742=>array(-98.529412,42.352415),68743=>array(-96.630154,42.458331),68745=>array(-97.083883,42.456197),68746=>array(-98.437442,42.809636),68747=>array(-97.496125,42.391145),68748=>array(-97.473669,41.842603),68749=>array(-97.475351,42.453088),68751=>array(-96.980916,42.690454),68752=>array(-97.723726,42.028776),68753=>array(-99.427656,42.889507),68755=>array(-99.130016,42.926512),68756=>array(-97.98185,42.18246),68757=>array(-96.929689,42.652949),68758=>array(-97.785946,41.792434),68759=>array(-99.31054,42.70414),68760=>array(-97.874979,42.708842),68761=>array(-97.96205,42.049904),68763=>array(-98.608208,42.501043),68764=>array(-98.23167,42.404882),68765=>array(-97.613711,42.3423),68766=>array(-98.403063,42.433234),68767=>array(-97.552777,42.199402),68768=>array(-97.066425,41.995221),68769=>array(-97.811327,42.325158),68770=>array(-96.764827,42.561623),68771=>array(-97.359991,42.395624),68773=>array(-98.118578,42.359065),68774=>array(-97.274313,42.81287),68776=>array(-96.44705,42.467422),68777=>array(-98.688029,42.860843),68778=>array(-99.798484,42.853013),68779=>array(-97.19901,41.957174),68780=>array(-99.12819,42.632961),68781=>array(-97.863783,42.025745),68783=>array(-98.159234,42.618474),68784=>array(-96.891367,42.257167),68785=>array(-96.724096,42.426528),68786=>array(-97.557442,42.50156),68787=>array(-97.03097,42.213113),68788=>array(-96.721283,41.839631),68789=>array(-97.97032,42.543523),68790=>array(-97.181822,42.156671),68791=>array(-96.984375,41.988425),68792=>array(-97.108243,42.742919),68801=>array(-98.290699,40.94804),68803=>array(-98.414575,40.956077),68810=>array(-98.463677,40.855284),68812=>array(-99.283842,40.887782),68813=>array(-99.856377,41.699128),68814=>array(-99.412938,41.316486),68815=>array(-99.14399,41.418284),68816=>array(-98.132949,41.177383),68817=>array(-98.793822,41.26748),68818=>array(-98.005876,40.817854),68820=>array(-98.701416,41.112899),68821=>array(-99.767592,42.010446),68822=>array(-99.631719,41.380918),68823=>array(-99.111788,41.924397),68824=>array(-98.597716,40.994135),68825=>array(-99.968062,41.264062),68826=>array(-98.016399,41.163588),68827=>array(-98.181454,41.042659),68828=>array(-99.237374,41.54954),68831=>array(-98.554699,41.108676),68832=>array(-98.369182,40.7633),68833=>array(-100.205383,41.825835),68834=>array(-99.658913,41.031607),68835=>array(-98.61724,41.331899),68836=>array(-99.373986,40.709811),68837=>array(-99.076621,41.659793),68838=>array(-98.670906,41.217662),68840=>array(-98.877542,40.759666),68841=>array(-98.171175,40.758828),68842=>array(-98.500538,41.567553),68843=>array(-97.890768,40.905251),68844=>array(-99.05941,41.054098),68845=>array(-99.164684,40.721039),68846=>array(-97.895188,41.068251),68847=>array(-99.017084,40.76003),68849=>array(-99.109416,40.700703),68850=>array(-99.739779,40.826405),68852=>array(-99.124626,41.161301),68853=>array(-98.99183,41.294283),68854=>array(-98.002428,41.009922),68855=>array(-99.325507,41.169365),68856=>array(-99.758395,41.541733),68858=>array(-99.37631,40.965652),68859=>array(-98.825464,41.474517),68860=>array(-99.795328,41.13393),68861=>array(-99.258817,40.702356),68862=>array(-98.936456,41.599956),68863=>array(-99.532137,40.766301),68864=>array(-98.235239,41.26363),68865=>array(-98.178659,40.896549),68866=>array(-99.124408,40.976946),68869=>array(-98.884197,40.996135),68870=>array(-99.167086,40.853989),68871=>array(-98.852753,41.140917),68872=>array(-98.334,41.094857),68873=>array(-98.453771,41.240105),68874=>array(-99.418929,41.644123),68875=>array(-98.670522,41.563132),68876=>array(-98.755243,40.818433),68878=>array(-99.517885,40.982333),68879=>array(-99.509764,41.897714),68881=>array(-99.351889,41.438428),68882=>array(-98.389411,41.439999),68883=>array(-98.597294,40.808239),68901=>array(-98.372329,40.592593),68920=>array(-99.339914,40.154543),68922=>array(-99.896424,40.335199),68923=>array(-99.468322,40.359107),68924=>array(-99.118997,40.495556),68925=>array(-98.43011,40.428762),68926=>array(-99.839105,40.105271),68927=>array(-99.633924,40.499975),68928=>array(-98.60684,40.284345),68929=>array(-99.04998,40.15088),68930=>array(-98.415566,40.284768),68932=>array(-98.722738,40.315286),68933=>array(-98.022998,40.517843),68934=>array(-98.138986,40.338815),68935=>array(-97.962002,40.378358),68936=>array(-99.771423,40.328446),68937=>array(-99.88188,40.59096),68938=>array(-98.117141,40.415596),68939=>array(-98.968918,40.101287),68940=>array(-99.246818,40.547151),68941=>array(-98.278089,40.45721),68942=>array(-98.300584,40.096601),68943=>array(-97.90725,40.05737),68944=>array(-98.094793,40.643601),68945=>array(-98.777823,40.568226),68946=>array(-99.985789,40.111639),68947=>array(-99.047663,40.280096),68948=>array(-100.021482,40.318263),68949=>array(-99.389597,40.427217),68950=>array(-98.669439,40.461783),68952=>array(-98.662556,40.07628),68954=>array(-98.234368,40.622945),68955=>array(-98.539686,40.595497),68956=>array(-98.691023,40.636323),68957=>array(-98.246364,40.273952),68958=>array(-99.497357,40.51881),68959=>array(-98.91601,40.484),68960=>array(-99.136253,40.096651),68961=>array(-98.043802,40.208997),68964=>array(-97.911878,40.238096),68966=>array(-99.467272,40.159905),68967=>array(-99.624404,40.254035),68969=>array(-99.283398,40.303874),68970=>array(-98.509567,40.110321),68971=>array(-99.247931,40.110633),68972=>array(-98.810982,40.118855),68973=>array(-98.56483,40.454782),68974=>array(-97.867653,40.125862),68975=>array(-97.948619,40.61881),68976=>array(-99.727626,40.590459),68977=>array(-99.630867,40.069843),68978=>array(-98.0975,40.06666),68979=>array(-97.851484,40.589677),68980=>array(-98.250701,40.676614),68981=>array(-98.896151,40.278734),68982=>array(-99.180146,40.332296),69001=>array(-100.643942,40.246709),69020=>array(-100.300903,40.197245),69021=>array(-101.540343,40.14161),69022=>array(-100.189357,40.360199),69023=>array(-101.90732,40.482983),69024=>array(-100.847051,40.232726),69025=>array(-100.50948,40.620868),69026=>array(-100.429674,40.046771),69027=>array(-101.544243,40.42728),69028=>array(-100.057395,40.639148),69029=>array(-100.252969,40.708969),69030=>array(-101.919863,40.211719),69032=>array(-101.014404,40.570659),69033=>array(-101.67601,40.559381),69034=>array(-100.433897,40.250914),69036=>array(-100.27435,40.048682),69037=>array(-101.405741,40.184984),69038=>array(-100.748476,40.589874),69039=>array(-100.391408,40.692107),69040=>array(-101.125171,40.350306),69041=>array(-101.743643,40.171238),69042=>array(-100.405251,40.476668),69043=>array(-101.255201,40.128711),69044=>array(-101.016489,40.130145),69045=>array(-101.369178,40.465392),69046=>array(-100.086526,40.076407),69101=>array(-100.800597,41.141895),69120=>array(-100.218112,41.397011),69121=>array(-101.696401,41.55743),69122=>array(-102.102414,41.131252),69123=>array(-100.371817,41.011466),69125=>array(-102.824548,41.62649),69127=>array(-101.929094,41.141045),69128=>array(-103.928819,41.22667),69129=>array(-102.409026,41.113295),69130=>array(-99.952965,40.894116),69131=>array(-102.973516,41.407395),69132=>array(-100.957871,40.793401),69133=>array(-103.460347,41.188423),69134=>array(-101.376254,40.835298),69135=>array(-100.206025,42.22783),69138=>array(-100.176551,40.995816),69140=>array(-101.773477,40.850303),69141=>array(-102.955003,41.306523),69142=>array(-100.320427,41.91818),69143=>array(-101.042025,41.211518),69144=>array(-101.537461,41.272158),69145=>array(-103.667696,41.246022),69146=>array(-101.773429,41.312561),69147=>array(-102.086642,41.579126),69148=>array(-102.598259,41.590372),69149=>array(-102.677147,41.221745),69150=>array(-101.543056,40.8477),69151=>array(-100.495252,41.090203),69152=>array(-101.146814,42.124962),69153=>array(-101.675692,41.101361),69154=>array(-102.351775,41.430572),69155=>array(-101.396154,41.189373),69156=>array(-103.331902,41.310781),69157=>array(-100.144245,42.060157),69161=>array(-100.781305,42.156506),69162=>array(-103.020689,41.12886),69163=>array(-100.541642,41.569639),69165=>array(-101.209874,41.269716),69166=>array(-100.608556,42.028175),69167=>array(-101.006031,41.596232),69168=>array(-101.986523,40.798996),69169=>array(-101.160866,40.821942),69170=>array(-100.744306,40.796027),69171=>array(-100.070711,40.890044),69201=>array(-100.596392,42.723626),69210=>array(-99.923176,42.34939),69211=>array(-101.303366,42.832233),69212=>array(-100.801436,42.93293),69214=>array(-100.099662,42.598549),69216=>array(-100.983593,42.97781),69217=>array(-99.666992,42.565207),69218=>array(-101.674835,42.789248),69219=>array(-101.192427,42.600609),69220=>array(-100.130357,42.865604),69221=>array(-100.300943,42.582492),69301=>array(-102.88128,42.122965),69331=>array(-102.982627,41.913434),69333=>array(-101.974382,42.056214),69334=>array(-103.29016,41.821808),69335=>array(-102.105309,42.073797),69336=>array(-103.167371,41.628527),69337=>array(-103.012899,42.827175),69339=>array(-103.413648,42.60693),69340=>array(-102.207861,42.21487),69341=>array(-103.633028,41.720755),69343=>array(-102.024422,42.705504),69345=>array(-103.744617,41.589582),69346=>array(-103.782541,42.671533),69347=>array(-102.684723,42.60682),69348=>array(-103.350427,42.275532),69350=>array(-101.763242,41.96242),69351=>array(-102.420461,42.038757),69352=>array(-103.973548,41.803986),69353=>array(-103.416509,41.747228),69354=>array(-103.603633,42.369194),69355=>array(-103.506205,41.783287),69356=>array(-103.45094,41.901589),69357=>array(-103.768458,42.110496),69358=>array(-103.968435,42.065333),69360=>array(-102.467141,42.696594),69361=>array(-103.622904,41.922838),69365=>array(-102.500583,42.984091),69366=>array(-101.54977,42.159428),69367=>array(-103.330405,42.811821),70001=>array(-90.167179,29.983724),70002=>array(-90.162523,30.012223),70003=>array(-90.209724,30.001164),70005=>array(-90.134065,29.999416),70006=>array(-90.191345,30.014032),70030=>array(-90.43316,29.819271),70031=>array(-90.298986,29.941918),70032=>array(-89.997477,29.958602),70036=>array(-90.121496,29.714032),70037=>array(-90.030559,29.818986),70038=>array(-89.43845,29.349224),70039=>array(-90.389186,29.886734),70040=>array(-89.938296,29.744682),70041=>array(-89.493269,29.341824),70043=>array(-89.962678,29.948414),70047=>array(-90.367309,29.968947),70049=>array(-90.570797,30.02809),70050=>array(-89.590148,29.37952),70051=>array(-90.647603,30.08615),70052=>array(-90.695015,30.055069),70053=>array(-90.053201,29.913421),70056=>array(-90.029014,29.888653),70057=>array(-90.467386,29.965327),70058=>array(-90.064875,29.868864),70062=>array(-90.258065,29.99171),70065=>array(-90.25345,30.027292),70067=>array(-90.096785,29.71088),70068=>array(-90.436745,30.156056),70070=>array(-90.310628,29.829844),70071=>array(-90.705712,30.051526),70072=>array(-90.112449,29.837276),70075=>array(-89.921256,29.933315),70076=>array(-90.64905,30.061579),70079=>array(-90.41021,30.003414),70080=>array(-90.433699,29.883998),70082=>array(-89.735531,29.55425),70083=>array(-89.894753,29.463084),70084=>array(-90.566652,30.075606),70085=>array(-89.737441,29.836707),70086=>array(-90.866682,30.036818),70087=>array(-90.315015,29.976027),70090=>array(-90.701136,29.969253),70091=>array(-89.271121,29.119054),70092=>array(-89.895262,29.89894),70094=>array(-90.207605,29.915778),70112=>array(-90.076936,29.957008),70113=>array(-90.083074,29.943022),70114=>array(-90.032322,29.937445),70115=>array(-90.101795,29.923968),70116=>array(-90.064783,29.96744),70117=>array(-90.029962,29.968157),70118=>array(-90.125661,29.944727),70119=>array(-90.086944,29.975137),70121=>array(-90.163314,29.959763),70122=>array(-90.062798,30.013437),70123=>array(-90.205801,29.949674),70124=>array(-90.103919,30.007379),70125=>array(-90.103313,29.952072),70126=>array(-90.020724,30.0182),70127=>array(-89.976804,30.023738),70128=>array(-89.956039,30.050846),70129=>array(-89.813366,30.080851),70130=>array(-90.069648,29.937353),70131=>array(-89.958343,29.906312),70139=>array(-90.071002,29.950279),70163=>array(-90.075441,29.950058),70301=>array(-90.750267,29.808328),70339=>array(-91.182867,29.9095),70340=>array(-91.105354,29.669779),70341=>array(-91.06746,30.03252),70342=>array(-91.23834,29.693147),70343=>array(-90.557051,29.548266),70344=>array(-90.515055,29.176879),70345=>array(-90.25902,29.548416),70346=>array(-91.0032,30.153716),70352=>array(-90.940158,29.684401),70353=>array(-90.700118,29.358143),70354=>array(-90.281745,29.436974),70355=>array(-90.46895,29.7172),70356=>array(-90.970879,29.631566),70357=>array(-90.219498,29.242273),70358=>array(-90.025543,29.216515),70359=>array(-90.776515,29.694018),70360=>array(-90.805402,29.578671),70363=>array(-90.704647,29.538288),70364=>array(-90.681803,29.62765),70372=>array(-90.988969,29.782968),70373=>array(-90.318653,29.597954),70374=>array(-90.501695,29.602497),70375=>array(-90.533421,29.691512),70377=>array(-90.502648,29.347284),70380=>array(-91.134095,29.731623),70390=>array(-91.031061,29.897281),70391=>array(-91.0608,29.990822),70392=>array(-91.318321,29.731242),70393=>array(-91.007272,29.991358),70394=>array(-90.616014,29.692722),70395=>array(-90.86173,29.697436),70397=>array(-90.792692,29.39385),70401=>array(-90.455381,30.533587),70402=>array(-90.470129,30.516161),70403=>array(-90.487941,30.485236),70420=>array(-89.953028,30.484687),70422=>array(-90.479388,30.734462),70426=>array(-89.860415,30.932581),70427=>array(-89.912079,30.744198),70431=>array(-89.967389,30.616728),70433=>array(-90.156595,30.45886),70435=>array(-90.103423,30.565961),70436=>array(-90.521701,30.793499),70437=>array(-90.209238,30.619596),70438=>array(-90.111321,30.846224),70441=>array(-90.749066,30.859967),70442=>array(-90.334028,30.69314),70443=>array(-90.534579,30.632673),70444=>array(-90.489367,30.89704),70445=>array(-89.91084,30.37464),70446=>array(-90.349707,30.630171),70447=>array(-90.198684,30.421875),70448=>array(-90.039451,30.36218),70449=>array(-90.670157,30.273972),70450=>array(-90.266152,30.929199),70451=>array(-90.480881,30.54842),70452=>array(-89.799212,30.420852),70453=>array(-90.764888,30.700689),70454=>array(-90.358594,30.362846),70455=>array(-90.323623,30.524975),70456=>array(-90.505923,30.791766),70458=>array(-89.792557,30.262109),70460=>array(-89.840688,30.297957),70461=>array(-89.716933,30.231078),70462=>array(-90.580763,30.376282),70463=>array(-89.903867,30.658239),70464=>array(-89.919008,30.551195),70465=>array(-90.52393,30.856259),70466=>array(-90.500761,30.568714),70471=>array(-90.061652,30.408722),70501=>array(-91.991044,30.24171),70503=>array(-92.055824,30.163949),70506=>array(-92.081292,30.195474),70507=>array(-92.027952,30.27826),70508=>array(-92.028225,30.155239),70510=>array(-92.193173,29.894612),70512=>array(-91.918607,30.416317),70513=>array(-91.903251,29.899969),70514=>array(-91.548808,29.846514),70515=>array(-92.577743,30.452467),70516=>array(-92.304219,30.364974),70517=>array(-91.83357,30.298246),70518=>array(-91.927448,30.134806),70519=>array(-91.897382,30.080175),70520=>array(-92.033704,30.330999),70523=>array(-91.470316,29.879201),70524=>array(-92.311285,30.556953),70525=>array(-92.218809,30.411533),70526=>array(-92.379963,30.210073),70528=>array(-91.984992,29.939505),70529=>array(-92.16158,30.202279),70531=>array(-92.517483,30.233947),70532=>array(-92.697025,30.452737),70533=>array(-92.046464,29.89014),70534=>array(-92.431559,30.22709),70535=>array(-92.420164,30.463256),70537=>array(-92.569402,30.250363),70538=>array(-91.498353,29.805551),70541=>array(-92.047499,30.426836),70542=>array(-92.584774,30.009678),70543=>array(-92.501138,30.335404),70544=>array(-91.662095,29.904121),70546=>array(-92.673552,30.266368),70548=>array(-92.405155,29.784928),70549=>array(-92.802184,30.069531),70550=>array(-92.187657,30.518594),70552=>array(-91.672717,30.067552),70554=>array(-92.484346,30.61818),70555=>array(-92.145854,30.0814),70556=>array(-92.555922,30.194416),70558=>array(-92.075759,30.100525),70559=>array(-92.502668,30.128785),70560=>array(-91.878669,29.921943),70563=>array(-91.710041,30.01663),70570=>array(-92.104961,30.533657),70575=>array(-92.158095,29.948922),70576=>array(-92.418254,30.780968),70577=>array(-91.934234,30.550352),70578=>array(-92.261529,30.22935),70580=>array(-92.428327,30.675238),70581=>array(-92.731431,30.250866),70582=>array(-91.783868,30.161555),70583=>array(-92.123965,30.261107),70584=>array(-92.09849,30.386694),70585=>array(-92.407676,30.878345),70586=>array(-92.328138,30.746507),70589=>array(-92.003197,30.680315),70591=>array(-92.832802,30.257744),70592=>array(-92.012358,30.080625),70601=>array(-93.215443,30.226792),70605=>array(-93.2747,30.128204),70607=>array(-93.190125,30.038425),70611=>array(-93.2036,30.348118),70615=>array(-93.126507,30.255414),70630=>array(-93.016943,30.025908),70631=>array(-93.568288,29.853375),70632=>array(-93.057765,29.836947),70633=>array(-93.39129,30.426005),70634=>array(-93.240067,30.793357),70637=>array(-92.963463,30.697645),70638=>array(-92.797138,30.849148),70639=>array(-93.491139,30.978267),70640=>array(-92.904722,30.371931),70643=>array(-92.811553,29.820556),70644=>array(-92.945596,30.792345),70645=>array(-93.473885,29.928002),70646=>array(-92.918574,30.088888),70647=>array(-93.023942,30.254625),70648=>array(-92.889361,30.505073),70650=>array(-92.923188,30.237437),70651=>array(-92.954149,30.567901),70652=>array(-93.266029,30.60854),70653=>array(-93.562092,30.667154),70654=>array(-92.875433,30.661452),70655=>array(-92.72321,30.664765),70656=>array(-92.968114,30.961373),70657=>array(-93.153008,30.503084),70658=>array(-93.043397,30.527772),70659=>array(-93.284285,30.921932),70660=>array(-93.444692,30.556098),70661=>array(-93.649655,30.354504),70662=>array(-92.993759,30.799561),70663=>array(-93.37169,30.290269),70665=>array(-93.447613,30.120167),70668=>array(-93.598313,30.187906),70669=>array(-93.272318,30.242348),70706=>array(-90.907376,30.607221),70710=>array(-91.26223,30.352897),70711=>array(-90.598868,30.530369),70712=>array(-91.596702,30.969575),70714=>array(-91.127633,30.587189),70715=>array(-91.690985,30.754248),70719=>array(-91.298207,30.37742),70721=>array(-91.084262,30.223688),70722=>array(-90.929032,30.857424),70723=>array(-90.839604,30.058907),70725=>array(-90.958896,30.128332),70726=>array(-90.88612,30.425575),70729=>array(-91.344857,30.587693),70730=>array(-91.102324,30.816514),70732=>array(-91.608398,30.61923),70733=>array(-90.812688,30.299662),70734=>array(-90.996981,30.206621),70736=>array(-91.338362,30.632183),70737=>array(-90.922197,30.22238),70739=>array(-90.965337,30.601066),70740=>array(-91.443419,30.3229),70743=>array(-90.779453,30.031281),70744=>array(-90.674224,30.553487),70747=>array(-91.676232,30.873669),70748=>array(-91.193986,30.817729),70749=>array(-91.394511,30.650223),70750=>array(-91.765791,30.501282),70752=>array(-91.406589,30.58668),70753=>array(-91.732185,30.942185),70754=>array(-90.746721,30.411567),70755=>array(-91.530033,30.593309),70756=>array(-91.614154,30.546816),70757=>array(-91.519489,30.489381),70759=>array(-91.579455,30.697384),70760=>array(-91.450744,30.706456),70761=>array(-91.031423,30.978671),70762=>array(-91.464653,30.57834),70763=>array(-90.741628,30.044055),70764=>array(-91.282778,30.216866),70767=>array(-91.330712,30.481128),70769=>array(-90.940643,30.30743),70770=>array(-90.996933,30.643797),70772=>array(-91.468653,30.436961),70773=>array(-91.36188,30.611166),70774=>array(-90.761905,30.214553),70775=>array(-91.368979,30.858188),70776=>array(-91.09536,30.264282),70777=>array(-91.078628,30.740249),70778=>array(-90.862655,30.157789),70780=>array(-91.185298,30.298733),70782=>array(-91.509241,30.955114),70783=>array(-91.403798,30.685464),70785=>array(-90.819236,30.557101),70787=>array(-91.44071,30.961632),70788=>array(-91.177771,30.13219),70789=>array(-91.082957,30.940581),70791=>array(-91.15444,30.651982),70801=>array(-91.185977,30.449656),70802=>array(-91.177389,30.444393),70803=>array(-91.177653,30.414307),70805=>array(-91.158289,30.488966),70806=>array(-91.124753,30.448759),70807=>array(-91.219682,30.543725),70808=>array(-91.139138,30.404141),70809=>array(-91.070972,30.394045),70810=>array(-91.091478,30.332364),70811=>array(-91.134691,30.537702),70812=>array(-91.110436,30.500728),70814=>array(-91.067984,30.485177),70815=>array(-91.066262,30.455462),70816=>array(-91.021967,30.431813),70817=>array(-90.98042,30.375106),70818=>array(-91.049894,30.542532),70819=>array(-91.009536,30.472459),70820=>array(-91.204051,30.365042),70836=>array(-91.090342,30.391248),71001=>array(-92.889253,32.591547),71003=>array(-93.030824,32.629546),71004=>array(-93.859811,32.748798),71006=>array(-93.630387,32.722679),71007=>array(-94.006751,32.362527),71008=>array(-92.96727,32.346501),71016=>array(-93.11627,32.224416),71018=>array(-93.426706,32.823719),71019=>array(-93.316966,32.048755),71021=>array(-93.446542,32.967708),71023=>array(-93.410302,32.476212),71024=>array(-93.201695,32.498109),71027=>array(-93.640018,32.253378),71028=>array(-93.075167,32.497702),71029=>array(-93.841034,32.8372),71030=>array(-93.784896,32.195972),71031=>array(-92.904241,32.002968),71032=>array(-93.795369,32.094865),71033=>array(-94.010585,32.412084),71034=>array(-93.311368,32.181488),71037=>array(-93.487497,32.474983),71038=>array(-93.06287,32.951539),71039=>array(-93.2897,32.430294),71040=>array(-93.02373,32.772862),71043=>array(-93.887836,32.886012),71044=>array(-93.882456,32.954178),71045=>array(-93.184616,32.331678),71046=>array(-93.948825,32.163058),71047=>array(-93.914938,32.289524),71048=>array(-92.845589,32.838519),71049=>array(-93.966552,32.009206),71051=>array(-93.477953,32.319454),71052=>array(-93.663325,32.003718),71055=>array(-93.293272,32.677002),71060=>array(-93.980594,32.65415),71061=>array(-93.955346,32.778379),71063=>array(-93.515127,31.911493),71064=>array(-93.679607,32.91318),71065=>array(-93.504181,31.80069),71067=>array(-93.503881,32.598629),71068=>array(-93.310394,32.278612),71069=>array(-93.987968,32.967888),71070=>array(-93.012875,32.101917),71071=>array(-93.456762,32.921887),71072=>array(-93.311269,32.937113),71073=>array(-93.311594,32.520966),71075=>array(-93.509177,32.994947),71078=>array(-93.781822,32.256499),71079=>array(-92.810705,32.933417),71082=>array(-93.964837,32.832885),71101=>array(-93.747221,32.506371),71103=>array(-93.772098,32.491936),71104=>array(-93.731646,32.483775),71105=>array(-93.70989,32.456691),71106=>array(-93.730665,32.378473),71107=>array(-93.859525,32.595618),71108=>array(-93.787826,32.443173),71109=>array(-93.813872,32.467911),71110=>array(-93.596138,32.504882),71111=>array(-93.699378,32.573112),71112=>array(-93.63312,32.444413),71115=>array(-93.579561,32.268803),71118=>array(-93.804064,32.393679),71119=>array(-93.92546,32.490693),71129=>array(-93.913016,32.386201),71201=>array(-92.105168,32.532695),71202=>array(-92.05655,32.399905),71203=>array(-92.01842,32.582214),71209=>array(-92.069586,32.528999),71219=>array(-91.69322,32.325706),71220=>array(-91.908541,32.864539),71222=>array(-92.657274,32.827193),71223=>array(-91.654814,32.888914),71225=>array(-92.338609,32.51227),71226=>array(-92.437982,32.250749),71227=>array(-92.478015,32.5365),71229=>array(-91.896748,32.631926),71232=>array(-91.466092,32.405303),71233=>array(-90.932097,32.325178),71234=>array(-92.330561,32.645272),71235=>array(-92.674464,32.69253),71237=>array(-91.494797,32.59716),71238=>array(-92.375771,32.363146),71241=>array(-92.353396,32.779113),71243=>array(-91.810966,31.95477),71245=>array(-92.725885,32.534093),71247=>array(-92.722117,32.27363),71250=>array(-91.583189,32.954994),71251=>array(-92.67689,32.220631),71253=>array(-91.30944,32.991202),71254=>array(-91.253379,32.796481),71256=>array(-92.721146,32.94964),71259=>array(-91.848307,32.271101),71260=>array(-92.234961,32.907919),71261=>array(-91.698336,32.772402),71263=>array(-91.425862,32.873248),71264=>array(-91.772528,32.601281),71266=>array(-91.504375,32.694663),71268=>array(-92.73702,32.346067),71269=>array(-91.793784,32.440635),71270=>array(-92.64212,32.494104),71272=>array(-92.649341,32.526867),71275=>array(-92.816833,32.511899),71276=>array(-91.147841,32.570222),71277=>array(-92.550972,32.943343),71279=>array(-91.857122,32.487355),71280=>array(-92.091646,32.723664),71282=>array(-91.181064,32.358981),71286=>array(-91.199855,32.661616),71291=>array(-92.172926,32.565664),71292=>array(-92.214764,32.396678),71295=>array(-91.707292,32.148625),71301=>array(-92.467107,31.274156),71302=>array(-92.37022,31.197018),71303=>array(-92.547344,31.281321),71316=>array(-91.741404,31.241848),71322=>array(-92.161866,30.858308),71323=>array(-92.211702,31.267741),71325=>array(-92.322145,30.999205),71326=>array(-91.603933,31.777078),71327=>array(-92.031295,30.982392),71328=>array(-92.175672,31.355107),71331=>array(-92.113148,31.257244),71333=>array(-92.07187,30.909986),71334=>array(-91.564781,31.659268),71336=>array(-91.598722,32.03475),71339=>array(-91.932294,31.013823),71340=>array(-91.80805,31.759812),71341=>array(-92.168056,31.06543),71342=>array(-92.143215,31.606608),71343=>array(-91.896812,31.523925),71345=>array(-91.975451,30.728356),71346=>array(-92.374928,31.118246),71350=>array(-92.074182,31.067691),71351=>array(-91.961712,31.183488),71353=>array(-91.789004,30.77293),71354=>array(-91.750055,31.404453),71355=>array(-91.843964,31.080929),71356=>array(-92.040935,30.815703),71357=>array(-91.29999,32.117473),71358=>array(-91.870105,30.69188),71360=>array(-92.350376,31.328109),71362=>array(-91.96106,30.899115),71366=>array(-91.337058,31.937216),71367=>array(-92.298045,30.881575),71368=>array(-91.680146,31.872681),71369=>array(-91.87706,30.930023),71371=>array(-92.255293,31.681682),71373=>array(-91.608958,31.311094),71375=>array(-91.487794,31.874207),71377=>array(-91.786272,31.610604),71378=>array(-91.709405,31.952617),71401=>array(-91.945921,31.797481),71403=>array(-93.434114,31.215061),71404=>array(-92.751585,31.747006),71405=>array(-92.402686,31.4102),71406=>array(-93.504579,31.733102),71407=>array(-92.485916,31.511005),71409=>array(-92.698494,31.312475),71410=>array(-92.771461,31.964808),71411=>array(-93.090534,31.905455),71414=>array(-93.023897,31.827932),71416=>array(-92.896951,31.540434),71417=>array(-92.649637,31.508165),71418=>array(-92.06672,32.153925),71419=>array(-93.712333,31.819541),71422=>array(-92.665698,32.075286),71423=>array(-92.56839,31.608231),71424=>array(-92.689845,31.198217),71425=>array(-91.873993,31.88607),71426=>array(-93.459873,31.498836),71427=>array(-92.895939,31.393954),71429=>array(-93.434636,31.409171),71430=>array(-92.495816,31.045222),71432=>array(-92.46771,31.749577),71433=>array(-92.645832,31.002986),71435=>array(-92.166355,32.031741),71438=>array(-92.824105,31.123274),71439=>array(-93.395725,31.336817),71441=>array(-92.15344,31.951563),71446=>array(-93.186912,31.166711),71447=>array(-92.812704,31.439054),71449=>array(-93.511491,31.545133),71450=>array(-93.415279,31.777653),71452=>array(-92.944474,31.585083),71454=>array(-92.858382,31.69142),71455=>array(-92.9895,31.403448),71456=>array(-92.978467,31.642077),71457=>array(-93.105944,31.74185),71459=>array(-93.223895,31.049335),71461=>array(-93.288907,31.117968),71462=>array(-93.721339,31.656767),71463=>array(-92.609872,30.810055),71465=>array(-92.179144,31.876805),71466=>array(-92.748626,31.215147),71467=>array(-92.387126,31.563307),71468=>array(-93.148903,31.480849),71469=>array(-93.270631,31.694472),71472=>array(-92.787163,31.168851),71473=>array(-92.436094,32.060376),71474=>array(-93.013045,31.274616),71479=>array(-92.367977,31.848859),71480=>array(-92.290599,31.862283),71483=>array(-92.657875,31.892384),71485=>array(-92.541679,31.15661),71486=>array(-93.607437,31.659006),71601=>array(-91.892651,34.179353),71602=>array(-92.145566,34.265166),71603=>array(-92.088127,34.121075),71630=>array(-91.207069,33.620304),71631=>array(-92.264958,33.580025),71635=>array(-91.99661,33.130555),71638=>array(-91.484745,33.520939),71639=>array(-91.520374,33.901476),71640=>array(-91.278079,33.101218),71642=>array(-91.887479,33.387395),71643=>array(-91.576497,34.016891),71644=>array(-91.704714,34.098301),71646=>array(-91.787587,33.235544),71647=>array(-92.114035,33.36436),71651=>array(-92.284943,33.322335),71652=>array(-92.333039,33.932638),71653=>array(-91.251768,33.343373),71654=>array(-91.363284,33.621364),71655=>array(-91.747241,33.633633),71658=>array(-91.562057,33.315968),71659=>array(-91.775854,34.143566),71660=>array(-92.202721,33.758739),71661=>array(-91.550243,33.151034),71662=>array(-91.506833,33.843455),71663=>array(-91.429483,33.226443),71665=>array(-92.110319,33.930085),71666=>array(-91.282223,33.761035),71667=>array(-91.837096,33.924493),71670=>array(-91.407232,33.725289),71671=>array(-92.096049,33.601989),71674=>array(-91.175209,33.837006),71675=>array(-91.938191,33.591748),71676=>array(-91.567617,33.052156),71677=>array(-91.480643,33.761875),71701=>array(-92.81969,33.586463),71711=>array(-92.720251,33.637549),71720=>array(-92.653926,33.785026),71722=>array(-93.166445,33.71503),71724=>array(-92.535675,33.327776),71725=>array(-92.557937,34.04963),71726=>array(-92.998159,33.678186),71730=>array(-92.627072,33.198815),71740=>array(-93.167354,33.076871),71742=>array(-92.448887,33.852672),71743=>array(-93.097793,33.889332),71744=>array(-92.48092,33.498821),71745=>array(-92.396088,33.500735),71747=>array(-92.202891,33.060731),71749=>array(-92.818579,33.071881),71751=>array(-92.76026,33.411484),71752=>array(-93.192015,33.392631),71753=>array(-93.183903,33.227759),71758=>array(-92.914948,33.309289),71759=>array(-92.644185,33.320987),71762=>array(-92.768358,33.342916),71763=>array(-92.80534,33.916457),71764=>array(-93.047925,33.432526),71765=>array(-92.331795,33.141882),71766=>array(-92.506653,33.725131),71770=>array(-93.317427,33.388092),71772=>array(-93.126092,33.832642),71801=>array(-93.600599,33.64173),71820=>array(-94.272322,33.798767),71822=>array(-94.156265,33.663107),71823=>array(-94.121611,33.826826),71825=>array(-93.556496,33.877783),71826=>array(-93.723219,33.09254),71827=>array(-93.396517,33.425189),71832=>array(-94.351136,34.036919),71833=>array(-94.04125,34.141928),71834=>array(-93.957839,33.114846),71835=>array(-93.429182,33.644014),71836=>array(-94.39765,33.714994),71837=>array(-93.844922,33.254863),71838=>array(-93.812294,33.652497),71839=>array(-93.729032,33.334884),71841=>array(-94.339512,34.161996),71842=>array(-94.285269,33.902882),71845=>array(-93.634637,33.323581),71846=>array(-94.127736,33.943737),71847=>array(-93.636805,33.926251),71851=>array(-93.942522,33.856659),71852=>array(-93.855553,33.997681),71853=>array(-93.938035,33.593799),71854=>array(-93.881829,33.451415),71855=>array(-93.750907,33.864553),71857=>array(-93.33759,33.801468),71858=>array(-93.263796,33.585136),71859=>array(-93.910186,33.744439),71860=>array(-93.489882,33.290403),71861=>array(-93.499952,33.100673),71862=>array(-93.727827,33.777523),71865=>array(-94.149863,33.740987),71866=>array(-94.406484,33.877497),71901=>array(-92.974072,34.526453),71909=>array(-92.997552,34.643688),71913=>array(-93.095565,34.448083),71921=>array(-93.390909,34.243654),71922=>array(-93.415372,34.023734),71923=>array(-93.045228,34.0851),71929=>array(-93.159556,34.303737),71933=>array(-93.342843,34.439307),71935=>array(-93.751549,34.395731),71937=>array(-94.390304,34.399366),71940=>array(-93.520406,34.023354),71941=>array(-92.948746,34.24725),71943=>array(-93.607268,34.340316),71944=>array(-94.332769,34.242824),71945=>array(-94.339565,34.485153),71949=>array(-93.22044,34.698923),71950=>array(-93.717836,34.256518),71952=>array(-93.825032,34.277731),71953=>array(-94.196979,34.608105),71956=>array(-93.153103,34.597999),71957=>array(-93.574701,34.565024),71958=>array(-93.661109,34.120932),71959=>array(-93.931584,34.243165),71960=>array(-93.709571,34.483985),71961=>array(-93.841855,34.596691),71962=>array(-93.322844,34.036161),71964=>array(-93.240731,34.424134),71965=>array(-93.746571,34.670485),71968=>array(-93.290405,34.524148),71969=>array(-93.62921,34.669242),71970=>array(-93.488527,34.668442),71971=>array(-94.034257,34.304022),71972=>array(-94.276862,34.382891),71973=>array(-94.318986,34.301882),71998=>array(-93.055286,34.126385),71999=>array(-93.059067,34.127458),72001=>array(-92.885846,35.058351),72002=>array(-92.527512,34.660794),72003=>array(-91.390261,34.382529),72004=>array(-91.77931,34.282786),72005=>array(-91.070427,35.537189),72006=>array(-91.359583,35.243873),72007=>array(-91.9832,35.001906),72010=>array(-91.536893,35.319509),72011=>array(-92.465885,34.500623),72012=>array(-91.907692,35.094896),72013=>array(-92.368576,35.455378),72014=>array(-91.111806,35.432519),72015=>array(-92.585282,34.485476),72016=>array(-92.632882,34.970823),72017=>array(-91.415565,34.899441),72019=>array(-92.685264,34.63803),72020=>array(-91.470145,35.472034),72021=>array(-91.217479,34.84554),72022=>array(-92.488535,34.607453),72023=>array(-92.063696,34.964293),72024=>array(-91.741919,34.760848),72025=>array(-92.999978,35.052266),72026=>array(-91.300494,34.502506),72027=>array(-92.572871,35.373818),72029=>array(-91.238574,34.707121),72030=>array(-92.675901,35.42709),72031=>array(-92.532111,35.632831),72032=>array(-92.362874,35.065889),72034=>array(-92.486049,35.049921),72035=>array(-92.457353,35.078763),72036=>array(-91.273098,35.011116),72037=>array(-91.874679,34.537243),72038=>array(-91.240529,34.453852),72039=>array(-92.397334,35.355769),72040=>array(-91.540872,34.974056),72041=>array(-91.467356,34.721785),72042=>array(-91.324459,34.26058),72044=>array(-92.164976,35.660028),72045=>array(-92.03229,35.129841),72046=>array(-91.949635,34.554711),72047=>array(-92.210687,35.223782),72048=>array(-91.127703,34.217058),72051=>array(-92.321011,35.786051),72055=>array(-91.35419,34.098693),72057=>array(-92.310368,34.140939),72058=>array(-92.3745,35.245942),72059=>array(-91.315003,35.139594),72060=>array(-91.599008,35.073708),72061=>array(-92.299994,35.322763),72063=>array(-92.790206,35.318065),72064=>array(-91.608698,34.791589),72065=>array(-92.282418,34.52671),72067=>array(-92.155437,35.563373),72068=>array(-91.710765,35.190309),72069=>array(-91.150062,34.536297),72070=>array(-92.706952,35.00812),72072=>array(-91.739547,34.523961),72073=>array(-91.669076,34.381138),72074=>array(-91.095316,35.07827),72076=>array(-92.139537,34.916269),72079=>array(-92.173539,34.390546),72080=>array(-92.83451,35.437998),72081=>array(-91.670425,35.382007),72082=>array(-91.67357,35.232834),72083=>array(-92.008712,34.593528),72084=>array(-92.667512,34.143958),72085=>array(-91.829069,35.363958),72086=>array(-91.90763,34.80709),72087=>array(-92.826199,34.596727),72088=>array(-92.267834,35.595187),72099=>array(-92.141459,34.899278),72101=>array(-91.164298,35.242387),72102=>array(-91.830016,35.147155),72103=>array(-92.390045,34.590486),72104=>array(-92.821803,34.342042),72106=>array(-92.522958,34.973953),72107=>array(-92.536244,35.14182),72108=>array(-91.066022,34.687786),72110=>array(-92.781666,35.156629),72111=>array(-92.131305,35.238551),72112=>array(-91.230074,35.582263),72113=>array(-92.397596,34.859543),72114=>array(-92.258752,34.764532),72116=>array(-92.245317,34.800258),72117=>array(-92.140707,34.775747),72118=>array(-92.325288,34.84038),72119=>array(-92.292252,34.834025),72120=>array(-92.241495,34.900292),72121=>array(-91.78614,35.455321),72122=>array(-92.787412,34.781864),72123=>array(-91.235388,35.25874),72125=>array(-92.790755,35.066154),72126=>array(-92.916184,34.942789),72127=>array(-92.606244,35.173287),72128=>array(-92.621432,34.31307),72129=>array(-92.542736,34.325635),72130=>array(-92.056438,35.661399),72131=>array(-92.187763,35.41589),72132=>array(-92.204774,34.446273),72134=>array(-91.350619,34.617709),72135=>array(-92.5401,34.877841),72136=>array(-92.005774,35.241599),72137=>array(-92.037221,35.335706),72139=>array(-91.507798,35.361003),72140=>array(-91.167189,34.362455),72141=>array(-92.672187,35.513306),72142=>array(-92.054865,34.692358),72143=>array(-91.736474,35.232983),72149=>array(-91.726214,35.249093),72150=>array(-92.394063,34.313365),72152=>array(-91.979332,34.356114),72153=>array(-92.32628,35.646118),72156=>array(-92.685033,35.281036),72157=>array(-92.556658,35.271247),72160=>array(-91.528699,34.427743),72165=>array(-91.457962,35.575447),72166=>array(-91.233567,34.058494),72167=>array(-92.647499,34.417804),72168=>array(-91.971787,34.440061),72169=>array(-91.226561,35.396488),72170=>array(-91.417505,34.586),72173=>array(-92.211144,35.100101),72175=>array(-91.76404,34.336715),72176=>array(-91.835241,35.002357),72179=>array(-91.855553,35.503585),72181=>array(-92.445162,35.162396),72201=>array(-92.280049,34.746905),72202=>array(-92.233147,34.730509),72204=>array(-92.358338,34.717617),72205=>array(-92.351206,34.750326),72206=>array(-92.234986,34.632496),72207=>array(-92.346499,34.773531),72209=>array(-92.345074,34.676378),72210=>array(-92.50845,34.7139),72211=>array(-92.417622,34.750556),72212=>array(-92.415028,34.785888),72223=>array(-92.511369,34.788813),72227=>array(-92.374573,34.775283),72301=>array(-90.189236,35.144685),72311=>array(-90.891487,34.723828),72315=>array(-89.903372,35.902592),72320=>array(-90.523669,34.823642),72321=>array(-89.944581,35.815941),72322=>array(-90.822094,35.064935),72324=>array(-90.786566,35.390418),72325=>array(-90.24596,35.322096),72326=>array(-90.910607,35.11711),72327=>array(-90.331957,35.233284),72328=>array(-91.091192,33.986204),72329=>array(-89.988074,35.614568),72330=>array(-90.210299,35.587784),72331=>array(-90.466262,35.281139),72332=>array(-90.308837,35.10195),72333=>array(-90.866645,34.302008),72335=>array(-90.745988,34.994363),72338=>array(-90.147781,35.413944),72339=>array(-90.268104,35.422012),72340=>array(-91.027828,34.93932),72341=>array(-90.753835,34.883947),72342=>array(-90.684489,34.448956),72346=>array(-90.484497,35.082327),72347=>array(-91.014418,35.377743),72348=>array(-90.417877,34.941736),72350=>array(-90.129287,35.499753),72351=>array(-90.096329,35.673714),72353=>array(-91.007283,34.300515),72354=>array(-90.319289,35.618852),72355=>array(-90.797703,34.474201),72358=>array(-89.890811,35.792191),72359=>array(-90.722124,35.026355),72360=>array(-90.780746,34.749251),72364=>array(-90.189224,35.217536),72365=>array(-90.450066,35.520899),72366=>array(-90.96086,34.518108),72367=>array(-90.943901,34.197327),72368=>array(-91.023371,34.810402),72370=>array(-90.027711,35.714403),72372=>array(-90.950562,34.96759),72373=>array(-90.594228,35.308676),72374=>array(-90.833499,34.566337),72376=>array(-90.29975,35.087232),72377=>array(-90.335954,35.692845),72379=>array(-91.041036,34.05478),72383=>array(-91.039621,34.491055),72384=>array(-90.219459,35.37583),72386=>array(-90.365994,35.45024),72389=>array(-90.912075,34.371344),72390=>array(-90.67941,34.551045),72392=>array(-91.096575,34.96728),72394=>array(-90.61402,35.060029),72395=>array(-90.079509,35.593114),72396=>array(-90.82373,35.229931),72401=>array(-90.656776,35.886339),72404=>array(-90.77883,35.773928),72410=>array(-91.094667,35.940746),72411=>array(-90.575507,35.74509),72412=>array(-90.694378,36.124168),72413=>array(-90.822219,36.30183),72414=>array(-90.374049,35.824609),72415=>array(-91.174948,36.126736),72416=>array(-90.795722,35.963977),72417=>array(-90.539526,35.916276),72419=>array(-90.35355,35.749599),72421=>array(-90.971951,35.785321),72422=>array(-90.527118,36.42643),72424=>array(-90.736363,36.390527),72425=>array(-90.732294,36.215476),72426=>array(-90.041639,35.868207),72427=>array(-90.935772,35.867056),72428=>array(-90.224596,35.739351),72429=>array(-90.925826,35.49138),72430=>array(-90.171274,36.334529),72431=>array(-91.079409,35.632571),72432=>array(-90.719944,35.551768),72433=>array(-91.047639,36.025741),72434=>array(-91.156352,36.217536),72435=>array(-90.5791,36.315759),72436=>array(-90.484839,36.237337),72437=>array(-90.458281,35.848382),72438=>array(-90.217756,35.949108),72440=>array(-91.227055,36.005556),72441=>array(-90.385317,36.436953),72442=>array(-90.186693,35.818572),72443=>array(-90.411414,36.17577),72444=>array(-90.852789,36.428649),72445=>array(-91.026627,35.976503),72447=>array(-90.327485,35.910876),72449=>array(-90.819634,36.177465),72450=>array(-90.51644,36.079546),72453=>array(-90.707988,36.294577),72454=>array(-90.202573,36.406767),72455=>array(-91.029353,36.319716),72456=>array(-90.338356,36.447254),72457=>array(-91.068221,36.088891),72458=>array(-91.158549,36.072601),72459=>array(-91.29299,36.292523),72460=>array(-91.169303,36.349823),72461=>array(-90.285306,36.264943),72462=>array(-90.759335,36.389116),72464=>array(-90.144108,36.457748),72466=>array(-91.330727,36.053793),72467=>array(-90.675602,35.841039),72469=>array(-91.288951,35.951943),72470=>array(-90.702257,36.470822),72471=>array(-91.110148,35.827874),72472=>array(-90.534178,35.596449),72473=>array(-91.171319,35.738259),72476=>array(-90.919912,36.049514),72478=>array(-91.059874,36.447888),72479=>array(-90.905465,35.633662),72482=>array(-91.366309,36.276702),72501=>array(-91.653381,35.791171),72512=>array(-91.746312,36.220421),72513=>array(-91.658306,36.226285),72515=>array(-92.056433,36.276377),72517=>array(-91.973272,36.132313),72519=>array(-92.180271,36.13407),72520=>array(-91.720193,36.3909),72521=>array(-91.541118,35.949672),72522=>array(-91.470426,35.810884),72523=>array(-91.844162,35.628072),72524=>array(-91.299239,35.835033),72526=>array(-91.779304,35.883198),72527=>array(-91.684967,35.73986),72528=>array(-92.138311,36.227487),72529=>array(-91.564285,36.292323),72530=>array(-91.94472,35.603916),72531=>array(-92.144212,36.329984),72532=>array(-91.599911,36.104385),72533=>array(-92.246613,35.978576),72534=>array(-91.744389,35.601037),72536=>array(-91.76834,36.142308),72537=>array(-92.222556,36.446131),72538=>array(-92.100286,36.445552),72539=>array(-91.711144,36.33214),72540=>array(-91.910048,35.919706),72542=>array(-91.467533,36.299525),72543=>array(-91.987292,35.450539),72544=>array(-92.188339,36.403465),72546=>array(-91.941061,35.578882),72550=>array(-91.783974,35.710126),72553=>array(-91.48084,35.7005),72554=>array(-91.562211,36.438698),72555=>array(-91.877982,35.781172),72556=>array(-91.970013,36.013876),72560=>array(-92.094066,35.851011),72561=>array(-91.808538,35.948021),72562=>array(-91.401119,35.735469),72564=>array(-91.456611,35.59588),72565=>array(-91.912766,36.217416),72566=>array(-92.078015,36.21676),72567=>array(-91.925955,35.814568),72568=>array(-91.624998,35.569396),72569=>array(-91.399363,36.146178),72571=>array(-91.537156,35.631477),72572=>array(-91.291045,35.899142),72573=>array(-91.797364,36.076165),72576=>array(-91.856033,36.348536),72577=>array(-91.713924,36.027133),72578=>array(-91.886354,36.453153),72579=>array(-91.449196,35.848827),72581=>array(-91.989243,35.550954),72583=>array(-91.99411,36.414776),72584=>array(-91.843699,36.140997),72585=>array(-92.008137,36.183223),72587=>array(-91.816758,36.225589),72601=>array(-93.08597,36.238029),72611=>array(-93.330718,36.244796),72616=>array(-93.555323,36.330648),72617=>array(-92.39053,36.022871),72619=>array(-92.591631,36.373473),72623=>array(-92.308496,36.455556),72624=>array(-93.381785,36.057715),72626=>array(-92.551574,36.322222),72628=>array(-93.281762,35.839875),72629=>array(-92.566795,35.738502),72630=>array(-92.904907,36.478794),72631=>array(-93.713362,36.462434),72632=>array(-93.743893,36.373213),72633=>array(-92.872765,36.128875),72634=>array(-92.513515,36.200113),72635=>array(-92.513781,36.318384),72636=>array(-92.716224,35.989702),72638=>array(-93.404544,36.322765),72639=>array(-92.48045,36.021332),72640=>array(-93.062042,36.001187),72641=>array(-93.243741,35.986549),72642=>array(-92.540407,36.375472),72644=>array(-92.992763,36.433124),72645=>array(-92.575385,35.804138),72648=>array(-93.151902,36.078547),72650=>array(-92.701437,35.884317),72651=>array(-92.482359,36.388396),72653=>array(-92.38543,36.342381),72655=>array(-93.016516,35.90072),72658=>array(-92.319143,36.167387),72660=>array(-93.377872,36.478646),72661=>array(-92.578136,36.449273),72662=>array(-93.180824,36.431043),72663=>array(-92.327794,35.937773),72666=>array(-93.265263,35.942186),72668=>array(-92.780989,36.434791),72669=>array(-92.876157,36.064963),72670=>array(-93.388128,35.981417),72672=>array(-92.844404,36.288088),72675=>array(-92.795221,35.99951),72677=>array(-92.685642,36.253163),72679=>array(-92.832143,35.730057),72680=>array(-92.32953,35.887334),72682=>array(-92.741396,36.137542),72683=>array(-93.102771,35.92313),72685=>array(-92.984561,36.065548),72686=>array(-92.843856,35.780128),72687=>array(-92.706768,36.262223),72701=>array(-94.085584,35.992387),72703=>array(-94.043243,36.118332),72704=>array(-94.296796,36.105701),72712=>array(-94.25628,36.346567),72714=>array(-94.220903,36.467299),72715=>array(-94.30454,36.465817),72717=>array(-94.42464,35.838873),72718=>array(-94.219446,36.268458),72719=>array(-94.295087,36.367161),72721=>array(-93.825719,35.798415),72722=>array(-94.468192,36.342698),72727=>array(-93.900502,35.916365),72729=>array(-94.456211,35.771526),72730=>array(-94.268676,36.030477),72732=>array(-93.959444,36.432516),72734=>array(-94.452834,36.27015),72736=>array(-94.465066,36.413778),72738=>array(-93.886845,36.1559),72739=>array(-94.327383,36.423158),72740=>array(-93.684034,36.105438),72742=>array(-93.50124,35.963804),72744=>array(-94.435365,35.96258),72745=>array(-94.103144,36.247242),72747=>array(-94.582789,36.36863),72749=>array(-94.437597,35.868416),72751=>array(-94.115428,36.460064),72752=>array(-93.590342,35.817589),72753=>array(-94.331072,35.933889),72756=>array(-93.978383,36.320391),72758=>array(-94.13721,36.299665),72760=>array(-93.706729,35.832945),72761=>array(-94.455335,36.168191),72762=>array(-94.230652,36.181583),72764=>array(-94.060223,36.175682),72768=>array(-94.498595,36.478322),72769=>array(-94.495892,36.035853),72773=>array(-93.835944,36.022251),72774=>array(-94.147174,35.948126),72776=>array(-93.649644,35.921488),72801=>array(-93.140877,35.279127),72802=>array(-93.08164,35.318851),72821=>array(-93.717371,35.434935),72823=>array(-92.905571,35.251217),72824=>array(-93.412111,35.132996),72826=>array(-93.70889,35.11944),72827=>array(-93.615705,34.882965),72828=>array(-93.534996,34.930718),72830=>array(-93.515619,35.509167),72832=>array(-93.670516,35.41474),72833=>array(-93.472595,35.021703),72834=>array(-93.183821,35.168824),72835=>array(-93.346311,35.277805),72837=>array(-93.109424,35.503672),72838=>array(-93.679045,34.910749),72839=>array(-93.244275,35.629695),72840=>array(-93.615427,35.45809),72841=>array(-93.800771,34.837318),72842=>array(-93.617393,35.08238),72843=>array(-92.93752,35.59993),72845=>array(-93.377869,35.361637),72846=>array(-93.326796,35.4839),72847=>array(-93.273453,35.377533),72851=>array(-93.438152,35.255293),72852=>array(-93.5534,35.669875),72853=>array(-93.202344,35.016833),72854=>array(-93.423363,35.709147),72855=>array(-93.683862,35.258968),72856=>array(-93.083345,35.786064),72857=>array(-93.319913,34.861544),72858=>array(-93.044393,35.240223),72860=>array(-93.432355,34.953573),72863=>array(-93.511253,35.369401),72865=>array(-93.57433,35.309458),72901=>array(-94.416458,35.366187),72903=>array(-94.361247,35.350978),72904=>array(-94.382352,35.41334),72908=>array(-94.410646,35.305453),72916=>array(-94.389414,35.261053),72921=>array(-94.196225,35.477101),72923=>array(-94.309688,35.314863),72926=>array(-94.036964,34.732436),72927=>array(-93.940515,35.079823),72928=>array(-93.930613,35.291336),72930=>array(-93.965301,35.43045),72932=>array(-94.377357,35.604219),72933=>array(-94.013245,35.328499),72934=>array(-94.284334,35.686804),72935=>array(-94.12648,35.491333),72936=>array(-94.219961,35.18923),72937=>array(-94.392017,35.135024),72938=>array(-94.377819,35.004118),72940=>array(-94.259252,35.121991),72941=>array(-94.156301,35.367921),72943=>array(-93.786949,35.180144),72944=>array(-94.234595,35.024077),72945=>array(-94.347301,35.087473),72946=>array(-94.134989,35.66954),72947=>array(-94.028384,35.572054),72948=>array(-94.392995,35.702673),72949=>array(-93.805165,35.584277),72950=>array(-93.888006,34.776041),72951=>array(-93.872128,35.327345),72952=>array(-94.300414,35.568761),72955=>array(-94.437808,35.61417),72956=>array(-94.349293,35.466),72958=>array(-94.137433,34.903829),72959=>array(-94.064776,35.786762),73002=>array(-97.728318,34.939235),73003=>array(-97.49738,35.668905),73004=>array(-97.844118,35.152297),73005=>array(-98.240141,35.051308),73006=>array(-98.40022,34.906219),73007=>array(-97.328268,35.68664),73008=>array(-97.647993,35.513888),73009=>array(-98.372763,35.286403),73010=>array(-97.679215,35.111365),73011=>array(-97.746577,34.847842),73012=>array(-97.593657,35.667234),73013=>array(-97.484375,35.618788),73014=>array(-98.145189,35.587533),73015=>array(-98.594435,35.083633),73016=>array(-97.687697,35.802136),73017=>array(-98.093596,34.926555),73018=>array(-97.940504,35.051452),73019=>array(-97.44358,35.206058),73020=>array(-97.262802,35.45881),73021=>array(-98.663738,35.345111),73024=>array(-98.797453,35.360504),73025=>array(-97.577365,35.733923),73026=>array(-97.275732,35.24046),73027=>array(-97.251982,35.978178),73028=>array(-97.631503,35.977961),73029=>array(-98.206268,34.905404),73030=>array(-97.164542,34.466145),73032=>array(-97.047107,34.398207),73033=>array(-98.546625,35.314385),73034=>array(-97.434052,35.703414),73036=>array(-97.959769,35.509391),73038=>array(-98.451304,35.124504),73040=>array(-98.375225,35.645563),73041=>array(-98.876115,35.042288),73042=>array(-98.246944,35.222872),73043=>array(-98.403416,35.73425),73044=>array(-97.422809,35.859572),73045=>array(-97.15053,35.514271),73047=>array(-98.315115,35.456816),73048=>array(-98.546273,35.49658),73049=>array(-97.309326,35.587046),73050=>array(-97.263815,35.938697),73051=>array(-97.246341,35.031853),73052=>array(-97.589045,34.833535),73053=>array(-98.413998,35.355475),73054=>array(-97.191089,35.67065),73055=>array(-97.910747,34.64385),73056=>array(-97.626209,36.176938),73057=>array(-97.420312,34.830332),73058=>array(-97.220104,35.815567),73059=>array(-98.04639,35.311705),73061=>array(-97.005557,36.355132),73062=>array(-98.740922,35.046247),73063=>array(-97.425008,36.052707),73064=>array(-97.746556,35.368764),73065=>array(-97.609981,35.256171),73066=>array(-97.327478,35.500215),73067=>array(-97.907103,34.911077),73068=>array(-97.291801,35.13851),73069=>array(-97.462408,35.249662),73071=>array(-97.411896,35.238349),73072=>array(-97.504181,35.212702),73073=>array(-97.41561,36.151761),73074=>array(-97.274101,34.833387),73075=>array(-97.232285,34.748808),73077=>array(-97.266383,36.306134),73078=>array(-97.753837,35.674945),73079=>array(-98.012001,35.210934),73080=>array(-97.479806,34.994519),73082=>array(-97.90211,34.776197),73084=>array(-97.344367,35.52586),73086=>array(-96.964187,34.481795),73089=>array(-97.792855,35.268623),73090=>array(-97.948406,35.398904),73092=>array(-98.100016,35.123886),73093=>array(-97.486492,35.109609),73095=>array(-97.29614,34.898559),73096=>array(-98.740993,35.514052),73097=>array(-97.644789,35.400491),73098=>array(-97.162187,34.626987),73099=>array(-97.771727,35.525168),73102=>array(-97.519001,35.470749),73103=>array(-97.518909,35.489073),73104=>array(-97.503918,35.47523),73105=>array(-97.501254,35.520032),73106=>array(-97.536812,35.481967),73107=>array(-97.575612,35.481606),73108=>array(-97.567737,35.450007),73109=>array(-97.524548,35.433138),73110=>array(-97.397639,35.461181),73111=>array(-97.477422,35.519496),73112=>array(-97.575423,35.51817),73114=>array(-97.517674,35.578137),73115=>array(-97.441523,35.442343),73116=>array(-97.564592,35.546701),73117=>array(-97.462502,35.474862),73118=>array(-97.528718,35.517968),73119=>array(-97.566125,35.422007),73120=>array(-97.573674,35.581316),73121=>array(-97.43954,35.521118),73122=>array(-97.61344,35.520484),73127=>array(-97.653194,35.477422),73128=>array(-97.662381,35.458482),73129=>array(-97.484275,35.431488),73130=>array(-97.345632,35.458633),73131=>array(-97.469294,35.576458),73132=>array(-97.635848,35.552908),73134=>array(-97.568447,35.614168),73135=>array(-97.433076,35.400268),73139=>array(-97.525661,35.386417),73141=>array(-97.39967,35.51683),73142=>array(-97.645321,35.616598),73145=>array(-97.394046,35.419088),73149=>array(-97.489325,35.389417),73150=>array(-97.329876,35.401238),73151=>array(-97.416568,35.571679),73159=>array(-97.578835,35.387855),73160=>array(-97.475217,35.332438),73162=>array(-97.640928,35.582011),73165=>array(-97.365215,35.355435),73169=>array(-97.642601,35.38277),73170=>array(-97.552609,35.325769),73173=>array(-97.624038,35.346324),73179=>array(-97.640843,35.428391),73401=>array(-97.11552,34.203289),73425=>array(-97.558417,34.455104),73430=>array(-97.361382,33.898323),73432=>array(-96.413873,34.251236),73433=>array(-97.406715,34.62817),73434=>array(-97.579188,34.618539),73437=>array(-97.412376,34.367943),73438=>array(-97.503211,34.281559),73439=>array(-96.744103,33.937903),73440=>array(-96.896744,33.944702),73441=>array(-97.430574,33.90447),73442=>array(-97.664593,34.327013),73443=>array(-97.297643,34.164985),73444=>array(-97.361366,34.475095),73446=>array(-96.777798,34.089592),73447=>array(-96.85345,34.247252),73448=>array(-97.106144,33.948312),73449=>array(-96.544138,34.00875),73450=>array(-96.533234,34.263432),73453=>array(-97.238508,34.041675),73455=>array(-96.760353,34.229981),73456=>array(-97.645662,34.124547),73458=>array(-97.249856,34.359542),73459=>array(-97.130517,33.77389),73460=>array(-96.65126,34.275807),73461=>array(-96.456915,34.360797),73463=>array(-97.434852,34.107709),73481=>array(-97.522015,34.43927),73487=>array(-97.448953,34.484337),73491=>array(-97.637933,34.473395),73501=>array(-98.290973,34.557945),73503=>array(-98.49182,34.682971),73505=>array(-98.481242,34.576274),73507=>array(-98.629094,34.795717),73520=>array(-97.989868,34.263009),73521=>array(-99.31594,34.641313),73526=>array(-99.275969,34.791644),73527=>array(-98.622288,34.578229),73528=>array(-98.633421,34.398379),73529=>array(-97.944725,34.350658),73530=>array(-99.022339,34.25518),73531=>array(-98.536922,34.194637),73532=>array(-99.585884,34.643206),73533=>array(-97.865916,34.505317),73537=>array(-99.664244,34.486692),73538=>array(-98.237715,34.673992),73539=>array(-99.280585,34.457183),73540=>array(-98.560889,34.467092),73541=>array(-98.180721,34.788728),73542=>array(-98.948196,34.401795),73543=>array(-98.374021,34.470062),73544=>array(-99.745682,34.682536),73546=>array(-98.723483,34.222944),73547=>array(-99.413335,34.992899),73548=>array(-98.108572,34.286479),73549=>array(-99.152829,34.644812),73550=>array(-99.90032,34.689605),73551=>array(-98.888948,34.354051),73552=>array(-98.761949,34.642436),73553=>array(-98.722084,34.326642),73554=>array(-99.616858,34.893237),73555=>array(-98.965922,34.501511),73556=>array(-99.384051,34.730084),73557=>array(-98.488973,34.731987),73559=>array(-98.963699,34.731386),73560=>array(-99.446744,34.539283),73562=>array(-98.40924,34.181006),73564=>array(-98.999659,34.84845),73565=>array(-97.893975,34.019909),73566=>array(-98.930065,34.61656),73567=>array(-98.144111,34.745916),73568=>array(-98.213039,34.252094),73569=>array(-97.782705,33.935967),73570=>array(-99.114772,34.51463),73571=>array(-99.891316,34.931971),73572=>array(-98.345276,34.359644),73573=>array(-97.938643,34.165641),73601=>array(-98.963496,35.489614),73620=>array(-99.025127,35.62233),73622=>array(-98.996649,35.386159),73624=>array(-99.177885,35.341629),73625=>array(-99.190504,35.676706),73626=>array(-99.278941,35.421462),73627=>array(-99.452704,35.197014),73628=>array(-99.700231,35.630124),73632=>array(-98.932044,35.26956),73638=>array(-99.784713,35.840371),73639=>array(-98.96062,35.739089),73641=>array(-99.173707,35.271211),73642=>array(-99.909944,35.822727),73644=>array(-99.437791,35.419594),73645=>array(-99.896396,35.197482),73646=>array(-98.609606,35.829574),73647=>array(-99.159954,35.435506),73650=>array(-99.402948,35.645945),73651=>array(-99.075637,35.014541),73654=>array(-99.367671,35.871027),73655=>array(-99.263681,34.98235),73658=>array(-98.741972,35.949209),73659=>array(-98.917268,35.862816),73660=>array(-99.917328,35.617653),73661=>array(-99.009351,35.167199),73662=>array(-99.684321,35.298362),73663=>array(-98.894969,36.102944),73664=>array(-99.247421,35.185996),73666=>array(-99.920163,35.472982),73667=>array(-99.0399,36.005902),73669=>array(-98.744834,35.730713),73673=>array(-99.567517,35.054415),73701=>array(-97.791989,36.426744),73703=>array(-97.969332,36.427053),73705=>array(-97.902629,36.338237),73716=>array(-98.524842,36.499454),73717=>array(-98.764389,36.848381),73718=>array(-98.166797,36.224794),73719=>array(-98.288439,36.956781),73720=>array(-97.87275,36.201132),73722=>array(-98.215556,36.84808),73724=>array(-98.663719,36.052152),73726=>array(-98.497112,36.587781),73727=>array(-98.041755,36.499524),73728=>array(-98.37246,36.747408),73729=>array(-98.476581,36.422415),73730=>array(-97.539278,36.320793),73731=>array(-98.603442,36.644994),73733=>array(-97.68794,36.254662),73734=>array(-97.863019,35.978388),73735=>array(-98.062871,36.280361),73736=>array(-97.68173,36.340239),73737=>array(-98.63988,36.293239),73738=>array(-97.552,36.451015),73739=>array(-98.143537,36.512467),73741=>array(-98.256726,36.557445),73742=>array(-97.93465,36.095059),73743=>array(-98.013178,36.576139),73744=>array(-98.306188,35.947878),73746=>array(-98.657624,36.685124),73747=>array(-98.331843,36.22789),73749=>array(-98.154929,36.716824),73750=>array(-97.952374,35.852627),73753=>array(-97.863739,36.555251),73754=>array(-98.096146,36.39819),73755=>array(-98.564734,36.138233),73756=>array(-98.130059,35.979497),73757=>array(-97.458177,36.28688),73758=>array(-98.081048,36.950248),73759=>array(-97.720424,36.860105),73760=>array(-98.169059,36.371004),73761=>array(-98.043453,36.68291),73762=>array(-97.964437,35.713187),73763=>array(-98.326387,36.092871),73764=>array(-98.201702,35.85474),73766=>array(-97.825727,36.655593),73768=>array(-98.292148,36.355228),73771=>array(-97.973133,36.875804),73772=>array(-98.430296,35.863246),73773=>array(-97.920476,36.265726),73801=>array(-99.438732,36.479952),73832=>array(-99.689764,36.049727),73834=>array(-99.540299,36.846523),73835=>array(-99.219327,35.967125),73838=>array(-98.895489,36.237873),73840=>array(-99.614847,36.356174),73841=>array(-99.624304,36.558739),73842=>array(-99.198573,36.81834),73843=>array(-99.814293,36.398532),73844=>array(-100.142151,36.871687),73848=>array(-100.012458,36.660888),73851=>array(-99.806525,36.591412),73852=>array(-99.120104,36.47926),73853=>array(-99.147365,36.241563),73855=>array(-99.86774,36.917876),73857=>array(-99.329123,36.269884),73858=>array(-99.921531,36.179173),73859=>array(-99.29964,36.126412),73860=>array(-98.83686,36.545708),73901=>array(-101.017225,36.740055),73931=>array(-100.797981,36.608697),73932=>array(-100.499279,36.715772),73933=>array(-102.579737,36.740858),73937=>array(-102.79591,36.554897),73938=>array(-100.578761,36.932374),73939=>array(-101.789896,36.776778),73942=>array(-101.506398,36.738486),73944=>array(-101.108017,36.590948),73945=>array(-101.232916,36.826905),73946=>array(-102.80408,36.935479),73947=>array(-102.149079,36.820446),73949=>array(-101.915456,36.581136),73950=>array(-100.894971,36.854769),73951=>array(-101.062787,36.942879),74001=>array(-96.082863,36.493357),74002=>array(-96.143004,36.557214),74003=>array(-96.067573,36.728272),74006=>array(-95.895038,36.712435),74008=>array(-95.877013,35.923478),74010=>array(-96.363831,35.814546),74011=>array(-95.809192,35.981808),74012=>array(-95.805771,36.051397),74014=>array(-95.680816,36.055628),74015=>array(-95.702838,36.180425),74016=>array(-95.45126,36.545156),74017=>array(-95.587812,36.390961),74019=>array(-95.603194,36.284765),74020=>array(-96.420895,36.246127),74021=>array(-95.841669,36.383434),74022=>array(-95.987771,36.944293),74023=>array(-96.751382,35.958944),74026=>array(-96.761978,35.711744),74027=>array(-95.585735,36.788842),74028=>array(-96.520013,35.786264),74029=>array(-95.889907,36.822884),74030=>array(-96.558831,35.986114),74032=>array(-96.898778,36.20693),74033=>array(-96.007443,35.945975),74034=>array(-96.579091,36.226279),74035=>array(-96.387983,36.42143),74036=>array(-95.506549,36.158045),74037=>array(-95.97989,35.998551),74038=>array(-96.559277,36.157622),74039=>array(-96.236557,35.901719),74041=>array(-96.054853,35.941561),74042=>array(-95.578615,36.858552),74044=>array(-96.385295,36.094022),74045=>array(-96.708163,36.221128),74046=>array(-96.559172,35.75095),74047=>array(-96.010833,35.853233),74048=>array(-95.658799,36.695375),74050=>array(-96.064557,36.072822),74051=>array(-95.956685,36.61301),74052=>array(-96.57806,36.085343),74053=>array(-95.731724,36.430563),74054=>array(-96.347466,36.279882),74055=>array(-95.819071,36.276705),74056=>array(-96.330851,36.795302),74058=>array(-96.758594,36.362625),74059=>array(-97.061042,35.957081),74060=>array(-96.246217,36.271979),74061=>array(-95.892635,36.533125),74062=>array(-96.90095,36.037717),74063=>array(-96.19959,36.150767),74066=>array(-96.164294,35.993142),74068=>array(-96.577983,35.907253),74070=>array(-96.082714,36.399677),74071=>array(-96.296196,35.783474),74072=>array(-95.534407,36.951523),74073=>array(-96.026136,36.293072),74074=>array(-97.074012,36.078949),74075=>array(-97.083226,36.169169),74078=>array(-97.07046,36.124101),74079=>array(-96.655169,35.746626),74080=>array(-95.749012,36.542107),74081=>array(-96.451582,36.180499),74082=>array(-95.881557,36.450476),74083=>array(-95.753383,36.87921),74084=>array(-96.351473,36.533455),74085=>array(-96.722608,36.110793),74103=>array(-95.994557,36.1556),74104=>array(-95.954005,36.146469),74105=>array(-95.961087,36.097442),74106=>array(-95.98515,36.191942),74107=>array(-96.032367,36.115021),74108=>array(-95.790064,36.139497),74110=>array(-95.953879,36.188107),74112=>array(-95.902328,36.147036),74114=>array(-95.946695,36.126943),74115=>array(-95.909152,36.192085),74116=>array(-95.842578,36.188754),74117=>array(-95.901508,36.246037),74119=>array(-95.989166,36.142076),74120=>array(-95.977408,36.150737),74126=>array(-96.025829,36.241925),74127=>array(-96.045507,36.179654),74128=>array(-95.85146,36.14747),74129=>array(-95.871215,36.12624),74130=>array(-95.95659,36.241481),74131=>array(-96.068613,36.052418),74132=>array(-96.016734,36.048782),74133=>array(-95.877428,36.039272),74134=>array(-95.805491,36.110481),74135=>array(-95.924016,36.096205),74136=>array(-95.941457,36.0624),74137=>array(-95.931955,36.019356),74145=>array(-95.890482,36.097138),74146=>array(-95.855191,36.098806),74301=>array(-95.224726,36.677726),74330=>array(-95.272373,36.437107),74331=>array(-94.940409,36.639422),74332=>array(-95.22863,36.516971),74333=>array(-95.08191,36.794004),74337=>array(-95.336936,36.140741),74338=>array(-94.731772,36.257119),74339=>array(-94.87971,36.933947),74340=>array(-95.023102,36.47523),74342=>array(-94.933848,36.429301),74343=>array(-94.828285,36.735704),74344=>array(-94.740686,36.595478),74346=>array(-94.754394,36.439457),74347=>array(-94.811983,36.209915),74349=>array(-95.037356,36.51752),74350=>array(-95.052442,36.465922),74352=>array(-95.180408,36.141902),74354=>array(-94.882511,36.886136),74358=>array(-94.880601,36.917847),74359=>array(-94.794922,36.171801),74360=>array(-94.833857,36.970393),74361=>array(-95.306842,36.302767),74363=>array(-94.715091,36.9554),74364=>array(-94.948524,36.196316),74365=>array(-95.071341,36.293708),74366=>array(-95.046162,36.390403),74367=>array(-95.112888,36.416088),74368=>array(-94.848541,36.207553),74369=>array(-95.202002,36.92462),74370=>array(-94.680369,36.749774),74401=>array(-95.4677,35.723078),74403=>array(-95.306945,35.670516),74421=>array(-96.04415,35.761858),74422=>array(-95.705786,35.627056),74423=>array(-95.191729,35.672774),74425=>array(-95.641497,35.170896),74426=>array(-95.530308,35.451697),74427=>array(-94.886897,35.677088),74428=>array(-95.637768,35.569374),74429=>array(-95.627569,35.955524),74430=>array(-95.660771,35.126839),74431=>array(-95.941735,35.470865),74432=>array(-95.65932,35.284422),74434=>array(-95.21087,35.809549),74435=>array(-95.093838,35.576616),74436=>array(-95.696981,35.797413),74437=>array(-95.935805,35.447877),74438=>array(-95.75857,35.544411),74441=>array(-95.145009,35.976851),74442=>array(-95.819115,35.133651),74445=>array(-95.828602,35.631467),74446=>array(-95.315722,35.849008),74447=>array(-96.001771,35.640224),74450=>array(-95.477888,35.600099),74451=>array(-94.963999,35.735657),74452=>array(-95.068078,36.120172),74454=>array(-95.515876,35.85432),74455=>array(-95.263055,35.361255),74456=>array(-95.996987,35.71124),74457=>array(-94.841179,36.005891),74458=>array(-95.591741,35.883581),74459=>array(-95.492198,35.534348),74460=>array(-95.956524,35.507855),74462=>array(-95.164244,35.29092),74463=>array(-95.550393,35.759869),74464=>array(-94.982454,35.927971),74467=>array(-95.392663,35.966337),74468=>array(-95.56809,35.612166),74469=>array(-95.308333,35.495106),74470=>array(-95.166878,35.476717),74471=>array(-94.871883,35.834204),74472=>array(-95.268414,35.249889),74477=>array(-95.266586,36.003882),74501=>array(-95.790791,34.985768),74521=>array(-95.088174,34.654509),74522=>array(-95.692957,34.903596),74523=>array(-95.611929,34.228459),74525=>array(-96.068225,34.336099),74528=>array(-95.723961,34.72012),74530=>array(-96.494625,34.436131),74531=>array(-96.251927,34.885419),74533=>array(-96.197011,34.208012),74534=>array(-96.367738,34.61523),74535=>array(-96.445879,34.484536),74536=>array(-95.459785,34.563839),74538=>array(-96.25896,34.582143),74540=>array(-95.708704,34.571449),74543=>array(-95.437629,34.37055),74546=>array(-95.579056,34.858319),74547=>array(-95.613452,34.810286),74549=>array(-94.89412,34.562466),74552=>array(-95.24249,35.12081),74553=>array(-95.925284,34.713411),74554=>array(-95.710699,34.921255),74555=>array(-95.964544,34.249162),74556=>array(-96.179638,34.464259),74557=>array(-95.700287,34.39103),74558=>array(-95.165928,34.50478),74560=>array(-95.760131,34.648749),74561=>array(-95.415131,35.129949),74562=>array(-95.285523,34.296),74563=>array(-95.072648,34.96993),74565=>array(-95.841908,34.807295),74567=>array(-95.392805,34.426298),74569=>array(-95.92432,34.477346),74570=>array(-96.100966,34.862799),74571=>array(-94.978738,34.717269),74572=>array(-96.428477,34.644407),74574=>array(-95.290387,34.689048),74576=>array(-96.039321,34.655609),74577=>array(-94.808016,34.674841),74578=>array(-95.341654,34.906148),74601=>array(-97.148862,36.702158),74604=>array(-96.982361,36.701928),74630=>array(-97.433506,36.512112),74631=>array(-97.30514,36.793015),74632=>array(-97.338198,36.938862),74633=>array(-96.776628,36.710203),74636=>array(-97.522271,36.817793),74637=>array(-96.664805,36.566438),74640=>array(-97.651364,36.551638),74641=>array(-96.886599,36.795045),74643=>array(-97.572768,36.656364),74644=>array(-97.098284,36.551919),74646=>array(-97.441607,36.832439),74647=>array(-96.994561,36.9181),74650=>array(-96.750533,36.487496),74651=>array(-97.173257,36.468416),74652=>array(-96.644012,36.859161),74653=>array(-97.35032,36.649344),74701=>array(-96.378921,34.006822),74720=>array(-96.371691,33.831466),74722=>array(-94.898336,34.379578),74723=>array(-96.017162,33.992934),74724=>array(-94.86133,34.346276),74726=>array(-96.174356,33.941333),74727=>array(-95.858764,34.018744),74728=>array(-94.802807,34.150313),74729=>array(-96.253999,34.146482),74730=>array(-96.430988,33.912019),74731=>array(-96.560439,33.873765),74733=>array(-96.479035,33.836767),74734=>array(-94.54251,34.102246),74735=>array(-95.24752,34.096968),74736=>array(-94.991693,33.932253),74738=>array(-95.44334,33.895661),74740=>array(-94.60479,33.784428),74741=>array(-96.304088,33.780883),74743=>array(-95.494469,34.008426),74745=>array(-94.816353,33.859098),74747=>array(-96.357317,33.776584),74748=>array(-96.398918,34.151028),74750=>array(-95.018636,33.967835),74753=>array(-96.536581,33.907926),74754=>array(-95.134579,34.197888),74755=>array(-95.114767,34.134683),74756=>array(-95.374012,34.08451),74759=>array(-95.712147,34.056602),74760=>array(-95.362964,34.161523),74761=>array(-95.200867,34.005089),74764=>array(-95.095766,34.047907),74766=>array(-94.980172,34.143876),74801=>array(-96.969671,35.315129),74804=>array(-96.921469,35.391465),74820=>array(-96.715184,34.788674),74824=>array(-96.871192,35.888673),74825=>array(-96.409963,34.817952),74826=>array(-96.893188,35.02191),74827=>array(-96.341858,34.946034),74829=>array(-96.472326,35.517014),74830=>array(-96.664968,35.143876),74831=>array(-97.059948,34.908121),74832=>array(-97.006776,35.828769),74833=>array(-96.412003,35.572085),74834=>array(-96.884595,35.701353),74836=>array(-96.705068,34.466523),74837=>array(-96.449187,35.362686),74839=>array(-96.032446,35.241382),74840=>array(-96.798752,35.252916),74842=>array(-96.612564,34.624919),74843=>array(-96.728586,34.657025),74844=>array(-96.572386,34.865518),74845=>array(-95.8889,35.252338),74848=>array(-96.361626,35.078885),74849=>array(-96.735519,34.978391),74850=>array(-96.107056,35.109677),74851=>array(-97.081938,35.426235),74852=>array(-97.008872,35.12394),74854=>array(-96.749097,35.108543),74855=>array(-96.898554,35.519045),74856=>array(-96.807482,34.421746),74857=>array(-97.19679,35.336799),74859=>array(-96.321622,35.456479),74860=>array(-96.569823,35.531903),74864=>array(-96.710291,35.495862),74865=>array(-96.803604,34.602136),74867=>array(-96.563479,34.970304),74868=>array(-96.644613,35.278531),74869=>array(-96.760192,35.60117),74871=>array(-96.544061,34.605109),74872=>array(-96.988016,34.771695),74873=>array(-96.969539,35.220987),74875=>array(-96.969603,35.877069),74878=>array(-97.069829,35.004771),74880=>array(-96.119784,35.377444),74881=>array(-97.079617,35.714363),74883=>array(-96.225558,35.219684),74884=>array(-96.5154,35.190549),74901=>array(-94.441795,35.367066),74902=>array(-94.484116,35.248925),74930=>array(-94.776318,35.18348),74931=>array(-94.741134,35.699605),74932=>array(-94.537988,35.151594),74935=>array(-94.896888,34.949693),74936=>array(-94.724464,35.376865),74937=>array(-94.587128,34.816741),74939=>array(-94.632473,34.729807),74940=>array(-94.622427,34.953637),74941=>array(-94.883911,35.287754),74942=>array(-94.978885,34.900349),74943=>array(-95.079876,35.072116),74944=>array(-94.989919,35.139371),74945=>array(-94.809421,35.599526),74946=>array(-94.454714,35.392451),74948=>array(-94.568942,35.467968),74949=>array(-94.753786,34.660805),74951=>array(-94.656684,35.170654),74953=>array(-94.610418,35.043436),74954=>array(-94.501593,35.42509),74955=>array(-94.748101,35.496424),74956=>array(-94.769089,35.109713),74957=>array(-94.655141,34.523791),74959=>array(-94.623306,35.270912),74960=>array(-94.650483,35.810418),74962=>array(-94.940814,35.544019),74963=>array(-94.579138,34.400588),74964=>array(-94.658801,36.111948),74965=>array(-94.630755,35.996383),74966=>array(-94.865138,34.917644),75001=>array(-96.838522,32.960047),75002=>array(-96.607767,33.089587),75006=>array(-96.89817,32.962473),75007=>array(-96.896742,33.005262),75009=>array(-96.752977,33.338899),75010=>array(-96.87454,33.050164),75013=>array(-96.693964,33.114327),75019=>array(-96.984664,32.963417),75020=>array(-96.604061,33.770785),75021=>array(-96.470794,33.727126),75022=>array(-97.124906,33.03489),75023=>array(-96.730831,33.056756),75024=>array(-96.802686,33.075422),75025=>array(-96.740008,33.090085),75028=>array(-97.06007,33.03271),75032=>array(-96.43617,32.851681),75034=>array(-96.856347,33.146336),75035=>array(-96.790192,33.163129),75038=>array(-96.996735,32.874833),75039=>array(-96.942108,32.885259),75040=>array(-96.619782,32.928902),75041=>array(-96.651555,32.880196),75042=>array(-96.674838,32.911702),75043=>array(-96.576325,32.857617),75044=>array(-96.649686,32.964607),75048=>array(-96.580883,32.969008),75050=>array(-97.009389,32.776671),75051=>array(-96.996462,32.72944),75052=>array(-97.024692,32.664953),75054=>array(-97.039429,32.59121),75056=>array(-96.912391,33.070292),75057=>array(-96.974546,33.050715),75058=>array(-96.742245,33.450768),75060=>array(-96.954903,32.796608),75061=>array(-96.966915,32.825907),75062=>array(-96.957871,32.84737),75063=>array(-96.985989,32.920435),75065=>array(-97.005469,33.110351),75067=>array(-97.00016,33.013546),75068=>array(-96.950551,33.176495),75069=>array(-96.586856,33.179994),75070=>array(-96.69627,33.172033),75071=>array(-96.631295,33.245879),75074=>array(-96.673164,33.031561),75075=>array(-96.741558,33.021268),75076=>array(-96.725989,33.800717),75077=>array(-97.061017,33.081367),75078=>array(-96.807989,33.241902),75080=>array(-96.74208,32.976063),75081=>array(-96.709719,32.948918),75082=>array(-96.663063,32.991557),75087=>array(-96.452875,32.943901),75088=>array(-96.550385,32.897846),75089=>array(-96.556367,32.938077),75090=>array(-96.550405,33.604131),75092=>array(-96.703808,33.656879),75093=>array(-96.811607,33.034225),75094=>array(-96.615482,33.021793),75098=>array(-96.534936,33.012135),75101=>array(-96.702494,32.270032),75102=>array(-96.632547,32.057938),75103=>array(-95.888865,32.518146),75104=>array(-96.964675,32.580181),75105=>array(-96.387663,32.26301),75109=>array(-96.350943,32.043193),75110=>array(-96.528172,32.084915),75114=>array(-96.444256,32.610576),75115=>array(-96.864075,32.599427),75116=>array(-96.911882,32.66066),75117=>array(-95.854461,32.715013),75119=>array(-96.588241,32.325868),75124=>array(-95.974056,32.326026),75125=>array(-96.621747,32.5367),75126=>array(-96.4549,32.743178),75127=>array(-95.789932,32.690295),75132=>array(-96.375325,32.945503),75134=>array(-96.778058,32.617663),75135=>array(-96.222134,33.066284),75137=>array(-96.916468,32.643212),75140=>array(-95.687531,32.646573),75141=>array(-96.695516,32.63852),75142=>array(-96.255103,32.568801),75143=>array(-96.245039,32.366686),75144=>array(-96.207611,32.109406),75146=>array(-96.752161,32.562744),75147=>array(-96.079558,32.436676),75148=>array(-96.01423,32.12747),75149=>array(-96.616717,32.771707),75150=>array(-96.630277,32.817309),75152=>array(-96.678049,32.439873),75153=>array(-96.329632,32.158265),75154=>array(-96.807315,32.521773),75155=>array(-96.475509,32.229113),75156=>array(-96.105332,32.277759),75157=>array(-96.43952,32.464756),75158=>array(-96.402131,32.462831),75159=>array(-96.542308,32.6058),75160=>array(-96.301323,32.758408),75161=>array(-96.169166,32.738471),75163=>array(-96.11882,32.166584),75164=>array(-96.309004,33.066219),75165=>array(-96.784944,32.372201),75166=>array(-96.454083,33.012652),75167=>array(-96.915523,32.360829),75169=>array(-95.994666,32.703269),75172=>array(-96.674333,32.605192),75173=>array(-96.393331,33.061789),75180=>array(-96.620085,32.716601),75181=>array(-96.558988,32.725663),75182=>array(-96.547563,32.80051),75189=>array(-96.31166,32.94205),75201=>array(-96.79939,32.787742),75202=>array(-96.804786,32.779274),75203=>array(-96.802681,32.746823),75204=>array(-96.788852,32.802132),75205=>array(-96.795514,32.835893),75206=>array(-96.771191,32.831279),75207=>array(-96.819971,32.786796),75208=>array(-96.839613,32.753141),75209=>array(-96.825474,32.84831),75210=>array(-96.746362,32.770635),75211=>array(-96.907815,32.736986),75212=>array(-96.878831,32.781246),75214=>array(-96.745951,32.828651),75215=>array(-96.756846,32.750602),75216=>array(-96.781215,32.711324),75217=>array(-96.678549,32.710306),75218=>array(-96.702574,32.841987),75219=>array(-96.812903,32.811847),75220=>array(-96.876118,32.868529),75223=>array(-96.744003,32.792244),75224=>array(-96.838591,32.711405),75225=>array(-96.790359,32.864887),75226=>array(-96.776443,32.782826),75227=>array(-96.689321,32.767119),75228=>array(-96.679438,32.824924),75229=>array(-96.864339,32.893295),75230=>array(-96.793393,32.902679),75231=>array(-96.747539,32.873485),75232=>array(-96.840948,32.660862),75233=>array(-96.871889,32.703913),75234=>array(-96.891721,32.923189),75235=>array(-96.849082,32.832614),75236=>array(-96.936565,32.676238),75237=>array(-96.873056,32.665618),75238=>array(-96.707819,32.878497),75240=>array(-96.787496,32.930338),75241=>array(-96.759451,32.665447),75243=>array(-96.736637,32.912633),75244=>array(-96.8368,32.925283),75246=>array(-96.772763,32.792496),75247=>array(-96.878036,32.813576),75248=>array(-96.797334,32.969699),75249=>array(-96.964622,32.636077),75251=>array(-96.770948,32.919789),75252=>array(-96.788213,32.997373),75253=>array(-96.609953,32.674006),75254=>array(-96.801792,32.944622),75270=>array(-96.802229,32.781197),75287=>array(-96.841688,32.999309),75390=>array(-96.84065,32.814164),75401=>array(-96.10887,33.189011),75402=>array(-96.084274,33.068454),75407=>array(-96.483157,33.151747),75409=>array(-96.515553,33.355461),75410=>array(-95.631982,32.790203),75411=>array(-95.649137,33.857868),75412=>array(-95.151966,33.801868),75413=>array(-96.179163,33.44144),75414=>array(-96.427874,33.623645),75415=>array(-95.757461,33.462218),75416=>array(-95.344733,33.683869),75417=>array(-95.140371,33.439658),75418=>array(-96.175218,33.572107),75420=>array(-95.72123,33.052795),75421=>array(-95.731361,33.661952),75422=>array(-95.934195,33.1414),75423=>array(-96.200389,33.284385),75424=>array(-96.378479,33.321734),75426=>array(-94.997258,33.663063),75428=>array(-95.917415,33.271869),75431=>array(-95.460935,33.01419),75432=>array(-95.677824,33.395031),75433=>array(-95.803234,33.098096),75435=>array(-95.320088,33.482646),75436=>array(-95.240033,33.713765),75437=>array(-95.47242,33.261225),75438=>array(-96.072156,33.615539),75439=>array(-96.282897,33.55352),75440=>array(-95.749061,32.880733),75441=>array(-95.642911,33.427656),75442=>array(-96.356004,33.174219),75446=>array(-95.900109,33.615167),75447=>array(-96.10937,33.776751),75448=>array(-95.788968,33.316269),75449=>array(-95.945707,33.420872),75450=>array(-95.483203,33.40225),75451=>array(-95.127063,32.965772),75452=>array(-96.23857,33.402226),75453=>array(-95.912936,32.989261),75454=>array(-96.566247,33.285118),75455=>array(-94.979111,33.21622),75457=>array(-95.21515,33.168595),75459=>array(-96.671495,33.53262),75460=>array(-95.605194,33.655162),75462=>array(-95.490113,33.624551),75468=>array(-95.402913,33.502152),75469=>array(-95.810604,33.421409),75470=>array(-95.809701,33.576823),75471=>array(-95.373518,33.056806),75472=>array(-95.869602,32.884423),75473=>array(-95.488005,33.815579),75474=>array(-96.113355,32.924709),75475=>array(-96.238237,33.474888),75476=>array(-96.240654,33.708311),75477=>array(-95.738073,33.529909),75478=>array(-95.358602,33.176532),75479=>array(-96.34502,33.617364),75480=>array(-95.197098,33.024442),75481=>array(-95.368391,33.318688),75482=>array(-95.608219,33.167979),75486=>array(-95.744327,33.745236),75487=>array(-95.1615,33.334851),75488=>array(-95.996823,33.778716),75489=>array(-96.484322,33.519251),75490=>array(-96.311485,33.439125),75491=>array(-96.396115,33.494577),75492=>array(-95.993541,33.584371),75493=>array(-95.108087,33.146391),75494=>array(-95.25986,32.917192),75495=>array(-96.549913,33.43566),75496=>array(-96.057939,33.349615),75497=>array(-95.568154,32.925093),75501=>array(-94.139816,33.37187),75503=>array(-94.133888,33.511784),75550=>array(-94.890845,33.498221),75551=>array(-94.22049,33.119333),75554=>array(-94.780261,33.553515),75555=>array(-94.142287,32.9392),75556=>array(-94.062427,33.157645),75558=>array(-94.857848,33.241961),75559=>array(-94.627358,33.503694),75560=>array(-94.36393,33.185033),75561=>array(-94.282349,33.5162),75562=>array(-94.248447,32.925399),75563=>array(-94.383454,33.002696),75565=>array(-94.07656,32.929999),75566=>array(-94.491749,33.148176),75567=>array(-94.311707,33.310999),75568=>array(-94.588989,33.194056),75569=>array(-94.128587,33.441822),75570=>array(-94.438723,33.459236),75571=>array(-94.77363,33.207019),75572=>array(-94.127695,33.225893),75573=>array(-94.244427,33.340712),75574=>array(-94.550659,33.325004),75601=>array(-94.724433,32.509075),75602=>array(-94.666065,32.449538),75603=>array(-94.711174,32.40305),75604=>array(-94.824416,32.509164),75605=>array(-94.725315,32.582292),75630=>array(-94.549481,32.867565),75631=>array(-94.45307,32.249664),75633=>array(-94.254575,32.130161),75638=>array(-94.729699,33.020475),75639=>array(-94.169679,32.293824),75640=>array(-94.683181,32.708417),75641=>array(-94.575786,32.378409),75642=>array(-94.176599,32.371536),75643=>array(-94.361907,32.019371),75644=>array(-94.999833,32.791087),75645=>array(-94.871843,32.688692),75647=>array(-94.953266,32.514636),75650=>array(-94.548846,32.513277),75651=>array(-94.538189,32.664407),75652=>array(-94.728328,32.239409),75654=>array(-94.83013,32.077773),75656=>array(-94.572161,33.011304),75657=>array(-94.310306,32.794973),75661=>array(-94.171261,32.631317),75662=>array(-94.870169,32.384458),75667=>array(-94.844274,31.988175),75668=>array(-94.678637,32.907075),75669=>array(-94.57588,32.038799),75670=>array(-94.418658,32.569858),75672=>array(-94.299079,32.468303),75681=>array(-94.704029,31.925449),75682=>array(-94.936535,32.250339),75683=>array(-94.737224,32.826816),75684=>array(-94.937156,32.277021),75686=>array(-94.952884,32.966409),75691=>array(-94.552,32.311915),75692=>array(-94.118039,32.470839),75693=>array(-94.86066,32.53378),75701=>array(-95.302223,32.321937),75702=>array(-95.315262,32.362434),75703=>array(-95.321028,32.235066),75704=>array(-95.443348,32.413107),75705=>array(-95.086688,32.362631),75706=>array(-95.307879,32.469555),75707=>array(-95.177964,32.301523),75708=>array(-95.21307,32.418412),75709=>array(-95.390814,32.304235),75750=>array(-95.077715,32.26754),75751=>array(-95.906047,32.094348),75752=>array(-95.807608,32.244008),75754=>array(-95.661983,32.427978),75755=>array(-95.072192,32.64064),75756=>array(-95.601475,32.30302),75757=>array(-95.347503,32.11274),75758=>array(-95.521442,32.271436),75759=>array(-95.418796,32.035939),75760=>array(-94.85434,31.796249),75762=>array(-95.413415,32.218325),75763=>array(-95.523388,32.042754),75764=>array(-95.143719,31.895427),75765=>array(-95.234859,32.642043),75766=>array(-95.25698,31.945137),75770=>array(-95.643712,32.158557),75771=>array(-95.435716,32.537897),75773=>array(-95.447702,32.681453),75778=>array(-95.709837,32.300926),75779=>array(-95.484612,31.863226),75780=>array(-95.091844,31.99102),75783=>array(-95.424745,32.816432),75784=>array(-94.974153,31.872135),75785=>array(-95.19267,31.779325),75788=>array(-94.925873,31.825939),75789=>array(-95.100374,32.111861),75790=>array(-95.643977,32.535169),75791=>array(-95.220644,32.221577),75792=>array(-95.106353,32.482238),75801=>array(-95.531381,31.73452),75803=>array(-95.679494,31.881777),75831=>array(-96.009175,31.473728),75832=>array(-95.980743,31.93201),75833=>array(-95.84123,31.267759),75835=>array(-95.490625,31.284891),75838=>array(-96.229757,31.4789),75839=>array(-95.58334,31.606693),75840=>array(-96.093621,31.782559),75844=>array(-95.437616,31.513801),75845=>array(-95.076849,31.087456),75846=>array(-96.152778,31.32952),75847=>array(-95.152898,31.356209),75848=>array(-96.329922,31.76524),75849=>array(-95.481652,31.417425),75850=>array(-95.934344,31.136452),75851=>array(-95.499937,31.092367),75852=>array(-95.715509,30.959521),75853=>array(-95.813468,31.946003),75855=>array(-95.863721,31.557267),75856=>array(-95.255739,31.188898),75858=>array(-95.126653,31.390774),75859=>array(-96.236861,31.89408),75860=>array(-96.238051,31.61135),75861=>array(-95.888459,31.851579),75862=>array(-95.326074,30.964255),75901=>array(-94.641414,31.301706),75904=>array(-94.82617,31.340783),75925=>array(-95.06209,31.61295),75926=>array(-94.969099,31.248085),75928=>array(-93.71134,30.671395),75929=>array(-94.175514,31.245162),75930=>array(-94.032615,31.322048),75931=>array(-94.021385,31.113664),75932=>array(-93.615655,31.056147),75933=>array(-93.812696,30.553812),75934=>array(-94.755703,30.893277),75935=>array(-94.19129,31.732513),75936=>array(-94.579622,30.952076),75937=>array(-94.367277,31.465312),75938=>array(-94.357637,30.946401),75939=>array(-94.79742,31.013779),75941=>array(-94.758734,31.186933),75942=>array(-94.430587,30.815166),75943=>array(-94.907231,31.642378),75944=>array(-94.385215,31.325741),75946=>array(-94.520617,31.81932),75948=>array(-93.784102,31.307588),75949=>array(-94.509986,31.230511),75951=>array(-94.056005,30.937323),75954=>array(-94.048094,31.904341),75956=>array(-93.983158,30.676371),75959=>array(-93.861732,31.512307),75960=>array(-94.865672,30.912856),75961=>array(-94.504452,31.558383),75962=>array(-94.64708,31.619873),75964=>array(-94.740721,31.631742),75965=>array(-94.628596,31.723329),75966=>array(-93.714056,30.826908),75968=>array(-93.953926,31.252292),75969=>array(-94.887599,31.445713),75972=>array(-94.130647,31.485703),75973=>array(-93.943111,31.711246),75974=>array(-94.239838,31.958364),75975=>array(-94.413785,31.897138),75976=>array(-94.924113,31.514484),75977=>array(-93.7828,31.066591),75978=>array(-94.527216,31.509051),75979=>array(-94.38912,30.748559),75980=>array(-94.375214,31.138382),76001=>array(-97.148829,32.635563),76002=>array(-97.093204,32.622321),76006=>array(-97.100052,32.784952),76008=>array(-97.631482,32.695708),76009=>array(-97.196367,32.414944),76010=>array(-97.080239,32.722844),76011=>array(-97.083196,32.754272),76012=>array(-97.139242,32.75513),76013=>array(-97.155028,32.719328),76014=>array(-97.086517,32.692105),76015=>array(-97.133304,32.692186),76016=>array(-97.18913,32.689222),76017=>array(-97.164024,32.662513),76018=>array(-97.096815,32.665076),76020=>array(-97.561179,32.900196),76021=>array(-97.130443,32.852971),76022=>array(-97.145157,32.830658),76023=>array(-97.597083,33.041942),76028=>array(-97.306547,32.532666),76031=>array(-97.328078,32.346162),76033=>array(-97.508356,32.276663),76034=>array(-97.149641,32.891787),76035=>array(-97.631011,32.56207),76036=>array(-97.420575,32.581858),76039=>array(-97.086028,32.860285),76040=>array(-97.091323,32.814107),76041=>array(-96.842324,32.237512),76043=>array(-97.795247,32.208483),76044=>array(-97.539874,32.425936),76048=>array(-97.811051,32.421697),76049=>array(-97.706694,32.459828),76050=>array(-97.16076,32.280923),76051=>array(-97.071545,32.925765),76052=>array(-97.377255,32.986624),76053=>array(-97.180586,32.8172),76054=>array(-97.178636,32.85941),76055=>array(-97.1549,32.162639),76058=>array(-97.422013,32.474087),76059=>array(-97.32754,32.392588),76060=>array(-97.217476,32.639649),76061=>array(-97.188374,32.503973),76063=>array(-97.144834,32.570725),76064=>array(-97.037219,32.302367),76065=>array(-96.99071,32.469267),76066=>array(-97.993148,32.704456),76067=>array(-98.126806,32.799602),76070=>array(-97.655141,32.266222),76071=>array(-97.444409,33.00085),76073=>array(-97.723422,33.098727),76077=>array(-97.691539,32.278261),76078=>array(-97.462793,33.093365),76082=>array(-97.733748,32.970044),76084=>array(-97.090328,32.426322),76085=>array(-97.6966,32.853068),76086=>array(-97.791085,32.754964),76087=>array(-97.782298,32.682733),76088=>array(-97.903219,32.848403),76092=>array(-97.148582,32.959922),76093=>array(-97.392571,32.210496),76102=>array(-97.329756,32.759104),76103=>array(-97.272957,32.749099),76104=>array(-97.317801,32.728688),76105=>array(-97.269432,32.724047),76106=>array(-97.359532,32.816503),76107=>array(-97.38173,32.742058),76108=>array(-97.523856,32.787009),76109=>array(-97.386965,32.70065),76110=>array(-97.338265,32.707831),76111=>array(-97.300112,32.778499),76112=>array(-97.217658,32.747426),76114=>array(-97.402276,32.774494),76115=>array(-97.330511,32.6785),76116=>array(-97.447033,32.720723),76117=>array(-97.267376,32.803436),76118=>array(-97.192762,32.800434),76119=>array(-97.262625,32.691147),76120=>array(-97.180963,32.775915),76123=>array(-97.393562,32.619833),76126=>array(-97.503481,32.63587),76127=>array(-97.435599,32.775409),76129=>array(-97.363495,32.708639),76131=>array(-97.345955,32.881807),76132=>array(-97.416615,32.667305),76133=>array(-97.379538,32.652918),76134=>array(-97.335106,32.639029),76135=>array(-97.482178,32.847326),76137=>array(-97.291523,32.859685),76140=>array(-97.274934,32.620058),76148=>array(-97.252132,32.868421),76155=>array(-97.048681,32.823978),76164=>array(-97.354585,32.7811),76177=>array(-97.310486,32.975361),76179=>array(-97.433835,32.913522),76180=>array(-97.225295,32.840011),76182=>array(-97.208384,32.88659),76201=>array(-97.146038,33.220974),76205=>array(-97.129266,33.192632),76207=>array(-97.183844,33.227695),76208=>array(-97.055133,33.208811),76209=>array(-97.109882,33.231569),76210=>array(-97.096016,33.149467),76225=>array(-97.669953,33.372433),76226=>array(-97.173782,33.114675),76227=>array(-96.990119,33.273449),76228=>array(-98.063303,33.616916),76230=>array(-97.95612,33.520572),76233=>array(-96.906575,33.537706),76234=>array(-97.514178,33.276319),76238=>array(-97.351845,33.479016),76239=>array(-97.540249,33.516403),76240=>array(-97.17635,33.661583),76244=>array(-97.283914,32.928037),76245=>array(-96.839764,33.830932),76247=>array(-97.340499,33.099993),76248=>array(-97.225148,32.924009),76249=>array(-97.302309,33.278823),76250=>array(-97.235755,33.630167),76251=>array(-97.687873,33.626904),76252=>array(-97.382855,33.682081),76253=>array(-97.310834,33.615855),76255=>array(-97.734876,33.820785),76258=>array(-96.933242,33.371246),76259=>array(-97.311628,33.198704),76261=>array(-97.963802,33.793074),76262=>array(-97.22672,33.009335),76263=>array(-97.445189,33.471617),76264=>array(-96.839543,33.737974),76265=>array(-97.535329,33.741367),76266=>array(-97.213359,33.373051),76268=>array(-96.767394,33.627623),76270=>array(-97.751818,33.455991),76271=>array(-96.892724,33.464643),76272=>array(-97.128552,33.458028),76273=>array(-96.936121,33.743893),76301=>array(-98.479881,33.905544),76302=>array(-98.491046,33.864515),76305=>array(-98.388757,34.004783),76306=>array(-98.523064,33.943784),76308=>array(-98.54073,33.852942),76309=>array(-98.54367,33.894941),76310=>array(-98.50984,33.799085),76311=>array(-98.509016,33.969523),76351=>array(-98.695247,33.558131),76354=>array(-98.622467,34.103273),76357=>array(-98.183817,34.081265),76360=>array(-98.961142,33.963477),76363=>array(-99.544699,33.47622),76364=>array(-98.992952,34.042817),76365=>array(-98.202251,33.75849),76366=>array(-98.783672,33.723849),76367=>array(-98.721096,33.973297),76370=>array(-98.884782,33.527396),76371=>array(-99.642707,33.484962),76372=>array(-98.925556,33.250203),76373=>array(-99.106624,34.131688),76374=>array(-98.740056,33.358656),76377=>array(-98.25932,34.008308),76379=>array(-98.489098,33.668251),76380=>array(-99.243765,33.621145),76384=>array(-99.342853,34.16089),76388=>array(-99.642126,33.322836),76389=>array(-98.457627,33.512628),76401=>array(-98.196717,32.282235),76402=>array(-98.217166,32.216328),76424=>array(-98.892466,32.804272),76426=>array(-97.845101,33.166041),76427=>array(-98.377664,33.158189),76429=>array(-98.666449,32.759373),76430=>array(-99.24184,32.790131),76431=>array(-97.857678,33.315883),76432=>array(-98.805134,31.842565),76433=>array(-98.022849,32.315739),76435=>array(-98.85714,32.242637),76436=>array(-98.228103,31.863402),76437=>array(-99.035195,32.401501),76442=>array(-98.614553,31.891101),76443=>array(-99.213349,32.13383),76444=>array(-98.573858,32.124074),76445=>array(-98.552257,32.298594),76446=>array(-98.34862,32.075301),76448=>array(-98.801051,32.399119),76449=>array(-98.324274,32.904994),76450=>array(-98.622222,33.057759),76452=>array(-98.364392,31.747542),76453=>array(-98.333604,32.587603),76454=>array(-98.735794,32.21185),76455=>array(-98.384478,31.813332),76457=>array(-98.027972,31.944662),76458=>array(-98.188154,33.219585),76459=>array(-98.382374,33.276426),76460=>array(-98.500474,33.310107),76462=>array(-98.008849,32.527015),76463=>array(-98.418168,32.455408),76464=>array(-99.164736,32.556004),76466=>array(-98.73742,32.433309),76469=>array(-99.198272,32.341152),76470=>array(-98.66402,32.495875),76471=>array(-98.98514,32.116953),76472=>array(-98.17276,32.600503),76474=>array(-98.793857,31.976523),76475=>array(-98.494478,32.665466),76476=>array(-97.924354,32.362649),76481=>array(-98.74549,32.99042),76483=>array(-99.265034,33.187712),76484=>array(-98.276879,32.764096),76486=>array(-98.053654,33.014983),76487=>array(-97.889781,32.97278),76490=>array(-98.018901,32.945471),76491=>array(-99.048807,33.036872),76501=>array(-97.252433,31.075303),76502=>array(-97.41202,31.103931),76504=>array(-97.373626,31.137885),76508=>array(-97.364064,31.077568),76511=>array(-97.424411,30.801782),76513=>array(-97.499909,31.051688),76518=>array(-97.148898,30.852653),76519=>array(-97.12069,31.020832),76520=>array(-96.907601,30.891129),76522=>array(-97.968224,31.219045),76523=>array(-97.291628,30.789254),76524=>array(-97.202495,31.268644),76525=>array(-98.136304,31.491738),76527=>array(-97.809699,30.841795),76528=>array(-97.755604,31.417256),76530=>array(-97.413885,30.710857),76531=>array(-98.187029,31.686814),76534=>array(-97.378809,30.884326),76537=>array(-97.6029,30.817401),76538=>array(-97.895645,31.647684),76539=>array(-98.01069,31.088158),76541=>array(-97.729602,31.112884),76542=>array(-97.746417,31.009641),76543=>array(-97.633196,31.149208),76544=>array(-97.761047,31.143642),76548=>array(-97.644625,31.050856),76549=>array(-97.833092,31.017077),76550=>array(-98.25934,31.102377),76554=>array(-97.372768,30.964981),76556=>array(-96.83055,30.700385),76557=>array(-97.390061,31.285086),76559=>array(-97.604369,31.075955),76561=>array(-97.531134,31.409518),76565=>array(-98.350878,31.644769),76566=>array(-98.049081,31.553908),76567=>array(-97.006126,30.649547),76569=>array(-97.227023,30.940183),76570=>array(-96.953514,31.082267),76571=>array(-97.59865,30.925736),76573=>array(-97.502485,30.818633),76574=>array(-97.388622,30.579327),76577=>array(-97.17025,30.627232),76578=>array(-97.23717,30.535409),76579=>array(-97.265253,31.195905),76596=>array(-97.728745,31.476579),76597=>array(-97.706884,31.486416),76598=>array(-97.735455,31.47532),76599=>array(-97.735272,31.467983),76621=>array(-97.08541,31.881728),76622=>array(-97.243292,31.816191),76623=>array(-96.752827,32.211123),76624=>array(-96.955129,31.661047),76626=>array(-96.723661,32.122927),76627=>array(-97.395815,32.108512),76628=>array(-96.94732,32.030037),76629=>array(-96.651785,31.14975),76630=>array(-97.211141,31.340747),76631=>array(-96.977168,31.975524),76632=>array(-97.060171,31.303129),76633=>array(-97.325271,31.693947),76634=>array(-97.546568,31.817062),76635=>array(-96.661428,31.71629),76636=>array(-97.29118,32.171095),76637=>array(-97.804426,31.769003),76638=>array(-97.44265,31.549983),76639=>array(-96.655804,31.866953),76640=>array(-97.073707,31.696619),76641=>array(-96.807932,32.038687),76642=>array(-96.520013,31.503056),76643=>array(-97.195339,31.453501),76645=>array(-97.133361,32.022461),76648=>array(-96.807276,31.848506),76649=>array(-97.8826,32.001481),76650=>array(-96.863626,31.980079),76651=>array(-96.85118,32.177712),76652=>array(-97.575601,32.117538),76653=>array(-96.608952,31.299588),76654=>array(-97.010835,31.734146),76655=>array(-97.183101,31.401145),76656=>array(-97.043667,31.185096),76657=>array(-97.382609,31.44554),76660=>array(-96.904503,31.924604),76661=>array(-96.847975,31.319912),76664=>array(-96.802449,31.560995),76665=>array(-97.710123,31.916215),76666=>array(-96.91458,32.043976),76667=>array(-96.468137,31.654919),76670=>array(-96.99247,32.137513),76671=>array(-97.52976,31.988989),76673=>array(-96.891872,31.751192),76676=>array(-96.951488,31.863748),76678=>array(-96.760043,31.661096),76679=>array(-96.579359,31.927546),76680=>array(-96.814239,31.202394),76681=>array(-96.433735,31.89348),76682=>array(-96.913619,31.453378),76685=>array(-97.012872,31.354734),76686=>array(-96.559327,31.767574),76687=>array(-96.495028,31.372916),76689=>array(-97.506079,31.662159),76690=>array(-97.736712,32.083522),76691=>array(-97.098169,31.769854),76692=>array(-97.330421,31.959701),76693=>array(-96.404161,31.783988),76701=>array(-97.1382,31.552011),76704=>array(-97.127249,31.576824),76705=>array(-97.09851,31.620954),76706=>array(-97.083854,31.475671),76707=>array(-97.159082,31.553876),76708=>array(-97.215893,31.627123),76710=>array(-97.195009,31.539723),76711=>array(-97.152983,31.513756),76712=>array(-97.260442,31.529664),76798=>array(-97.119061,31.548378),76801=>array(-99.032891,31.748303),76802=>array(-98.911407,31.743587),76820=>array(-99.050013,30.766987),76821=>array(-99.934162,31.738576),76823=>array(-99.151374,31.706204),76824=>array(-98.467066,30.936768),76825=>array(-99.394226,31.105959),76827=>array(-99.135467,31.517913),76828=>array(-99.290758,32.006925),76831=>array(-98.918266,30.653746),76832=>array(-98.735535,30.985777),76834=>array(-99.481164,31.881335),76836=>array(-99.549127,31.443363),76837=>array(-99.896212,31.222764),76841=>array(-100.107479,30.897544),76842=>array(-99.079893,30.93982),76844=>array(-98.508681,31.432417),76845=>array(-99.488185,31.538066),76848=>array(-99.570053,30.843122),76849=>array(-99.821945,30.472197),76852=>array(-99.446986,31.369401),76853=>array(-98.376742,31.257224),76854=>array(-99.581345,30.694792),76856=>array(-99.276239,30.69089),76857=>array(-98.927404,31.931233),76858=>array(-99.616412,31.176951),76859=>array(-99.854936,30.883707),76861=>array(-100.192616,31.592013),76862=>array(-99.682323,31.411505),76864=>array(-98.731107,31.553975),76865=>array(-100.165338,31.858516),76866=>array(-99.933766,31.460967),76869=>array(-98.994062,30.910963),76870=>array(-98.546717,31.627357),76871=>array(-98.995473,31.289123),76872=>array(-99.165902,31.331919),76873=>array(-99.380601,31.515316),76874=>array(-100.06915,30.45867),76875=>array(-99.999545,31.602931),76877=>array(-98.763991,31.157093),76878=>array(-99.295378,31.649138),76882=>array(-99.702274,31.816904),76884=>array(-99.567791,31.736902),76885=>array(-98.861313,30.858957),76887=>array(-99.159484,31.011897),76888=>array(-99.64049,31.609899),76890=>array(-98.776277,31.686677),76901=>array(-100.553311,31.610896),76903=>array(-100.43787,31.484819),76904=>array(-100.405795,31.27837),76905=>array(-100.322075,31.50972),76908=>array(-100.402169,31.432075),76930=>array(-101.172783,31.272551),76932=>array(-101.542078,31.268726),76933=>array(-100.284253,31.858897),76934=>array(-100.668988,31.603063),76935=>array(-100.423683,31.083442),76936=>array(-100.595464,30.883539),76937=>array(-100.151449,31.388546),76939=>array(-100.563525,31.268843),76940=>array(-100.142932,31.439035),76941=>array(-100.889468,31.272382),76943=>array(-101.297786,30.537596),76945=>array(-100.610567,31.885049),76949=>array(-100.69458,32.04114),76950=>array(-100.56062,30.441414),76951=>array(-101.055625,31.802748),76953=>array(-100.331902,31.723768),76955=>array(-100.15267,31.289523),76957=>array(-100.30516,31.372148),76958=>array(-100.799358,31.595106),77002=>array(-95.365652,29.756845),77003=>array(-95.345901,29.749808),77004=>array(-95.363752,29.724893),77005=>array(-95.423555,29.718435),77006=>array(-95.391302,29.74097),77007=>array(-95.411083,29.771545),77008=>array(-95.416933,29.798249),77009=>array(-95.36759,29.795344),77010=>array(-95.35981,29.753624),77011=>array(-95.30891,29.743564),77012=>array(-95.274137,29.718525),77013=>array(-95.228991,29.791808),77014=>array(-95.463971,29.981209),77015=>array(-95.173121,29.76393),77016=>array(-95.29998,29.862532),77017=>array(-95.252393,29.689824),77018=>array(-95.426267,29.826448),77019=>array(-95.409498,29.75415),77020=>array(-95.314327,29.773179),77021=>array(-95.3569,29.69843),77022=>array(-95.379553,29.83159),77023=>array(-95.318275,29.721825),77024=>array(-95.511751,29.771225),77025=>array(-95.434764,29.685706),77026=>array(-95.328888,29.800187),77027=>array(-95.446409,29.740079),77028=>array(-95.286149,29.825715),77029=>array(-95.256251,29.759665),77030=>array(-95.401748,29.706787),77031=>array(-95.54623,29.652205),77032=>array(-95.353412,29.987805),77033=>array(-95.335133,29.66688),77034=>array(-95.191192,29.619365),77035=>array(-95.475296,29.653418),77036=>array(-95.534537,29.701847),77037=>array(-95.392527,29.89036),77038=>array(-95.441194,29.918595),77039=>array(-95.341182,29.911171),77040=>array(-95.527099,29.874575),77041=>array(-95.580768,29.8586),77042=>array(-95.560254,29.741325),77043=>array(-95.583634,29.812687),77044=>array(-95.180595,29.906619),77045=>array(-95.432889,29.635793),77046=>array(-95.433346,29.733777),77047=>array(-95.386863,29.61065),77048=>array(-95.324221,29.618714),77049=>array(-95.14904,29.832928),77050=>array(-95.269296,29.902887),77051=>array(-95.378696,29.656113),77053=>array(-95.460693,29.583542),77054=>array(-95.404913,29.68025),77055=>array(-95.49165,29.796871),77056=>array(-95.468948,29.748202),77057=>array(-95.487974,29.744081),77058=>array(-95.099626,29.561579),77059=>array(-95.11937,29.613602),77060=>array(-95.394872,29.934695),77061=>array(-95.27663,29.647012),77062=>array(-95.130613,29.573552),77063=>array(-95.523292,29.736295),77064=>array(-95.535685,29.918045),77065=>array(-95.603242,29.926556),77066=>array(-95.503258,29.957234),77067=>array(-95.446609,29.952629),77068=>array(-95.488362,30.007063),77069=>array(-95.531201,29.988446),77070=>array(-95.572835,29.97967),77071=>array(-95.521183,29.652393),77072=>array(-95.584817,29.699688),77073=>array(-95.400207,29.999296),77074=>array(-95.515725,29.687947),77075=>array(-95.268939,29.62042),77076=>array(-95.382184,29.860021),77077=>array(-95.615384,29.750233),77078=>array(-95.254076,29.852379),77079=>array(-95.603037,29.776093),77080=>array(-95.522964,29.815893),77081=>array(-95.480935,29.712099),77082=>array(-95.640002,29.72449),77083=>array(-95.649627,29.694472),77084=>array(-95.65992,29.827486),77085=>array(-95.48615,29.620736),77086=>array(-95.489993,29.917695),77087=>array(-95.304159,29.685621),77088=>array(-95.452619,29.881487),77089=>array(-95.225601,29.586959),77090=>array(-95.438996,30.00824),77091=>array(-95.435966,29.853067),77092=>array(-95.474409,29.830024),77093=>array(-95.341409,29.8634),77094=>array(-95.681292,29.769285),77095=>array(-95.651234,29.909215),77096=>array(-95.479372,29.675339),77098=>array(-95.416098,29.734813),77099=>array(-95.58599,29.670869),77201=>array(-95.364364,29.766003),77301=>array(-95.438548,30.307375),77302=>array(-95.338811,30.221853),77303=>array(-95.37714,30.377954),77304=>array(-95.505008,30.324546),77306=>array(-95.312397,30.28584),77316=>array(-95.68639,30.306163),77318=>array(-95.533229,30.438807),77320=>array(-95.550872,30.804668),77326=>array(-94.817018,30.504882),77327=>array(-94.917669,30.317569),77328=>array(-95.191181,30.392374),77331=>array(-95.158878,30.629453),77334=>array(-95.373442,30.781835),77335=>array(-94.911174,30.574329),77336=>array(-95.098858,30.063168),77338=>array(-95.286217,30.017301),77339=>array(-95.221022,30.046777),77340=>array(-95.538432,30.6402),77342=>array(-95.555832,30.740381),77345=>array(-95.157943,30.053105),77346=>array(-95.177499,29.994499),77350=>array(-94.833454,30.824427),77351=>array(-94.817231,30.717816),77354=>array(-95.647214,30.216858),77355=>array(-95.74926,30.156257),77356=>array(-95.729888,30.465662),77357=>array(-95.189761,30.161219),77358=>array(-95.436252,30.558321),77359=>array(-95.301591,30.751892),77360=>array(-95.117513,30.846249),77362=>array(-95.669154,30.160534),77363=>array(-95.84999,30.316397),77364=>array(-95.218681,30.767587),77365=>array(-95.297121,30.106685),77367=>array(-95.397909,30.857216),77368=>array(-94.82258,30.443808),77369=>array(-94.73533,30.421815),77371=>array(-94.989562,30.483532),77372=>array(-95.16446,30.23801),77373=>array(-95.383966,30.062169),77374=>array(-94.62375,30.396003),77375=>array(-95.585826,30.094886),77376=>array(-94.663769,30.443771),77377=>array(-95.681504,30.061727),77378=>array(-95.363872,30.471374),77379=>array(-95.528919,30.040876),77380=>array(-95.46836,30.136972),77381=>array(-95.50096,30.178248),77382=>array(-95.548211,30.194985),77384=>array(-95.495681,30.233845),77385=>array(-95.416291,30.188194),77386=>array(-95.356377,30.100394),77388=>array(-95.470689,30.059307),77389=>array(-95.517064,30.123428),77396=>array(-95.258689,29.944166),77401=>array(-95.460905,29.704019),77406=>array(-95.794526,29.64609),77407=>array(-95.708089,29.670004),77412=>array(-96.412132,29.553762),77414=>array(-95.868152,28.908185),77415=>array(-95.734948,28.933093),77417=>array(-95.966234,29.464406),77418=>array(-96.252942,29.987117),77419=>array(-96.254814,28.849303),77420=>array(-95.930309,29.258985),77422=>array(-95.558277,28.960572),77423=>array(-95.977102,29.848463),77426=>array(-96.258442,30.1223),77428=>array(-96.189925,28.623423),77429=>array(-95.669444,29.997775),77430=>array(-95.667662,29.259878),77432=>array(-96.188569,29.067417),77433=>array(-95.74763,29.93433),77434=>array(-96.305185,29.527955),77435=>array(-96.120409,29.515593),77436=>array(-96.234019,29.418712),77437=>array(-96.280585,29.212328),77440=>array(-96.147768,28.894647),77441=>array(-95.922239,29.670435),77442=>array(-96.506236,29.422281),77443=>array(-96.191821,29.349096),77444=>array(-95.777811,29.286377),77445=>array(-96.065554,30.099931),77446=>array(-95.990493,30.086834),77447=>array(-95.833733,30.047619),77448=>array(-96.085418,29.416447),77449=>array(-95.733756,29.837561),77450=>array(-95.742143,29.745681),77451=>array(-96.004602,29.434977),77453=>array(-95.999923,29.213766),77454=>array(-96.218695,29.522218),77455=>array(-96.426592,29.13261),77456=>array(-96.060809,29.040018),77457=>array(-95.881868,28.73116),77458=>array(-96.237096,28.951217),77459=>array(-95.530597,29.529061),77460=>array(-96.384508,29.397447),77461=>array(-95.807011,29.382583),77464=>array(-95.955277,29.592427),77465=>array(-96.2304,28.763461),77466=>array(-96.012215,29.792687),77467=>array(-96.101539,29.201173),77468=>array(-95.94109,29.132669),77469=>array(-95.680186,29.482678),77470=>array(-96.546208,29.537157),77471=>array(-95.861706,29.548404),77473=>array(-96.107713,29.795148),77474=>array(-96.181158,29.780109),77475=>array(-96.652467,29.488624),77476=>array(-95.95226,29.687606),77477=>array(-95.567968,29.62431),77478=>array(-95.605693,29.620312),77479=>array(-95.636016,29.566996),77480=>array(-95.766667,29.086319),77481=>array(-95.558148,29.473418),77482=>array(-95.903553,29.092422),77483=>array(-95.83925,28.788479),77484=>array(-95.932264,30.079593),77485=>array(-96.055105,29.632734),77486=>array(-95.683469,29.155616),77488=>array(-96.091291,29.307215),77489=>array(-95.515549,29.600434),77493=>array(-95.831456,29.853215),77494=>array(-95.829571,29.74063),77498=>array(-95.65327,29.643586),77502=>array(-95.199783,29.679518),77503=>array(-95.158895,29.703477),77504=>array(-95.18978,29.647916),77505=>array(-95.140315,29.645644),77506=>array(-95.199702,29.713919),77507=>array(-95.063488,29.624554),77510=>array(-95.087402,29.360426),77511=>array(-95.241857,29.380858),77514=>array(-94.603226,29.700296),77515=>array(-95.450088,29.174921),77517=>array(-95.131078,29.364468),77518=>array(-94.987247,29.507162),77519=>array(-94.587172,30.232894),77520=>array(-94.994123,29.733283),77521=>array(-94.970225,29.802438),77523=>array(-94.859125,29.789523),77530=>array(-95.117207,29.785907),77531=>array(-95.392183,29.046833),77532=>array(-95.057187,29.932872),77533=>array(-94.599575,30.087167),77534=>array(-95.314319,29.231528),77535=>array(-94.921994,30.054436),77536=>array(-95.121268,29.698461),77538=>array(-94.527364,29.983919),77539=>array(-95.031051,29.456766),77541=>array(-95.278251,29.021218),77545=>array(-95.474615,29.537301),77546=>array(-95.192133,29.515074),77547=>array(-95.238178,29.735876),77550=>array(-94.775768,29.310535),77551=>array(-94.83329,29.278188),77554=>array(-94.924652,29.253166),77560=>array(-94.603021,29.868546),77561=>array(-94.735446,30.166506),77562=>array(-95.050891,29.832539),77563=>array(-95.032327,29.303555),77564=>array(-94.670931,30.19127),77565=>array(-95.026393,29.535935),77566=>array(-95.475843,29.050464),77568=>array(-94.980107,29.363162),77571=>array(-95.057338,29.688431),77573=>array(-95.087307,29.50379),77575=>array(-94.733441,30.075658),77577=>array(-95.28151,29.284543),77578=>array(-95.361402,29.481461),77580=>array(-94.865324,29.871693),77581=>array(-95.279739,29.561554),77583=>array(-95.469968,29.381402),77584=>array(-95.350068,29.545325),77585=>array(-94.524753,30.295238),77586=>array(-95.036166,29.583816),77587=>array(-95.229784,29.661032),77590=>array(-94.920149,29.391397),77591=>array(-94.997254,29.399203),77597=>array(-94.702005,29.836207),77598=>array(-95.1361,29.53864),77611=>array(-93.82824,30.014437),77612=>array(-93.922373,30.401982),77613=>array(-94.360752,30.052049),77614=>array(-93.774566,30.301184),77615=>array(-94.051956,30.327002),77616=>array(-94.17932,30.566846),77617=>array(-94.520121,29.506866),77619=>array(-93.918571,29.947516),77622=>array(-94.288429,29.862143),77623=>array(-94.414427,29.560344),77624=>array(-94.291805,30.685013),77625=>array(-94.373937,30.377234),77627=>array(-94.009416,29.986791),77629=>array(-94.403073,29.97984),77630=>array(-93.864976,30.071743),77632=>array(-93.804542,30.201442),77640=>array(-93.940858,29.881613),77642=>array(-93.891921,29.95802),77650=>array(-94.685696,29.426496),77651=>array(-93.955832,29.985972),77655=>array(-93.93785,29.710502),77656=>array(-94.173656,30.414774),77657=>array(-94.197185,30.228019),77659=>array(-94.429636,30.170761),77660=>array(-94.14075,30.649823),77661=>array(-94.420716,29.751627),77662=>array(-94.018189,30.177937),77663=>array(-94.39227,30.513404),77664=>array(-94.413805,30.601435),77665=>array(-94.416117,29.812999),77701=>array(-94.105486,30.073053),77702=>array(-94.128303,30.086268),77703=>array(-94.111285,30.136892),77705=>array(-94.161175,29.898029),77706=>array(-94.173449,30.102291),77707=>array(-94.170654,30.053431),77708=>array(-94.160386,30.145017),77713=>array(-94.252206,30.065065),77801=>array(-96.362454,30.639285),77802=>array(-96.322612,30.661252),77803=>array(-96.386067,30.681053),77807=>array(-96.483601,30.677687),77808=>array(-96.312084,30.797736),77830=>array(-96.011435,30.527987),77831=>array(-95.90388,30.726709),77833=>array(-96.410272,30.215075),77835=>array(-96.588048,30.19364),77836=>array(-96.676232,30.541565),77837=>array(-96.688981,31.003109),77840=>array(-96.325984,30.609093),77845=>array(-96.272583,30.561385),77853=>array(-96.840158,30.354823),77855=>array(-96.13919,31.132442),77856=>array(-96.425786,31.0758),77857=>array(-96.706056,30.785246),77859=>array(-96.526934,30.871914),77861=>array(-96.096428,30.726087),77864=>array(-95.905344,30.953672),77865=>array(-96.22928,31.235882),77867=>array(-96.548436,30.743004),77868=>array(-96.054766,30.369294),77871=>array(-96.126916,31.064172),77872=>array(-96.146599,30.871997),77873=>array(-95.807719,30.569055),77876=>array(-95.874704,30.599232),77878=>array(-96.438114,30.471301),77879=>array(-96.497852,30.398612),77880=>array(-96.189365,30.286936),77901=>array(-96.984711,28.804947),77904=>array(-97.02035,28.938252),77905=>array(-97.043002,28.731567),77950=>array(-96.899059,28.291147),77951=>array(-96.901049,28.634388),77954=>array(-97.282413,29.097035),77957=>array(-96.689715,29.042415),77960=>array(-97.198682,28.67673),77961=>array(-96.353868,28.85788),77962=>array(-96.48981,29.020933),77963=>array(-97.405775,28.652457),77964=>array(-96.836189,29.380036),77968=>array(-96.829055,28.905088),77969=>array(-96.658931,28.775164),77970=>array(-96.428807,28.846631),77971=>array(-96.521612,28.833262),77973=>array(-96.97109,28.543661),77974=>array(-97.310298,28.891576),77975=>array(-97.083825,29.5649),77976=>array(-97.122655,28.954115),77977=>array(-96.794157,28.695562),77978=>array(-96.570992,28.667111),77979=>array(-96.609368,28.609718),77982=>array(-96.491788,28.444644),77983=>array(-96.574173,28.429626),77984=>array(-97.191865,29.453329),77987=>array(-97.075651,29.342572),77988=>array(-96.889623,28.83905),77990=>array(-96.928782,28.482983),77991=>array(-96.614555,28.798662),77993=>array(-97.428562,28.857734),77994=>array(-97.470843,29.178194),77995=>array(-97.076333,29.202338),78001=>array(-99.214344,28.293173),78002=>array(-98.737267,29.283035),78003=>array(-99.095171,29.707222),78004=>array(-98.556446,29.903262),78005=>array(-98.851298,28.941736),78006=>array(-98.706275,29.859217),78007=>array(-98.368762,28.498),78008=>array(-98.281256,28.721144),78009=>array(-98.886655,29.357251),78010=>array(-99.037691,29.902027),78011=>array(-98.717634,28.790915),78012=>array(-98.48596,28.764536),78013=>array(-98.904706,29.972312),78014=>array(-99.13556,28.375283),78015=>array(-98.65027,29.747683),78016=>array(-98.967448,29.17158),78017=>array(-99.191188,28.703396),78019=>array(-99.399193,28.041684),78021=>array(-98.820347,28.496434),78022=>array(-98.143051,28.257475),78023=>array(-98.746764,29.609914),78024=>array(-99.507979,30.026917),78025=>array(-99.282981,30.081841),78026=>array(-98.610076,28.821017),78027=>array(-98.539209,29.969074),78028=>array(-99.163039,30.036701),78029=>array(-99.345011,30.159136),78039=>array(-98.834802,29.312148),78040=>array(-99.502143,27.513811),78041=>array(-99.461989,27.545404),78043=>array(-99.267161,27.556989),78044=>array(-99.126085,27.751747),78045=>array(-99.685482,27.833509),78046=>array(-99.350596,27.373543),78050=>array(-98.48181,29.070547),78052=>array(-98.776694,29.203679),78055=>array(-99.331413,29.830327),78056=>array(-98.933944,29.537033),78057=>array(-99.001103,29.037278),78058=>array(-99.628211,30.095115),78059=>array(-98.842165,29.1998),78060=>array(-98.107053,28.446801),78061=>array(-99.141829,28.890855),78063=>array(-98.911216,29.689692),78064=>array(-98.428996,28.935779),78065=>array(-98.642309,29.079849),78066=>array(-98.853494,29.501055),78067=>array(-99.33083,27.128233),78069=>array(-98.680853,29.186232),78070=>array(-98.390967,29.89476),78071=>array(-98.226391,28.470281),78072=>array(-98.573186,28.310347),78073=>array(-98.622442,29.243915),78075=>array(-98.369358,28.622685),78076=>array(-99.162765,26.930929),78101=>array(-98.238308,29.353553),78102=>array(-97.71062,28.407712),78104=>array(-97.761958,28.522541),78107=>array(-97.579237,28.568278),78108=>array(-98.220552,29.575004),78109=>array(-98.291474,29.487774),78112=>array(-98.370855,29.214414),78113=>array(-98.240425,28.867033),78114=>array(-98.208661,29.114718),78116=>array(-97.759342,29.110831),78117=>array(-97.923572,28.938338),78118=>array(-98.062937,28.800642),78119=>array(-97.894958,28.733411),78121=>array(-98.10703,29.350393),78122=>array(-97.735834,29.428917),78123=>array(-98.047576,29.600453),78124=>array(-98.146886,29.557266),78125=>array(-97.957001,28.5409),78130=>array(-98.070726,29.696878),78132=>array(-98.190462,29.758823),78133=>array(-98.244624,29.889085),78140=>array(-97.765502,29.333756),78141=>array(-97.632623,28.914138),78142=>array(-97.810515,28.536632),78143=>array(-97.851216,29.258664),78144=>array(-97.887161,28.952237),78145=>array(-97.994125,28.645184),78146=>array(-97.838545,28.603142),78147=>array(-98.080406,29.073446),78148=>array(-98.295356,29.543813),78150=>array(-98.277499,29.525969),78151=>array(-97.705273,28.864482),78152=>array(-98.205116,29.43659),78154=>array(-98.262642,29.547068),78155=>array(-97.937078,29.54277),78159=>array(-97.590672,29.231774),78160=>array(-97.922547,29.241795),78161=>array(-98.057016,29.293499),78162=>array(-97.773497,28.589962),78163=>array(-98.453225,29.769466),78164=>array(-97.520734,28.98256),78201=>array(-98.528889,29.468413),78202=>array(-98.460881,29.428169),78203=>array(-98.459123,29.4151),78204=>array(-98.505028,29.404404),78205=>array(-98.48642,29.423945),78207=>array(-98.525943,29.422404),78208=>array(-98.458718,29.43993),78209=>array(-98.456235,29.488906),78210=>array(-98.464401,29.395776),78211=>array(-98.570052,29.342535),78212=>array(-98.493653,29.464611),78213=>array(-98.52303,29.516401),78214=>array(-98.470039,29.324786),78215=>array(-98.480515,29.44123),78216=>array(-98.487882,29.537264),78217=>array(-98.415198,29.538074),78218=>array(-98.397127,29.49163),78219=>array(-98.387361,29.44665),78220=>array(-98.394314,29.418151),78221=>array(-98.479052,29.27828),78222=>array(-98.371889,29.35494),78223=>array(-98.390911,29.311912),78224=>array(-98.531136,29.305467),78225=>array(-98.526019,29.387986),78226=>array(-98.56994,29.383778),78227=>array(-98.630303,29.406624),78228=>array(-98.571279,29.460646),78229=>array(-98.569451,29.501708),78230=>array(-98.556564,29.545289),78231=>array(-98.541904,29.578541),78232=>array(-98.474585,29.588638),78233=>array(-98.360283,29.556038),78234=>array(-98.438554,29.460597),78235=>array(-98.443874,29.345246),78236=>array(-98.618734,29.391283),78237=>array(-98.570938,29.421133),78238=>array(-98.617755,29.471464),78239=>array(-98.362961,29.518637),78240=>array(-98.606564,29.52502),78242=>array(-98.607054,29.3504),78243=>array(-98.593411,29.371436),78244=>array(-98.348083,29.474147),78245=>array(-98.730674,29.400889),78247=>array(-98.406811,29.585862),78248=>array(-98.525262,29.590028),78249=>array(-98.619211,29.56527),78250=>array(-98.664636,29.503453),78251=>array(-98.676785,29.462006),78252=>array(-98.705628,29.341337),78253=>array(-98.79771,29.468805),78254=>array(-98.734752,29.537782),78255=>array(-98.656213,29.65235),78256=>array(-98.624048,29.624725),78257=>array(-98.583454,29.660485),78258=>array(-98.497426,29.634097),78259=>array(-98.427068,29.627214),78260=>array(-98.486728,29.697453),78261=>array(-98.401812,29.690514),78263=>array(-98.304962,29.364762),78264=>array(-98.492701,29.200063),78266=>array(-98.33912,29.6562),78330=>array(-97.915651,27.742626),78332=>array(-98.135459,27.725998),78335=>array(-97.092196,27.873028),78336=>array(-97.177776,27.926913),78338=>array(-97.773774,26.911014),78339=>array(-97.792233,27.805059),78340=>array(-97.19689,28.120701),78341=>array(-98.496692,27.634419),78342=>array(-98.07572,27.65992),78343=>array(-97.75143,27.622119),78344=>array(-98.864745,27.480039),78349=>array(-98.285472,27.373485),78351=>array(-97.759701,27.673154),78352=>array(-97.679027,27.962924),78353=>array(-98.216213,26.880517),78355=>array(-98.207295,27.194074),78357=>array(-98.62897,27.835918),78358=>array(-97.042224,28.067971),78359=>array(-97.287034,27.923819),78361=>array(-98.789966,27.100448),78362=>array(-97.202971,27.867937),78363=>array(-97.865597,27.444204),78368=>array(-97.808031,28.103247),78369=>array(-98.996708,27.36513),78370=>array(-97.598732,27.948129),78371=>array(-98.946373,27.615256),78372=>array(-98.060187,27.986244),78373=>array(-97.114983,27.777437),78374=>array(-97.384238,27.892132),78375=>array(-98.171284,27.396308),78376=>array(-98.514272,27.421353),78377=>array(-97.154755,28.351725),78379=>array(-97.780427,27.306614),78380=>array(-97.742139,27.791253),78382=>array(-97.06207,28.132627),78383=>array(-97.962915,28.093161),78384=>array(-98.385775,27.849558),78385=>array(-97.90137,27.139147),78387=>array(-97.553013,28.121597),78389=>array(-97.650894,28.246189),78390=>array(-97.327442,27.997261),78391=>array(-97.708393,28.179576),78393=>array(-97.382251,28.187086),78401=>array(-97.399067,27.797802),78402=>array(-97.392456,27.819419),78404=>array(-97.399135,27.768021),78405=>array(-97.438774,27.77425),78406=>array(-97.518791,27.771237),78407=>array(-97.440395,27.810698),78408=>array(-97.446828,27.794993),78409=>array(-97.522886,27.809474),78410=>array(-97.596306,27.838247),78411=>array(-97.385247,27.729894),78412=>array(-97.345045,27.703573),78413=>array(-97.406289,27.683277),78414=>array(-97.371365,27.662514),78415=>array(-97.479816,27.65787),78416=>array(-97.436501,27.752006),78417=>array(-97.46682,27.73963),78418=>array(-97.269242,27.627121),78419=>array(-97.269443,27.695151),78501=>array(-98.239592,26.215816),78503=>array(-98.2487,26.162344),78504=>array(-98.23657,26.271965),78516=>array(-98.121312,26.144539),78520=>array(-97.550453,25.963264),78521=>array(-97.317944,25.943923),78526=>array(-97.443582,25.988942),78535=>array(-97.743596,26.252832),78536=>array(-98.451125,26.649282),78537=>array(-98.058657,26.1619),78538=>array(-97.98028,26.374541),78539=>array(-98.183295,26.280689),78541=>array(-98.276935,26.450369),78542=>array(-98.092002,26.451477),78543=>array(-97.999973,26.297375),78545=>array(-99.119871,26.587174),78548=>array(-98.654824,26.274827),78549=>array(-98.035943,26.454669),78550=>array(-97.667502,26.255523),78552=>array(-97.750546,26.196865),78557=>array(-98.241746,26.111189),78558=>array(-98.039361,26.307831),78559=>array(-97.831112,26.148831),78560=>array(-98.494493,26.242813),78561=>array(-97.921496,26.477435),78562=>array(-97.902485,26.297669),78563=>array(-98.260022,26.654283),78564=>array(-99.103088,26.678196),78565=>array(-98.567191,26.253727),78566=>array(-97.370376,26.148406),78567=>array(-97.740451,26.052713),78569=>array(-97.74357,26.368214),78570=>array(-97.912597,26.174517),78572=>array(-98.376166,26.228735),78573=>array(-98.299977,26.296434),78574=>array(-98.370054,26.318913),78575=>array(-97.526109,26.02176),78576=>array(-98.476164,26.321607),78577=>array(-98.189714,26.149684),78578=>array(-97.312767,26.051625),78579=>array(-97.96214,26.083177),78580=>array(-97.738953,26.48774),78582=>array(-98.715803,26.546335),78583=>array(-97.489015,26.261363),78584=>array(-98.965905,26.573299),78585=>array(-99.112986,26.53255),78586=>array(-97.629292,26.106086),78588=>array(-98.397207,26.737863),78589=>array(-98.154843,26.167835),78590=>array(-97.647775,26.508366),78591=>array(-98.521632,26.582929),78592=>array(-97.846971,26.062006),78593=>array(-97.823524,26.275747),78594=>array(-97.794892,26.345257),78595=>array(-98.54548,26.291399),78596=>array(-97.989155,26.158622),78597=>array(-97.271778,26.235),78598=>array(-97.442331,26.569308),78602=>array(-97.32771,30.12382),78605=>array(-98.04518,30.773295),78606=>array(-98.476159,30.083786),78607=>array(-98.477388,30.821753),78608=>array(-97.934579,30.936006),78609=>array(-98.438345,30.759723),78610=>array(-97.838012,30.078514),78611=>array(-98.283025,30.800718),78612=>array(-97.495104,30.094098),78613=>array(-97.8242,30.503949),78614=>array(-97.587174,29.41041),78615=>array(-97.384111,30.465454),78616=>array(-97.568294,29.940066),78617=>array(-97.607312,30.150985),78618=>array(-99.156225,30.465163),78619=>array(-98.033573,30.111915),78620=>array(-98.134815,30.224134),78621=>array(-97.361224,30.338584),78622=>array(-97.775837,29.754521),78623=>array(-98.228231,29.971139),78624=>array(-98.876683,30.280938),78626=>array(-97.618195,30.659122),78628=>array(-97.753177,30.647924),78629=>array(-97.448924,29.476954),78631=>array(-99.30658,30.33977),78632=>array(-97.470663,29.69611),78633=>array(-97.758071,30.74766),78634=>array(-97.546124,30.560042),78635=>array(-98.566548,30.182914),78636=>array(-98.423509,30.315196),78638=>array(-97.785202,29.659595),78639=>array(-98.442748,30.672818),78640=>array(-97.828207,29.999103),78641=>array(-97.907897,30.562551),78642=>array(-97.941426,30.69088),78643=>array(-98.689889,30.688543),78644=>array(-97.676772,29.871471),78645=>array(-97.971806,30.449996),78648=>array(-97.633555,29.690184),78650=>array(-97.218899,30.303885),78652=>array(-97.874687,30.132806),78653=>array(-97.523512,30.339696),78654=>array(-98.208732,30.581216),78655=>array(-97.835042,29.816002),78656=>array(-97.807296,29.904758),78657=>array(-98.377752,30.5309),78659=>array(-97.125389,30.207417),78660=>array(-97.59458,30.438534),78661=>array(-97.756438,29.728332),78662=>array(-97.411709,29.932072),78663=>array(-98.359569,30.402261),78664=>array(-97.647206,30.501747),78665=>array(-97.64559,30.543356),78666=>array(-97.966164,29.880162),78669=>array(-98.112655,30.430044),78670=>array(-97.81674,29.77395),78671=>array(-98.629253,30.219091),78672=>array(-98.469511,30.858836),78675=>array(-98.708714,30.437069),78676=>array(-98.142776,30.034449),78677=>array(-97.580206,29.349952),78681=>array(-97.725618,30.534355),78701=>array(-97.742589,30.270569),78702=>array(-97.714483,30.263378),78703=>array(-97.76605,30.293268),78704=>array(-97.765081,30.243032),78705=>array(-97.738517,30.294333),78712=>array(-97.731003,30.282173),78717=>array(-97.748312,30.492379),78719=>array(-97.684275,30.183798),78721=>array(-97.683557,30.269969),78722=>array(-97.714696,30.289963),78723=>array(-97.685722,30.304265),78724=>array(-97.617767,30.297099),78725=>array(-97.608521,30.230283),78726=>array(-97.840085,30.430749),78727=>array(-97.717796,30.429937),78728=>array(-97.689368,30.452674),78729=>array(-97.755344,30.458396),78730=>array(-97.835844,30.370456),78731=>array(-97.768136,30.348236),78732=>array(-97.895023,30.377889),78733=>array(-97.884751,30.321025),78734=>array(-97.951209,30.37835),78735=>array(-97.86919,30.268138),78736=>array(-97.959435,30.261084),78737=>array(-97.956989,30.190321),78738=>array(-97.958224,30.319748),78739=>array(-97.888662,30.178419),78741=>array(-97.714082,30.230475),78742=>array(-97.6592,30.242354),78744=>array(-97.725888,30.177014),78745=>array(-97.79742,30.206844),78746=>array(-97.80835,30.295424),78747=>array(-97.739969,30.126966),78748=>array(-97.823998,30.16711),78749=>array(-97.856006,30.216168),78750=>array(-97.802545,30.418557),78751=>array(-97.722757,30.310783),78752=>array(-97.704294,30.331818),78753=>array(-97.673467,30.382481),78754=>array(-97.644682,30.355657),78756=>array(-97.740167,30.32223),78757=>array(-97.732571,30.351538),78758=>array(-97.706853,30.38798),78759=>array(-97.761064,30.402654),78801=>array(-99.898132,29.362904),78802=>array(-100.01587,29.151012),78827=>array(-99.733002,28.421951),78828=>array(-100.01853,29.867563),78829=>array(-99.562652,28.888748),78830=>array(-99.50848,28.524903),78832=>array(-100.439985,29.395621),78833=>array(-100.078588,29.6747),78834=>array(-99.918204,28.453936),78836=>array(-99.704277,28.301642),78837=>array(-101.212436,29.83722),78838=>array(-99.746893,29.536636),78839=>array(-99.823476,28.718319),78840=>array(-100.881337,29.729903),78843=>array(-100.777486,29.358523),78850=>array(-99.329182,29.285285),78851=>array(-101.970461,30.028067),78852=>array(-100.311368,28.745217),78860=>array(-100.276888,28.476396),78861=>array(-99.141134,29.427375),78870=>array(-99.630829,29.303817),78871=>array(-101.654794,30.006991),78872=>array(-99.865266,28.926375),78873=>array(-99.727201,29.815503),78877=>array(-100.593386,28.951173),78879=>array(-99.682471,29.64447),78880=>array(-100.286076,29.988092),78881=>array(-99.529697,29.38367),78883=>array(-99.316592,29.678291),78884=>array(-99.456287,29.606582),78885=>array(-99.54045,29.80869),78886=>array(-99.168888,29.135837),78931=>array(-96.451051,30.024253),78932=>array(-96.705271,30.164577),78933=>array(-96.359065,29.790645),78934=>array(-96.557401,29.693447),78935=>array(-96.42546,29.695979),78938=>array(-96.686537,29.806557),78940=>array(-96.662607,29.930627),78941=>array(-97.15845,29.727617),78942=>array(-96.923038,30.167624),78943=>array(-96.615598,29.708998),78944=>array(-96.507905,30.014637),78945=>array(-96.889562,29.912324),78946=>array(-96.778992,30.188404),78947=>array(-97.035831,30.420154),78948=>array(-96.976365,30.321105),78949=>array(-97.087403,29.833182),78950=>array(-96.482617,29.904948),78951=>array(-96.824373,29.587283),78953=>array(-97.357996,29.844013),78954=>array(-96.699188,30.043016),78956=>array(-96.933605,29.686278),78957=>array(-97.182148,30.013899),78959=>array(-97.301328,29.700745),78962=>array(-96.732546,29.65846),78963=>array(-97.028763,29.91692),79001=>array(-102.794987,35.339757),79003=>array(-100.068724,35.581845),79005=>array(-100.507442,36.380233),79007=>array(-101.398793,35.706837),79009=>array(-102.879628,34.533282),79010=>array(-102.140605,35.450973),79011=>array(-100.231215,35.639883),79012=>array(-102.109125,35.270514),79013=>array(-102.00311,36.038774),79014=>array(-100.285338,35.908257),79015=>array(-101.916036,34.937472),79016=>array(-101.91874,34.983347),79018=>array(-102.213391,35.748254),79019=>array(-101.394035,35.0071),79021=>array(-102.027747,33.984844),79022=>array(-102.603518,36.098587),79024=>array(-100.369084,36.439773),79025=>array(-102.205885,34.940988),79027=>array(-102.419542,34.408048),79029=>array(-102.025897,35.901966),79031=>array(-102.449583,34.270256),79032=>array(-101.941418,34.282885),79033=>array(-100.983997,36.33004),79034=>array(-100.157216,36.359771),79035=>array(-102.784877,34.690472),79036=>array(-101.547377,35.612828),79039=>array(-101.096311,35.259837),79040=>array(-101.559664,36.324086),79041=>array(-101.931966,34.043255),79042=>array(-101.906795,34.741334),79043=>array(-102.131315,34.370661),79044=>array(-102.367722,35.863447),79045=>array(-102.554528,34.914806),79046=>array(-100.121753,36.163536),79051=>array(-102.259356,36.483086),79052=>array(-101.742898,34.361819),79053=>array(-102.579402,34.408017),79054=>array(-100.821516,35.374819),79056=>array(-100.211576,36.223812),79057=>array(-100.642178,35.246),79058=>array(-101.855136,35.5795),79059=>array(-100.765905,35.830763),79061=>array(-100.442492,35.524915),79062=>array(-101.529403,36.030624),79063=>array(-102.09627,34.531086),79064=>array(-102.119153,34.195479),79065=>array(-100.906572,35.541234),79068=>array(-101.444262,35.346662),79070=>array(-100.795007,36.270658),79072=>array(-101.73385,34.169757),79078=>array(-101.580421,35.720328),79079=>array(-100.242918,35.20898),79080=>array(-101.213702,35.74865),79081=>array(-101.218409,36.24162),79082=>array(-102.287745,34.224256),79083=>array(-101.515093,35.886172),79084=>array(-101.996725,36.276881),79085=>array(-102.514426,34.740717),79086=>array(-101.768389,36.04178),79087=>array(-102.911789,36.287379),79088=>array(-101.697218,34.580896),79091=>array(-102.126227,34.897796),79092=>array(-102.446391,35.312969),79093=>array(-101.033947,36.289912),79094=>array(-101.5097,34.840077),79095=>array(-100.20826,34.90404),79096=>array(-100.196706,35.437391),79097=>array(-101.17836,35.435886),79098=>array(-102.216656,35.15335),79101=>array(-101.839602,35.20603),79102=>array(-101.86625,35.19634),79103=>array(-101.794475,35.177308),79104=>array(-101.788728,35.202967),79105=>array(-101.820831,35.691238),79106=>array(-101.895003,35.203066),79107=>array(-101.802502,35.230592),79108=>array(-101.690933,35.307898),79109=>array(-101.886423,35.166416),79110=>array(-101.878122,35.144451),79111=>array(-101.708143,35.220537),79118=>array(-101.739911,35.106367),79119=>array(-102.017887,35.109084),79121=>array(-101.92975,35.174715),79124=>array(-101.965268,35.262174),79201=>array(-100.280962,34.437766),79220=>array(-100.794632,33.753501),79225=>array(-99.515204,34.255931),79226=>array(-100.994549,34.90076),79227=>array(-99.773497,33.899813),79229=>array(-100.676563,33.665706),79230=>array(-100.069222,34.702273),79231=>array(-101.070036,33.906379),79233=>array(-100.525648,34.520996),79234=>array(-100.935228,34.230443),79235=>array(-101.246139,33.961846),79236=>array(-100.384217,33.710684),79237=>array(-100.645545,34.918283),79239=>array(-100.763893,34.655623),79240=>array(-100.779931,34.886066),79241=>array(-101.384912,34.178502),79243=>array(-100.990114,33.774479),79244=>array(-100.843759,34.030397),79245=>array(-100.512868,34.857258),79247=>array(-99.409069,34.329813),79248=>array(-100.287247,33.994322),79250=>array(-101.594755,33.877689),79251=>array(-100.451566,34.943421),79252=>array(-99.818916,34.304335),79255=>array(-101.050762,34.349913),79256=>array(-100.745875,33.900389),79257=>array(-101.287161,34.457478),79258=>array(-101.288735,34.228291),79259=>array(-100.472927,34.398492),79261=>array(-100.809848,34.447226),79311=>array(-101.881538,33.857882),79312=>array(-102.419954,34.019064),79313=>array(-102.162291,33.804892),79314=>array(-103.014509,33.5849),79316=>array(-102.326183,33.137907),79322=>array(-101.180116,33.634566),79323=>array(-102.869403,32.945746),79324=>array(-102.68249,33.897884),79325=>array(-102.943742,34.424608),79326=>array(-102.216144,34.077938),79329=>array(-101.674963,33.715143),79330=>array(-101.224946,33.040784),79331=>array(-102.00957,32.695214),79336=>array(-102.398414,33.603903),79339=>array(-102.336677,33.886503),79342=>array(-102.3366,32.908208),79343=>array(-101.531037,33.658671),79344=>array(-102.930411,33.844961),79345=>array(-102.33135,33.337542),79346=>array(-102.824958,33.648086),79347=>array(-102.78941,34.17256),79350=>array(-101.825789,33.73182),79351=>array(-101.764414,32.92701),79353=>array(-102.581946,33.783518),79355=>array(-102.876731,33.181664),79356=>array(-101.339267,33.28589),79357=>array(-101.404701,33.611886),79358=>array(-102.195033,33.442185),79359=>array(-102.586555,32.971141),79360=>array(-102.724661,32.68982),79363=>array(-102.043175,33.706516),79364=>array(-101.644174,33.452572),79366=>array(-101.685343,33.530315),79367=>array(-102.190786,33.621453),79369=>array(-102.145171,33.955743),79370=>array(-100.907042,33.506923),79371=>array(-102.966213,33.952621),79372=>array(-102.488401,33.434243),79373=>array(-101.832563,33.173872),79376=>array(-102.673107,33.23386),79377=>array(-102.133506,32.929648),79378=>array(-102.474677,33.058133),79379=>array(-102.646422,33.510507),79380=>array(-102.332216,33.735629),79381=>array(-101.769604,33.315959),79382=>array(-102.014055,33.455287),79401=>array(-101.850444,33.588771),79403=>array(-101.77545,33.643503),79404=>array(-101.793717,33.527702),79406=>array(-101.878382,33.585909),79407=>array(-102.079243,33.566862),79410=>array(-101.891011,33.570071),79411=>array(-101.857733,33.570034),79412=>array(-101.856516,33.546383),79413=>array(-101.885644,33.547402),79414=>array(-101.92023,33.547794),79415=>array(-101.897836,33.701386),79416=>array(-101.982772,33.600102),79423=>array(-101.855463,33.439976),79424=>array(-101.94769,33.468334),79501=>array(-99.905394,32.747863),79502=>array(-100.245133,33.183064),79503=>array(-99.694492,32.868619),79504=>array(-99.350571,32.335802),79505=>array(-99.811884,33.577449),79506=>array(-100.313408,32.106426),79508=>array(-99.826041,32.274081),79510=>array(-99.518879,32.2664),79511=>array(-101.250314,32.415915),79512=>array(-100.918356,32.314505),79517=>array(-101.246784,32.879511),79518=>array(-100.714732,33.341053),79519=>array(-99.69465,32.052075),79520=>array(-100.124032,32.857004),79521=>array(-99.650389,33.122685),79525=>array(-99.830642,32.630473),79526=>array(-100.71688,32.636295),79527=>array(-101.059442,32.593166),79528=>array(-100.893642,33.192636),79529=>array(-99.853667,33.431837),79530=>array(-99.753027,32.120249),79532=>array(-100.711396,32.404869),79533=>array(-99.551961,32.85713),79534=>array(-100.211993,32.76433),79535=>array(-100.479835,32.223438),79536=>array(-100.032723,32.473621),79537=>array(-100.210748,32.291861),79538=>array(-99.684164,31.970613),79539=>array(-99.876875,33.361114),79540=>array(-100.040999,33.169164),79541=>array(-99.810552,32.150183),79543=>array(-100.407773,32.71433),79544=>array(-99.8529,33.301509),79545=>array(-100.573539,32.415212),79546=>array(-100.498206,32.891818),79547=>array(-99.905443,33.197744),79548=>array(-99.918963,33.049768),79549=>array(-100.841389,32.887589),79553=>array(-99.850964,32.940911),79556=>array(-100.357939,32.458787),79560=>array(-100.212875,32.664859),79561=>array(-100.195108,32.515445),79562=>array(-99.866451,32.236251),79563=>array(-99.90623,32.415823),79565=>array(-101.087816,32.397372),79566=>array(-100.132071,32.115508),79567=>array(-99.950305,31.97243),79601=>array(-99.665323,32.576489),79602=>array(-99.667488,32.335677),79603=>array(-99.927724,32.333551),79605=>array(-99.781827,32.434599),79606=>array(-99.817314,32.362783),79607=>array(-99.832641,32.43035),79699=>array(-99.715894,32.462235),79701=>array(-102.081464,31.992384),79703=>array(-102.132366,31.979427),79705=>array(-102.059634,32.051211),79706=>array(-102.005075,31.848988),79707=>array(-102.20166,32.053604),79713=>array(-101.754488,32.489818),79714=>array(-102.697303,32.335729),79718=>array(-103.759065,31.004969),79719=>array(-103.404137,31.460655),79720=>array(-101.47264,32.253541),79730=>array(-103.085134,31.169523),79731=>array(-102.487774,31.422796),79733=>array(-101.365434,32.102911),79734=>array(-103.96015,30.686139),79735=>array(-102.790792,30.747459),79738=>array(-101.484963,32.748999),79739=>array(-101.501775,31.763075),79741=>array(-102.630882,31.969312),79742=>array(-102.868447,31.34204),79743=>array(-102.596253,31.186888),79744=>array(-101.970268,30.92201),79745=>array(-103.055986,31.831415),79748=>array(-101.647745,32.408946),79749=>array(-101.871764,32.289048),79752=>array(-102.162001,31.227747),79754=>array(-103.599914,31.803547),79755=>array(-101.918007,31.517628),79756=>array(-102.844644,31.540255),79758=>array(-102.312423,32.001129),79759=>array(-102.632933,31.799171),79761=>array(-102.350647,31.855051),79762=>array(-102.357792,31.925304),79763=>array(-102.47409,31.799158),79764=>array(-102.537544,31.866262),79765=>array(-102.262348,31.906736),79766=>array(-102.413607,31.725171),79770=>array(-103.933311,31.875118),79772=>array(-103.627309,31.422363),79777=>array(-103.161046,31.484586),79778=>array(-101.923824,31.176246),79780=>array(-103.59209,31.06196),79781=>array(-101.78453,30.596998),79782=>array(-101.836937,32.155614),79783=>array(-102.042298,32.321673),79785=>array(-103.906799,31.327482),79788=>array(-102.97685,31.582473),79789=>array(-103.138992,31.696251),79821=>array(-106.596021,31.983697),79830=>array(-103.22236,29.802094),79831=>array(-103.325765,30.429399),79834=>array(-103.275783,29.160935),79835=>array(-106.589725,31.936406),79836=>array(-106.198866,31.57255),79837=>array(-105.286539,32.23357),79838=>array(-106.168049,31.482839),79839=>array(-105.902546,31.333177),79842=>array(-103.11774,30.085732),79843=>array(-104.005761,30.285296),79845=>array(-104.519139,29.888046),79846=>array(-103.990465,29.387655),79847=>array(-105.05386,31.835363),79848=>array(-102.301073,30.261302),79849=>array(-106.250112,31.560649),79851=>array(-105.311629,31.278347),79852=>array(-103.617232,29.39623),79853=>array(-106.064089,31.434001),79854=>array(-104.660157,30.59127),79855=>array(-104.624514,31.09348),79901=>array(-106.478578,31.760618),79902=>array(-106.498544,31.783715),79903=>array(-106.441937,31.786182),79904=>array(-106.447636,31.852764),79905=>array(-106.426202,31.766054),79906=>array(-106.404743,31.810651),79907=>array(-106.326563,31.707231),79908=>array(-106.380388,31.857201),79911=>array(-106.542594,31.892468),79912=>array(-106.534316,31.848583),79915=>array(-106.371426,31.746041),79916=>array(-106.41803,31.814157),79920=>array(-106.451727,31.824725),79922=>array(-106.561208,31.814872),79924=>array(-106.413245,31.902442),79925=>array(-106.356829,31.796943),79927=>array(-106.272524,31.644008),79928=>array(-106.155823,31.628665),79930=>array(-106.483334,31.829304),79932=>array(-106.607988,31.874964),79934=>array(-106.433518,31.95067),79935=>array(-106.329332,31.767715),79936=>array(-106.296976,31.776593),79938=>array(-105.971362,31.829712),79942=>array(-101.331239,30.575618),80002=>array(-105.105292,39.794822),80003=>array(-105.063525,39.825373),80004=>array(-105.122787,39.816686),80005=>array(-105.130234,39.85108),80007=>array(-105.19237,39.862538),80010=>array(-104.862881,39.739249),80011=>array(-104.782261,39.738841),80012=>array(-104.837652,39.699705),80013=>array(-104.765655,39.661408),80014=>array(-104.838067,39.663558),80015=>array(-104.779035,39.62732),80016=>array(-104.705114,39.602253),80017=>array(-104.78546,39.697928),80018=>array(-104.68974,39.688002),80019=>array(-104.70217,39.786982),80020=>array(-105.074287,39.930782),80021=>array(-105.113724,39.890663),80022=>array(-104.798561,39.879644),80023=>array(-105.009387,39.975858),80024=>array(-104.917925,39.843876),80025=>array(-105.283939,39.939842),80026=>array(-105.099734,40.01225),80027=>array(-105.159078,39.950948),80030=>array(-105.03747,39.830822),80031=>array(-105.038674,39.873833),80033=>array(-105.103009,39.772326),80045=>array(-104.838313,39.747876),80101=>array(-104.01917,39.36503),80102=>array(-104.442995,39.745605),80103=>array(-104.142596,39.78001),80104=>array(-104.830365,39.293814),80105=>array(-103.968891,39.668495),80106=>array(-104.515915,39.186147),80107=>array(-104.572571,39.409358),80108=>array(-104.852987,39.445501),80109=>array(-104.901375,39.364266),80110=>array(-105.011411,39.645994),80111=>array(-104.877957,39.613005),80112=>array(-104.857645,39.57574),80113=>array(-104.965111,39.644445),80116=>array(-104.709712,39.319995),80117=>array(-104.342891,39.369598),80118=>array(-104.905265,39.192431),80120=>array(-105.01146,39.593836),80121=>array(-104.95273,39.610992),80122=>array(-104.954917,39.580309),80123=>array(-105.069449,39.61601),80124=>array(-104.891965,39.53207),80125=>array(-105.052316,39.485069),80126=>array(-104.958557,39.540572),80127=>array(-105.164662,39.530599),80128=>array(-105.078981,39.563846),80129=>array(-105.010351,39.545535),80130=>array(-104.923416,39.530958),80131=>array(-105.007544,39.47644),80132=>array(-104.84653,39.09941),80133=>array(-104.975692,39.095018),80134=>array(-104.778638,39.4855),80135=>array(-105.157637,39.253871),80136=>array(-104.280905,39.784898),80137=>array(-104.598055,39.771182),80138=>array(-104.670906,39.51766),80202=>array(-104.997633,39.751907),80203=>array(-104.98265,39.731686),80204=>array(-105.020394,39.73484),80205=>array(-104.962829,39.758857),80206=>array(-104.952618,39.730292),80207=>array(-104.916636,39.762296),80209=>array(-104.96575,39.706581),80210=>array(-104.962315,39.676626),80211=>array(-105.019736,39.767444),80212=>array(-105.048027,39.772047),80214=>array(-105.069027,39.743291),80215=>array(-105.115977,39.744773),80216=>array(-104.957249,39.78728),80218=>array(-104.970673,39.731082),80219=>array(-105.035601,39.695293),80220=>array(-104.916597,39.733812),80221=>array(-105.011035,39.817067),80222=>array(-104.927899,39.671027),80223=>array(-105.003843,39.695794),80224=>array(-104.911337,39.687765),80226=>array(-105.091519,39.712845),80227=>array(-105.089824,39.666295),80228=>array(-105.173161,39.694967),80229=>array(-104.957119,39.855318),80230=>array(-104.890279,39.719464),80231=>array(-104.887803,39.671421),80232=>array(-105.090234,39.686866),80233=>array(-104.946561,39.899671),80234=>array(-105.002506,39.909994),80235=>array(-105.08835,39.649838),80236=>array(-105.039573,39.651675),80237=>array(-104.901711,39.639871),80238=>array(-104.882483,39.771658),80239=>array(-104.838551,39.787628),80241=>array(-104.954808,39.929518),80246=>array(-104.930842,39.705197),80247=>array(-104.878815,39.698327),80249=>array(-104.695551,39.851866),80260=>array(-105.006059,39.866918),80264=>array(-104.985482,39.742477),80290=>array(-104.986754,39.744092),80293=>array(-104.989935,39.746253),80294=>array(-104.98927,39.749452),80301=>array(-105.201421,40.049468),80302=>array(-105.372017,40.039191),80303=>array(-105.209276,39.973222),80304=>array(-105.291263,40.045421),80305=>array(-105.248158,39.975334),80310=>array(-105.263655,40.002148),80401=>array(-105.236031,39.718726),80403=>array(-105.29305,39.834622),80419=>array(-105.202819,39.728392),80420=>array(-106.116959,39.324867),80421=>array(-105.502065,39.462296),80422=>array(-105.528825,39.870497),80423=>array(-106.583549,39.893953),80424=>array(-106.004129,39.473334),80425=>array(-105.205825,39.348402),80426=>array(-107.000453,39.912085),80427=>array(-105.49496,39.780281),80428=>array(-106.925249,40.843694),80432=>array(-105.796907,39.222376),80433=>array(-105.262386,39.477721),80434=>array(-106.286789,40.843252),80435=>array(-105.934581,39.573678),80436=>array(-105.64221,39.781638),80438=>array(-105.784735,39.763029),80439=>array(-105.440245,39.634422),80440=>array(-105.969036,39.230807),80442=>array(-105.889416,39.924007),80443=>array(-106.17275,39.543602),80444=>array(-105.751005,39.6084),80446=>array(-105.949368,40.176165),80447=>array(-105.762482,40.296378),80448=>array(-105.649921,39.423128),80449=>array(-105.856797,38.976576),80451=>array(-106.073143,40.098446),80452=>array(-105.670791,39.689403),80453=>array(-105.242573,39.662687),80454=>array(-105.242263,39.628546),80455=>array(-105.398382,40.094826),80456=>array(-105.536533,39.24737),80457=>array(-105.290978,39.64825),80459=>array(-106.454609,40.177204),80461=>array(-106.313157,39.231742),80463=>array(-106.720487,39.970544),80465=>array(-105.205578,39.609086),80466=>array(-105.541527,39.976421),80467=>array(-106.826395,40.207641),80468=>array(-106.122681,39.951923),80469=>array(-106.968565,40.200081),80470=>array(-105.324766,39.379452),80471=>array(-105.421253,39.935251),80473=>array(-106.134341,40.416344),80475=>array(-105.570418,39.455282),80476=>array(-105.834343,39.670628),80477=>array(-106.829354,40.486391),80478=>array(-105.852772,40.029019),80479=>array(-106.814497,40.035912),80480=>array(-106.341566,40.672888),80481=>array(-105.576764,40.101411),80482=>array(-105.785558,39.890695),80483=>array(-106.928985,40.096085),80487=>array(-106.850131,40.540946),80488=>array(-106.818184,40.448703),80497=>array(-106.000063,39.670756),80498=>array(-106.27053,39.746631),80501=>array(-105.103179,40.164837),80503=>array(-105.210376,40.169014),80504=>array(-105.030087,40.163388),80510=>array(-105.606668,40.213151),80511=>array(-105.572189,40.340181),80512=>array(-105.581555,40.633408),80513=>array(-105.103928,40.300348),80514=>array(-104.955523,40.065738),80515=>array(-105.382289,40.462379),80516=>array(-105.027632,40.051112),80517=>array(-105.585956,40.384776),80520=>array(-104.931431,40.113099),80521=>array(-105.127416,40.594597),80524=>array(-105.029257,40.647612),80525=>array(-105.036788,40.529646),80526=>array(-105.143224,40.518836),80528=>array(-105.004639,40.494596),80530=>array(-104.929279,40.097792),80532=>array(-105.467197,40.493095),80534=>array(-104.937474,40.331818),80535=>array(-105.183846,40.732954),80536=>array(-105.369065,40.868337),80537=>array(-105.179966,40.364469),80538=>array(-105.049404,40.458831),80540=>array(-105.364549,40.235694),80542=>array(-104.999386,40.235081),80543=>array(-104.850948,40.344353),80544=>array(-105.171093,40.103412),80545=>array(-105.638065,40.87567),80546=>array(-104.849696,40.525242),80547=>array(-104.965364,40.52663),80549=>array(-105.048773,40.864456),80550=>array(-104.900983,40.484657),80601=>array(-104.807809,39.962027),80602=>array(-104.911602,39.964431),80603=>array(-104.737094,39.982211),80610=>array(-104.591187,40.660666),80611=>array(-104.287097,40.624982),80612=>array(-104.852569,40.872141),80615=>array(-104.645698,40.545658),80620=>array(-104.717482,40.373756),80621=>array(-104.801093,40.107238),80622=>array(-104.460409,40.538013),80623=>array(-104.782532,40.285379),80624=>array(-104.498802,40.486784),80631=>array(-104.673072,40.442868),80634=>array(-104.792917,40.403315),80640=>array(-104.882674,39.885331),80642=>array(-104.612139,40.051416),80643=>array(-104.482398,40.11274),80644=>array(-104.462805,40.382841),80645=>array(-104.667961,40.330728),80648=>array(-104.740919,40.755864),80649=>array(-104.176362,40.380745),80650=>array(-104.829835,40.621518),80651=>array(-104.809426,40.241718),80652=>array(-104.276173,40.138533),80653=>array(-103.971541,40.398768),80654=>array(-104.065491,40.138103),80701=>array(-103.831757,40.168193),80705=>array(-103.829653,40.270499),80720=>array(-103.219881,40.078252),80721=>array(-102.1539,40.689612),80722=>array(-103.271661,40.506613),80723=>array(-103.555197,40.166261),80726=>array(-102.793047,40.905042),80727=>array(-102.513988,40.071179),80728=>array(-102.873872,40.644866),80729=>array(-104.269296,40.884243),80731=>array(-102.600328,40.59445),80733=>array(-103.450535,40.371386),80734=>array(-102.291952,40.519891),80735=>array(-102.273164,39.709824),80736=>array(-103.027237,40.811815),80737=>array(-102.177979,40.87614),80740=>array(-103.382898,39.725661),80741=>array(-103.477138,40.573942),80742=>array(-103.831083,40.752316),80743=>array(-102.95496,40.196787),80744=>array(-102.391968,40.873626),80745=>array(-103.387875,40.896443),80746=>array(-102.465912,40.609603),80747=>array(-103.086174,40.942361),80749=>array(-102.547276,40.867058),80750=>array(-103.604846,40.414765),80751=>array(-103.232406,40.63688),80754=>array(-103.666956,40.723113),80755=>array(-102.344974,39.911897),80757=>array(-103.583221,39.790981),80758=>array(-102.193094,40.138836),80759=>array(-102.685959,40.135241),80801=>array(-103.101271,39.73228),80802=>array(-102.173384,38.836946),80804=>array(-103.248069,39.34684),80805=>array(-102.455614,39.305959),80807=>array(-102.223231,39.321667),80808=>array(-104.30347,38.988167),80809=>array(-105.000241,38.855321),80810=>array(-102.4449,38.821854),80812=>array(-102.849918,39.619003),80813=>array(-105.157507,38.805574),80814=>array(-105.189763,38.960297),80815=>array(-103.063405,39.396721),80816=>array(-105.315864,38.857741),80817=>array(-104.686472,38.63858),80818=>array(-103.480409,39.385913),80819=>array(-105.011583,38.962513),80820=>array(-105.579799,38.789998),80821=>array(-103.381661,38.979683),80822=>array(-102.675394,39.700145),80823=>array(-103.419186,38.663464),80824=>array(-102.507129,39.650352),80825=>array(-102.831705,38.795426),80827=>array(-105.467609,39.056483),80828=>array(-103.729511,39.333574),80829=>array(-104.935752,38.827928),80830=>array(-103.894118,39.114246),80831=>array(-104.487819,38.986634),80832=>array(-104.012874,39.017177),80833=>array(-103.96509,38.763233),80834=>array(-102.88364,39.264797),80835=>array(-104.024141,39.221174),80836=>array(-102.576778,39.298071),80840=>array(-104.861958,38.994694),80860=>array(-105.08828,38.705877),80861=>array(-102.721831,39.331861),80862=>array(-103.057916,38.873184),80863=>array(-105.113586,39.019995),80864=>array(-104.186739,38.697666),80902=>array(-104.807971,38.669371),80903=>array(-104.814501,38.83149),80904=>array(-104.876163,38.860829),80905=>array(-104.838348,38.81891),80906=>array(-104.878195,38.752622),80907=>array(-104.826451,38.878612),80908=>array(-104.693246,39.046483),80909=>array(-104.775218,38.853475),80910=>array(-104.77458,38.812066),80911=>array(-104.723477,38.752916),80913=>array(-104.748776,38.687472),80914=>array(-104.704184,38.824001),80915=>array(-104.717043,38.849797),80916=>array(-104.708018,38.806967),80917=>array(-104.745264,38.886168),80918=>array(-104.780362,38.910393),80919=>array(-104.852626,38.928208),80920=>array(-104.770779,38.957604),80921=>array(-104.910486,39.016197),80922=>array(-104.70063,38.890569),80923=>array(-104.714788,38.926858),80924=>array(-104.721285,38.968013),80925=>array(-104.655864,38.757764),80926=>array(-104.903006,38.634733),80927=>array(-104.658341,38.928577),80928=>array(-104.401634,38.630403),80929=>array(-104.626967,38.82471),80930=>array(-104.502478,38.814229),80938=>array(-104.663423,38.904708),80939=>array(-104.677361,38.877605),80951=>array(-104.651538,38.894945),81001=>array(-104.536493,38.293234),81003=>array(-104.626098,38.277713),81004=>array(-104.714356,38.04374),81005=>array(-104.810446,38.197683),81006=>array(-104.501002,38.236078),81007=>array(-104.773198,38.360042),81008=>array(-104.621526,38.441619),81019=>array(-104.841876,37.9437),81020=>array(-104.49102,37.548854),81021=>array(-103.38093,38.387612),81022=>array(-104.422573,38.050166),81023=>array(-104.964263,38.052616),81024=>array(-104.734713,37.249355),81025=>array(-104.355296,38.455047),81027=>array(-103.799939,37.189352),81029=>array(-102.495606,37.087819),81030=>array(-103.523617,38.100738),81033=>array(-103.861345,38.194886),81036=>array(-102.75621,38.388466),81038=>array(-103.14042,38.079243),81039=>array(-104.085204,37.93907),81040=>array(-105.226512,37.783983),81041=>array(-102.370249,37.867474),81043=>array(-102.220817,38.131096),81044=>array(-102.950617,37.925042),81045=>array(-103.164635,38.487746),81047=>array(-102.151319,38.111178),81049=>array(-103.387574,37.378762),81050=>array(-103.505893,37.940231),81052=>array(-102.639554,37.918016),81054=>array(-103.157396,37.945704),81055=>array(-105.111759,37.491613),81057=>array(-102.88319,38.121759),81058=>array(-103.882859,38.099953),81059=>array(-104.020765,37.505391),81062=>array(-103.964339,38.29689),81063=>array(-103.77106,38.43071),81064=>array(-102.999283,37.224707),81067=>array(-103.778471,37.933631),81069=>array(-104.903626,37.893271),81071=>array(-102.246008,38.436195),81073=>array(-102.712418,37.420622),81076=>array(-103.601595,38.343221),81077=>array(-103.630845,38.017621),81081=>array(-104.214951,37.048164),81082=>array(-104.516734,37.178909),81084=>array(-102.410872,37.584413),81087=>array(-102.409003,37.3659),81089=>array(-104.737761,37.651579),81090=>array(-102.222224,37.358203),81091=>array(-104.964753,37.148986),81092=>array(-102.752246,38.193819),81101=>array(-105.833213,37.481245),81120=>array(-106.319313,37.22756),81121=>array(-107.439077,37.109777),81122=>array(-107.475814,37.351492),81123=>array(-105.571815,37.399731),81124=>array(-106.160588,37.306244),81125=>array(-106.069857,37.819261),81126=>array(-105.334587,37.15559),81128=>array(-106.617244,37.082226),81129=>array(-106.029047,37.103361),81130=>array(-107.057537,37.6204),81131=>array(-105.679141,37.865412),81132=>array(-106.428957,37.71128),81133=>array(-105.307195,37.43013),81136=>array(-105.827948,37.735128),81137=>array(-107.613601,37.051911),81138=>array(-105.620375,37.030764),81140=>array(-106.110838,37.313495),81141=>array(-105.858338,37.162298),81143=>array(-105.856686,38.049008),81144=>array(-106.167043,37.553439),81146=>array(-105.684002,37.62445),81147=>array(-107.085622,37.322856),81148=>array(-105.985414,37.171819),81149=>array(-106.34589,38.101708),81151=>array(-105.808117,37.278604),81152=>array(-105.40212,37.110768),81154=>array(-106.603691,37.574789),81155=>array(-106.074407,38.288315),81201=>array(-106.066038,38.554832),81210=>array(-106.677959,38.808675),81211=>array(-106.381737,38.973415),81212=>array(-105.399681,38.535973),81220=>array(-107.480574,38.308243),81221=>array(-105.144129,38.362348),81222=>array(-105.830935,38.347997),81223=>array(-105.612643,38.364745),81224=>array(-106.934054,38.879886),81225=>array(-106.903504,38.95425),81226=>array(-105.142833,38.320931),81227=>array(-106.290217,38.549241),81230=>array(-106.953683,38.395065),81231=>array(-106.919672,38.550024),81232=>array(-105.610466,38.285131),81233=>array(-105.824878,38.425974),81235=>array(-107.299418,38.012835),81236=>array(-106.264738,38.675427),81237=>array(-106.614052,38.603067),81239=>array(-106.663673,38.508808),81240=>array(-105.034304,38.500352),81241=>array(-106.508421,38.622869),81242=>array(-106.075489,38.508149),81243=>array(-107.192094,38.265999),81244=>array(-105.177721,38.362933),81248=>array(-106.378258,38.464302),81251=>array(-106.478184,39.112263),81252=>array(-105.427522,38.110643),81253=>array(-105.065186,38.226594),81301=>array(-107.852781,37.441078),81303=>array(-107.885499,37.12149),81320=>array(-108.735147,37.720141),81321=>array(-108.734537,37.31297),81323=>array(-108.126994,37.702838),81324=>array(-109.029605,37.658451),81325=>array(-108.727136,37.919007),81326=>array(-108.187079,37.156378),81327=>array(-108.660749,37.518051),81328=>array(-108.258342,37.360003),81330=>array(-108.482502,37.231252),81331=>array(-108.907306,37.446213),81332=>array(-107.991189,37.700337),81334=>array(-108.612966,37.14614),81335=>array(-108.757071,37.496409),81401=>array(-107.770845,38.484148),81403=>array(-107.957315,38.368817),81410=>array(-107.966364,38.804613),81411=>array(-108.979946,38.250859),81413=>array(-107.955456,38.966929),81415=>array(-107.638132,38.632823),81416=>array(-108.136935,38.752097),81418=>array(-107.987839,38.848899),81419=>array(-107.745058,38.881231),81422=>array(-108.711308,38.346587),81423=>array(-108.37247,38.023159),81424=>array(-108.444624,38.32656),81425=>array(-108.247485,38.493599),81426=>array(-107.891294,37.868211),81427=>array(-107.635903,38.030529),81428=>array(-107.599578,38.962987),81429=>array(-108.876176,38.323946),81430=>array(-108.022862,38.022192),81431=>array(-108.570085,38.110654),81432=>array(-107.749673,38.110115),81433=>array(-107.585706,37.764768),81434=>array(-107.348515,38.961138),81435=>array(-107.869218,37.909549),81501=>array(-108.547131,39.071848),81503=>array(-108.434062,39.029795),81504=>array(-108.491247,39.079602),81505=>array(-108.534246,39.255826),81506=>array(-108.526808,39.114829),81507=>array(-108.652183,39.008939),81520=>array(-108.433769,39.110944),81521=>array(-108.798568,39.123299),81522=>array(-108.913333,38.618218),81523=>array(-108.891394,38.968751),81524=>array(-108.787139,39.274252),81525=>array(-108.946167,39.286708),81526=>array(-108.334424,39.096926),81527=>array(-108.469867,38.799081),81601=>array(-107.304314,39.601448),81610=>array(-108.761563,40.279698),81611=>array(-106.687538,39.160355),81612=>array(-106.837368,39.134183),81615=>array(-106.927919,39.221649),81620=>array(-106.513435,39.595601),81621=>array(-106.880042,39.407141),81623=>array(-107.161909,39.236653),81624=>array(-107.698685,39.194911),81625=>array(-107.694794,40.745223),81630=>array(-108.57641,39.433871),81631=>array(-106.750037,39.629387),81632=>array(-106.607659,39.629169),81633=>array(-108.429206,40.338315),81635=>array(-108.047779,39.495158),81637=>array(-107.105819,39.777824),81638=>array(-107.549052,40.315572),81639=>array(-107.23923,40.506919),81640=>array(-108.513364,40.66773),81641=>array(-107.747761,40.082055),81642=>array(-106.655769,39.316471),81643=>array(-108.151554,39.06629),81645=>array(-106.458351,39.455605),81646=>array(-108.002603,39.097235),81647=>array(-107.566625,39.610533),81648=>array(-108.684475,39.97013),81649=>array(-106.278162,39.530227),81650=>array(-108.113722,39.751037),81652=>array(-107.654716,39.485172),81653=>array(-107.267453,40.975779),81654=>array(-107.052509,39.197543),81655=>array(-106.459886,39.781173),81656=>array(-106.897256,39.28385),81657=>array(-106.308296,39.675999),82001=>array(-104.936269,41.092356),82005=>array(-104.874531,41.14025),82007=>array(-104.707126,41.08307),82009=>array(-104.853614,41.374415),82050=>array(-104.150543,41.457633),82051=>array(-105.595429,41.581934),82052=>array(-105.308612,41.118551),82053=>array(-104.359433,41.252071),82054=>array(-104.36052,41.064273),82055=>array(-106.175891,41.332419),82058=>array(-105.636173,42.087082),82059=>array(-105.178649,41.053423),82060=>array(-104.496976,41.277387),82061=>array(-105.161358,41.445182),82063=>array(-105.997396,40.882289),82070=>array(-105.84162,41.195479),82072=>array(-105.4761,41.414802),82073=>array(-105.587542,41.356764),82081=>array(-104.49209,41.533638),82082=>array(-104.134235,41.235319),82083=>array(-106.079964,41.662571),82084=>array(-105.619771,41.025388),82190=>array(-110.530132,44.552613),82201=>array(-105.149002,42.018732),82210=>array(-104.830324,41.743934),82212=>array(-104.539289,42.278608),82213=>array(-105.00441,42.494794),82214=>array(-104.780339,42.259722),82215=>array(-104.759567,42.382),82217=>array(-104.136425,41.76036),82219=>array(-104.513283,42.498716),82221=>array(-104.328472,41.638038),82222=>array(-104.650472,43.196135),82223=>array(-104.395784,42.130328),82224=>array(-104.808472,43.027155),82225=>array(-104.323952,42.98571),82227=>array(-104.72402,42.756447),82229=>array(-104.967096,42.878051),82240=>array(-104.158324,42.265226),82242=>array(-104.109376,42.694543),82243=>array(-104.429236,41.995412),82244=>array(-104.430492,41.882915),82301=>array(-107.490595,41.892016),82321=>array(-107.741403,41.23657),82322=>array(-107.561028,42.237737),82323=>array(-107.500073,41.052461),82324=>array(-106.412014,41.674026),82325=>array(-106.713116,41.246959),82327=>array(-106.694547,42.151449),82329=>array(-106.080739,42.07776),82331=>array(-106.796539,41.370024),82332=>array(-107.280717,41.036084),82334=>array(-107.017768,41.901041),82335=>array(-106.760179,41.75378),82336=>array(-108.208558,41.698195),82401=>array(-108.152151,43.988573),82410=>array(-108.119184,44.354714),82411=>array(-108.458033,44.414494),82412=>array(-108.553488,44.796848),82414=>array(-109.593597,44.492387),82420=>array(-108.457721,44.93433),82421=>array(-108.599103,44.909692),82422=>array(-108.382274,44.497663),82423=>array(-108.581214,44.966206),82426=>array(-107.761004,44.512585),82428=>array(-107.511112,44.326469),82430=>array(-108.184935,43.815454),82431=>array(-108.164383,44.840242),82432=>array(-107.864542,44.202999),82433=>array(-109.102295,44.061115),82434=>array(-108.298132,44.382893),82435=>array(-108.910331,44.810631),82440=>array(-108.864172,44.719748),82441=>array(-107.768788,44.644857),82442=>array(-107.321733,43.879297),82443=>array(-108.47213,43.726647),82450=>array(-109.435558,44.505179),82501=>array(-108.20743,43.03257),82510=>array(-108.59786,42.994046),82512=>array(-109.282617,43.301564),82513=>array(-109.668165,43.627183),82514=>array(-108.931134,43.036205),82515=>array(-108.542611,42.903732),82516=>array(-108.83184,43.188442),82520=>array(-108.618598,42.69917),82523=>array(-108.82266,43.46283),82601=>array(-106.381848,43.088983),82604=>array(-106.770764,42.857603),82609=>array(-106.180846,42.805201),82620=>array(-107.107171,42.463048),82630=>array(-107.31724,43.165169),82633=>array(-105.41025,43.02227),82635=>array(-106.22239,43.398153),82636=>array(-106.17064,42.90612),82637=>array(-105.88458,42.814344),82638=>array(-107.323054,43.114517),82639=>array(-106.612634,43.712117),82640=>array(-106.199923,43.563825),82642=>array(-107.60045,43.245827),82643=>array(-106.259854,43.439187),82644=>array(-106.36661,42.840611),82646=>array(-106.821962,43.000925),82648=>array(-107.152676,43.281053),82649=>array(-108.053346,43.301333),82701=>array(-104.433861,43.711636),82710=>array(-104.248772,44.706522),82711=>array(-104.458623,44.709224),82712=>array(-104.121622,44.45326),82714=>array(-104.699607,44.571551),82715=>array(-104.133391,44.119155),82716=>array(-105.695059,44.464635),82718=>array(-105.621622,43.878837),82720=>array(-104.670544,44.795997),82721=>array(-104.916416,44.481838),82723=>array(-104.422888,44.001929),82725=>array(-105.702597,44.876794),82727=>array(-105.198216,44.324072),82729=>array(-104.365032,44.343178),82730=>array(-104.704001,44.046568),82731=>array(-105.292104,44.824769),82732=>array(-105.619567,43.705442),82801=>array(-106.835993,44.843713),82831=>array(-106.049796,44.600097),82832=>array(-106.797089,44.594845),82833=>array(-107.063438,44.611284),82834=>array(-106.658714,44.239738),82835=>array(-106.352084,44.757249),82836=>array(-107.507688,44.766328),82837=>array(-106.255973,44.772036),82838=>array(-107.585109,44.925684),82839=>array(-107.161076,44.925813),82842=>array(-106.932521,44.57301),82844=>array(-107.221085,44.782566),82845=>array(-106.673474,44.763362),82901=>array(-108.978212,41.379251),82922=>array(-110.411256,43.12648),82923=>array(-109.462622,42.65045),82925=>array(-109.905707,43.239387),82929=>array(-109.843634,41.555746),82930=>array(-110.644785,41.015672),82932=>array(-109.35698,42.254112),82933=>array(-110.438425,41.295938),82934=>array(-110.012916,41.604085),82935=>array(-109.664735,41.688569),82936=>array(-110.183863,41.062349),82937=>array(-110.264655,41.347104),82938=>array(-109.888823,41.099639),82939=>array(-110.345571,41.218919),82941=>array(-109.740146,42.905092),82942=>array(-108.870798,41.714292),82943=>array(-109.208006,41.754643),82944=>array(-110.464639,41.162096),82945=>array(-109.051037,41.744069),83001=>array(-110.629763,43.39455),83011=>array(-110.455876,43.52418),83012=>array(-110.790642,43.732465),83013=>array(-110.465484,43.993776),83014=>array(-110.974384,43.456152),83025=>array(-110.848171,43.593599),83101=>array(-110.555433,41.964275),83110=>array(-110.849219,42.725902),83111=>array(-111.174362,42.77175),83112=>array(-110.832476,42.920608),83113=>array(-110.257868,42.531855),83114=>array(-110.97657,42.205382),83115=>array(-110.315631,42.890755),83116=>array(-110.53334,41.768998),83118=>array(-110.997576,43.047855),83119=>array(-110.988197,42.643918),83120=>array(-111.118724,42.918126),83121=>array(-110.533905,41.819716),83122=>array(-110.946526,42.820258),83123=>array(-110.250207,42.221111),83124=>array(-110.234012,41.773109),83126=>array(-110.830763,42.593741),83127=>array(-110.963905,42.96043),83128=>array(-110.776831,43.064401),83201=>array(-112.380079,42.904933),83202=>array(-112.182744,42.925509),83203=>array(-112.495945,43.042388),83204=>array(-112.629866,42.856338),83209=>array(-112.426322,42.857791),83210=>array(-112.866464,43.01833),83211=>array(-113.028458,42.701149),83212=>array(-112.543984,42.538792),83213=>array(-113.266673,43.539144),83214=>array(-112.307658,42.539852),83215=>array(-112.812491,43.443158),83217=>array(-111.942715,42.777857),83218=>array(-112.165272,43.317687),83220=>array(-111.423937,42.376948),83221=>array(-112.552045,43.324081),83223=>array(-111.406959,42.181781),83226=>array(-114.349893,44.631956),83227=>array(-114.506633,44.248912),83228=>array(-112.060367,42.233732),83232=>array(-111.971088,42.138463),83233=>array(-111.237351,42.132912),83234=>array(-112.101094,42.422579),83235=>array(-113.696705,44.575992),83236=>array(-111.87246,43.191056),83237=>array(-111.778558,42.027452),83238=>array(-111.116429,42.321016),83239=>array(-111.30744,42.51462),83241=>array(-111.765362,42.514851),83243=>array(-112.65128,42.297425),83244=>array(-113.123868,44.116803),83245=>array(-112.207732,42.818119),83246=>array(-112.02467,42.611018),83250=>array(-112.204751,42.672528),83251=>array(-113.884177,43.942426),83252=>array(-112.406565,42.174414),83253=>array(-113.690673,44.315204),83254=>array(-111.271892,42.328791),83255=>array(-113.583637,43.685697),83261=>array(-111.433149,42.216058),83262=>array(-112.774496,43.225761),83263=>array(-111.753213,42.181249),83271=>array(-112.91278,42.442204),83272=>array(-111.509215,42.166402),83274=>array(-112.098021,43.348121),83276=>array(-111.515908,42.757689),83277=>array(-112.667158,43.066895),83278=>array(-114.813801,44.336337),83281=>array(-111.965452,42.329852),83283=>array(-111.632456,42.371097),83285=>array(-111.326986,43.072445),83286=>array(-112.015748,42.063423),83287=>array(-111.399191,42.042246),83301=>array(-114.524876,42.400555),83302=>array(-115.009033,42.226893),83311=>array(-113.56472,42.391735),83312=>array(-113.650773,41.975985),83313=>array(-114.257191,43.351684),83314=>array(-114.951592,42.985016),83316=>array(-114.880351,42.606181),83318=>array(-113.816498,42.437884),83320=>array(-113.872708,43.481455),83321=>array(-114.914924,42.463501),83322=>array(-114.978595,43.349499),83323=>array(-113.392146,42.50359),83324=>array(-114.27211,42.87274),83325=>array(-114.240846,42.587877),83327=>array(-114.809455,43.492599),83328=>array(-114.613167,42.570448),83330=>array(-114.707998,42.951933),83332=>array(-114.924985,42.803115),83333=>array(-114.310894,43.568303),83334=>array(-114.292089,42.44446),83335=>array(-114.066822,42.579582),83336=>array(-113.824649,42.564676),83337=>array(-115.152058,43.224071),83338=>array(-114.431903,42.725104),83340=>array(-114.618421,43.706431),83341=>array(-114.370835,42.419134),83342=>array(-113.255097,42.177466),83344=>array(-114.138302,42.446919),83346=>array(-113.819913,42.278315),83347=>array(-113.80902,42.663622),83348=>array(-114.10768,43.249472),83349=>array(-114.181472,43.096594),83350=>array(-113.579982,42.694326),83352=>array(-114.412326,43.070085),83353=>array(-114.320818,43.692284),83354=>array(-114.322264,43.670188),83355=>array(-114.722206,42.757435),83401=>array(-111.877936,43.542409),83402=>array(-112.173804,43.534558),83404=>array(-112.012073,43.422784),83406=>array(-111.811633,43.443948),83414=>array(-110.943196,43.905298),83420=>array(-111.346444,44.077471),83421=>array(-111.529228,44.020108),83422=>array(-111.231457,43.728569),83423=>array(-112.280545,44.300087),83424=>array(-111.168114,43.909949),83425=>array(-112.242431,43.912196),83427=>array(-111.932544,43.524613),83428=>array(-111.168679,43.473108),83429=>array(-111.398116,44.477202),83431=>array(-112.032935,43.688427),83433=>array(-111.333103,44.484482),83434=>array(-112.006385,43.752647),83435=>array(-112.568602,43.988863),83436=>array(-111.472046,43.857158),83440=>array(-111.822546,43.81469),83442=>array(-111.893735,43.671181),83443=>array(-111.518092,43.515951),83444=>array(-112.301586,43.719411),83445=>array(-111.767357,43.979292),83446=>array(-112.187636,44.472573),83448=>array(-111.692649,43.850004),83449=>array(-111.417191,43.259048),83450=>array(-112.405569,43.830648),83451=>array(-111.633321,43.866555),83452=>array(-111.218327,43.835421),83454=>array(-111.952242,43.595424),83455=>array(-111.183881,43.614042),83460=>array(-111.782214,43.81702),83462=>array(-113.809337,45.301183),83463=>array(-114.053957,45.582568),83464=>array(-113.249572,44.525949),83465=>array(-113.674737,44.784888),83466=>array(-114.046629,45.414846),83467=>array(-113.897498,44.980597),83468=>array(-113.592332,44.922259),83469=>array(-114.420694,45.388152),83501=>array(-116.928725,46.210115),83520=>array(-116.325017,46.546311),83522=>array(-116.51154,45.9196),83523=>array(-116.443536,46.248904),83524=>array(-116.665542,46.365734),83525=>array(-115.510371,45.803736),83526=>array(-116.412071,46.147763),83530=>array(-116.084204,45.919928),83533=>array(-116.236915,46.094501),83535=>array(-116.724005,46.534195),83536=>array(-116.001351,46.224382),83537=>array(-116.550863,46.637598),83539=>array(-114.980094,46.177855),83540=>array(-116.782679,46.345211),83541=>array(-116.469465,46.513376),83542=>array(-116.357252,45.569135),83543=>array(-116.233428,46.273204),83544=>array(-116.143058,46.497315),83545=>array(-116.4218,46.42642),83546=>array(-115.822238,46.560005),83547=>array(-116.218129,45.173515),83548=>array(-116.505033,46.360925),83549=>array(-116.190931,45.344169),83552=>array(-115.932942,46.008057),83553=>array(-115.890577,46.383616),83554=>array(-116.270666,45.714301),83555=>array(-116.689431,46.127543),83601=>array(-115.259938,43.89117),83602=>array(-116.10868,44.070601),83604=>array(-115.747855,42.515345),83605=>array(-116.65629,43.661908),83607=>array(-116.750541,43.709411),83610=>array(-116.773317,44.743436),83611=>array(-115.367783,44.727283),83612=>array(-116.588592,44.919575),83615=>array(-116.054852,44.720244),83616=>array(-116.394918,43.775559),83617=>array(-116.505201,43.936885),83619=>array(-116.910261,43.9661),83622=>array(-115.898062,44.103371),83623=>array(-115.392631,43.082032),83624=>array(-116.158361,42.900895),83626=>array(-116.832129,43.667499),83627=>array(-115.547313,42.91784),83628=>array(-116.985621,43.595444),83629=>array(-116.130431,43.911839),83631=>array(-115.640485,43.865442),83632=>array(-116.412891,44.54001),83633=>array(-115.220812,43.013653),83634=>array(-116.328453,43.455781),83636=>array(-116.663508,43.908912),83637=>array(-115.24948,44.109258),83638=>array(-115.965305,45.066978),83639=>array(-116.866526,43.397377),83641=>array(-116.584684,43.354103),83642=>array(-116.403731,43.568795),83643=>array(-116.440976,44.632147),83644=>array(-116.579646,43.750958),83645=>array(-116.583493,44.368971),83646=>array(-116.431756,43.649557),83647=>array(-115.523354,43.400294),83648=>array(-115.866402,43.049579),83650=>array(-116.673568,42.853438),83651=>array(-116.620338,43.587749),83654=>array(-116.359415,45.109953),83655=>array(-116.789646,43.951269),83656=>array(-116.799128,43.726469),83657=>array(-116.296435,44.223025),83660=>array(-116.929571,43.797717),83661=>array(-116.708522,44.080716),83666=>array(-115.975879,43.963326),83669=>array(-116.495406,43.719715),83670=>array(-116.312919,44.018634),83671=>array(-115.271213,45.282735),83672=>array(-116.957074,44.374143),83676=>array(-116.907523,43.656041),83677=>array(-115.481385,45.080689),83686=>array(-116.607705,43.492217),83687=>array(-116.529134,43.609971),83702=>array(-116.152104,43.676435),83703=>array(-116.243033,43.665568),83704=>array(-116.287653,43.627161),83705=>array(-116.214892,43.561591),83706=>array(-116.19436,43.591127),83709=>array(-116.290079,43.551112),83712=>array(-116.107716,43.614926),83713=>array(-116.333613,43.639768),83714=>array(-116.288433,43.732675),83716=>array(-115.944475,43.546065),83801=>array(-116.666177,47.936835),83802=>array(-115.57172,47.049875),83803=>array(-116.443566,48.031501),83804=>array(-116.971311,48.045266),83805=>array(-116.540727,48.867052),83806=>array(-116.361162,46.894062),83808=>array(-116.011684,47.332912),83809=>array(-116.573546,48.063601),83810=>array(-116.450785,47.542484),83811=>array(-116.138084,48.10796),83812=>array(-116.233587,47.023228),83813=>array(-116.672772,48.085042),83814=>array(-116.654109,47.691736),83815=>array(-116.789948,47.726282),83821=>array(-116.850647,48.538977),83822=>array(-116.989568,48.179546),83823=>array(-116.544647,46.821265),83824=>array(-116.910037,47.113599),83825=>array(-116.594634,48.245783),83826=>array(-116.188948,48.976124),83827=>array(-116.173759,46.778612),83830=>array(-116.364991,47.086727),83832=>array(-116.909567,46.552294),83833=>array(-116.718369,47.509953),83834=>array(-116.639608,46.990696),83835=>array(-116.660205,47.797214),83836=>array(-116.26911,48.250939),83837=>array(-116.111104,47.505619),83839=>array(-116.163816,47.609496),83840=>array(-116.515166,48.310572),83841=>array(-116.751107,48.201518),83842=>array(-116.546548,47.444837),83843=>array(-116.940158,46.722245),83844=>array(-117.014806,46.730066),83845=>array(-116.114617,48.789034),83846=>array(-115.767256,47.480713),83847=>array(-116.449093,48.577859),83848=>array(-116.891538,48.672214),83849=>array(-115.991945,47.538107),83850=>array(-116.234095,47.454339),83851=>array(-116.922804,47.296877),83852=>array(-116.543458,48.31108),83854=>array(-116.96746,47.719292),83855=>array(-116.888117,46.994808),83856=>array(-116.907683,48.298487),83857=>array(-116.796131,46.896561),83858=>array(-116.949074,47.863127),83860=>array(-116.536291,48.180561),83861=>array(-116.540566,47.264602),83864=>array(-116.51238,48.455281),83866=>array(-116.424772,47.155053),83867=>array(-115.945426,47.512968),83868=>array(-116.182611,47.516289),83869=>array(-116.892359,47.982344),83870=>array(-116.831523,47.125874),83871=>array(-116.742676,46.741942),83872=>array(-116.976959,46.867496),83873=>array(-115.843577,47.582863),83874=>array(-115.804004,47.643351),83876=>array(-116.930561,47.45747),84001=>array(-110.275956,40.346686),84002=>array(-110.306744,40.452048),84003=>array(-111.680586,40.47156),84004=>array(-111.751659,40.508238),84005=>array(-111.996538,40.325116),84006=>array(-112.117237,40.601478),84007=>array(-110.207858,40.323702),84010=>array(-111.867845,40.867942),84013=>array(-112.094468,40.295924),84014=>array(-111.884033,40.932087),84015=>array(-112.06076,41.120367),84017=>array(-111.224304,40.929601),84018=>array(-111.445654,41.215208),84020=>array(-111.869576,40.500154),84021=>array(-110.533742,40.108244),84022=>array(-112.626718,40.391646),84023=>array(-109.189534,40.939026),84024=>array(-111.447336,41.007664),84025=>array(-111.904831,40.980801),84026=>array(-109.837771,40.28278),84027=>array(-110.820052,40.153749),84028=>array(-111.417602,41.928262),84029=>array(-112.7377,40.645952),84031=>array(-110.808566,40.564876),84032=>array(-111.321274,40.539413),84033=>array(-111.501145,40.985609),84034=>array(-113.878081,40.059081),84035=>array(-109.199537,40.366293),84036=>array(-111.015709,40.675892),84037=>array(-111.950728,41.027177),84038=>array(-111.306214,41.922699),84039=>array(-109.803813,40.479556),84040=>array(-111.928061,41.092343),84041=>array(-111.981254,41.069915),84042=>array(-111.724517,40.340772),84043=>array(-111.872684,40.409121),84044=>array(-112.164945,40.72115),84045=>array(-111.911198,40.336496),84046=>array(-109.830689,40.920945),84047=>array(-111.895066,40.617184),84049=>array(-111.519703,40.523647),84050=>array(-111.676848,41.022588),84051=>array(-110.423206,40.386804),84052=>array(-109.997558,40.166547),84053=>array(-110.01015,40.454672),84054=>array(-111.917281,40.838886),84055=>array(-111.198457,40.708041),84056=>array(-111.99193,41.129127),84057=>array(-111.710402,40.314277),84058=>array(-111.727923,40.287743),84060=>array(-111.501916,40.652531),84061=>array(-111.329532,40.75216),84062=>array(-111.67045,40.441154),84063=>array(-109.680896,39.84959),84064=>array(-111.137731,41.679273),84065=>array(-111.943116,40.495789),84066=>array(-110.026744,40.328339),84067=>array(-112.048138,41.17105),84069=>array(-112.522732,40.393687),84070=>array(-111.889047,40.577106),84071=>array(-112.307126,40.393861),84072=>array(-110.66031,40.355405),84073=>array(-110.434844,40.354653),84074=>array(-112.265077,40.557899),84075=>array(-112.080698,41.080987),84076=>array(-109.845533,40.466458),84078=>array(-109.483101,40.630436),84080=>array(-112.429974,40.100245),84081=>array(-112.037636,40.602803),84082=>array(-111.395246,40.365805),84083=>array(-113.568588,40.815615),84084=>array(-111.964564,40.622887),84085=>array(-109.952164,40.590702),84086=>array(-111.233054,41.473679),84087=>array(-111.932247,40.884929),84088=>array(-111.960909,40.595163),84092=>array(-111.706362,40.554125),84093=>array(-111.828532,40.594774),84094=>array(-111.862135,40.571872),84095=>array(-111.978584,40.555303),84096=>array(-112.102079,40.515825),84097=>array(-111.673117,40.304832),84098=>array(-111.533007,40.733567),84101=>array(-111.900065,40.75638),84102=>array(-111.864386,40.76025),84103=>array(-111.842571,40.79508),84104=>array(-111.979512,40.751489),84105=>array(-111.859559,40.738309),84106=>array(-111.855656,40.706763),84107=>array(-111.884454,40.658021),84108=>array(-111.729104,40.808532),84109=>array(-111.704544,40.705812),84111=>array(-111.883983,40.755959),84112=>array(-111.841491,40.765074),84113=>array(-111.833633,40.764656),84115=>array(-111.892687,40.714497),84116=>array(-111.957074,40.801642),84117=>array(-111.8347,40.661033),84118=>array(-112.013394,40.653529),84119=>array(-111.946425,40.700258),84120=>array(-112.001241,40.697474),84121=>array(-111.714916,40.611653),84123=>array(-111.921627,40.658892),84124=>array(-111.813266,40.6772),84128=>array(-112.046771,40.70045),84144=>array(-111.892525,40.76826),84180=>array(-111.901105,40.770444),84301=>array(-112.130121,41.608192),84302=>array(-112.050758,41.553614),84304=>array(-111.99777,41.819409),84305=>array(-112.075561,41.944033),84306=>array(-112.042427,41.795442),84307=>array(-112.504802,41.458565),84308=>array(-112.008643,41.967782),84309=>array(-112.098565,41.714096),84310=>array(-111.847402,41.335665),84311=>array(-112.11592,41.823617),84312=>array(-112.152564,41.773829),84313=>array(-113.962312,41.660143),84314=>array(-112.092798,41.648335),84315=>array(-112.137773,41.167508),84316=>array(-112.484431,41.770965),84317=>array(-111.620061,41.307999),84318=>array(-111.81369,41.802537),84319=>array(-111.663276,41.606288),84320=>array(-111.845155,41.964118),84321=>array(-111.836493,41.717722),84324=>array(-111.952659,41.48782),84325=>array(-111.988952,41.72476),84326=>array(-111.817847,41.670663),84327=>array(-111.992929,41.869888),84328=>array(-111.834778,41.545839),84329=>array(-113.418857,41.760498),84330=>array(-112.163256,41.926057),84331=>array(-112.273634,41.948447),84332=>array(-111.812263,41.699981),84333=>array(-111.812116,41.907231),84334=>array(-112.14764,41.782587),84335=>array(-111.874843,41.836112),84336=>array(-112.770604,41.912978),84337=>array(-112.317414,41.765101),84338=>array(-111.94062,41.912155),84339=>array(-111.946203,41.626019),84340=>array(-112.036066,41.363536),84341=>array(-111.806434,41.775527),84401=>array(-112.033495,41.212322),84403=>array(-111.906345,41.194538),84404=>array(-112.117645,41.269473),84405=>array(-111.965799,41.156796),84414=>array(-111.976065,41.321951),84501=>array(-110.757509,39.546389),84511=>array(-109.408255,37.58529),84512=>array(-109.592317,37.134403),84513=>array(-111.014475,39.237671),84515=>array(-109.128567,38.975092),84516=>array(-111.06884,39.142987),84518=>array(-110.876886,39.388873),84520=>array(-110.429496,39.533055),84521=>array(-110.762446,39.417033),84522=>array(-111.210417,38.923418),84523=>array(-111.197985,39.093675),84525=>array(-110.054367,39.081441),84526=>array(-110.936495,39.739534),84528=>array(-111.085621,39.410978),84529=>array(-110.820751,39.679446),84530=>array(-109.158651,38.283551),84531=>array(-109.883606,37.176854),84532=>array(-109.548307,38.526496),84533=>array(-110.379196,37.519792),84534=>array(-109.231924,37.253519),84535=>array(-109.55723,37.999676),84536=>array(-110.349581,37.120416),84537=>array(-111.216278,39.32395),84539=>array(-110.337801,39.613451),84540=>array(-109.435768,39.243399),84542=>array(-110.734989,39.542324),84601=>array(-111.69709,40.226534),84604=>array(-111.576503,40.318627),84606=>array(-111.625544,40.214442),84620=>array(-111.927668,38.914823),84621=>array(-111.826247,39.050965),84622=>array(-111.821679,39.103831),84623=>array(-111.58845,39.453838),84624=>array(-112.642706,39.459894),84626=>array(-111.99898,39.904448),84627=>array(-111.561178,39.353135),84628=>array(-112.131344,39.941547),84629=>array(-111.471852,39.795141),84630=>array(-111.841091,39.30267),84631=>array(-112.388643,38.957653),84632=>array(-111.658267,39.620158),84633=>array(-111.90677,39.967495),84634=>array(-111.811071,39.158405),84635=>array(-112.722943,39.401963),84636=>array(-112.338928,39.140602),84637=>array(-112.517661,38.677945),84638=>array(-112.256195,39.511247),84639=>array(-111.900076,39.507673),84640=>array(-112.380686,39.497242),84642=>array(-111.616009,39.287997),84643=>array(-111.71285,39.115164),84645=>array(-111.843671,39.835528),84646=>array(-111.608795,39.541055),84647=>array(-111.415821,39.541107),84648=>array(-111.864493,39.685806),84649=>array(-112.329197,39.344434),84651=>array(-111.715491,39.95811),84652=>array(-111.868223,39.016903),84653=>array(-111.644209,40.026902),84654=>array(-111.62588,38.879534),84655=>array(-111.80682,39.971313),84656=>array(-112.068389,39.135627),84657=>array(-111.938937,38.818586),84660=>array(-111.695542,40.121268),84662=>array(-111.471926,39.42947),84663=>array(-111.495076,40.165629),84664=>array(-111.565118,40.11511),84665=>array(-111.670247,39.195679),84667=>array(-111.665536,39.500475),84701=>array(-111.698408,38.601242),84710=>array(-112.477748,37.482301),84711=>array(-112.021466,38.668541),84712=>array(-111.935578,37.988257),84713=>array(-112.650931,38.322179),84714=>array(-113.724295,37.848004),84715=>array(-111.548776,38.290094),84716=>array(-111.44226,37.94439),84718=>array(-112.045105,37.539582),84719=>array(-112.81035,37.672574),84720=>array(-113.187631,37.590013),84721=>array(-113.078614,37.77034),84722=>array(-113.605411,37.457594),84723=>array(-112.252464,38.180067),84724=>array(-112.148888,38.675277),84725=>array(-113.780206,37.540352),84726=>array(-111.588585,37.739223),84728=>array(-113.906591,39.295173),84729=>array(-112.62899,37.376776),84730=>array(-112.01938,38.736308),84731=>array(-112.853201,38.253489),84732=>array(-111.90231,38.445396),84733=>array(-113.774912,37.259209),84734=>array(-110.652037,38.305338),84735=>array(-112.430772,37.6406),84736=>array(-111.99795,37.549884),84737=>array(-113.205549,37.042385),84738=>array(-113.705884,37.175509),84739=>array(-112.206129,38.629228),84740=>array(-112.271437,38.275966),84741=>array(-112.249449,37.187134),84742=>array(-113.20803,37.540108),84743=>array(-112.138466,38.174184),84744=>array(-111.943044,38.620207),84745=>array(-113.244595,37.231638),84746=>array(-113.356165,37.242775),84747=>array(-111.643882,38.406572),84749=>array(-111.529071,38.431025),84750=>array(-112.193361,38.438354),84751=>array(-112.927663,38.383423),84752=>array(-112.872617,38.186768),84753=>array(-113.857595,37.967787),84754=>array(-112.108705,38.624276),84755=>array(-112.770291,37.229667),84756=>array(-113.569077,37.574253),84757=>array(-113.263495,37.459631),84758=>array(-112.72246,37.318801),84759=>array(-112.399422,37.906609),84760=>array(-112.669182,37.954968),84761=>array(-112.848443,37.875242),84762=>array(-112.755671,37.497286),84763=>array(-113.070534,37.142288),84764=>array(-112.167286,37.590136),84765=>array(-113.702106,37.122914),84766=>array(-112.317073,38.576349),84767=>array(-112.986607,37.236992),84770=>array(-113.609837,37.185679),84772=>array(-112.937704,37.774317),84773=>array(-111.340953,38.225681),84774=>array(-113.281239,37.290426),84775=>array(-110.949438,37.934018),84776=>array(-112.077341,37.635599),84779=>array(-113.122148,37.334886),84780=>array(-113.494186,37.125869),84781=>array(-113.462096,37.41155),84782=>array(-113.664474,37.34882),84783=>array(-113.701443,37.241141),84784=>array(-112.96389,37.025334),84790=>array(-113.558054,37.048309),85003=>array(-112.078353,33.450662),85004=>array(-112.069886,33.451567),85006=>array(-112.048771,33.465234),85007=>array(-112.090883,33.447614),85008=>array(-111.985178,33.462954),85009=>array(-112.128136,33.443097),85012=>array(-112.070981,33.507577),85013=>array(-112.084749,33.511087),85014=>array(-112.057351,33.508316),85015=>array(-112.102018,33.508664),85016=>array(-112.019166,33.511517),85017=>array(-112.123068,33.508782),85018=>array(-111.985386,33.505956),85019=>array(-112.144514,33.508879),85020=>array(-112.053591,33.567351),85021=>array(-112.092875,33.559421),85022=>array(-112.048414,33.62724),85023=>array(-112.093768,33.635109),85024=>array(-112.029599,33.736104),85027=>array(-112.092529,33.679761),85028=>array(-112.008409,33.57574),85029=>array(-112.109861,33.594738),85031=>array(-112.166926,33.493971),85032=>array(-112.002503,33.62592),85033=>array(-112.209757,33.492969),85034=>array(-112.013854,33.429462),85035=>array(-112.194732,33.471449),85037=>array(-112.268027,33.490164),85040=>array(-112.025469,33.406479),85041=>array(-112.110307,33.38593),85042=>array(-112.04351,33.369197),85043=>array(-112.196998,33.431905),85044=>array(-112.019082,33.352957),85045=>array(-112.103388,33.303866),85048=>array(-112.057185,33.312552),85050=>array(-111.998063,33.682738),85051=>array(-112.132418,33.558659),85053=>array(-112.131344,33.629939),85054=>array(-111.941099,33.678527),85083=>array(-112.158544,33.724574),85085=>array(-112.090231,33.750396),85086=>array(-112.119836,33.815971),85087=>array(-112.127494,33.924909),85118=>array(-111.320989,33.352129),85119=>array(-111.50196,33.409685),85120=>array(-111.567878,33.402386),85121=>array(-111.922207,33.144406),85122=>array(-111.74421,32.917125),85123=>array(-111.697663,32.715395),85128=>array(-111.537957,32.989934),85131=>array(-111.547278,32.672511),85132=>array(-111.215101,32.926782),85135=>array(-110.785507,33.003771),85137=>array(-111.022623,33.136413),85138=>array(-111.989258,33.007286),85139=>array(-112.144852,32.979987),85140=>array(-111.543814,33.244531),85141=>array(-111.434452,32.641547),85142=>array(-111.636294,33.19999),85143=>array(-111.51904,33.15866),85145=>array(-111.365677,32.552311),85147=>array(-111.733471,33.129087),85172=>array(-111.953347,32.883417),85173=>array(-111.123283,33.270161),85192=>array(-110.678531,32.962942),85193=>array(-111.817404,32.800249),85194=>array(-111.628756,32.897651),85201=>array(-111.8504,33.433545),85202=>array(-111.874001,33.381349),85203=>array(-111.802894,33.450359),85204=>array(-111.786608,33.39572),85205=>array(-111.718512,33.43242),85206=>array(-111.717093,33.396337),85207=>array(-111.63565,33.453507),85208=>array(-111.628063,33.403307),85209=>array(-111.63867,33.37545),85210=>array(-111.843505,33.389733),85212=>array(-111.635342,33.322324),85213=>array(-111.769015,33.448733),85215=>array(-111.579396,33.511896),85224=>array(-111.878217,33.324113),85225=>array(-111.830487,33.317448),85226=>array(-112.015898,33.250545),85233=>array(-111.811432,33.353505),85234=>array(-111.740547,33.363458),85248=>array(-111.869917,33.21479),85249=>array(-111.795717,33.224956),85250=>array(-111.887354,33.534451),85251=>array(-111.919239,33.493513),85253=>array(-111.957563,33.544833),85254=>array(-111.952235,33.615485),85255=>array(-111.823682,33.668727),85256=>array(-111.843728,33.500584),85257=>array(-111.916392,33.46196),85258=>array(-111.895881,33.564295),85259=>array(-111.809488,33.601112),85260=>array(-111.891472,33.610739),85262=>array(-111.806018,33.835028),85263=>array(-111.523604,33.839559),85264=>array(-111.532284,33.635113),85266=>array(-111.918051,33.76646),85268=>array(-111.743277,33.606089),85281=>array(-111.933836,33.427413),85282=>array(-111.931698,33.393682),85283=>array(-111.931604,33.364638),85284=>array(-111.934469,33.338075),85286=>array(-111.831899,33.271995),85295=>array(-111.740678,33.303148),85296=>array(-111.740629,33.335384),85297=>array(-111.731454,33.277771),85298=>array(-111.726727,33.241186),85301=>array(-112.177935,33.531753),85302=>array(-112.177961,33.567972),85303=>array(-112.22343,33.531968),85304=>array(-112.178276,33.599739),85305=>array(-112.2562,33.531789),85306=>array(-112.17659,33.624556),85307=>array(-112.312959,33.539456),85308=>array(-112.183426,33.660412),85309=>array(-112.382786,33.530879),85310=>array(-112.159214,33.707649),85320=>array(-113.209957,33.910187),85321=>array(-112.653302,32.237753),85322=>array(-112.872034,33.159109),85323=>array(-112.32689,33.419747),85324=>array(-112.044271,34.119191),85325=>array(-113.911284,33.992347),85326=>array(-112.589247,33.291722),85328=>array(-114.620356,33.252625),85331=>array(-111.912668,33.878937),85332=>array(-112.904743,34.18111),85333=>array(-113.283539,33.022104),85334=>array(-114.516445,33.516581),85335=>array(-112.327691,33.592283),85336=>array(-114.788734,32.548757),85337=>array(-112.704343,32.964032),85338=>array(-112.410262,33.373698),85339=>array(-112.161592,33.237127),85340=>array(-112.414041,33.515827),85341=>array(-112.798973,31.879191),85342=>array(-112.451374,33.944549),85343=>array(-112.685675,33.337738),85344=>array(-114.216239,34.080654),85345=>array(-112.245852,33.573244),85346=>array(-114.145935,33.635948),85347=>array(-113.789955,32.797564),85348=>array(-113.721274,33.714236),85349=>array(-114.746669,32.509136),85350=>array(-114.693547,32.561218),85351=>array(-112.284114,33.606131),85352=>array(-113.839513,32.719373),85353=>array(-112.276974,33.417511),85354=>array(-113.04609,33.430339),85355=>array(-112.454619,33.576119),85356=>array(-114.162243,32.689021),85357=>array(-113.448323,34.020006),85360=>array(-113.464036,34.73943),85361=>array(-112.614597,33.764116),85362=>array(-112.834716,34.279917),85363=>array(-112.304916,33.584969),85364=>array(-114.657231,32.701461),85365=>array(-114.125339,33.096439),85367=>array(-114.395516,32.671715),85371=>array(-114.375841,33.828542),85373=>array(-112.299656,33.671423),85374=>array(-112.37833,33.640996),85375=>array(-112.366168,33.685809),85377=>array(-111.914146,33.823073),85379=>array(-112.369625,33.603311),85381=>array(-112.231694,33.609311),85382=>array(-112.249474,33.654291),85383=>array(-112.247703,33.802087),85387=>array(-112.45096,33.709497),85388=>array(-112.431672,33.601603),85390=>array(-112.875667,33.903622),85392=>array(-112.308889,33.47758),85395=>array(-112.395249,33.478693),85396=>array(-112.702244,33.526254),85501=>array(-110.757756,33.566039),85530=>array(-110.199614,33.065221),85531=>array(-109.790074,32.884109),85533=>array(-109.405765,33.353953),85534=>array(-109.141655,32.753782),85535=>array(-109.91267,32.986305),85536=>array(-110.015939,33.120651),85539=>array(-110.894685,33.339679),85540=>array(-109.384572,33.000218),85541=>array(-111.305069,34.194999),85542=>array(-110.318864,33.317205),85543=>array(-109.989395,32.978573),85544=>array(-111.561133,34.303856),85545=>array(-111.140585,33.564906),85546=>array(-109.355257,32.813765),85550=>array(-110.472435,33.539393),85551=>array(-109.588476,32.724329),85552=>array(-109.770844,32.819926),85553=>array(-111.186564,33.847269),85554=>array(-110.960344,33.976652),85601=>array(-111.314701,31.588666),85602=>array(-110.405093,32.176377),85603=>array(-109.91955,31.432725),85605=>array(-109.481369,32.302065),85606=>array(-109.898983,32.042554),85607=>array(-109.379676,31.521172),85608=>array(-109.580936,31.456911),85609=>array(-110.096991,32.069477),85610=>array(-109.722324,31.744197),85611=>array(-110.510286,31.665168),85613=>array(-110.376844,31.567873),85614=>array(-110.9194,31.814301),85615=>array(-110.212252,31.402474),85616=>array(-110.321906,31.701894),85617=>array(-109.708595,31.519639),85618=>array(-110.538112,32.719696),85619=>array(-110.73315,32.407525),85620=>array(-109.941325,31.337282),85621=>array(-110.912001,31.387978),85622=>array(-111.075511,31.826851),85623=>array(-110.805211,32.706246),85624=>array(-110.692999,31.504971),85625=>array(-109.614066,31.886952),85626=>array(-109.566679,31.35781),85627=>array(-110.235541,32.007786),85629=>array(-111.019035,31.917838),85630=>array(-110.181047,31.886572),85631=>array(-110.551263,32.590912),85632=>array(-109.161043,32.043861),85633=>array(-111.50306,31.612902),85634=>array(-111.99443,32.034496),85635=>array(-110.170235,31.571011),85637=>array(-110.69111,31.719507),85638=>array(-110.051604,31.716172),85640=>array(-111.047743,31.557786),85641=>array(-110.622932,32.049034),85643=>array(-109.96549,32.407245),85645=>array(-111.160631,31.686279),85646=>array(-110.940689,31.647318),85648=>array(-111.038096,31.490441),85650=>array(-110.201835,31.500707),85653=>array(-111.386333,32.39879),85654=>array(-111.15441,32.415256),85658=>array(-111.143446,32.551052),85701=>array(-110.971015,32.216946),85704=>array(-110.984997,32.33942),85705=>array(-110.992051,32.271355),85706=>array(-110.933341,32.147619),85707=>array(-110.886905,32.179209),85708=>array(-110.866407,32.181923),85710=>array(-110.823718,32.214133),85711=>array(-110.883389,32.215243),85712=>array(-110.886567,32.252886),85713=>array(-111.014995,32.19457),85714=>array(-110.950864,32.167395),85715=>array(-110.836125,32.24675),85716=>array(-110.923197,32.241537),85718=>array(-110.916605,32.333306),85719=>array(-110.948654,32.246721),85723=>array(-110.965154,32.180232),85724=>array(-110.945636,32.240828),85726=>array(-110.945598,32.204728),85730=>array(-110.746552,32.181544),85735=>array(-111.349265,32.094109),85736=>array(-111.364423,31.909842),85737=>array(-110.946561,32.414615),85739=>array(-110.989667,32.621072),85741=>array(-111.042191,32.335182),85742=>array(-111.065397,32.393721),85743=>array(-111.181848,32.302273),85745=>array(-111.08014,32.253908),85746=>array(-111.044296,32.091607),85747=>array(-110.76537,32.095243),85748=>array(-110.75211,32.218928),85749=>array(-110.733528,32.289584),85750=>array(-110.835996,32.300129),85755=>array(-110.981461,32.468265),85756=>array(-110.89894,32.079264),85757=>array(-111.122067,32.128511),85901=>array(-110.020527,34.313307),85911=>array(-110.367333,34.173052),85912=>array(-109.898716,34.434774),85920=>array(-109.17701,33.86192),85922=>array(-109.150787,33.467624),85923=>array(-110.340559,34.32496),85924=>array(-109.672357,34.566622),85925=>array(-109.322992,34.08811),85926=>array(-109.979282,33.76925),85927=>array(-109.464318,34.006415),85928=>array(-110.557227,34.53576),85929=>array(-109.939822,34.184683),85930=>array(-109.720674,34.047324),85931=>array(-110.868598,34.461789),85932=>array(-109.213499,33.953341),85933=>array(-110.509263,34.357093),85934=>array(-110.245734,34.300249),85935=>array(-109.896691,34.119928),85936=>array(-109.268741,34.652683),85937=>array(-110.064102,34.573702),85938=>array(-109.336502,34.149295),85939=>array(-110.085261,34.431429),85940=>array(-109.682257,34.251663),85941=>array(-109.969827,33.821391),85942=>array(-109.954702,34.735705),86001=>array(-111.639303,35.287661),86003=>array(-111.224015,35.189708),86004=>array(-111.373463,35.380939),86011=>array(-111.655035,35.180062),86015=>array(-111.838598,35.231027),86016=>array(-111.641839,35.752417),86017=>array(-111.626136,34.88931),86018=>array(-111.916128,35.188694),86020=>array(-111.497809,35.99279),86021=>array(-113.024318,36.972279),86022=>array(-112.836996,36.856316),86023=>array(-112.022616,36.033131),86024=>array(-111.343217,34.651938),86025=>array(-110.104808,34.930781),86028=>array(-109.764547,35.073762),86029=>array(-109.992631,35.021012),86030=>array(-110.730472,35.968491),86031=>array(-110.051698,35.386597),86032=>array(-110.283924,35.07961),86033=>array(-110.228223,36.675775),86034=>array(-110.125868,35.794204),86035=>array(-110.944184,35.456718),86036=>array(-111.823136,36.738246),86038=>array(-111.430313,34.983818),86039=>array(-110.525216,36.055803),86040=>array(-111.427506,36.705495),86042=>array(-110.384151,35.861758),86043=>array(-110.535077,35.809743),86044=>array(-110.810274,36.693192),86045=>array(-111.116082,36.096622),86046=>array(-112.124541,35.415891),86047=>array(-110.671248,35.113436),86052=>array(-112.030486,36.146572),86053=>array(-111.055195,36.735052),86054=>array(-110.612172,36.724637),86301=>array(-112.426312,34.591349),86303=>array(-112.449736,34.482438),86305=>array(-112.912153,34.864252),86313=>array(-112.4524,34.553561),86314=>array(-112.306194,34.625976),86315=>array(-112.270208,34.703415),86320=>array(-112.645484,35.346129),86321=>array(-113.103111,34.492831),86322=>array(-111.801158,34.500279),86323=>array(-112.405819,34.777226),86324=>array(-112.120427,34.857441),86325=>array(-111.897955,34.734673),86326=>array(-112.023634,34.700031),86327=>array(-112.105026,34.571319),86329=>array(-112.224999,34.471629),86331=>array(-112.143872,34.726842),86332=>array(-112.632932,34.320536),86333=>array(-112.081924,34.322744),86334=>array(-112.54456,34.949042),86335=>array(-111.6734,34.694711),86336=>array(-111.867252,34.909886),86337=>array(-113.031283,35.359804),86338=>array(-112.753836,34.581751),86343=>array(-112.299986,34.176983),86351=>array(-111.785069,34.778447),86401=>array(-113.703932,35.131719),86403=>array(-114.348518,34.48025),86404=>array(-114.307852,34.590011),86406=>array(-114.109863,34.423236),86409=>array(-114.021257,35.460834),86411=>array(-113.783155,35.58084),86413=>array(-114.346048,35.210542),86426=>array(-114.56959,35.007621),86429=>array(-114.484927,35.163628),86431=>array(-114.219825,35.415567),86432=>array(-113.446572,36.366634),86433=>array(-114.348809,34.917564),86434=>array(-113.620551,35.676651),86435=>array(-112.90389,36.044172),86436=>array(-114.385008,34.757087),86437=>array(-113.614085,35.37885),86438=>array(-113.805421,34.548925),86440=>array(-114.525317,34.896683),86441=>array(-114.372332,35.571314),86442=>array(-114.560868,35.089613),86443=>array(-114.440288,35.971296),86444=>array(-114.047212,35.897037),86445=>array(-114.50202,35.773741),86502=>array(-109.591862,35.217949),86503=>array(-109.685366,36.153388),86504=>array(-109.135461,35.932269),86505=>array(-109.712349,35.627097),86506=>array(-109.220401,35.358053),86507=>array(-109.265689,36.411213),86508=>array(-109.095689,35.329904),86510=>array(-110.220374,36.257984),86511=>array(-109.153663,35.550101),86512=>array(-109.243165,35.095074),86514=>array(-109.332878,36.880257),86515=>array(-108.954226,35.67925),86520=>array(-109.935612,36.109913),86535=>array(-109.855226,36.794027),86538=>array(-109.595691,36.407631),86540=>array(-109.443978,35.941437),86544=>array(-109.150767,36.625751),86545=>array(-109.606619,36.711413),86547=>array(-109.494082,36.512528),86556=>array(-109.255499,36.288363),87001=>array(-106.337081,35.376617),87002=>array(-106.659036,34.606524),87004=>array(-106.59731,35.368394),87005=>array(-107.977093,35.267898),87006=>array(-106.843685,34.489728),87007=>array(-107.509117,35.024095),87008=>array(-106.407013,35.119923),87010=>array(-106.129827,35.408286),87011=>array(-105.946918,34.063668),87012=>array(-106.664988,36.107476),87013=>array(-107.380201,35.912766),87014=>array(-107.390449,35.230813),87015=>array(-106.182589,35.076686),87016=>array(-105.924043,34.77589),87017=>array(-106.765493,36.317041),87018=>array(-107.56353,36.165554),87020=>array(-107.948264,34.865013),87021=>array(-107.878884,35.192842),87022=>array(-106.707189,34.895491),87023=>array(-106.759585,34.598436),87024=>array(-106.723247,35.67285),87025=>array(-106.628405,35.841342),87026=>array(-107.233587,34.965327),87027=>array(-106.947981,36.126272),87028=>array(-106.76708,34.37961),87029=>array(-106.998492,36.396636),87031=>array(-107.020536,34.705471),87032=>array(-106.011454,34.851278),87034=>array(-107.564562,34.776465),87035=>array(-105.965548,34.930805),87036=>array(-106.255477,34.422883),87037=>array(-107.762433,36.166818),87038=>array(-107.412347,35.087627),87040=>array(-107.384409,35.103875),87041=>array(-106.335322,35.686667),87042=>array(-106.686572,34.828007),87043=>array(-106.462126,35.275451),87044=>array(-106.644271,35.665541),87045=>array(-108.088619,35.351817),87046=>array(-106.909432,36.253528),87047=>array(-106.288766,35.25084),87048=>array(-106.627078,35.239583),87049=>array(-107.596844,35.113635),87051=>array(-107.852853,35.035308),87052=>array(-106.312548,35.493604),87053=>array(-107.019619,35.632313),87056=>array(-105.875931,35.183058),87059=>array(-106.300636,34.996756),87061=>array(-106.379632,34.731143),87062=>array(-106.658818,34.440031),87063=>array(-105.856713,34.491637),87064=>array(-106.58098,36.179253),87068=>array(-106.583062,34.861925),87070=>array(-105.777997,35.021835),87072=>array(-106.396834,35.60703),87083=>array(-106.34276,35.648474),87102=>array(-106.646575,35.081357),87104=>array(-106.675548,35.103183),87105=>array(-106.608155,34.977206),87106=>array(-106.621262,35.05792),87107=>array(-106.642543,35.1378),87108=>array(-106.578362,35.072478),87109=>array(-106.575536,35.152882),87110=>array(-106.578147,35.108194),87111=>array(-106.48746,35.143913),87112=>array(-106.516275,35.100609),87113=>array(-106.593624,35.181016),87114=>array(-106.685666,35.19364),87116=>array(-106.542538,35.063087),87117=>array(-106.563864,35.008492),87120=>array(-106.75494,35.134802),87121=>array(-106.89747,35.089534),87122=>array(-106.501625,35.191009),87123=>array(-106.470746,35.067584),87124=>array(-106.783682,35.268498),87144=>array(-106.705446,35.3252),87301=>array(-108.737949,35.534983),87305=>array(-108.804064,35.382497),87310=>array(-108.539632,35.805114),87311=>array(-108.515804,35.606491),87312=>array(-108.32301,35.422601),87313=>array(-108.076499,35.81245),87315=>array(-108.684918,34.766798),87316=>array(-108.379958,35.364684),87317=>array(-108.761032,35.58753),87319=>array(-108.949089,35.472249),87320=>array(-108.876098,35.807855),87321=>array(-108.361158,35.008797),87322=>array(-108.653142,35.52602),87323=>array(-108.193532,35.457714),87325=>array(-108.614262,35.993895),87326=>array(-108.821265,35.261868),87327=>array(-108.781728,35.005278),87328=>array(-108.981282,35.97874),87347=>array(-108.446455,35.427243),87357=>array(-108.314887,34.909665),87364=>array(-108.698339,36.14142),87375=>array(-108.756811,35.67555),87401=>array(-108.178691,36.740321),87402=>array(-108.144509,36.781273),87410=>array(-107.882308,36.868277),87412=>array(-107.47553,36.697866),87413=>array(-107.97852,36.415501),87415=>array(-108.094079,36.81731),87416=>array(-108.420803,36.702191),87417=>array(-108.345287,36.743778),87418=>array(-108.150215,36.950686),87419=>array(-107.492391,36.864723),87420=>array(-108.899622,36.852599),87421=>array(-108.513048,36.766274),87455=>array(-108.654475,36.330432),87461=>array(-108.941587,36.329475),87499=>array(-108.215832,36.344524),87501=>array(-105.85681,35.744123),87505=>array(-105.874874,35.616815),87506=>array(-105.984455,35.813114),87507=>array(-106.110998,35.595053),87508=>array(-105.96875,35.527445),87510=>array(-106.411504,36.283201),87511=>array(-105.930245,36.105695),87512=>array(-105.343607,36.923617),87513=>array(-105.68733,36.579582),87514=>array(-105.5252,36.541237),87515=>array(-106.393396,36.497233),87516=>array(-106.463052,36.153554),87517=>array(-105.787582,36.394846),87518=>array(-106.562067,36.50822),87519=>array(-105.627938,36.769912),87520=>array(-106.633097,36.874364),87521=>array(-105.612977,36.017328),87522=>array(-105.789765,35.930826),87523=>array(-105.842738,36.013644),87524=>array(-105.672292,36.932428),87525=>array(-105.456847,36.569317),87527=>array(-105.838296,36.151259),87528=>array(-106.983307,36.671546),87529=>array(-105.62284,36.470056),87530=>array(-106.191469,36.348839),87531=>array(-105.839533,36.246711),87532=>array(-106.088977,35.993867),87533=>array(-106.066584,36.024269),87535=>array(-105.747703,35.528725),87537=>array(-106.188827,36.052227),87538=>array(-105.571254,35.494523),87539=>array(-106.043173,36.376682),87540=>array(-105.907902,35.449374),87543=>array(-105.661206,36.107035),87544=>array(-106.288109,35.840721),87548=>array(-106.137809,36.172398),87549=>array(-106.009074,36.237098),87551=>array(-106.669448,36.694598),87552=>array(-105.601579,35.646149),87553=>array(-105.687472,36.214889),87554=>array(-106.01867,36.482898),87556=>array(-105.492012,36.783877),87557=>array(-105.681509,36.291014),87558=>array(-105.441614,36.663936),87560=>array(-105.526197,35.236758),87562=>array(-105.684476,35.41683),87564=>array(-105.62789,36.607972),87565=>array(-105.489881,35.413824),87566=>array(-106.068631,36.072233),87567=>array(-106.020201,35.993887),87569=>array(-105.300633,35.346377),87571=>array(-105.467624,36.39145),87573=>array(-105.685641,35.78939),87574=>array(-105.899105,35.82166),87575=>array(-106.370823,36.740095),87577=>array(-106.014158,36.669246),87578=>array(-105.770114,36.047441),87579=>array(-105.56341,36.094483),87580=>array(-105.565783,36.570074),87581=>array(-106.139632,36.51348),87582=>array(-106.016092,36.156352),87583=>array(-105.336304,35.231374),87701=>array(-104.933487,35.542113),87710=>array(-105.236309,36.382459),87711=>array(-105.103828,35.229352),87712=>array(-105.182856,35.850482),87713=>array(-105.364871,36.167125),87714=>array(-104.912988,36.38948),87715=>array(-105.429042,36.017058),87718=>array(-105.291885,36.599808),87722=>array(-105.261219,36.191932),87723=>array(-105.375577,36.058752),87724=>array(-105.077485,35.173363),87728=>array(-104.619084,36.596537),87729=>array(-104.817967,36.303476),87730=>array(-104.214447,36.153001),87731=>array(-105.41273,35.759858),87732=>array(-105.364286,35.958002),87733=>array(-103.839126,35.815432),87734=>array(-105.085884,36.166544),87735=>array(-105.153162,36.069461),87736=>array(-105.197076,35.980449),87740=>array(-104.415322,36.746631),87742=>array(-105.510938,35.902351),87743=>array(-104.090814,35.973565),87745=>array(-105.213646,35.810926),87746=>array(-104.046894,35.776068),87747=>array(-104.471772,36.356194),87749=>array(-105.103365,36.544433),87750=>array(-104.927202,35.825334),87752=>array(-104.649986,36.021594),87753=>array(-104.954298,35.863313),87801=>array(-106.826187,34.127211),87820=>array(-108.58682,33.937653),87821=>array(-108.0625,33.979952),87823=>array(-106.985948,34.206693),87824=>array(-108.981932,33.828511),87825=>array(-107.656226,33.877317),87827=>array(-108.096748,34.406825),87828=>array(-106.916719,34.205853),87829=>array(-108.642767,34.357703),87830=>array(-108.743608,33.728055),87831=>array(-106.932923,34.264803),87832=>array(-106.821217,33.766896),87901=>array(-107.100585,33.216795),87930=>array(-107.443567,32.850681),87931=>array(-107.42684,32.953468),87933=>array(-107.277913,32.790195),87935=>array(-107.229274,33.254803),87936=>array(-107.263614,32.752827),87937=>array(-107.18432,32.593181),87939=>array(-107.488561,33.412681),87940=>array(-107.006541,32.621516),87941=>array(-107.219612,32.720691),87942=>array(-107.34892,33.060988),87943=>array(-107.736143,33.383092),88001=>array(-106.753893,32.290052),88002=>array(-106.486158,32.462947),88003=>array(-106.745944,32.280653),88004=>array(-106.987431,32.223096),88005=>array(-106.823126,32.258348),88007=>array(-106.921275,32.441092),88008=>array(-106.682084,31.839378),88009=>array(-108.574773,31.996024),88011=>array(-106.655684,32.322234),88012=>array(-106.771378,32.583384),88020=>array(-108.839423,31.77241),88021=>array(-107.016272,31.951887),88022=>array(-108.176468,32.808002),88023=>array(-108.144426,32.732574),88024=>array(-106.639411,32.070555),88025=>array(-108.743434,33.046807),88026=>array(-108.162884,32.752508),88027=>array(-106.789582,32.044128),88028=>array(-108.635946,32.93282),88029=>array(-107.694722,31.844879),88030=>array(-107.729431,32.191634),88032=>array(-106.81876,32.399562),88033=>array(-107.028854,32.319619),88034=>array(-107.938061,32.613183),88038=>array(-108.383037,33.12197),88039=>array(-108.802691,33.298451),88040=>array(-108.354901,31.597337),88041=>array(-107.912538,32.790119),88042=>array(-107.578383,32.812478),88043=>array(-108.10017,32.610356),88044=>array(-106.80585,32.147978),88045=>array(-108.756093,32.385089),88046=>array(-106.802262,32.250018),88047=>array(-106.71469,32.210041),88048=>array(-106.660086,32.163447),88049=>array(-107.918696,33.035582),88051=>array(-108.920335,32.999155),88052=>array(-106.599427,32.425361),88053=>array(-108.205929,32.902516),88055=>array(-108.74099,32.727817),88056=>array(-108.982525,31.844199),88061=>array(-108.333546,32.654439),88063=>array(-106.599107,31.817964),88065=>array(-108.328867,32.677476),88072=>array(-106.616106,32.138064),88081=>array(-106.230566,32.231243),88101=>array(-103.275272,34.499384),88103=>array(-103.31805,34.383968),88112=>array(-103.17692,34.845972),88113=>array(-103.085179,33.77201),88114=>array(-103.199379,33.523567),88115=>array(-103.345497,33.930877),88116=>array(-103.878832,33.9157),88118=>array(-103.689486,34.229541),88119=>array(-104.406747,34.321996),88120=>array(-103.346467,34.79985),88121=>array(-103.980636,34.714623),88124=>array(-103.651819,34.543377),88125=>array(-103.225925,33.705531),88126=>array(-103.372005,33.811264),88130=>array(-103.299416,34.129177),88132=>array(-103.166766,33.907299),88134=>array(-104.018715,34.323093),88135=>array(-103.099614,34.582808),88136=>array(-104.751178,34.465332),88201=>array(-104.377926,33.637061),88203=>array(-104.088238,33.309569),88210=>array(-104.219669,32.771797),88220=>array(-104.431913,32.311477),88230=>array(-104.397567,33.219165),88231=>array(-103.262771,32.451909),88232=>array(-104.465505,33.077377),88240=>array(-103.485112,32.703708),88242=>array(-103.162258,32.813416),88250=>array(-104.960413,32.701888),88252=>array(-103.377932,32.155119),88253=>array(-104.626368,32.934647),88254=>array(-104.450247,32.612744),88255=>array(-103.996448,32.814201),88256=>array(-103.908039,32.198065),88260=>array(-103.381883,32.991905),88262=>array(-103.421158,33.11714),88263=>array(-104.081618,32.097881),88264=>array(-103.711709,32.890912),88265=>array(-103.302871,32.620454),88267=>array(-103.425219,33.337444),88268=>array(-104.379667,32.176318),88301=>array(-105.78572,33.784013),88310=>array(-106.075211,32.640069),88311=>array(-105.987545,32.807979),88312=>array(-105.672598,33.437646),88314=>array(-105.866968,33.110124),88316=>array(-105.322893,33.797656),88317=>array(-105.636987,32.923773),88318=>array(-105.396938,34.207102),88321=>array(-105.45833,34.761307),88323=>array(-105.527545,33.494704),88324=>array(-105.439057,33.389812),88325=>array(-105.858376,32.856605),88330=>array(-106.077383,32.836613),88336=>array(-105.280003,33.328305),88337=>array(-105.884699,32.996694),88338=>array(-105.39452,33.489525),88339=>array(-105.26062,32.941875),88340=>array(-105.583242,33.176135),88341=>array(-105.856659,33.426176),88342=>array(-106.111844,32.388579),88343=>array(-105.07718,33.225921),88344=>array(-105.292323,32.558694),88345=>array(-105.680284,33.347226),88346=>array(-105.540052,33.353807),88347=>array(-105.657681,32.756185),88348=>array(-105.358391,33.396166),88349=>array(-105.802258,32.779277),88350=>array(-105.677014,32.643391),88351=>array(-105.087715,33.549422),88352=>array(-105.994033,33.166311),88353=>array(-105.116141,34.571355),88354=>array(-105.494342,32.755149),88355=>array(-105.667375,33.360416),88401=>array(-103.82223,35.119482),88410=>array(-103.290783,35.877027),88411=>array(-103.150619,35.140656),88414=>array(-103.995689,36.776962),88415=>array(-103.326817,36.31176),88416=>array(-104.194698,35.285771),88417=>array(-104.376625,35.05921),88418=>array(-103.684739,36.725861),88419=>array(-103.531021,36.910053),88421=>array(-104.481343,35.298352),88422=>array(-103.991533,36.345307),88424=>array(-103.656438,36.412538),88426=>array(-103.509461,35.541549),88427=>array(-103.774375,34.770502),88430=>array(-103.180367,35.581506),88431=>array(-104.274806,35.170055),88434=>array(-103.30598,35.1747),88435=>array(-104.695792,34.91415),88436=>array(-103.123137,36.137269),89001=>array(-115.394121,37.276925),89002=>array(-114.960945,35.998374),89003=>array(-116.744158,36.971364),89004=>array(-115.487884,36.102747),89005=>array(-114.808625,35.986732),89007=>array(-114.226747,36.666657),89008=>array(-114.513105,37.286087),89010=>array(-118.0749,37.782535),89011=>array(-114.968477,36.082721),89012=>array(-115.04326,36.011893),89013=>array(-117.346901,37.415175),89014=>array(-115.058058,36.061711),89015=>array(-114.928019,36.039297),89017=>array(-115.250938,37.744047),89018=>array(-115.645121,36.511372),89019=>array(-115.734797,35.766629),89020=>array(-116.44361,36.532267),89021=>array(-114.471037,36.640293),89022=>array(-117.020737,38.540993),89025=>array(-114.885509,36.562868),89026=>array(-115.289723,35.755242),89027=>array(-114.120202,36.813688),89029=>array(-114.656532,35.129221),89030=>array(-115.124148,36.211456),89031=>array(-115.171802,36.258889),89032=>array(-115.172685,36.223177),89039=>array(-114.879811,35.287924),89040=>array(-114.578916,36.356616),89042=>array(-114.332372,37.74549),89043=>array(-114.473413,38.255898),89044=>array(-115.17894,35.902436),89045=>array(-116.968867,38.880562),89046=>array(-114.888087,35.501134),89047=>array(-117.647869,37.76595),89048=>array(-116.003323,36.165343),89049=>array(-116.262314,38.356663),89052=>array(-115.056694,35.955099),89054=>array(-115.208272,35.927208),89060=>array(-116.060445,36.385724),89061=>array(-115.89833,36.086419),89074=>array(-115.080923,36.036566),89081=>array(-115.103228,36.257886),89084=>array(-115.174209,36.296907),89085=>array(-115.198089,36.309655),89086=>array(-115.108589,36.292251),89101=>array(-115.122231,36.172538),89102=>array(-115.186819,36.145412),89103=>array(-115.211676,36.111833),89104=>array(-115.10869,36.151355),89106=>array(-115.163224,36.181688),89107=>array(-115.209288,36.171241),89108=>array(-115.223617,36.205266),89109=>array(-115.168382,36.131662),89110=>array(-115.047748,36.171425),89113=>array(-115.2635,36.061133),89115=>array(-115.041025,36.253638),89117=>array(-115.281091,36.140961),89118=>array(-115.213966,36.07738),89119=>array(-115.146127,36.084718),89120=>array(-115.095454,36.081322),89121=>array(-115.091324,36.121523),89122=>array(-115.040317,36.106445),89123=>array(-115.148777,36.035207),89124=>array(-115.613219,36.114842),89128=>array(-115.26437,36.196822),89129=>array(-115.29015,36.233315),89130=>array(-115.227091,36.253967),89131=>array(-115.245989,36.307145),89134=>array(-115.307758,36.202731),89135=>array(-115.375912,36.100975),89138=>array(-115.361278,36.16661),89139=>array(-115.211674,36.03468),89141=>array(-115.207041,35.988444),89142=>array(-115.036334,36.147921),89143=>array(-115.293151,36.322319),89144=>array(-115.320765,36.178887),89145=>array(-115.277754,36.167688),89146=>array(-115.226889,36.143242),89147=>array(-115.280099,36.112796),89148=>array(-115.297071,36.08017),89149=>array(-115.292516,36.272251),89156=>array(-114.988132,36.163408),89161=>array(-115.363878,36.00036),89166=>array(-115.506876,36.380644),89169=>array(-115.141303,36.124162),89178=>array(-115.286067,35.997669),89179=>array(-115.331936,35.894539),89183=>array(-115.157608,35.995852),89191=>array(-115.025738,36.239491),89301=>array(-114.770485,39.54005),89310=>array(-117.162771,39.430542),89311=>array(-114.200069,38.986044),89314=>array(-115.772027,38.822807),89316=>array(-115.900602,39.827988),89317=>array(-115.025158,38.797901),89318=>array(-114.810189,39.443721),89319=>array(-114.976004,39.296292),89402=>array(-120.002192,39.22507),89403=>array(-119.478309,39.231543),89404=>array(-118.668673,41.903178),89405=>array(-119.424671,40.480566),89406=>array(-118.270419,39.525701),89408=>array(-119.173626,39.563323),89409=>array(-118.11,38.801841),89410=>array(-119.604152,38.871803),89411=>array(-119.850215,39.019002),89412=>array(-119.695361,41.102934),89413=>array(-119.922857,39.073447),89414=>array(-117.181049,41.04458),89415=>array(-118.637507,38.480395),89418=>array(-118.034358,40.54828),89419=>array(-118.189048,40.374813),89420=>array(-118.226681,38.544555),89421=>array(-117.855797,42.052099),89422=>array(-118.453799,38.177609),89423=>array(-119.755643,39.018863),89424=>array(-119.284054,39.888166),89425=>array(-117.916223,41.629858),89426=>array(-117.424872,41.487947),89427=>array(-118.633369,38.891607),89428=>array(-119.634643,39.261033),89429=>array(-119.297035,39.324826),89430=>array(-119.305082,38.77509),89431=>array(-119.749111,39.540398),89433=>array(-119.776657,39.608937),89434=>array(-119.650155,39.541317),89436=>array(-119.689298,39.604161),89438=>array(-117.093499,40.798541),89439=>array(-119.9998,39.520351),89440=>array(-119.658713,39.296482),89441=>array(-119.675827,39.676372),89442=>array(-119.414848,39.709319),89444=>array(-119.38563,38.669814),89445=>array(-118.263916,41.169339),89446=>array(-117.870321,41.217004),89447=>array(-119.131304,38.811278),89448=>array(-119.917476,38.996486),89449=>array(-119.911221,38.954993),89450=>array(-119.939145,39.240488),89451=>array(-119.934182,39.24158),89460=>array(-119.792493,38.902253),89501=>array(-119.813051,39.525749),89502=>array(-119.743845,39.491314),89503=>array(-119.840126,39.54104),89506=>array(-119.820815,39.712124),89508=>array(-119.913754,39.780602),89509=>array(-119.827452,39.495957),89510=>array(-119.612974,40.081901),89511=>array(-119.876909,39.385441),89512=>array(-119.800887,39.55587),89519=>array(-119.857872,39.480704),89521=>array(-119.691971,39.385286),89523=>array(-119.917297,39.52432),89701=>array(-119.725249,39.130227),89702=>array(-119.73581,39.159097),89703=>array(-119.834819,39.163819),89704=>array(-119.815844,39.262661),89705=>array(-119.860561,39.111672),89706=>array(-119.701535,39.222699),89801=>array(-115.761405,41.247991),89815=>array(-115.594252,40.615333),89820=>array(-116.977156,40.411623),89821=>array(-116.468358,40.495361),89822=>array(-116.193978,40.530669),89823=>array(-115.280794,41.007325),89825=>array(-114.7774,41.876177),89826=>array(-115.385386,41.890603),89828=>array(-115.296463,40.779688),89830=>array(-114.286701,41.269963),89831=>array(-116.078505,41.716264),89832=>array(-116.15806,41.980015),89833=>array(-115.331629,40.481519),89834=>array(-116.203471,41.379983),89835=>array(-114.852524,41.114501),89883=>array(-114.156963,40.848683),90001=>array(-118.249509,33.974027),90002=>array(-118.246737,33.949099),90003=>array(-118.272783,33.964131),90004=>array(-118.310722,34.076198),90005=>array(-118.306892,34.059163),90006=>array(-118.294177,34.048041),90007=>array(-118.284828,34.028133),90008=>array(-118.346724,34.009552),90010=>array(-118.315889,34.062148),90011=>array(-118.258681,34.00709),90012=>array(-118.238728,34.065875),90013=>array(-118.240454,34.045405),90014=>array(-118.251746,34.043146),90015=>array(-118.266299,34.039378),90016=>array(-118.354338,34.028331),90017=>array(-118.26434,34.052913),90018=>array(-118.317183,34.028887),90019=>array(-118.33846,34.049841),90020=>array(-118.30987,34.066379),90021=>array(-118.23787,34.029036),90022=>array(-118.156275,34.023728),90023=>array(-118.199613,34.022502),90024=>array(-118.434999,34.065729),90025=>array(-118.445818,34.04536),90026=>array(-118.262643,34.080017),90027=>array(-118.295647,34.127194),90028=>array(-118.326912,34.099912),90029=>array(-118.294661,34.089848),90031=>array(-118.206617,34.085807),90032=>array(-118.185497,34.078195),90033=>array(-118.211991,34.05038),90034=>array(-118.399613,34.030578),90035=>array(-118.383674,34.051809),90036=>array(-118.350411,34.07041),90037=>array(-118.287487,34.002723),90038=>array(-118.325527,34.088475),90039=>array(-118.260552,34.111525),90040=>array(-118.149953,33.994524),90041=>array(-118.207607,34.137412),90042=>array(-118.192098,34.114708),90043=>array(-118.336358,33.988505),90044=>array(-118.291904,33.952724),90045=>array(-118.417488,33.942108),90046=>array(-118.362081,34.108455),90047=>array(-118.308428,33.953617),90048=>array(-118.37271,34.072924),90049=>array(-118.491244,34.091829),90056=>array(-118.370361,33.988047),90057=>array(-118.276757,34.061735),90058=>array(-118.2164,34.002844),90059=>array(-118.249883,33.926262),90061=>array(-118.274186,33.92128),90062=>array(-118.308806,34.003638),90063=>array(-118.185914,34.045105),90064=>array(-118.423573,34.037251),90065=>array(-118.225496,34.112272),90066=>array(-118.430656,34.002028),90067=>array(-118.413998,34.057597),90068=>array(-118.330989,34.129772),90069=>array(-118.381697,34.093828),90071=>array(-118.254943,34.052876),90073=>array(-118.45703,34.054533),90077=>array(-118.457081,34.108537),90079=>array(-118.255404,34.040587),90089=>array(-118.286035,34.020221),90090=>array(-118.240989,34.072862),90094=>array(-118.416989,33.975416),90095=>array(-118.443545,34.071312),90201=>array(-118.171368,33.970343),90210=>array(-118.415972,34.10263),90211=>array(-118.382979,34.064958),90212=>array(-118.401966,34.06221),90220=>array(-118.234451,33.88151),90221=>array(-118.205918,33.885624),90222=>array(-118.236773,33.912246),90230=>array(-118.394059,33.998213),90232=>array(-118.391902,34.019323),90240=>array(-118.118346,33.955729),90241=>array(-118.128628,33.940884),90242=>array(-118.140588,33.921793),90245=>array(-118.404267,33.91714),90247=>array(-118.297967,33.890853),90248=>array(-118.284077,33.876482),90249=>array(-118.315697,33.90139),90250=>array(-118.348083,33.914775),90254=>array(-118.399303,33.864259),90255=>array(-118.217141,33.97803),90260=>array(-118.351813,33.88856),90262=>array(-118.200705,33.923533),90263=>array(-118.707992,34.039034),90265=>array(-118.846342,34.066117),90266=>array(-118.402127,33.889151),90270=>array(-118.186597,33.987729),90272=>array(-118.544232,34.08746),90274=>array(-118.372454,33.780065),90275=>array(-118.367459,33.753146),90277=>array(-118.387124,33.830006),90278=>array(-118.370359,33.873214),90280=>array(-118.192761,33.944159),90290=>array(-118.615981,34.107728),90291=>array(-118.465193,33.993396),90292=>array(-118.457852,33.979007),90293=>array(-118.439841,33.947305),90301=>array(-118.358653,33.956526),90302=>array(-118.355252,33.975332),90303=>array(-118.331085,33.939766),90304=>array(-118.358559,33.937887),90305=>array(-118.330548,33.95889),90401=>array(-118.49375,34.013666),90402=>array(-118.504039,34.034666),90403=>array(-118.492101,34.030755),90404=>array(-118.473643,34.026608),90405=>array(-118.46963,34.011167),90501=>array(-118.314022,33.833744),90502=>array(-118.292062,33.833181),90503=>array(-118.353714,33.840399),90504=>array(-118.330794,33.867257),90505=>array(-118.347957,33.807882),90506=>array(-118.329998,33.884696),90601=>array(-118.030271,34.00784),90602=>array(-118.022557,33.972232),90603=>array(-117.992066,33.945318),90604=>array(-118.01208,33.929704),90605=>array(-118.024352,33.950295),90606=>array(-118.066363,33.977272),90620=>array(-118.012225,33.846302),90621=>array(-117.993368,33.874224),90623=>array(-118.039892,33.850504),90630=>array(-118.038307,33.818477),90631=>array(-117.952483,33.942708),90638=>array(-118.008961,33.902045),90640=>array(-118.111012,34.015444),90650=>array(-118.08264,33.906956),90660=>array(-118.089299,33.989524),90670=>array(-118.062611,33.933565),90680=>array(-117.994901,33.801178),90701=>array(-118.080612,33.8676),90703=>array(-118.069208,33.868049),90704=>array(-118.441282,33.397729),90706=>array(-118.12725,33.887821),90710=>array(-118.298661,33.799904),90712=>array(-118.147902,33.849034),90713=>array(-118.112601,33.847989),90715=>array(-118.079141,33.841027),90716=>array(-118.072639,33.830457),90717=>array(-118.31717,33.793809),90720=>array(-118.062692,33.795012),90723=>array(-118.166629,33.898883),90731=>array(-118.278869,33.731442),90732=>array(-118.312878,33.74212),90740=>array(-118.075043,33.758405),90742=>array(-118.076906,33.716666),90743=>array(-118.090327,33.726516),90744=>array(-118.261723,33.779284),90745=>array(-118.264112,33.821605),90746=>array(-118.252272,33.859171),90747=>array(-118.251318,33.8629),90755=>array(-118.168135,33.803448),90802=>array(-118.208042,33.745762),90803=>array(-118.130636,33.756289),90804=>array(-118.148365,33.781686),90805=>array(-118.180567,33.864617),90806=>array(-118.188596,33.80564),90807=>array(-118.17482,33.82774),90808=>array(-118.111335,33.823943),90810=>array(-118.222416,33.819814),90813=>array(-118.196793,33.782259),90814=>array(-118.143631,33.771616),90815=>array(-118.116391,33.794348),90822=>array(-118.118648,33.778436),90831=>array(-118.201639,33.768338),91001=>array(-118.137227,34.195275),91006=>array(-118.026704,34.136258),91007=>array(-118.047732,34.128284),91008=>array(-117.968818,34.153159),91010=>array(-117.957627,34.141586),91011=>array(-118.205369,34.222261),91016=>array(-118.000482,34.1528),91020=>array(-118.230652,34.211341),91024=>array(-118.050216,34.168771),91030=>array(-118.156615,34.108957),91040=>array(-118.336078,34.261962),91042=>array(-118.237917,34.32222),91046=>array(-118.241036,34.211452),91101=>array(-118.139456,34.146671),91103=>array(-118.164941,34.169538),91104=>array(-118.123752,34.165383),91105=>array(-118.166649,34.13946),91106=>array(-118.128658,34.139402),91107=>array(-118.085873,34.156397),91108=>array(-118.112911,34.122671),91201=>array(-118.289463,34.17051),91202=>array(-118.267539,34.167926),91203=>array(-118.262974,34.153338),91204=>array(-118.260934,34.136194),91205=>array(-118.245839,34.13658),91206=>array(-118.213769,34.160359),91207=>array(-118.262922,34.182378),91208=>array(-118.239524,34.185832),91210=>array(-118.256507,34.144557),91214=>array(-118.249185,34.236302),91301=>array(-118.758541,34.123286),91302=>array(-118.671028,34.12331),91303=>array(-118.600913,34.198292),91304=>array(-118.632656,34.224377),91306=>array(-118.577563,34.209532),91307=>array(-118.6649,34.200833),91311=>array(-118.603883,34.294142),91316=>array(-118.515472,34.160236),91320=>array(-118.945118,34.175969),91321=>array(-118.489037,34.36811),91324=>array(-118.55029,34.238208),91325=>array(-118.517588,34.236683),91326=>array(-118.556005,34.281486),91330=>array(-118.526076,34.247532),91331=>array(-118.421314,34.255442),91335=>array(-118.540958,34.200175),91340=>array(-118.435078,34.286689),91342=>array(-118.382262,34.326674),91343=>array(-118.482306,34.237912),91344=>array(-118.507001,34.294615),91345=>array(-118.457241,34.265878),91350=>array(-118.501747,34.440891),91351=>array(-118.448088,34.441427),91352=>array(-118.365856,34.230854),91354=>array(-118.553789,34.465755),91355=>array(-118.634816,34.439741),91356=>array(-118.547553,34.155097),91360=>array(-118.882175,34.212798),91361=>array(-118.888909,34.136057),91362=>array(-118.818678,34.193329),91364=>array(-118.593408,34.153733),91367=>array(-118.615714,34.178068),91371=>array(-118.576125,34.184616),91377=>array(-118.766918,34.184975),91381=>array(-118.647017,34.384545),91384=>array(-118.699048,34.506627),91387=>array(-118.372452,34.402488),91390=>array(-118.420095,34.545587),91401=>array(-118.431791,34.178483),91402=>array(-118.444689,34.222506),91403=>array(-118.463365,34.147149),91405=>array(-118.447609,34.199824),91406=>array(-118.490752,34.195685),91411=>array(-118.459234,34.178522),91423=>array(-118.433298,34.148617),91436=>array(-118.490755,34.151729),91501=>array(-118.292773,34.200992),91502=>array(-118.31003,34.177267),91504=>array(-118.326365,34.204568),91505=>array(-118.346937,34.173885),91506=>array(-118.323548,34.169706),91601=>array(-118.372498,34.1692),91602=>array(-118.368159,34.150818),91604=>array(-118.39275,34.139082),91605=>array(-118.400022,34.207295),91606=>array(-118.388323,34.185767),91607=>array(-118.399795,34.165783),91608=>array(-118.350933,34.138761),91701=>array(-117.599944,34.137563),91702=>array(-117.866141,34.280333),91706=>array(-117.968269,34.09741),91708=>array(-117.639209,33.953755),91709=>array(-117.738491,33.963746),91710=>array(-117.684702,34.004473),91711=>array(-117.715284,34.12744),91722=>array(-117.906736,34.097345),91723=>array(-117.886844,34.084747),91724=>array(-117.854733,34.080444),91730=>array(-117.57882,34.10097),91731=>array(-118.043456,34.078573),91732=>array(-118.015345,34.07342),91733=>array(-118.053748,34.046243),91737=>array(-117.577707,34.152583),91739=>array(-117.52302,34.171699),91740=>array(-117.855059,34.119363),91741=>array(-117.841605,34.156529),91744=>array(-117.93647,34.031415),91745=>array(-117.972146,33.999005),91746=>array(-117.985366,34.044416),91748=>array(-117.900676,33.974883),91750=>array(-117.779803,34.17707),91752=>array(-117.535347,33.994305),91754=>array(-118.143465,34.052922),91755=>array(-118.114394,34.050965),91759=>array(-117.69947,34.263636),91761=>array(-117.591528,34.035602),91762=>array(-117.674011,34.05941),91763=>array(-117.698315,34.072329),91764=>array(-117.605618,34.074087),91765=>array(-117.820908,33.986775),91766=>array(-117.756106,34.042286),91767=>array(-117.737997,34.083086),91768=>array(-117.790379,34.063516),91770=>array(-118.084529,34.065493),91773=>array(-117.81039,34.110186),91775=>array(-118.089431,34.114772),91776=>array(-118.095091,34.090776),91780=>array(-118.055929,34.101674),91784=>array(-117.655583,34.141146),91786=>array(-117.662035,34.105281),91789=>array(-117.85492,34.018354),91790=>array(-117.937007,34.066964),91791=>array(-117.893169,34.061634),91792=>array(-117.902359,34.022581),91801=>array(-118.127527,34.090728),91803=>array(-118.145959,34.074736),91901=>array(-116.710667,32.810624),91902=>array(-117.018657,32.665762),91905=>array(-116.314445,32.682149),91906=>array(-116.465373,32.654863),91910=>array(-117.057991,32.637898),91911=>array(-117.053949,32.607008),91913=>array(-116.98582,32.619459),91914=>array(-116.944653,32.673652),91915=>array(-116.949053,32.623185),91916=>array(-116.621359,32.887991),91917=>array(-116.71966,32.608865),91931=>array(-116.557729,32.846363),91932=>array(-117.120872,32.573755),91934=>array(-116.152562,32.648995),91935=>array(-116.792813,32.722157),91941=>array(-116.99726,32.759327),91942=>array(-117.021511,32.777999),91945=>array(-117.034164,32.733177),91948=>array(-116.448325,32.866646),91950=>array(-117.094668,32.670646),91962=>array(-116.415161,32.735124),91963=>array(-116.61002,32.626231),91977=>array(-116.994318,32.726236),91978=>array(-116.940093,32.724154),91980=>array(-116.619172,32.588866),92003=>array(-117.199489,33.284926),92004=>array(-116.106046,33.142077),92007=>array(-117.274923,33.02325),92008=>array(-117.319439,33.144219),92009=>array(-117.243796,33.09532),92010=>array(-117.277163,33.1585),92011=>array(-117.292182,33.107582),92014=>array(-117.248296,32.965617),92019=>array(-116.880634,32.776012),92020=>array(-116.969721,32.79551),92021=>array(-116.872692,32.841221),92024=>array(-117.2599,33.056022),92025=>array(-117.08042,33.102005),92026=>array(-117.1161,33.212452),92027=>array(-116.976997,33.131156),92028=>array(-117.209427,33.390477),92029=>array(-117.129422,33.084281),92036=>array(-116.493688,33.022474),92037=>array(-117.250058,32.856347),92040=>array(-116.892002,32.908904),92054=>array(-117.354538,33.195534),92055=>array(-117.444758,33.387723),92056=>array(-117.296984,33.201242),92057=>array(-117.283379,33.25461),92058=>array(-117.304765,33.326859),92059=>array(-117.066121,33.376467),92060=>array(-116.852856,33.346494),92061=>array(-116.924785,33.298504),92064=>array(-117.019037,32.983612),92065=>array(-116.850651,33.053006),92066=>array(-116.535247,33.219365),92067=>array(-117.190346,33.020908),92069=>array(-117.158674,33.170778),92070=>array(-116.726767,33.149301),92071=>array(-116.987842,32.852358),92075=>array(-117.26058,32.997248),92078=>array(-117.180965,33.115978),92081=>array(-117.24027,33.164374),92082=>array(-117.002555,33.254381),92083=>array(-117.248203,33.19784),92084=>array(-117.202606,33.219935),92086=>array(-116.659989,33.327021),92091=>array(-117.243552,33.016044),92101=>array(-117.170912,32.724103),92102=>array(-117.117058,32.716221),92103=>array(-117.166884,32.747412),92104=>array(-117.127948,32.741501),92105=>array(-117.092669,32.737826),92106=>array(-117.237613,32.710818),92107=>array(-117.245404,32.739055),92108=>array(-117.142454,32.774046),92109=>array(-117.234207,32.786772),92110=>array(-117.200391,32.765244),92111=>array(-117.168864,32.806479),92113=>array(-117.117827,32.696526),92114=>array(-117.055095,32.707756),92115=>array(-117.073643,32.765001),92116=>array(-117.123151,32.764968),92117=>array(-117.199521,32.824567),92118=>array(-117.209642,32.699234),92119=>array(-117.031956,32.817888),92120=>array(-117.071764,32.794714),92121=>array(-117.201203,32.899592),92122=>array(-117.171224,32.861727),92123=>array(-117.134914,32.806777),92124=>array(-117.092378,32.823766),92126=>array(-117.141293,32.908406),92127=>array(-117.132686,33.011833),92128=>array(-117.071808,32.999818),92129=>array(-117.126181,32.966976),92130=>array(-117.214366,32.945791),92131=>array(-117.083325,32.886218),92132=>array(-117.172089,32.713608),92134=>array(-117.146596,32.724208),92135=>array(-117.192775,32.697543),92139=>array(-117.0489,32.679875),92140=>array(-117.197401,32.739496),92145=>array(-117.008063,32.930554),92147=>array(-117.219293,32.724618),92154=>array(-117.006117,32.557011),92155=>array(-117.161726,32.674984),92173=>array(-117.042502,32.553631),92201=>array(-116.204844,33.710984),92203=>array(-116.246488,33.75396),92210=>array(-116.34123,33.692193),92211=>array(-116.334205,33.765401),92220=>array(-116.832362,33.948948),92222=>array(-114.545506,32.785826),92223=>array(-116.987836,33.948254),92225=>array(-114.687973,33.736458),92227=>array(-115.358757,32.990121),92230=>array(-116.765723,33.910412),92231=>array(-115.541,32.68755),92233=>array(-115.553769,33.172881),92234=>array(-116.466743,33.818256),92236=>array(-116.172918,33.686145),92239=>array(-115.4661,33.762149),92240=>array(-116.520104,33.95154),92241=>array(-116.292771,33.835639),92242=>array(-114.319121,34.163216),92243=>array(-115.598602,32.770275),92249=>array(-115.472614,32.725546),92250=>array(-115.152865,32.811001),92251=>array(-115.675459,32.881449),92252=>array(-116.288431,34.168333),92253=>array(-116.273943,33.641767),92254=>array(-115.993906,33.543835),92256=>array(-116.606626,34.077059),92257=>array(-115.293842,33.299478),92258=>array(-116.559873,33.915839),92259=>array(-115.932182,32.737701),92260=>array(-116.403644,33.708076),92262=>array(-116.566176,33.860925),92264=>array(-116.49762,33.70859),92266=>array(-114.930437,33.344936),92267=>array(-114.196525,34.273755),92268=>array(-116.564222,34.222079),92270=>array(-116.429973,33.768611),92273=>array(-115.700076,32.817225),92274=>array(-116.084589,33.460511),92275=>array(-115.844166,33.292095),92276=>array(-116.364238,33.82233),92277=>array(-115.621176,34.141356),92278=>array(-116.055053,34.229973),92280=>array(-114.633391,34.112956),92281=>array(-115.608751,33.051757),92282=>array(-116.683221,33.97963),92283=>array(-114.772944,32.891548),92284=>array(-116.432416,34.185894),92285=>array(-116.540435,34.340222),92301=>array(-117.453724,34.585234),92304=>array(-115.644609,34.541483),92305=>array(-116.817981,34.141671),92307=>array(-117.133076,34.571446),92308=>array(-117.161732,34.425262),92309=>array(-116.038586,35.332155),92310=>array(-116.690639,35.261739),92311=>array(-116.964449,34.980294),92313=>array(-117.312929,34.031011),92314=>array(-116.809496,34.261092),92315=>array(-116.903843,34.233757),92316=>array(-117.39104,34.059722),92320=>array(-117.052249,33.990365),92321=>array(-117.150891,34.253816),92322=>array(-117.326453,34.254361),92324=>array(-117.289351,34.024368),92325=>array(-117.281304,34.243482),92327=>array(-116.862059,34.863585),92328=>array(-116.827387,36.597877),92332=>array(-115.342092,34.912426),92333=>array(-116.949312,34.270608),92335=>array(-117.465136,34.085957),92336=>array(-117.464506,34.147718),92337=>array(-117.470612,34.04981),92338=>array(-116.190564,34.782699),92339=>array(-116.936222,34.093661),92341=>array(-117.062838,34.236643),92342=>array(-117.350142,34.757047),92344=>array(-117.405721,34.391146),92345=>array(-117.300435,34.374627),92346=>array(-117.183148,34.12738),92347=>array(-117.219606,34.957406),92352=>array(-117.199381,34.259971),92354=>array(-117.248563,34.051177),92356=>array(-116.896718,34.510646),92358=>array(-117.520971,34.259272),92359=>array(-117.073317,34.083016),92363=>array(-114.640335,34.894366),92364=>array(-115.426224,35.34042),92365=>array(-116.655003,34.900018),92368=>array(-117.320224,34.649186),92371=>array(-117.541815,34.442625),92372=>array(-117.623946,34.447894),92373=>array(-117.159696,34.011935),92374=>array(-117.172,34.067213),92376=>array(-117.377406,34.111605),92377=>array(-117.406066,34.157868),92378=>array(-117.225931,34.226083),92382=>array(-117.117403,34.205287),92384=>array(-116.178478,36.007706),92385=>array(-117.192326,34.21474),92386=>array(-116.827695,34.237229),92389=>array(-116.18637,35.901353),92391=>array(-117.234788,34.237898),92392=>array(-117.408186,34.480247),92394=>array(-117.353632,34.556111),92395=>array(-117.291635,34.501576),92397=>array(-117.628429,34.374009),92398=>array(-116.849376,34.910795),92399=>array(-117.010508,34.032284),92401=>array(-117.29215,34.104794),92404=>array(-117.221583,34.183506),92405=>array(-117.301301,34.14463),92407=>array(-117.381097,34.212216),92408=>array(-117.270016,34.083458),92410=>array(-117.297553,34.106922),92411=>array(-117.320138,34.122501),92501=>array(-117.373184,33.99504),92503=>array(-117.442303,33.882579),92504=>array(-117.398044,33.903134),92505=>array(-117.493881,33.936193),92506=>array(-117.367319,33.934335),92507=>array(-117.32512,33.970847),92508=>array(-117.32675,33.891132),92509=>array(-117.442161,34.003028),92518=>array(-117.278368,33.889103),92530=>array(-117.372457,33.650799),92532=>array(-117.302951,33.692675),92536=>array(-116.837955,33.492391),92539=>array(-116.64762,33.527867),92543=>array(-116.963506,33.667301),92544=>array(-116.882748,33.646625),92545=>array(-117.03406,33.729853),92548=>array(-117.109484,33.758663),92549=>array(-116.753505,33.768565),92551=>array(-117.224878,33.88274),92553=>array(-117.244825,33.923386),92555=>array(-117.112789,33.890645),92557=>array(-117.258448,33.97216),92561=>array(-116.627212,33.637201),92562=>array(-117.344739,33.548299),92563=>array(-117.14719,33.581045),92567=>array(-117.105415,33.810743),92570=>array(-117.320673,33.787292),92571=>array(-117.205481,33.82931),92582=>array(-117.020069,33.806708),92583=>array(-116.934097,33.79736),92584=>array(-117.173618,33.658592),92585=>array(-117.172142,33.746707),92586=>array(-117.198846,33.708976),92587=>array(-117.250024,33.692805),92590=>array(-117.227005,33.480536),92591=>array(-117.104785,33.535276),92592=>array(-117.042388,33.511218),92595=>array(-117.259304,33.617845),92596=>array(-117.050379,33.665531),92602=>array(-117.750414,33.757245),92603=>array(-117.780978,33.623874),92604=>array(-117.788058,33.688584),92606=>array(-117.8159,33.701704),92610=>array(-117.67594,33.696122),92612=>array(-117.826009,33.65844),92614=>array(-117.833295,33.680302),92617=>array(-117.841688,33.642512),92618=>array(-117.732135,33.667145),92620=>array(-117.751372,33.712629),92624=>array(-117.659056,33.451469),92625=>array(-117.864253,33.601966),92626=>array(-117.911715,33.678399),92627=>array(-117.919761,33.647763),92629=>array(-117.705675,33.47512),92630=>array(-117.685503,33.645736),92637=>array(-117.731443,33.612925),92646=>array(-117.968459,33.66205),92647=>array(-118.008692,33.723228),92648=>array(-118.014603,33.67901),92649=>array(-118.051579,33.72524),92651=>array(-117.773037,33.570925),92653=>array(-117.697512,33.591304),92655=>array(-117.984872,33.745101),92656=>array(-117.730364,33.576205),92657=>array(-117.829038,33.595088),92660=>array(-117.874882,33.634626),92661=>array(-117.913001,33.601984),92662=>array(-117.892319,33.605086),92663=>array(-117.933903,33.623208),92672=>array(-117.606843,33.42362),92673=>array(-117.613509,33.467372),92675=>array(-117.608674,33.501773),92676=>array(-117.612607,33.752512),92677=>array(-117.701175,33.529047),92678=>array(-117.526144,33.680226),92679=>array(-117.60436,33.606695),92683=>array(-117.993904,33.75245),92688=>array(-117.612087,33.619672),92691=>array(-117.665867,33.611945),92692=>array(-117.643112,33.606497),92694=>array(-117.62376,33.547236),92701=>array(-117.858473,33.74822),92703=>array(-117.906761,33.747615),92704=>array(-117.90511,33.721131),92705=>array(-117.790075,33.765639),92706=>array(-117.881976,33.765301),92707=>array(-117.870431,33.709935),92708=>array(-117.951129,33.710582),92780=>array(-117.819157,33.73401),92782=>array(-117.78471,33.739689),92801=>array(-117.952151,33.844983),92802=>array(-117.923655,33.808271),92804=>array(-117.974997,33.818251),92805=>array(-117.906109,33.830209),92806=>array(-117.870494,33.83796),92807=>array(-117.788357,33.848733),92808=>array(-117.74021,33.856495),92821=>array(-117.887086,33.927561),92823=>array(-117.809353,33.928202),92831=>array(-117.89634,33.879767),92832=>array(-117.929055,33.868649),92833=>array(-117.961743,33.879309),92835=>array(-117.916639,33.901886),92840=>array(-117.931889,33.787165),92841=>array(-117.98202,33.786846),92843=>array(-117.93138,33.763928),92844=>array(-117.969509,33.76548),92845=>array(-118.026268,33.783064),92860=>array(-117.551958,33.925519),92861=>array(-117.810013,33.81766),92865=>array(-117.851196,33.827031),92866=>array(-117.844774,33.784615),92867=>array(-117.843772,33.80098),92868=>array(-117.87655,33.788145),92869=>array(-117.791041,33.808485),92870=>array(-117.854783,33.881158),92879=>array(-117.5269,33.882879),92880=>array(-117.617809,33.918043),92881=>array(-117.524091,33.827409),92882=>array(-117.601961,33.840451),92883=>array(-117.474266,33.752748),92886=>array(-117.796416,33.896339),92887=>array(-117.730164,33.885514),93001=>array(-119.80079,34.037342),93003=>array(-119.223196,34.283668),93004=>array(-119.165615,34.278679),93010=>array(-119.079869,34.227855),93012=>array(-118.988163,34.198821),93013=>array(-119.513163,34.441398),93015=>array(-118.897776,34.404104),93021=>array(-118.898546,34.297029),93022=>array(-119.306554,34.40778),93023=>array(-119.310134,34.5302),93030=>array(-119.174092,34.205247),93033=>array(-119.127729,34.150212),93035=>array(-119.224985,34.181971),93036=>array(-119.184377,34.236999),93040=>array(-118.797181,34.473883),93041=>array(-119.099535,34.106896),93042=>array(-119.503588,33.255655),93043=>array(-119.202409,34.170854),93060=>array(-119.094824,34.402343),93063=>array(-118.687222,34.30873),93064=>array(-118.70094,34.247556),93065=>array(-118.774661,34.258272),93066=>array(-119.014627,34.297628),93067=>array(-119.593483,34.421964),93101=>array(-119.709166,34.418979),93103=>array(-119.678826,34.438786),93105=>array(-119.797628,34.534881),93108=>array(-119.616984,34.448024),93109=>array(-119.726936,34.406256),93110=>array(-119.761971,34.449656),93111=>array(-119.804023,34.448902),93117=>array(-120.083673,34.479077),93201=>array(-119.51094,35.862574),93202=>array(-119.708452,36.313344),93203=>array(-118.832292,35.112617),93204=>array(-120.06859,35.889811),93205=>array(-118.430032,35.518295),93206=>array(-119.477735,35.437302),93207=>array(-118.630592,35.889831),93208=>array(-118.568462,36.056587),93210=>array(-120.424244,36.216313),93212=>array(-119.5277,36.042151),93215=>array(-119.200825,35.779507),93218=>array(-119.03614,35.860883),93219=>array(-119.281551,35.873666),93220=>array(-118.756525,35.403611),93221=>array(-119.026031,36.295014),93222=>array(-119.20368,34.842272),93223=>array(-119.204896,36.304539),93224=>array(-119.569304,35.228199),93225=>array(-119.030293,34.768537),93226=>array(-118.738483,35.735694),93230=>array(-119.622676,36.29223),93234=>array(-120.090096,36.191269),93235=>array(-119.219896,36.389827),93238=>array(-118.391705,35.729097),93239=>array(-119.990217,36.04719),93240=>array(-118.451991,35.617518),93241=>array(-118.912678,35.254701),93242=>array(-119.727723,36.442073),93243=>array(-118.791975,34.7727),93244=>array(-118.997291,36.462671),93245=>array(-119.829463,36.29227),93247=>array(-119.071075,36.206269),93249=>array(-119.888623,35.619272),93250=>array(-119.197958,35.665082),93251=>array(-119.758248,35.335636),93252=>array(-119.243479,34.709947),93254=>array(-119.810428,34.966833),93255=>array(-118.101378,35.676978),93256=>array(-119.312992,35.960636),93257=>array(-118.860221,35.988087),93258=>array(-119.150397,36.05438),93260=>array(-118.669124,35.817247),93261=>array(-119.128083,35.808535),93262=>array(-118.697481,36.615495),93263=>array(-119.286861,35.492805),93265=>array(-118.693138,36.245926),93266=>array(-119.867288,36.145394),93267=>array(-119.049222,36.15118),93268=>array(-119.425116,35.162393),93270=>array(-119.072843,35.952426),93271=>array(-118.800833,36.469541),93272=>array(-119.344304,36.047414),93274=>array(-119.370752,36.178091),93276=>array(-119.358368,35.299176),93277=>array(-119.375646,36.303793),93280=>array(-119.4464,35.652242),93283=>array(-118.297851,35.592029),93285=>array(-118.507202,35.715239),93286=>array(-119.094348,36.464635),93287=>array(-118.988161,35.757886),93291=>array(-119.372842,36.391777),93292=>array(-119.211689,36.37559),93301=>array(-119.020562,35.384336),93304=>array(-119.023451,35.339702),93305=>array(-118.985186,35.389749),93306=>array(-118.779649,35.468183),93307=>array(-118.9411,35.24512),93308=>array(-118.789677,35.621087),93309=>array(-119.064803,35.342891),93311=>array(-119.175866,35.192404),93312=>array(-119.12046,35.393478),93313=>array(-119.046322,35.16319),93314=>array(-119.244846,35.393866),93401=>array(-120.615973,35.23575),93402=>array(-120.835464,35.295232),93405=>array(-120.733137,35.296964),93410=>array(-120.660937,35.3012),93420=>array(-120.476742,35.176005),93422=>array(-120.693236,35.463837),93424=>array(-120.731954,35.185922),93426=>array(-120.938911,35.848621),93427=>array(-120.219523,34.610436),93428=>array(-121.041499,35.584973),93429=>array(-120.536546,34.866032),93430=>array(-120.944413,35.484971),93432=>array(-120.477579,35.48124),93433=>array(-120.619664,35.120888),93434=>array(-120.60513,34.919206),93436=>array(-120.382917,34.601055),93437=>array(-120.543739,34.737964),93440=>array(-120.230146,34.712216),93441=>array(-119.989127,34.788159),93442=>array(-120.799356,35.401939),93444=>array(-120.504593,35.037198),93445=>array(-120.620201,35.044405),93446=>array(-120.729679,35.663575),93449=>array(-120.655845,35.165673),93450=>array(-120.818725,36.085435),93451=>array(-120.608661,35.886767),93452=>array(-121.223355,35.746484),93453=>array(-120.256567,35.303926),93454=>array(-120.256729,34.943523),93455=>array(-120.433509,34.831792),93458=>array(-120.490081,34.95934),93460=>array(-120.007238,34.653255),93461=>array(-120.266428,35.652911),93463=>array(-120.137875,34.624399),93465=>array(-120.739893,35.538809),93501=>array(-118.184941,35.067111),93505=>array(-117.886527,35.16374),93510=>array(-118.220854,34.46109),93512=>array(-118.555074,37.892565),93513=>array(-118.15588,37.131989),93514=>array(-118.389367,37.491769),93516=>array(-117.629941,35.002282),93517=>array(-119.380803,38.278853),93518=>array(-118.467651,35.383054),93519=>array(-117.925785,35.294349),93522=>array(-117.591286,36.316188),93523=>array(-117.835384,34.960825),93524=>array(-117.907127,34.931987),93526=>array(-118.281259,36.823846),93527=>array(-118.176768,36.119934),93528=>array(-117.643321,35.371604),93529=>array(-119.095647,37.815507),93530=>array(-117.860116,36.47583),93531=>array(-118.582566,35.221906),93532=>array(-118.533689,34.689848),93534=>array(-118.15292,34.713292),93535=>array(-117.86466,34.713656),93536=>array(-118.369249,34.74739),93541=>array(-119.114386,37.988074),93543=>array(-117.982006,34.481108),93544=>array(-117.756645,34.495537),93545=>array(-118.054221,36.556387),93546=>array(-118.83988,37.548771),93549=>array(-117.947995,36.21164),93550=>array(-118.123597,34.408383),93551=>array(-118.239005,34.60411),93552=>array(-118.023744,34.570867),93553=>array(-117.911825,34.407313),93554=>array(-117.764333,35.413944),93555=>array(-117.683472,35.606509),93558=>array(-117.621393,35.347928),93560=>array(-118.339832,34.866894),93561=>array(-118.493811,35.118772),93562=>array(-117.384948,35.74837),93563=>array(-117.766066,34.402521),93591=>array(-117.813682,34.594397),93592=>array(-117.224709,35.852815),93601=>array(-119.741037,37.393471),93602=>array(-119.316654,37.028835),93603=>array(-118.957187,36.622507),93604=>array(-119.425782,37.349585),93605=>array(-119.249243,37.203158),93606=>array(-120.01855,36.803208),93608=>array(-120.361622,36.493861),93609=>array(-119.864081,36.526601),93610=>array(-120.281214,37.098303),93611=>array(-119.68019,36.825296),93612=>array(-119.710595,36.814863),93614=>array(-119.749852,37.210039),93615=>array(-119.286328,36.503322),93616=>array(-119.593861,36.655353),93618=>array(-119.389446,36.521012),93619=>array(-119.593481,36.917573),93620=>array(-120.626723,37.018947),93621=>array(-119.140384,36.789242),93622=>array(-120.57524,36.814503),93623=>array(-119.644344,37.494819),93624=>array(-120.116591,36.378434),93625=>array(-119.671874,36.624538),93626=>array(-119.6872,37.046782),93627=>array(-120.061497,36.474404),93628=>array(-118.938691,36.779832),93630=>array(-120.123526,36.727418),93631=>array(-119.52137,36.478239),93633=>array(-118.649328,36.822163),93634=>array(-119.001021,37.223),93635=>array(-120.843606,37.068051),93636=>array(-119.873914,36.984885),93637=>array(-120.185933,36.918079),93638=>array(-120.031309,37.040928),93640=>array(-120.446521,36.672683),93641=>array(-119.024051,36.696759),93643=>array(-119.470738,37.224696),93644=>array(-119.632385,37.377787),93645=>array(-119.64103,37.17395),93646=>array(-119.289181,36.644737),93647=>array(-119.175485,36.60076),93648=>array(-119.520731,36.620634),93650=>array(-119.799812,36.840813),93651=>array(-119.518794,36.999336),93652=>array(-119.904577,36.595012),93653=>array(-119.944935,37.248335),93654=>array(-119.401274,36.658709),93656=>array(-119.934478,36.450225),93657=>array(-119.457602,36.817791),93660=>array(-120.173897,36.585446),93662=>array(-119.638651,36.536573),93664=>array(-119.21954,37.129321),93665=>array(-120.64806,36.960108),93666=>array(-119.335641,36.547067),93667=>array(-119.335294,36.95594),93668=>array(-120.284085,36.650275),93669=>array(-119.548406,37.290563),93673=>array(-119.482343,36.452697),93675=>array(-119.192779,36.724723),93701=>array(-119.787684,36.74966),93702=>array(-119.753932,36.739193),93703=>array(-119.762393,36.76886),93704=>array(-119.801608,36.799054),93705=>array(-119.828335,36.786671),93706=>array(-119.906542,36.652041),93710=>array(-119.760241,36.822348),93711=>array(-119.83335,36.834289),93720=>array(-119.760793,36.862209),93721=>array(-119.783739,36.732892),93722=>array(-119.874794,36.799361),93723=>array(-119.956818,36.793477),93725=>array(-119.731888,36.627211),93726=>array(-119.761461,36.793661),93727=>array(-119.680602,36.751519),93728=>array(-119.818483,36.757293),93730=>array(-119.754143,36.900387),93901=>array(-121.622188,36.64152),93905=>array(-121.605904,36.682351),93906=>array(-121.63365,36.722713),93907=>array(-121.667532,36.769389),93908=>array(-121.599444,36.651745),93920=>array(-121.549826,36.092975),93921=>array(-121.92396,36.553175),93923=>array(-121.849502,36.448672),93924=>array(-121.637712,36.41408),93925=>array(-121.398908,36.588003),93926=>array(-121.396719,36.52588),93927=>array(-121.386617,36.248708),93928=>array(-121.244009,36.038868),93930=>array(-121.010363,36.20506),93932=>array(-121.055933,35.989792),93933=>array(-121.786887,36.686845),93940=>array(-121.840727,36.57485),93943=>array(-121.874136,36.597004),93950=>array(-121.925179,36.621181),93953=>array(-121.945282,36.585219),93954=>array(-120.928512,36.133362),93955=>array(-121.786901,36.61441),93960=>array(-121.343146,36.389618),93962=>array(-121.646487,36.624716),94002=>array(-122.298896,37.514352),94005=>array(-122.408935,37.688826),94010=>array(-122.365778,37.57028),94014=>array(-122.447437,37.690868),94015=>array(-122.480591,37.681267),94019=>array(-122.411841,37.469453),94020=>array(-122.23242,37.274612),94021=>array(-122.280738,37.270838),94022=>array(-122.144416,37.357472),94024=>array(-122.094337,37.352252),94025=>array(-122.176542,37.457524),94027=>array(-122.204756,37.453514),94028=>array(-122.209784,37.376855),94030=>array(-122.401991,37.59897),94037=>array(-122.496668,37.554358),94038=>array(-122.512164,37.526902),94040=>array(-122.085286,37.380566),94041=>array(-122.075734,37.388528),94043=>array(-122.070895,37.421865),94044=>array(-122.477228,37.606593),94060=>array(-122.271032,37.247137),94061=>array(-122.236948,37.461147),94062=>array(-122.297142,37.410563),94063=>array(-122.195525,37.493297),94065=>array(-122.247372,37.534106),94066=>array(-122.43363,37.625102),94070=>array(-122.272556,37.496461),94074=>array(-122.341444,37.331762),94080=>array(-122.422075,37.65549),94085=>array(-122.01774,37.388556),94086=>array(-122.023152,37.371647),94087=>array(-122.036962,37.351528),94089=>array(-122.015605,37.412402),94102=>array(-122.419318,37.779588),94103=>array(-122.411167,37.773134),94104=>array(-122.40213,37.791409),94105=>array(-122.393665,37.789864),94107=>array(-122.399724,37.76046),94108=>array(-122.408575,37.792007),94109=>array(-122.422453,37.795388),94110=>array(-122.415201,37.750021),94111=>array(-122.398407,37.799367),94112=>array(-122.44295,37.720375),94114=>array(-122.43541,37.758057),94115=>array(-122.437253,37.785969),94116=>array(-122.486065,37.745399),94117=>array(-122.447662,37.769436),94118=>array(-122.462605,37.780097),94121=>array(-122.494707,37.776769),94122=>array(-122.485128,37.758797),94123=>array(-122.438366,37.800934),94124=>array(-122.382779,37.728895),94127=>array(-122.459338,37.73622),94128=>array(-122.385694,37.626369),94129=>array(-122.464462,37.797336),94130=>array(-122.369725,37.820894),94131=>array(-122.441472,37.745916),94132=>array(-122.484166,37.721969),94133=>array(-122.410852,37.804531),94134=>array(-122.413573,37.721052),94158=>array(-122.386927,37.768106),94301=>array(-122.149915,37.444122),94303=>array(-122.115398,37.45809),94304=>array(-122.181697,37.374707),94305=>array(-122.17147,37.41794),94306=>array(-122.130765,37.415727),94401=>array(-122.316903,37.576948),94402=>array(-122.344932,37.523688),94403=>array(-122.305447,37.538449),94404=>array(-122.267679,37.555999),94501=>array(-122.278123,37.773797),94502=>array(-122.245507,37.737572),94503=>array(-122.264565,38.186535),94505=>array(-121.596957,37.871707),94506=>array(-121.912929,37.809418),94507=>array(-122.021113,37.850399),94508=>array(-122.444388,38.576618),94509=>array(-121.812301,37.996501),94510=>array(-122.13594,38.098071),94511=>array(-121.640566,38.029003),94512=>array(-121.834156,38.134852),94513=>array(-121.668359,37.922228),94514=>array(-121.622546,37.826372),94515=>array(-122.615051,38.634822),94516=>array(-122.165034,37.833901),94517=>array(-121.878359,37.890221),94518=>array(-122.022034,37.950359),94519=>array(-122.01304,37.98846),94520=>array(-122.040624,37.995283),94521=>array(-121.956195,37.956008),94523=>array(-122.076124,37.954141),94525=>array(-122.232094,38.052951),94526=>array(-121.990552,37.814613),94528=>array(-121.950612,37.845601),94530=>array(-122.298347,37.921552),94531=>array(-121.77583,37.965782),94533=>array(-122.006681,38.280863),94534=>array(-122.135862,38.244889),94535=>array(-121.924715,38.282221),94536=>array(-121.98125,37.570508),94538=>array(-121.962472,37.505768),94539=>array(-121.911763,37.51691),94541=>array(-122.08482,37.673946),94542=>array(-122.037142,37.659883),94544=>array(-122.0572,37.63382),94545=>array(-122.126873,37.605905),94546=>array(-122.079542,37.714509),94547=>array(-122.261851,38.009937),94548=>array(-121.651441,37.974295),94549=>array(-122.114292,37.897009),94550=>array(-121.583391,37.526661),94551=>array(-121.749055,37.750502),94552=>array(-122.021552,37.72272),94553=>array(-122.136441,37.993892),94555=>array(-122.098635,37.548123),94556=>array(-122.114936,37.840669),94558=>array(-122.23832,38.442011),94559=>array(-122.313395,38.245729),94560=>array(-122.032359,37.504141),94561=>array(-121.691139,37.993936),94563=>array(-122.184572,37.879921),94564=>array(-122.282589,37.994038),94565=>array(-121.906255,38.014576),94566=>array(-121.849958,37.648118),94567=>array(-122.393997,38.706906),94568=>array(-121.913048,37.717399),94569=>array(-122.198765,38.044258),94571=>array(-121.737696,38.148862),94572=>array(-122.252247,38.032719),94573=>array(-122.428831,38.458864),94574=>array(-122.419923,38.542448),94575=>array(-122.109502,37.840961),94576=>array(-122.476383,38.549425),94577=>array(-122.16735,37.713275),94578=>array(-122.125551,37.706137),94579=>array(-122.157201,37.686491),94580=>array(-122.133017,37.675731),94582=>array(-121.915788,37.762174),94583=>array(-121.973009,37.755504),94585=>array(-121.927529,38.192498),94586=>array(-121.853708,37.57459),94587=>array(-122.018638,37.603156),94588=>array(-121.86059,37.792682),94589=>array(-122.224074,38.18735),94590=>array(-122.249096,38.103234),94591=>array(-122.196863,38.122869),94592=>array(-122.277394,38.08973),94595=>array(-122.069386,37.871953),94596=>array(-122.03756,37.889079),94597=>array(-122.071676,37.918195),94598=>array(-121.999244,37.899936),94599=>array(-122.361511,38.409878),94601=>array(-122.218705,37.775545),94602=>array(-122.207545,37.80432),94603=>array(-122.179454,37.736531),94605=>array(-122.150198,37.761408),94606=>array(-122.245334,37.791887),94607=>array(-122.301491,37.807211),94608=>array(-122.289569,37.836817),94609=>array(-122.264374,37.834391),94610=>array(-122.242458,37.811406),94611=>array(-122.203393,37.829483),94612=>array(-122.269196,37.8088),94613=>array(-122.182867,37.780849),94618=>array(-122.23811,37.843962),94619=>array(-122.13238,37.781467),94621=>array(-122.216825,37.748272),94702=>array(-122.286326,37.865784),94703=>array(-122.27564,37.863906),94704=>array(-122.257995,37.866536),94705=>array(-122.238209,37.865177),94706=>array(-122.295526,37.889704),94707=>array(-122.27913,37.898189),94708=>array(-122.261795,37.902944),94709=>array(-122.266839,37.879234),94710=>array(-122.306465,37.863914),94720=>array(-122.254934,37.873838),94801=>array(-122.381974,37.952844),94803=>array(-122.283555,37.95954),94804=>array(-122.341233,37.916555),94805=>array(-122.322933,37.942791),94806=>array(-122.337627,37.98079),94850=>array(-122.317378,37.902226),94901=>array(-122.496839,37.978316),94903=>array(-122.555605,38.022366),94904=>array(-122.56012,37.945512),94920=>array(-122.46858,37.885629),94922=>array(-122.948799,38.344946),94923=>array(-123.035056,38.339953),94924=>array(-122.72379,37.943087),94925=>array(-122.507735,37.932145),94928=>array(-122.694127,38.34642),94929=>array(-122.962717,38.25242),94930=>array(-122.616418,37.943963),94931=>array(-122.714633,38.324132),94933=>array(-122.687478,38.012599),94937=>array(-122.930234,38.116188),94938=>array(-122.726523,38.029069),94939=>array(-122.532369,37.937082),94940=>array(-122.883126,38.17859),94941=>array(-122.562961,37.897529),94945=>array(-122.52719,38.134068),94946=>array(-122.671527,38.082829),94947=>array(-122.634384,38.112166),94949=>array(-122.524004,38.067204),94950=>array(-122.759933,38.024885),94951=>array(-122.646138,38.320861),94952=>array(-122.760385,38.234553),94954=>array(-122.557332,38.235021),94956=>array(-122.861209,38.045857),94957=>array(-122.563588,37.963111),94960=>array(-122.577814,37.995864),94963=>array(-122.67012,38.013719),94964=>array(-122.492151,37.943257),94965=>array(-122.547207,37.852904),94970=>array(-122.64689,37.914513),94971=>array(-122.92825,38.231532),94972=>array(-122.971069,38.292103),94973=>array(-122.639598,38.012697),95002=>array(-122.011246,37.438525),95003=>array(-121.881646,37.011154),95004=>array(-121.63073,36.874753),95005=>array(-122.091668,37.099415),95006=>array(-122.149524,37.171267),95007=>array(-122.106903,37.104964),95008=>array(-121.955101,37.278563),95010=>array(-121.95316,36.976175),95012=>array(-121.759054,36.784482),95013=>array(-121.741423,37.215421),95014=>array(-122.080628,37.30661),95017=>array(-122.237162,37.114335),95018=>array(-122.059372,37.074092),95019=>array(-121.783134,36.935538),95020=>array(-121.554249,37.018419),95023=>array(-121.350783,36.902045),95030=>array(-121.983274,37.222788),95032=>array(-121.926548,37.216822),95033=>array(-121.984916,37.16132),95035=>array(-121.874953,37.443638),95037=>array(-121.598747,37.174063),95039=>array(-121.776583,36.82815),95041=>array(-122.057815,37.050419),95043=>array(-120.952122,36.525703),95045=>array(-121.518587,36.825745),95046=>array(-121.59924,37.099308),95050=>array(-121.952295,37.351158),95051=>array(-121.984376,37.348651),95053=>array(-121.937559,37.348725),95054=>array(-121.964672,37.39349),95060=>array(-122.12175,37.036461),95062=>array(-121.987488,36.970525),95064=>array(-122.059022,36.991107),95065=>array(-121.98334,37.031472),95066=>array(-122.01399,37.067923),95070=>array(-122.045164,37.257287),95073=>array(-121.930051,37.042254),95075=>array(-121.142439,36.779046),95076=>array(-121.756479,36.946256),95110=>array(-121.909871,37.346608),95111=>array(-121.826245,37.283111),95112=>array(-121.883537,37.344507),95113=>array(-121.891049,37.333707),95116=>array(-121.852602,37.350466),95117=>array(-121.96187,37.311181),95118=>array(-121.889982,37.255519),95119=>array(-121.7851,37.230059),95120=>array(-121.843554,37.186141),95121=>array(-121.809861,37.304151),95122=>array(-121.835328,37.3287),95123=>array(-121.831604,37.244238),95124=>array(-121.922764,37.256766),95125=>array(-121.89143,37.295097),95126=>array(-121.916765,37.326803),95127=>array(-121.800706,37.371079),95128=>array(-121.936313,37.315976),95129=>array(-122.000913,37.30574),95130=>array(-121.986133,37.277121),95131=>array(-121.897415,37.387105),95132=>array(-121.74841,37.424655),95133=>array(-121.860764,37.371645),95134=>array(-121.945416,37.42765),95135=>array(-121.68836,37.286454),95136=>array(-121.851333,37.270058),95138=>array(-121.73384,37.246621),95139=>array(-121.764075,37.224914),95140=>array(-121.620009,37.393503),95148=>array(-121.777603,37.335987),95202=>array(-121.288287,37.959736),95203=>array(-121.329655,37.952452),95204=>array(-121.319246,37.973736),95205=>array(-121.259841,37.964578),95206=>array(-121.417427,37.918854),95207=>array(-121.324979,38.002125),95209=>array(-121.351122,38.047664),95210=>array(-121.297912,38.030177),95211=>array(-121.313409,37.97925),95212=>array(-121.23297,38.049939),95215=>array(-121.157283,37.949421),95219=>array(-121.483036,38.051726),95220=>array(-121.235034,38.200231),95222=>array(-120.632221,38.071327),95223=>array(-119.983134,38.428475),95224=>array(-120.322688,38.231324),95225=>array(-120.886271,38.198402),95226=>array(-120.8567,38.228993),95227=>array(-121.052489,38.207403),95228=>array(-120.70667,37.933295),95230=>array(-120.898152,38.000494),95231=>array(-121.292034,37.873283),95232=>array(-120.594018,38.355338),95233=>array(-120.368144,38.161669),95234=>array(-121.528026,37.925763),95236=>array(-121.02389,38.02973),95237=>array(-121.15034,38.16154),95240=>array(-121.144658,38.114388),95242=>array(-121.384546,38.137068),95245=>array(-120.626707,38.299257),95246=>array(-120.515637,38.232845),95247=>array(-120.452903,38.138539),95248=>array(-120.461112,38.317709),95249=>array(-120.638708,38.189115),95250=>array(-120.428658,38.237833),95251=>array(-120.449079,38.077689),95252=>array(-120.84667,38.149816),95254=>array(-120.957842,38.192608),95255=>array(-120.474458,38.419902),95257=>array(-120.448,38.379703),95258=>array(-121.310964,38.169605),95301=>array(-120.636719,37.321154),95303=>array(-120.671083,37.470288),95304=>array(-121.406559,37.671103),95305=>array(-120.26914,37.794225),95306=>array(-120.127607,37.392622),95307=>array(-120.951523,37.554269),95310=>array(-120.37855,38.085839),95311=>array(-120.082158,37.705084),95312=>array(-120.652983,37.421071),95313=>array(-121.051294,37.431392),95314=>array(-119.789783,38.321892),95315=>array(-120.769282,37.4219),95316=>array(-120.714055,37.553376),95317=>array(-120.506433,37.12738),95318=>array(-119.784117,37.653372),95319=>array(-120.903049,37.63929),95320=>array(-121.005157,37.825598),95321=>array(-120.014557,37.854734),95322=>array(-121.024432,37.166199),95323=>array(-120.685156,37.608303),95324=>array(-120.890747,37.394536),95325=>array(-120.230418,37.479885),95326=>array(-120.855236,37.588918),95327=>array(-120.480322,37.861625),95328=>array(-120.90988,37.558453),95329=>array(-120.411517,37.666587),95330=>array(-121.315116,37.809477),95333=>array(-120.240442,37.242232),95334=>array(-120.742627,37.347307),95335=>array(-120.092801,38.125078),95336=>array(-121.201018,37.830267),95337=>array(-121.23838,37.743039),95338=>array(-119.982496,37.508765),95340=>array(-120.42415,37.345785),95341=>array(-120.501072,37.231045),95345=>array(-119.976728,37.583767),95346=>array(-120.170699,38.065529),95348=>array(-120.498299,37.392287),95350=>array(-121.007405,37.671978),95351=>array(-120.996324,37.623601),95354=>array(-120.964772,37.639029),95355=>array(-120.946594,37.672906),95356=>array(-121.032714,37.718023),95357=>array(-120.887136,37.672536),95358=>array(-121.108568,37.612612),95360=>array(-121.193383,37.325955),95361=>array(-120.757696,37.786492),95363=>array(-121.22995,37.452894),95364=>array(-119.78303,38.258381),95365=>array(-120.294817,37.331113),95366=>array(-121.125614,37.762939),95367=>array(-120.942905,37.729282),95368=>array(-121.089243,37.715625),95369=>array(-120.435972,37.531787),95370=>array(-120.349264,37.984549),95372=>array(-120.262774,37.991339),95374=>array(-120.855753,37.316807),95375=>array(-120.026235,38.186595),95376=>array(-121.433384,37.737191),95377=>array(-121.517281,37.674036),95379=>array(-120.188002,37.939768),95380=>array(-120.875917,37.474396),95382=>array(-120.853313,37.528476),95383=>array(-120.230625,38.107441),95385=>array(-121.24733,37.61074),95386=>array(-120.627047,37.668877),95387=>array(-121.298493,37.4987),95388=>array(-120.586787,37.41467),95389=>array(-119.68128,37.626489),95391=>array(-121.609686,37.768237),95401=>array(-122.793752,38.449137),95403=>array(-122.754057,38.503685),95404=>array(-122.69096,38.526298),95405=>array(-122.665993,38.437114),95407=>array(-122.745048,38.3933),95409=>array(-122.580539,38.468893),95410=>array(-123.690534,39.204746),95412=>array(-123.349777,38.713421),95415=>array(-123.370756,39.015251),95417=>array(-123.610022,39.68979),95420=>array(-123.804985,39.366146),95421=>array(-123.159486,38.628044),95422=>array(-122.622751,38.973642),95423=>array(-122.626701,39.064446),95425=>array(-123.063567,38.823075),95426=>array(-122.730395,38.832458),95427=>array(-123.563531,39.244183),95428=>array(-123.178799,39.824434),95429=>array(-123.300585,39.720542),95430=>array(-123.047185,38.461425),95431=>array(-122.517056,38.348343),95432=>array(-123.645121,39.108252),95435=>array(-122.86951,39.007213),95436=>array(-122.905772,38.48697),95437=>array(-123.742891,39.48586),95439=>array(-122.777546,38.493179),95441=>array(-122.906767,38.731694),95442=>array(-122.487136,38.371334),95443=>array(-122.751233,39.054131),95444=>array(-122.869001,38.433216),95445=>array(-123.472567,38.832535),95446=>array(-123.007892,38.527164),95448=>array(-122.89158,38.627028),95449=>array(-123.101055,38.943196),95450=>array(-123.170879,38.501363),95451=>array(-122.789559,38.922131),95452=>array(-122.53521,38.425523),95453=>array(-122.942355,39.044761),95454=>array(-123.51601,39.806149),95456=>array(-123.760729,39.258295),95457=>array(-122.53272,38.882973),95458=>array(-122.745312,39.161278),95459=>array(-123.626842,38.989323),95460=>array(-123.748616,39.305245),95461=>array(-122.557196,38.752774),95462=>array(-123.018428,38.462146),95463=>array(-123.558382,39.186791),95464=>array(-122.849302,39.128363),95465=>array(-123.065708,38.421306),95466=>array(-123.504872,39.081822),95467=>array(-122.539517,38.809463),95468=>array(-123.605813,38.916214),95469=>array(-123.052841,39.390917),95470=>array(-123.249924,39.31403),95471=>array(-122.968774,38.524077),95472=>array(-122.861923,38.398815),95476=>array(-122.470703,38.254935),95482=>array(-123.24235,39.121234),95485=>array(-122.922912,39.225478),95486=>array(-123.024203,38.474137),95488=>array(-123.741578,39.683731),95490=>array(-123.340973,39.492842),95492=>array(-122.821349,38.528079),95493=>array(-122.969574,39.184728),95494=>array(-123.337821,38.889651),95497=>array(-123.476087,38.742903),95501=>array(-124.15192,40.798802),95503=>array(-124.108897,40.737431),95511=>array(-123.681921,40.141856),95514=>array(-123.653473,40.294713),95519=>array(-124.051236,40.959368),95521=>array(-124.06672,40.855672),95524=>array(-124.049485,40.825486),95525=>array(-123.815266,40.92143),95526=>array(-123.673165,40.459063),95527=>array(-123.387964,41.012258),95528=>array(-123.93037,40.497283),95531=>array(-124.065667,41.819578),95536=>array(-124.326632,40.523168),95537=>array(-124.217378,40.726752),95540=>array(-124.136869,40.578828),95542=>array(-123.783948,40.080405),95543=>array(-123.86277,41.870812),95545=>array(-124.06367,40.280389),95546=>array(-123.675804,41.092824),95547=>array(-124.081215,40.557483),95548=>array(-124.045992,41.593204),95549=>array(-123.908398,40.666702),95550=>array(-123.826383,40.781218),95551=>array(-124.231146,40.674987),95552=>array(-123.219559,40.203939),95553=>array(-123.888871,40.244215),95554=>array(-123.777112,40.296346),95555=>array(-123.913425,41.241807),95556=>array(-123.586216,41.308073),95558=>array(-124.243071,40.298264),95559=>array(-123.744917,40.183684),95560=>array(-123.826148,40.168801),95562=>array(-124.12184,40.472423),95563=>array(-123.499144,40.87733),95564=>array(-124.20464,40.79102),95565=>array(-124.015148,40.455189),95567=>array(-124.097094,41.950683),95568=>array(-123.464802,41.452691),95569=>array(-123.844997,40.37886),95570=>array(-124.156283,41.080058),95571=>array(-123.920622,40.322772),95573=>array(-123.668723,40.914926),95585=>array(-123.656929,39.844682),95587=>array(-123.775737,39.96327),95589=>array(-123.969269,40.055796),95595=>array(-123.425497,40.109807),95601=>array(-120.825717,38.426699),95602=>array(-121.114408,38.99003),95603=>array(-121.080284,38.915869),95604=>array(-120.071406,39.243304),95605=>array(-121.539867,38.593521),95606=>array(-122.195441,38.756186),95607=>array(-122.127165,38.83447),95608=>array(-121.324911,38.62415),95610=>array(-121.271772,38.694908),95612=>array(-121.578701,38.384648),95614=>array(-120.982388,38.886062),95615=>array(-121.546207,38.324029),95616=>array(-121.798469,38.55413),95618=>array(-121.6815,38.543211),95619=>array(-120.814261,38.680605),95620=>array(-121.756222,38.412615),95621=>array(-121.308303,38.695704),95623=>array(-120.85663,38.605289),95624=>array(-121.315627,38.427651),95625=>array(-121.911547,38.358121),95626=>array(-121.468174,38.733145),95627=>array(-122.025346,38.734513),95628=>array(-121.25441,38.652065),95629=>array(-120.688517,38.516474),95630=>array(-121.141635,38.666597),95631=>array(-120.795632,39.053461),95632=>array(-121.259201,38.274451),95633=>array(-120.826574,38.844519),95634=>array(-120.768776,38.938067),95635=>array(-120.914049,38.9043),95636=>array(-120.383217,38.621278),95637=>array(-122.236937,38.834139),95638=>array(-121.123886,38.313448),95639=>array(-121.500428,38.38903),95640=>array(-120.955787,38.325248),95641=>array(-121.589599,38.140308),95642=>array(-120.760921,38.343033),95645=>array(-121.778654,38.884891),95646=>array(-120.054929,38.689283),95648=>array(-121.312005,38.922812),95650=>array(-121.171375,38.809175),95651=>array(-120.929272,38.81782),95652=>array(-121.401102,38.662977),95653=>array(-121.978759,38.6976),95655=>array(-121.278598,38.549228),95658=>array(-121.15918,38.883224),95659=>array(-121.572164,38.84223),95660=>array(-121.379969,38.678545),95661=>array(-121.247693,38.741074),95662=>array(-121.218435,38.689174),95663=>array(-121.182313,38.855811),95664=>array(-121.036736,38.800662),95665=>array(-120.649677,38.402083),95666=>array(-120.376629,38.523861),95667=>array(-120.789952,38.734925),95668=>array(-121.498102,38.833554),95669=>array(-120.899472,38.482619),95670=>array(-121.280327,38.604268),95672=>array(-121.000439,38.725093),95673=>array(-121.459014,38.689241),95674=>array(-121.48187,38.954159),95675=>array(-120.7405,38.5447),95677=>array(-121.234854,38.791075),95678=>array(-121.287515,38.764073),95679=>array(-122.348664,38.89667),95680=>array(-121.587535,38.240419),95681=>array(-121.353545,38.995557),95682=>array(-120.964522,38.612129),95683=>array(-121.096261,38.511992),95684=>array(-120.585956,38.593273),95685=>array(-120.770657,38.431898),95686=>array(-121.520223,38.157794),95687=>array(-121.920151,38.333133),95688=>array(-122.022775,38.408571),95689=>array(-120.611993,38.478832),95690=>array(-121.618273,38.199576),95691=>array(-121.593287,38.627951),95692=>array(-121.403091,39.046931),95693=>array(-121.210347,38.39955),95694=>array(-122.08021,38.568491),95695=>array(-121.85708,38.687044),95697=>array(-121.810264,38.73237),95698=>array(-121.910774,38.816357),95699=>array(-120.857671,38.436467),95701=>array(-120.768689,39.224484),95703=>array(-120.978665,38.985882),95709=>array(-120.675512,38.748316),95713=>array(-120.873765,39.113684),95714=>array(-120.840726,39.200502),95715=>array(-120.677611,39.269964),95717=>array(-120.852571,39.144524),95720=>array(-120.209673,38.766036),95721=>array(-120.077273,38.84119),95722=>array(-121.034108,39.009741),95724=>array(-120.328125,39.311704),95726=>array(-120.503871,38.800349),95728=>array(-120.399379,39.319332),95735=>array(-120.14951,38.840775),95736=>array(-120.97753,39.038809),95742=>array(-121.201788,38.577783),95746=>array(-121.184357,38.750964),95747=>array(-121.373155,38.78207),95757=>array(-121.431231,38.344888),95758=>array(-121.444696,38.427813),95762=>array(-121.064165,38.685222),95765=>array(-121.279552,38.815502),95776=>array(-121.694431,38.694081),95811=>array(-121.478101,38.58323),95814=>array(-121.49559,38.580568),95815=>array(-121.447593,38.605407),95816=>array(-121.466465,38.571577),95817=>array(-121.456373,38.550547),95818=>array(-121.497058,38.554487),95819=>array(-121.440067,38.569828),95820=>array(-121.444372,38.534879),95821=>array(-121.384916,38.625693),95822=>array(-121.493618,38.512787),95823=>array(-121.443454,38.474099),95824=>array(-121.440739,38.517585),95825=>array(-121.408467,38.591897),95826=>array(-121.377692,38.543754),95827=>array(-121.324257,38.556129),95828=>array(-121.395843,38.488809),95829=>array(-121.323454,38.489544),95830=>array(-121.284171,38.490508),95831=>array(-121.529447,38.494832),95832=>array(-121.496114,38.44705),95833=>array(-121.517552,38.619049),95834=>array(-121.518416,38.635653),95835=>array(-121.525983,38.670649),95837=>array(-121.599134,38.693945),95838=>array(-121.445152,38.64617),95841=>array(-121.347394,38.66037),95842=>array(-121.349146,38.686809),95843=>array(-121.363422,38.715463),95864=>array(-121.375846,38.584047),95901=>array(-121.49405,39.223939),95903=>array(-121.36818,39.106099),95910=>array(-120.817232,39.491126),95912=>array(-122.062143,39.016702),95914=>array(-121.330521,39.449005),95915=>array(-121.158894,40.006256),95916=>array(-121.351955,39.665539),95917=>array(-121.761286,39.413627),95918=>array(-121.337929,39.301229),95919=>array(-121.261143,39.432882),95920=>array(-121.936372,39.449794),95922=>array(-121.070237,39.48984),95923=>array(-121.092693,40.133728),95925=>array(-121.192649,39.484108),95926=>array(-121.843834,39.745628),95928=>array(-121.844084,39.68571),95930=>array(-121.192105,39.548599),95932=>array(-121.978604,39.266469),95934=>array(-120.902875,40.061086),95935=>array(-121.192259,39.379344),95936=>array(-120.791339,39.605958),95937=>array(-121.999043,38.885247),95938=>array(-121.795288,39.604713),95939=>array(-122.580828,39.571983),95941=>array(-121.242678,39.51733),95942=>array(-121.566635,40.01945),95943=>array(-122.032297,39.584807),95944=>array(-120.944288,39.494937),95945=>array(-120.972289,39.196387),95946=>array(-121.20324,39.215586),95947=>array(-120.819766,40.174567),95948=>array(-121.770785,39.339264),95949=>array(-121.138845,39.099249),95950=>array(-121.918099,39.043447),95951=>array(-122.003909,39.723808),95953=>array(-121.77697,39.258746),95954=>array(-121.583415,39.889504),95955=>array(-122.201715,39.294516),95956=>array(-121.134235,39.838288),95957=>array(-121.827155,39.060921),95959=>array(-120.918728,39.347811),95960=>array(-121.034486,39.403217),95961=>array(-121.560484,39.040304),95962=>array(-121.264443,39.344855),95963=>array(-122.258532,39.7353),95965=>array(-121.581363,39.593945),95966=>array(-121.415927,39.473896),95968=>array(-121.551925,39.435211),95969=>array(-121.64618,39.716846),95970=>array(-122.060946,39.398424),95971=>array(-120.885878,39.940174),95973=>array(-121.841982,39.891624),95974=>array(-121.838454,39.480221),95975=>array(-121.15162,39.224412),95977=>array(-121.291692,39.176595),95978=>array(-121.536315,39.875599),95979=>array(-122.511118,39.30204),95981=>array(-121.000123,39.687069),95982=>array(-121.805845,39.172777),95983=>array(-120.707315,40.077912),95984=>array(-121.122652,40.040955),95986=>array(-120.770868,39.342544),95987=>array(-122.286034,39.097947),95988=>array(-122.26208,39.491654),95991=>array(-121.598994,39.016059),95993=>array(-121.680114,39.082497),96001=>array(-122.455016,40.600342),96002=>array(-122.318749,40.527834),96003=>array(-122.230678,40.751937),96006=>array(-120.840356,41.13614),96007=>array(-122.277995,40.457991),96008=>array(-122.120397,40.705001),96009=>array(-121.020802,41.05604),96010=>array(-123.307474,40.913802),96011=>array(-121.984492,41.051216),96013=>array(-121.690281,40.975253),96014=>array(-122.773678,41.326624),96015=>array(-120.913975,41.486953),96016=>array(-121.505962,40.894419),96017=>array(-122.233836,41.080356),96019=>array(-122.377904,40.679219),96020=>array(-121.298528,40.397997),96021=>array(-122.270806,39.923446),96022=>array(-122.448533,40.336392),96023=>array(-121.906809,41.928894),96024=>array(-122.876964,40.543165),96025=>array(-122.307935,41.209942),96027=>array(-123.069287,41.400028),96028=>array(-121.480741,41.006417),96029=>array(-122.4892,39.94026),96031=>array(-123.181796,41.186066),96032=>array(-122.963514,41.60901),96033=>array(-122.584149,40.781633),96034=>array(-122.609441,41.428284),96035=>array(-122.184859,40.045637),96037=>array(-122.934665,41.544675),96038=>array(-122.545715,41.6071),96039=>array(-123.483269,41.687905),96040=>array(-121.438607,40.793535),96041=>array(-123.193917,40.525724),96044=>array(-122.510081,41.93095),96046=>array(-123.432743,40.586442),96047=>array(-122.661233,40.469818),96048=>array(-123.022859,40.829014),96049=>array(-123.328564,41.762515),96050=>array(-122.888552,41.89888),96051=>array(-122.383578,40.932935),96052=>array(-122.821085,40.738391),96054=>array(-121.036859,41.240175),96055=>array(-122.074735,40.103236),96056=>array(-121.308316,41.028176),96057=>array(-121.931033,41.268701),96058=>array(-121.906179,41.728474),96059=>array(-121.833052,40.421637),96061=>array(-121.47907,40.338068),96062=>array(-122.041447,40.580181),96063=>array(-121.60634,40.370532),96064=>array(-122.365378,41.756114),96065=>array(-121.876104,40.892563),96067=>array(-122.376724,41.307705),96068=>array(-121.207564,41.118402),96069=>array(-122.016069,40.685336),96071=>array(-121.462699,40.662919),96073=>array(-122.185739,40.603908),96074=>array(-122.587615,39.884401),96075=>array(-121.852205,40.343242),96076=>array(-122.937679,40.391935),96080=>array(-122.394899,40.171603),96084=>array(-121.969953,40.845006),96085=>array(-123.07557,41.737962),96086=>array(-123.260788,41.924174),96087=>array(-122.643648,40.619996),96088=>array(-121.884623,40.511966),96090=>array(-122.127672,40.021577),96091=>array(-122.791321,41.034706),96092=>array(-122.017242,39.96332),96093=>array(-122.941428,40.765478),96094=>array(-122.469367,41.456579),96096=>array(-121.823333,40.652845),96097=>array(-122.656617,41.755217),96101=>array(-120.53846,41.452711),96103=>array(-120.665982,39.80559),96104=>array(-120.143106,41.506276),96105=>array(-120.055178,39.753663),96106=>array(-120.543744,39.736644),96107=>array(-119.475741,38.42528),96108=>array(-120.431114,41.770135),96109=>array(-120.099183,40.019715),96110=>array(-120.078493,41.299897),96111=>array(-120.035318,39.468311),96112=>array(-120.104998,41.858844),96113=>array(-120.159007,40.142933),96114=>array(-120.499838,40.296745),96115=>array(-120.134337,41.70183),96116=>array(-120.372571,41.255254),96117=>array(-120.235306,40.533534),96118=>array(-120.247144,39.639597),96119=>array(-120.524014,41.022672),96120=>array(-119.86763,38.743387),96121=>array(-120.373766,40.167924),96122=>array(-120.476967,39.825506),96123=>array(-120.39628,40.728194),96124=>array(-120.445265,39.641871),96125=>array(-120.635732,39.602124),96126=>array(-120.454168,39.529719),96128=>array(-120.408154,40.358768),96129=>array(-120.357278,39.78927),96130=>array(-120.675673,40.551757),96132=>array(-120.402292,40.914835),96133=>array(-119.505184,38.620964),96134=>array(-121.440546,41.767323),96135=>array(-120.205672,39.808651),96136=>array(-120.081187,40.345949),96137=>array(-121.039461,40.270731),96140=>array(-120.096413,39.232027),96141=>array(-120.177111,39.07755),96142=>array(-120.12963,38.997146),96143=>array(-120.022169,39.254474),96145=>array(-120.183534,39.140222),96146=>array(-120.237787,39.198047),96148=>array(-120.064288,39.248269),96150=>array(-120.008943,38.869943),96155=>array(-120.088361,38.747069),96161=>array(-120.207783,39.313089),96701=>array(-157.884952,21.406053),96703=>array(-159.385681,22.145578),96704=>array(-155.837228,19.337368),96705=>array(-159.568039,21.899368),96706=>array(-158.022282,21.344756),96707=>array(-158.082206,21.363106),96708=>array(-156.223562,20.852389),96710=>array(-155.247662,19.842383),96712=>array(-158.048011,21.621367),96713=>array(-156.045046,20.738821),96714=>array(-159.520961,22.131244),96716=>array(-159.592419,22.049275),96717=>array(-157.905396,21.55775),96719=>array(-155.835941,20.234364),96720=>array(-155.232473,19.65981),96722=>array(-159.461105,22.188092),96725=>array(-155.910346,19.626487),96726=>array(-155.820986,19.42818),96727=>array(-155.636271,20.109943),96728=>array(-155.124957,19.861176),96729=>array(-157.116812,21.173558),96730=>array(-157.850479,21.543144),96731=>array(-157.978792,21.658692),96732=>array(-156.462641,20.883783),96734=>array(-157.758188,21.395084),96737=>array(-155.779672,19.064517),96738=>array(-155.79636,19.873144),96740=>array(-155.919968,19.75682),96741=>array(-159.512023,21.958288),96742=>array(-156.958641,21.170642),96743=>array(-155.698847,19.862157),96744=>array(-157.824227,21.451733),96746=>array(-159.383,22.091962),96747=>array(-159.624415,21.926296),96748=>array(-156.836399,21.131084),96749=>array(-154.989735,19.621282),96750=>array(-155.713752,19.534039),96751=>array(-159.302546,22.104971),96752=>array(-159.714507,21.970965),96753=>array(-156.438498,20.711955),96754=>array(-159.41223,22.177432),96755=>array(-155.789908,20.196906),96756=>array(-159.451665,21.907071),96757=>array(-156.974145,21.154207),96759=>array(-158.072417,21.467412),96760=>array(-155.056113,19.554764),96761=>array(-156.61354,20.897296),96762=>array(-157.943953,21.618479),96763=>array(-156.927377,20.836482),96764=>array(-155.276904,19.912071),96765=>array(-159.49213,21.922107),96766=>array(-159.401649,21.992908),96768=>array(-156.297856,20.832264),96769=>array(-160.151913,21.894997),96770=>array(-157.216486,21.134086),96771=>array(-155.123211,19.523869),96772=>array(-155.624963,19.155884),96773=>array(-155.239161,19.880162),96774=>array(-155.322559,19.964199),96776=>array(-155.399899,19.993371),96777=>array(-155.456769,19.251949),96778=>array(-155.028176,19.43894),96779=>array(-156.382963,20.908224),96780=>array(-155.216167,19.969757),96781=>array(-155.217704,19.786152),96782=>array(-157.936867,21.417374),96783=>array(-155.144159,19.830827),96785=>array(-155.407545,19.453729),96786=>array(-157.979384,21.57139),96789=>array(-157.934221,21.482531),96790=>array(-156.304151,20.685864),96791=>array(-158.185151,21.56364),96792=>array(-158.166919,21.468626),96793=>array(-156.530319,20.895344),96795=>array(-157.710924,21.335013),96796=>array(-159.719913,22.094078),96797=>array(-157.983838,21.417469),96813=>array(-157.845053,21.316548),96814=>array(-157.848767,21.293143),96815=>array(-157.822444,21.273462),96816=>array(-157.788328,21.290612),96817=>array(-157.821663,21.35548),96818=>array(-157.939889,21.344246),96819=>array(-157.876274,21.347927),96821=>array(-157.750269,21.311063),96822=>array(-157.810758,21.32021),96825=>array(-157.688748,21.294518),96826=>array(-157.826869,21.291518),96850=>array(-157.862652,21.303784),96853=>array(-157.938957,21.333755),96857=>array(-158.051525,21.48676),96859=>array(-157.890628,21.36046),96860=>array(-157.941232,21.355655),96863=>array(-157.762325,21.448453),97001=>array(-120.604029,44.990287),97002=>array(-122.793823,45.240464),97004=>array(-122.449377,45.254962),97005=>array(-122.80359,45.490964),97006=>array(-122.859822,45.517015),97007=>array(-122.879617,45.454273),97008=>array(-122.804191,45.46019),97009=>array(-122.33277,45.422994),97011=>array(-122.026423,45.387126),97013=>array(-122.66828,45.220824),97014=>array(-122.016805,45.582887),97015=>array(-122.536758,45.413524),97016=>array(-123.266951,46.060308),97017=>array(-122.38969,45.176519),97018=>array(-122.81063,45.897054),97019=>array(-122.24273,45.515631),97020=>array(-122.833621,45.222954),97021=>array(-121.142379,45.385919),97022=>array(-122.319961,45.346725),97023=>array(-122.323188,45.278476),97024=>array(-122.442402,45.546621),97026=>array(-122.959936,45.106152),97027=>array(-122.592827,45.38565),97028=>array(-121.807391,45.28845),97029=>array(-120.802277,45.287094),97030=>array(-122.433565,45.50923),97031=>array(-121.550474,45.6267),97032=>array(-122.783877,45.17663),97033=>array(-120.595882,45.280255),97034=>array(-122.683468,45.409354),97035=>array(-122.725171,45.413498),97037=>array(-121.027621,45.067048),97038=>array(-122.558954,45.095438),97039=>array(-120.664859,45.451556),97040=>array(-121.388115,45.617111),97041=>array(-121.624789,45.436254),97042=>array(-122.539832,45.205153),97045=>array(-122.536467,45.320277),97048=>array(-122.982023,46.044795),97049=>array(-121.862365,45.346366),97050=>array(-120.781653,45.673584),97051=>array(-122.950001,45.87932),97053=>array(-122.883286,45.827979),97054=>array(-122.949635,45.942244),97055=>array(-122.155174,45.388788),97056=>array(-122.969408,45.772048),97057=>array(-120.749973,45.002733),97058=>array(-121.155254,45.536452),97060=>array(-122.36909,45.531327),97062=>array(-122.762307,45.369302),97063=>array(-121.301127,45.224901),97064=>array(-123.235515,45.859087),97065=>array(-120.644619,45.607642),97067=>array(-122.054364,45.297834),97068=>array(-122.66856,45.352349),97070=>array(-122.773066,45.306108),97071=>array(-122.826479,45.134196),97080=>array(-122.390727,45.478314),97086=>array(-122.528077,45.445175),97089=>array(-122.443132,45.426602),97101=>array(-123.228702,45.090196),97102=>array(-123.95982,45.795655),97103=>array(-123.710609,46.133918),97106=>array(-123.118978,45.665732),97107=>array(-123.879381,45.552522),97108=>array(-123.708784,45.268884),97109=>array(-123.18121,45.737827),97110=>array(-123.955401,45.901039),97111=>array(-123.195186,45.284549),97112=>array(-123.868472,45.271232),97113=>array(-123.044336,45.497238),97114=>array(-123.07657,45.187855),97115=>array(-123.03946,45.275227),97116=>array(-123.165712,45.580829),97117=>array(-123.288449,45.631447),97118=>array(-123.911344,45.560774),97119=>array(-123.200213,45.468863),97121=>array(-123.951838,46.171919),97122=>array(-123.82578,45.161422),97123=>array(-122.98006,45.44016),97124=>array(-122.949619,45.569813),97125=>array(-123.196925,45.671107),97127=>array(-123.111352,45.246126),97128=>array(-123.282159,45.211928),97130=>array(-123.925733,45.701857),97131=>array(-123.817024,45.736903),97132=>array(-122.98733,45.324219),97133=>array(-123.022718,45.686112),97134=>array(-123.977041,45.457577),97135=>array(-123.962732,45.221925),97136=>array(-123.920769,45.630592),97137=>array(-122.948352,45.219549),97138=>array(-123.572177,45.849059),97140=>array(-122.865914,45.353118),97141=>array(-123.74336,45.510742),97144=>array(-123.300243,45.741563),97145=>array(-123.950728,45.851149),97146=>array(-123.945911,46.129699),97147=>array(-123.881376,45.688168),97148=>array(-123.248478,45.358403),97149=>array(-123.938853,45.11294),97201=>array(-122.690794,45.507856),97202=>array(-122.644441,45.482741),97203=>array(-122.737905,45.603549),97204=>array(-122.673946,45.518371),97205=>array(-122.710231,45.520562),97206=>array(-122.598605,45.482433),97208=>array(-122.678981,45.528666),97209=>array(-122.683941,45.531127),97210=>array(-122.726656,45.544186),97211=>array(-122.637305,45.581132),97212=>array(-122.643468,45.544236),97213=>array(-122.600014,45.538194),97214=>array(-122.643014,45.514672),97215=>array(-122.600627,45.515121),97216=>array(-122.558403,45.513887),97217=>array(-122.700798,45.601815),97218=>array(-122.600896,45.576291),97219=>array(-122.698526,45.454231),97220=>array(-122.559297,45.550024),97221=>array(-122.728839,45.498278),97222=>array(-122.618077,45.440945),97223=>array(-122.776605,45.44029),97224=>array(-122.795057,45.405501),97225=>array(-122.769994,45.501578),97227=>array(-122.6781,45.543386),97229=>array(-122.809275,45.551031),97230=>array(-122.505268,45.557757),97231=>array(-122.824209,45.687629),97232=>array(-122.643927,45.528929),97233=>array(-122.503259,45.515118),97236=>array(-122.509785,45.482892),97239=>array(-122.692457,45.492443),97266=>array(-122.558208,45.482957),97267=>array(-122.612867,45.408427),97301=>array(-123.003655,44.94878),97302=>array(-123.062159,44.902737),97303=>array(-123.023687,45.030348),97304=>array(-123.111691,45.006596),97305=>array(-122.928733,45.014335),97306=>array(-123.094751,44.842904),97317=>array(-122.907378,44.902603),97321=>array(-123.139526,44.65345),97322=>array(-123.017613,44.627553),97324=>array(-123.62312,44.365025),97325=>array(-122.85223,44.833821),97326=>array(-123.602815,44.619481),97327=>array(-122.947584,44.375035),97329=>array(-122.38461,44.411264),97330=>array(-123.256266,44.642489),97331=>array(-123.280419,44.564604),97333=>array(-123.293755,44.468006),97338=>array(-123.347474,44.926822),97341=>array(-124.051203,44.809281),97342=>array(-121.878925,44.739258),97343=>array(-123.751493,44.57526),97344=>array(-123.464616,44.869102),97345=>array(-122.578803,44.411572),97346=>array(-122.363191,44.768759),97347=>array(-123.656389,45.077114),97348=>array(-123.122261,44.383294),97350=>array(-121.86377,44.631507),97351=>array(-123.137765,44.816679),97352=>array(-123.026554,44.748649),97355=>array(-122.820656,44.532377),97357=>array(-123.825597,44.752668),97358=>array(-122.414007,44.804038),97360=>array(-122.499411,44.766266),97361=>array(-123.341673,44.767022),97362=>array(-122.77109,45.063442),97364=>array(-123.986853,44.99886),97365=>array(-124.010783,44.666397),97366=>array(-124.053577,44.577285),97367=>array(-123.97422,44.914753),97368=>array(-123.903094,45.024417),97369=>array(-124.051767,44.761539),97370=>array(-123.445448,44.563823),97371=>array(-123.190756,44.990697),97373=>array(-122.771763,45.056983),97374=>array(-122.778136,44.675902),97375=>array(-122.596337,44.977319),97376=>array(-123.983775,44.487394),97377=>array(-123.105998,44.463294),97378=>array(-123.421129,45.070687),97380=>array(-123.929969,44.786018),97381=>array(-122.720715,44.93946),97383=>array(-122.721862,44.794464),97384=>array(-122.618879,44.790993),97385=>array(-122.72355,44.865854),97386=>array(-122.726936,44.359706),97388=>array(-124.017859,44.903514),97389=>array(-123.089784,44.533482),97390=>array(-123.828419,44.308957),97391=>array(-123.898368,44.624538),97392=>array(-122.92885,44.794776),97394=>array(-123.920366,44.436746),97396=>array(-123.548956,45.103994),97401=>array(-123.080181,44.067988),97402=>array(-123.230911,44.047735),97403=>array(-123.052974,44.035821),97404=>array(-123.133112,44.105501),97405=>array(-123.192759,43.939557),97406=>array(-124.021255,42.615862),97408=>array(-123.058908,44.143552),97410=>array(-123.147871,42.79894),97411=>array(-124.359381,43.075636),97412=>array(-123.548077,44.204934),97413=>array(-122.072275,44.124779),97414=>array(-124.203021,42.961554),97415=>array(-124.174762,42.084386),97416=>array(-123.686734,43.034121),97417=>array(-123.230688,42.947656),97419=>array(-123.410669,44.180946),97420=>array(-124.136602,43.350962),97423=>array(-124.173445,43.193744),97424=>array(-123.014625,43.729601),97426=>array(-123.029956,43.898956),97429=>array(-123.0635,42.968299),97430=>array(-123.705193,44.17484),97431=>array(-122.84176,43.869513),97434=>array(-122.71676,43.622619),97435=>array(-123.328493,43.690179),97436=>array(-123.584772,43.640015),97437=>array(-123.392416,44.097414),97438=>array(-122.682456,43.944242),97439=>array(-124.048263,44.090672),97441=>array(-124.157182,43.774749),97442=>array(-123.423403,42.771523),97443=>array(-123.015591,43.248329),97444=>array(-124.337295,42.506105),97446=>array(-123.054648,44.260727),97447=>array(-122.210461,43.155248),97448=>array(-123.279453,44.211162),97449=>array(-124.040504,43.563367),97450=>array(-124.397057,42.905939),97451=>array(-123.268019,43.815227),97452=>array(-122.750081,43.874149),97453=>array(-123.863373,44.002797),97454=>array(-122.821646,44.221508),97455=>array(-122.919725,43.968577),97456=>array(-123.366418,44.339248),97457=>array(-123.229492,43.064509),97458=>array(-124.008537,43.048859),97459=>array(-124.182735,43.484217),97461=>array(-123.479762,44.108529),97462=>array(-123.379196,43.489969),97463=>array(-122.387167,43.740681),97465=>array(-124.3417,42.762771),97466=>array(-124.085231,42.848906),97467=>array(-123.823798,43.815954),97469=>array(-123.436869,42.915025),97470=>array(-123.242303,43.250807),97471=>array(-123.487741,43.218335),97473=>array(-123.852596,43.67591),97476=>array(-124.402796,42.842229),97477=>array(-123.011597,44.058465),97478=>array(-122.842245,44.089212),97479=>array(-123.208305,43.39035),97480=>array(-123.825169,44.122276),97481=>array(-123.56598,43.115279),97484=>array(-122.8503,42.940021),97486=>array(-123.531642,43.383323),97487=>array(-123.387762,43.988492),97488=>array(-122.417475,44.128635),97489=>array(-122.620682,44.164724),97490=>array(-123.612016,44.004139),97492=>array(-122.484787,43.71833),97493=>array(-124.024907,43.889588),97494=>array(-123.328081,43.330404),97495=>array(-123.313383,43.281871),97496=>array(-123.472705,43.066481),97497=>array(-123.425495,42.665706),97498=>array(-124.022676,44.284611),97499=>array(-123.247735,43.594965),97501=>array(-122.900832,42.265974),97502=>array(-122.953986,42.414858),97503=>array(-122.923719,42.604691),97504=>array(-122.799964,42.327975),97520=>array(-122.579211,42.181232),97522=>array(-122.532148,42.573005),97523=>array(-123.566871,42.123094),97524=>array(-122.647726,42.467463),97525=>array(-123.060902,42.450715),97526=>array(-123.338332,42.535654),97527=>array(-123.413626,42.371142),97530=>array(-123.057499,42.152148),97531=>array(-123.64545,42.200265),97532=>array(-123.521009,42.573758),97534=>array(-123.786285,42.118976),97535=>array(-122.811447,42.267738),97536=>array(-122.494698,42.781908),97537=>array(-123.13782,42.546408),97538=>array(-123.579993,42.271112),97539=>array(-122.785786,42.57584),97540=>array(-122.817754,42.193618),97541=>array(-122.738253,42.726621),97543=>array(-123.562116,42.375063),97544=>array(-123.28877,42.129584),97601=>array(-122.076826,42.442787),97603=>array(-121.680308,42.140888),97604=>array(-122.21319,42.953892),97620=>array(-119.78788,42.204181),97621=>array(-121.293655,42.469228),97622=>array(-121.027513,42.419733),97623=>array(-121.270439,42.201841),97624=>array(-121.63473,43.004051),97625=>array(-121.58089,42.31477),97626=>array(-122.02791,42.66735),97627=>array(-122.049929,42.140336),97630=>array(-120.36629,42.314478),97632=>array(-121.434832,42.036715),97633=>array(-121.562829,42.03414),97634=>array(-121.814925,42.128304),97635=>array(-120.294195,41.929992),97636=>array(-120.514464,42.616637),97637=>array(-119.890065,42.703382),97638=>array(-121.000604,43.138881),97639=>array(-121.429035,42.447776),97640=>array(-120.66334,42.847889),97641=>array(-120.513837,43.260266),97701=>array(-121.20634,44.112338),97702=>array(-121.233816,44.000626),97707=>array(-121.491435,43.826832),97710=>array(-118.470538,42.174184),97711=>array(-120.671364,44.707019),97712=>array(-120.456155,43.789447),97720=>array(-118.887819,43.585167),97721=>array(-118.445323,42.526763),97722=>array(-118.716044,42.94809),97730=>array(-121.647176,44.502297),97731=>array(-121.79748,43.145997),97732=>array(-118.443106,43.39729),97733=>array(-121.999522,43.371249),97734=>array(-121.336146,44.542438),97735=>array(-120.926174,43.41069),97736=>array(-119.006803,42.741885),97737=>array(-121.743673,43.49688),97738=>array(-119.157429,43.477671),97739=>array(-121.460906,43.694658),97741=>array(-121.054484,44.656448),97750=>array(-120.196698,44.658141),97751=>array(-119.869134,44.1455),97752=>array(-120.254399,44.142918),97753=>array(-121.018129,44.240512),97754=>array(-120.57008,44.15051),97756=>array(-121.216724,44.283326),97758=>array(-119.872338,43.339021),97759=>array(-121.90012,44.498775),97760=>array(-121.230283,44.38447),97761=>array(-121.261509,44.838526),97801=>array(-118.823944,45.671054),97810=>array(-118.457994,45.713984),97812=>array(-120.249407,45.57511),97813=>array(-118.528095,45.85043),97814=>array(-117.759035,44.832496),97817=>array(-118.612462,44.743414),97818=>array(-119.890171,45.785367),97819=>array(-117.760392,44.485347),97820=>array(-119.47291,44.072484),97823=>array(-120.216766,45.239934),97824=>array(-117.756383,45.354252),97825=>array(-119.496251,44.385128),97826=>array(-119.232316,45.664296),97827=>array(-117.83805,45.575424),97828=>array(-117.221884,45.716764),97830=>array(-120.183153,44.966553),97833=>array(-118.014879,44.928889),97834=>array(-117.161236,44.972346),97835=>array(-118.786545,45.910007),97836=>array(-119.486492,45.320593),97837=>array(-118.067264,44.55654),97838=>array(-119.287228,45.852978),97839=>array(-119.593042,45.59117),97840=>array(-116.918439,44.884711),97841=>array(-117.944925,45.465116),97842=>array(-116.736075,45.397799),97843=>array(-119.902866,45.502322),97844=>array(-119.548836,45.88415),97845=>array(-118.90306,44.401824),97846=>array(-117.039586,45.462699),97848=>array(-119.580294,44.72217),97850=>array(-118.113278,45.303538),97856=>array(-119.125255,44.815212),97857=>array(-117.480281,45.384444),97859=>array(-118.403204,45.531545),97862=>array(-118.316063,45.922063),97864=>array(-119.435932,44.805466),97865=>array(-119.18004,44.461466),97867=>array(-117.987902,45.076974),97868=>array(-118.854801,45.409901),97869=>array(-118.633979,44.397563),97870=>array(-117.186563,44.787989),97873=>array(-119.002878,44.132009),97874=>array(-119.867599,44.777572),97875=>array(-119.132853,45.818549),97876=>array(-118.035678,45.516439),97877=>array(-118.412927,44.713568),97880=>array(-118.892255,45.082438),97882=>array(-119.366491,45.897482),97883=>array(-117.634164,45.192443),97884=>array(-118.224967,44.455141),97885=>array(-117.511704,45.655669),97886=>array(-118.257458,45.792905),97901=>array(-117.107275,43.621445),97903=>array(-117.648559,44.246623),97904=>array(-118.522302,43.886287),97905=>array(-117.459512,44.57382),97906=>array(-117.774678,43.537039),97907=>array(-117.345516,44.419502),97908=>array(-117.928264,44.312247),97909=>array(-117.418958,44.246692),97910=>array(-117.511459,42.749076),97911=>array(-118.041388,43.736482),97913=>array(-117.323286,43.613589),97914=>array(-117.084162,44.113619),97918=>array(-117.354387,44.040036),97920=>array(-117.854271,44.072175),98001=>array(-122.264469,47.309496),98002=>array(-122.216812,47.308286),98003=>array(-122.315773,47.307713),98004=>array(-122.205341,47.618337),98005=>array(-122.168798,47.614533),98006=>array(-122.151005,47.557627),98007=>array(-122.144365,47.613825),98008=>array(-122.099118,47.605797),98010=>array(-122.000418,47.312036),98011=>array(-122.201968,47.753335),98012=>array(-122.199069,47.841169),98014=>array(-121.891613,47.660445),98019=>array(-121.855307,47.734333),98020=>array(-122.374193,47.802344),98021=>array(-122.208216,47.792523),98022=>array(-121.912906,47.216372),98023=>array(-122.36291,47.311414),98024=>array(-121.899182,47.573424),98026=>array(-122.332985,47.840794),98027=>array(-121.998724,47.493732),98028=>array(-122.248076,47.75568),98029=>array(-122.007748,47.557085),98030=>array(-122.197976,47.368522),98031=>array(-122.195772,47.405479),98032=>array(-122.257192,47.391942),98033=>array(-122.193578,47.675982),98034=>array(-122.213748,47.715769),98036=>array(-122.280394,47.809708),98037=>array(-122.285468,47.839227),98038=>array(-121.958008,47.419378),98039=>array(-122.240405,47.631695),98040=>array(-122.232776,47.567716),98042=>array(-122.117029,47.367737),98043=>array(-122.307751,47.791198),98045=>array(-121.606826,47.390316),98047=>array(-122.248889,47.261769),98050=>array(-121.939288,47.545269),98051=>array(-121.881291,47.34621),98052=>array(-122.120531,47.68099),98053=>array(-122.010131,47.669312),98055=>array(-122.201521,47.446982),98056=>array(-122.190248,47.512527),98057=>array(-122.2219,47.47202),98058=>array(-122.123973,47.442737),98059=>array(-122.113291,47.499676),98065=>array(-121.791951,47.584223),98068=>array(-121.374061,47.431918),98070=>array(-122.473322,47.407196),98072=>array(-122.130531,47.760785),98074=>array(-122.04421,47.622542),98075=>array(-122.037436,47.586092),98077=>array(-122.060283,47.752379),98087=>array(-122.266976,47.863071),98092=>array(-122.126874,47.290287),98101=>array(-122.336422,47.610902),98102=>array(-122.321891,47.63714),98103=>array(-122.338152,47.678255),98104=>array(-122.329459,47.601884),98105=>array(-122.284977,47.659861),98106=>array(-122.349874,47.544034),98107=>array(-122.377551,47.667527),98108=>array(-122.305794,47.534862),98109=>array(-122.344267,47.631863),98110=>array(-122.534561,47.646967),98112=>array(-122.288511,47.63281),98115=>array(-122.281589,47.685746),98116=>array(-122.400175,47.573933),98117=>array(-122.38487,47.687761),98118=>array(-122.268545,47.540246),98119=>array(-122.370946,47.638679),98121=>array(-122.350581,47.615192),98122=>array(-122.293207,47.611046),98125=>array(-122.295829,47.716513),98126=>array(-122.37959,47.555647),98133=>array(-122.342869,47.740475),98134=>array(-122.338045,47.577599),98136=>array(-122.394409,47.536464),98144=>array(-122.292492,47.585621),98146=>array(-122.357848,47.500058),98148=>array(-122.324859,47.444098),98154=>array(-122.333792,47.606211),98155=>array(-122.300477,47.754413),98158=>array(-122.307643,47.44967),98164=>array(-122.332029,47.605962),98166=>array(-122.352986,47.451576),98168=>array(-122.29996,47.489569),98174=>array(-122.335359,47.604569),98177=>array(-122.376608,47.742239),98178=>array(-122.243851,47.499387),98188=>array(-122.273092,47.447335),98195=>array(-122.308282,47.648763),98198=>array(-122.314976,47.391324),98199=>array(-122.407349,47.651371),98201=>array(-122.210044,48.006311),98203=>array(-122.231096,47.945519),98204=>array(-122.260891,47.901362),98205=>array(-122.150188,47.988498),98207=>array(-122.223307,47.98772),98208=>array(-122.187144,47.901779),98220=>array(-122.195194,48.684945),98221=>array(-122.659285,48.505025),98222=>array(-122.818103,48.566815),98223=>array(-121.952185,48.216688),98224=>array(-121.47091,47.595814),98225=>array(-122.508129,48.754092),98226=>array(-122.445452,48.798598),98229=>array(-122.413538,48.696127),98230=>array(-122.712014,48.953983),98232=>array(-122.411065,48.570552),98233=>array(-122.345587,48.500949),98235=>array(-122.23398,48.462505),98236=>array(-122.412822,47.948393),98237=>array(-121.689225,48.566272),98238=>array(-122.34462,48.335389),98239=>array(-122.657954,48.196498),98240=>array(-122.620684,48.948225),98241=>array(-121.208822,48.191666),98243=>array(-123.003654,48.608978),98244=>array(-121.933829,48.831811),98245=>array(-122.87177,48.619663),98247=>array(-122.330145,48.911877),98248=>array(-122.619419,48.864419),98249=>array(-122.542794,48.014236),98250=>array(-123.115077,48.573276),98251=>array(-121.606822,47.912317),98252=>array(-121.689606,48.07256),98253=>array(-122.576537,48.092397),98255=>array(-121.989398,48.52212),98256=>array(-121.406433,47.821438),98257=>array(-122.512147,48.406025),98258=>array(-122.076876,48.044199),98260=>array(-122.453899,48.033231),98261=>array(-122.883959,48.482492),98262=>array(-122.646705,48.674357),98263=>array(-122.065301,48.523723),98264=>array(-122.459792,48.950253),98266=>array(-122.122666,48.96397),98267=>array(-121.299048,48.437623),98270=>array(-122.146904,48.056723),98271=>array(-122.237681,48.089968),98272=>array(-121.894951,47.848591),98273=>array(-122.376148,48.402754),98274=>array(-122.145467,48.348771),98275=>array(-122.303436,47.916514),98276=>array(-122.326183,48.926701),98277=>array(-122.628582,48.315856),98278=>array(-122.671656,48.339706),98279=>array(-122.807614,48.638895),98280=>array(-122.910285,48.608001),98281=>array(-123.051184,48.99193),98282=>array(-122.500231,48.214112),98283=>array(-121.260324,48.802055),98284=>array(-122.123032,48.546532),98286=>array(-122.957539,48.568814),98288=>array(-121.278786,47.661553),98290=>array(-121.986472,47.955602),98292=>array(-122.31439,48.216792),98294=>array(-121.753864,47.874679),98295=>array(-122.200106,48.981355),98296=>array(-122.101113,47.839066),98297=>array(-123.026507,48.702062),98303=>array(-122.693536,47.157405),98304=>array(-121.736809,46.883744),98305=>array(-124.439072,48.062891),98310=>array(-122.626274,47.59196),98311=>array(-122.631017,47.631197),98312=>array(-122.784369,47.580848),98314=>array(-122.637118,47.556287),98315=>array(-122.716011,47.72455),98320=>array(-122.966923,47.718543),98321=>array(-122.071738,47.152606),98323=>array(-121.827511,47.043083),98325=>array(-122.759697,47.966648),98326=>array(-124.41166,48.179735),98327=>array(-122.66469,47.102369),98328=>array(-122.157916,46.86589),98329=>array(-122.726052,47.368089),98330=>array(-122.168652,46.776116),98331=>array(-124.191674,47.777349),98332=>array(-122.595828,47.372495),98333=>array(-122.639996,47.252432),98335=>array(-122.623661,47.296947),98336=>array(-122.07403,46.582238),98337=>array(-122.631558,47.568714),98338=>array(-122.276854,47.034316),98339=>array(-122.749033,48.024005),98340=>array(-122.570676,47.907713),98342=>array(-122.511506,47.755326),98345=>array(-122.62385,47.698622),98346=>array(-122.525526,47.821069),98349=>array(-122.763956,47.272817),98350=>array(-124.621522,47.90633),98351=>array(-122.774272,47.199642),98353=>array(-122.492613,47.53864),98354=>array(-122.317289,47.251994),98355=>array(-122.040018,46.703778),98356=>array(-122.290287,46.561126),98357=>array(-124.635404,48.333855),98358=>array(-122.713163,48.063796),98359=>array(-122.574916,47.431079),98360=>array(-122.144709,47.040716),98361=>array(-121.504714,46.538662),98362=>array(-123.368031,47.930938),98363=>array(-123.820847,48.002744),98364=>array(-122.588364,47.84711),98365=>array(-122.70137,47.88483),98366=>array(-122.578944,47.536047),98367=>array(-122.699443,47.461264),98368=>array(-122.838953,48.034402),98370=>array(-122.626331,47.754028),98371=>array(-122.323541,47.199448),98372=>array(-122.266339,47.205648),98373=>array(-122.324153,47.145083),98374=>array(-122.263923,47.12908),98375=>array(-122.322978,47.103783),98376=>array(-122.852262,47.846837),98377=>array(-121.894812,46.52484),98380=>array(-122.902886,47.578608),98381=>array(-124.474858,48.273676),98382=>array(-123.077988,48.014382),98383=>array(-122.716166,47.66247),98385=>array(-122.089493,47.136162),98387=>array(-122.394221,47.060959),98388=>array(-122.684422,47.20974),98390=>array(-122.227319,47.209445),98391=>array(-122.166317,47.177094),98392=>array(-122.562318,47.73228),98394=>array(-122.77848,47.31056),98396=>array(-122.001717,47.094772),98402=>array(-122.43903,47.250158),98403=>array(-122.458532,47.265966),98404=>array(-122.411638,47.208981),98405=>array(-122.472399,47.245647),98406=>array(-122.512591,47.264107),98407=>array(-122.517747,47.290365),98408=>array(-122.446518,47.197399),98409=>array(-122.481577,47.210957),98416=>array(-122.481199,47.262521),98418=>array(-122.446523,47.223229),98421=>array(-122.400209,47.260637),98422=>array(-122.392541,47.290403),98424=>array(-122.354192,47.235341),98430=>array(-122.567171,47.117835),98433=>array(-122.589062,47.112811),98438=>array(-122.496967,47.131631),98439=>array(-122.512691,47.132572),98443=>array(-122.372506,47.207776),98444=>array(-122.448831,47.153041),98445=>array(-122.409902,47.139967),98446=>array(-122.375825,47.131879),98447=>array(-122.443441,47.144096),98465=>array(-122.536065,47.251761),98466=>array(-122.539435,47.22605),98467=>array(-122.567719,47.203279),98498=>array(-122.553122,47.159194),98499=>array(-122.503347,47.168693),98501=>array(-122.875987,46.974504),98502=>array(-123.021968,47.087554),98503=>array(-122.797103,47.022032),98506=>array(-122.870623,47.108292),98512=>array(-123.063465,46.974998),98513=>array(-122.733942,46.97703),98516=>array(-122.794261,47.109684),98520=>array(-123.754329,47.205638),98524=>array(-122.862327,47.354792),98526=>array(-123.990748,47.454196),98527=>array(-123.924726,46.585142),98528=>array(-122.901331,47.44308),98530=>array(-122.823854,46.79051),98531=>array(-122.902774,46.730437),98532=>array(-123.052671,46.62629),98533=>array(-122.419588,46.67073),98535=>array(-124.137951,47.106431),98536=>array(-124.104372,47.194976),98537=>array(-123.597466,46.8324),98538=>array(-123.146135,46.482768),98541=>array(-123.389634,47.060749),98542=>array(-122.790632,46.525203),98544=>array(-123.026988,46.738971),98546=>array(-122.924625,47.319865),98547=>array(-124.035956,46.783949),98548=>array(-123.411582,47.382952),98550=>array(-123.925662,47.093788),98552=>array(-123.924198,47.315176),98555=>array(-123.060865,47.534733),98557=>array(-123.268321,47.04421),98558=>array(-122.557218,46.933941),98559=>array(-123.327364,46.958822),98560=>array(-123.425805,47.30235),98562=>array(-124.200325,47.238392),98563=>array(-123.615371,47.193599),98564=>array(-122.41965,46.449477),98565=>array(-122.901965,46.578315),98568=>array(-123.313712,46.854805),98569=>array(-124.136704,46.993744),98570=>array(-122.650947,46.630713),98571=>array(-124.170859,47.194626),98572=>array(-123.314084,46.546338),98575=>array(-123.802838,47.415917),98576=>array(-122.638356,46.837152),98577=>array(-123.610389,46.641849),98579=>array(-123.125473,46.788201),98580=>array(-122.521882,46.998953),98581=>array(-123.067314,46.357874),98582=>array(-122.62574,46.523682),98583=>array(-123.486596,47.000875),98584=>array(-123.145812,47.237448),98585=>array(-122.477076,46.550722),98586=>array(-123.830811,46.551443),98587=>array(-124.201924,47.308681),98588=>array(-123.020025,47.452373),98589=>array(-122.816364,46.834018),98590=>array(-123.998528,46.707873),98591=>array(-122.743598,46.441023),98592=>array(-123.082076,47.326304),98593=>array(-123.010061,46.402683),98595=>array(-124.113375,46.888036),98596=>array(-122.952677,46.492258),98597=>array(-122.492804,46.844426),98601=>array(-122.362516,45.943439),98602=>array(-121.265491,45.867106),98603=>array(-122.414757,46.055519),98604=>array(-122.510777,45.805747),98605=>array(-121.665459,45.776892),98606=>array(-122.456373,45.729741),98607=>array(-122.37998,45.642226),98610=>array(-122.065218,45.86589),98611=>array(-122.900688,46.305138),98612=>array(-123.325266,46.21568),98613=>array(-120.965657,45.736724),98614=>array(-123.909315,46.29699),98616=>array(-122.132873,46.19328),98617=>array(-121.167493,45.643032),98619=>array(-121.274747,45.975881),98620=>array(-120.77583,45.874447),98621=>array(-123.540555,46.379142),98624=>array(-123.992209,46.351431),98625=>array(-122.733384,46.037251),98626=>array(-122.774006,46.172087),98628=>array(-121.081948,45.887853),98629=>array(-122.61918,45.876604),98631=>array(-124.031543,46.404766),98632=>array(-123.057242,46.210694),98635=>array(-121.184345,45.748958),98638=>array(-123.761307,46.394046),98639=>array(-121.989665,45.669909),98640=>array(-124.027257,46.582723),98641=>array(-124.029936,46.546416),98642=>array(-122.693908,45.807695),98643=>array(-123.619706,46.295441),98644=>array(-124.056969,46.329607),98645=>array(-122.760081,46.331866),98647=>array(-123.401288,46.315247),98648=>array(-121.956311,45.706254),98649=>array(-122.5346,46.314143),98650=>array(-121.540782,45.947869),98651=>array(-121.583462,45.739924),98660=>array(-122.720499,45.678996),98661=>array(-122.625018,45.640067),98662=>array(-122.577847,45.688498),98663=>array(-122.663161,45.657396),98664=>array(-122.577179,45.61951),98665=>array(-122.66056,45.679501),98670=>array(-121.140927,45.858976),98671=>array(-122.238447,45.61442),98672=>array(-121.451833,45.839047),98673=>array(-121.028435,45.656199),98674=>array(-122.665541,45.951267),98675=>array(-122.342925,45.828452),98682=>array(-122.481749,45.673213),98683=>array(-122.51017,45.603287),98684=>array(-122.514839,45.630556),98685=>array(-122.693108,45.715191),98686=>array(-122.624397,45.723392),98801=>array(-120.336633,47.423594),98802=>array(-120.178727,47.487425),98811=>array(-120.376298,47.713843),98812=>array(-119.742877,48.153148),98813=>array(-119.560504,48.040679),98814=>array(-120.159044,48.206872),98815=>array(-120.478283,47.460575),98816=>array(-120.33999,48.002922),98817=>array(-119.994343,47.791063),98819=>array(-119.821449,48.616335),98821=>array(-120.558613,47.549717),98822=>array(-120.550451,47.901926),98823=>array(-119.620518,47.312005),98824=>array(-119.858684,47.077793),98826=>array(-120.843168,47.783145),98827=>array(-119.770722,48.868662),98828=>array(-120.178258,47.310078),98829=>array(-119.80556,48.297259),98830=>array(-119.523246,47.895366),98831=>array(-120.102873,47.959472),98832=>array(-119.024249,47.37163),98833=>array(-120.640178,48.772938),98834=>array(-120.066506,48.120299),98836=>array(-120.44101,47.475666),98837=>array(-119.305972,47.149902),98840=>array(-119.579942,48.315129),98841=>array(-119.268574,48.359648),98843=>array(-120.057948,47.756786),98844=>array(-119.227952,48.92728),98845=>array(-119.938731,47.431579),98846=>array(-119.971168,48.014877),98847=>array(-120.643727,47.419818),98848=>array(-119.842939,47.168643),98849=>array(-119.409523,48.54099),98850=>array(-120.075983,47.309924),98851=>array(-119.439646,47.412103),98852=>array(-120.555847,48.234024),98853=>array(-119.26389,47.460007),98855=>array(-119.253009,48.674509),98856=>array(-120.263948,48.343028),98857=>array(-119.052563,46.985135),98858=>array(-119.90278,47.649424),98859=>array(-118.956388,48.797928),98860=>array(-119.200475,47.461956),98862=>array(-120.32053,48.602734),98901=>array(-120.406039,46.722625),98902=>array(-120.533851,46.596673),98903=>array(-121.022416,46.54408),98908=>array(-120.724113,46.615206),98921=>array(-120.318817,46.431102),98922=>array(-120.878981,47.267033),98923=>array(-120.71763,46.666324),98925=>array(-121.270878,47.257288),98926=>array(-120.458691,47.014195),98929=>array(-121.285147,46.881702),98930=>array(-119.891977,46.2691),98932=>array(-120.156231,46.332713),98933=>array(-120.631233,46.402225),98934=>array(-120.415053,46.981871),98935=>array(-120.086267,46.132575),98936=>array(-120.1437,46.538212),98937=>array(-121.190309,46.811116),98938=>array(-120.094179,46.388203),98939=>array(-120.465789,46.496847),98940=>array(-121.080463,47.476791),98941=>array(-120.982011,47.223214),98942=>array(-120.66481,46.801335),98943=>array(-120.964863,47.184578),98944=>array(-119.630269,46.497628),98946=>array(-120.72462,47.08029),98947=>array(-120.801581,46.687471),98948=>array(-120.31262,46.297966),98950=>array(-119.988074,46.896466),98951=>array(-120.513604,46.456028),98952=>array(-120.763066,46.356211),98953=>array(-120.226814,46.442291),99001=>array(-117.586305,47.63649),99003=>array(-117.292679,47.920209),99004=>array(-117.631165,47.420062),99005=>array(-117.366196,47.844261),99006=>array(-117.502192,47.984122),99008=>array(-117.933438,47.503335),99009=>array(-117.252446,48.026086),99011=>array(-117.648158,47.618832),99012=>array(-117.192777,47.382041),99013=>array(-117.830817,47.893717),99016=>array(-117.121029,47.597292),99017=>array(-117.886758,47.184129),99018=>array(-117.154853,47.289792),99019=>array(-117.07562,47.643175),99020=>array(-117.496601,47.562601),99021=>array(-117.189612,47.848267),99022=>array(-117.708985,47.59978),99023=>array(-117.171784,47.561083),99025=>array(-117.075344,47.793859),99026=>array(-117.62654,47.811345),99027=>array(-117.12756,47.710128),99029=>array(-117.831006,47.693841),99030=>array(-117.110203,47.484075),99031=>array(-117.362419,47.423494),99032=>array(-118.040021,47.330252),99033=>array(-117.099273,47.232328),99034=>array(-117.75052,47.873668),99036=>array(-117.275915,47.525292),99037=>array(-117.197605,47.635784),99039=>array(-117.265585,47.344652),99040=>array(-118.003697,47.898357),99101=>array(-117.92066,48.320308),99102=>array(-117.250253,46.792025),99103=>array(-118.927608,47.756005),99105=>array(-118.071965,46.872987),99109=>array(-117.698545,48.292947),99110=>array(-117.576352,48.012086),99111=>array(-117.420749,46.837729),99113=>array(-117.189782,46.59349),99114=>array(-117.735834,48.655198),99115=>array(-119.416689,47.646834),99116=>array(-118.927373,48.03064),99117=>array(-118.532002,47.722069),99118=>array(-118.638565,48.896541),99119=>array(-117.315513,48.508882),99121=>array(-118.469793,48.936993),99122=>array(-118.208232,47.687849),99123=>array(-119.144468,47.845781),99124=>array(-118.952851,47.999935),99125=>array(-117.765154,46.93104),99126=>array(-117.972146,48.731364),99128=>array(-117.081344,47.09795),99129=>array(-118.192667,48.015253),99130=>array(-117.184125,46.997309),99131=>array(-118.131392,48.277409),99133=>array(-119.085091,48.021894),99134=>array(-118.277666,47.398104),99135=>array(-119.099296,47.664805),99136=>array(-117.955526,46.674643),99137=>array(-118.114956,48.147947),99138=>array(-118.395823,48.205843),99139=>array(-117.407626,48.752947),99140=>array(-118.64617,48.111414),99141=>array(-118.138691,48.73699),99143=>array(-117.848245,46.765536),99144=>array(-118.50429,47.377749),99146=>array(-118.29752,48.957548),99147=>array(-118.509373,47.873716),99148=>array(-117.597004,48.10047),99149=>array(-117.463958,47.217126),99150=>array(-118.556279,48.804478),99151=>array(-118.063636,48.66447),99152=>array(-117.396799,48.844574),99153=>array(-117.166021,48.911092),99154=>array(-118.365925,47.389734),99155=>array(-118.965682,48.249063),99156=>array(-117.196815,48.185849),99157=>array(-117.933374,48.820843),99158=>array(-117.247424,47.130271),99159=>array(-118.76587,47.32684),99160=>array(-118.306323,48.83871),99161=>array(-117.139126,46.903033),99163=>array(-117.218027,46.730331),99164=>array(-117.152568,46.730917),99166=>array(-118.664492,48.575632),99167=>array(-118.120985,48.419231),99169=>array(-118.340218,47.105898),99170=>array(-117.39372,47.235823),99171=>array(-117.65389,47.098248),99173=>array(-117.863003,48.036972),99174=>array(-117.358687,47.010562),99176=>array(-117.42389,47.080905),99179=>array(-117.125923,46.494979),99180=>array(-117.342169,48.292667),99181=>array(-117.786828,48.147363),99185=>array(-118.717317,47.749432),99201=>array(-117.436062,47.663466),99202=>array(-117.37897,47.657497),99203=>array(-117.402997,47.628641),99204=>array(-117.427263,47.645706),99205=>array(-117.444879,47.696825),99206=>array(-117.254657,47.629296),99207=>array(-117.387464,47.68875),99208=>array(-117.455721,47.782109),99212=>array(-117.310362,47.664705),99216=>array(-117.218458,47.685677),99217=>array(-117.261506,47.740696),99218=>array(-117.409388,47.758924),99223=>array(-117.344623,47.589407),99224=>array(-117.526046,47.65241),99301=>array(-118.95419,46.379049),99320=>array(-119.487243,46.265888),99321=>array(-119.908803,46.878455),99322=>array(-120.180774,45.943983),99323=>array(-118.872864,46.190789),99324=>array(-118.386845,46.042578),99326=>array(-118.853349,46.650082),99328=>array(-117.865424,46.263368),99329=>array(-118.145298,46.156331),99330=>array(-119.043221,46.489767),99333=>array(-118.172717,46.685782),99335=>array(-118.488378,46.651795),99336=>array(-119.175728,46.21405),99337=>array(-119.09074,46.073223),99338=>array(-119.273475,46.147861),99341=>array(-118.653019,46.912897),99343=>array(-119.180088,46.593609),99344=>array(-119.178054,46.820069),99345=>array(-119.70767,45.952216),99346=>array(-119.299293,45.997621),99347=>array(-117.565388,46.427734),99348=>array(-118.472036,46.377121),99349=>array(-119.700579,46.731191),99350=>array(-119.695943,46.183292),99352=>array(-119.288217,46.252589),99353=>array(-119.387768,46.313808),99354=>array(-119.302716,46.331608),99356=>array(-120.321453,45.82475),99357=>array(-119.661625,46.89131),99359=>array(-118.097372,46.543252),99360=>array(-118.66303,46.090217),99361=>array(-118.143838,46.236553),99362=>array(-118.313609,46.101083),99363=>array(-118.883536,46.060441),99371=>array(-118.312036,46.800118),99401=>array(-117.249975,46.087216),99402=>array(-117.127417,46.190773),99403=>array(-117.282597,46.362367),99501=>array(-149.855702,61.220018),99502=>array(-149.996609,61.163643),99503=>array(-158.175667,62.043951),99504=>array(-149.746095,61.2046),99505=>array(-149.602697,61.256851),99506=>array(-149.810757,61.253463),99507=>array(-149.753642,61.147656),99508=>array(-149.817528,61.201406),99510=>array(-149.86736,70.101886),99513=>array(-149.885658,61.214772),99515=>array(-149.890375,61.116381),99516=>array(-149.710038,61.079486),99517=>array(-149.939108,61.190346),99518=>array(-149.884627,61.159577),99519=>array(-146.787467,69.216237),99540=>array(-149.417716,60.990566),99546=>array(-176.629994,51.829438),99547=>array(-174.215643,52.213091),99548=>array(-158.751683,56.237395),99549=>array(-158.580635,56.964177),99550=>array(-153.042807,57.904339),99551=>array(-161.421759,60.902886),99552=>array(-161.228698,60.903841),99553=>array(-165.830835,54.117357),99554=>array(-164.644712,62.71116),99555=>array(-158.636148,59.268124),99556=>array(-151.511808,59.893272),99557=>array(-156.044199,61.420118),99558=>array(-160.213686,62.631016),99559=>array(-161.85081,60.814155),99561=>array(-164.251364,60.15122),99563=>array(-165.597175,61.530883),99564=>array(-158.39618,56.304665),99565=>array(-158.501266,56.303506),99566=>array(-142.605516,61.270907),99567=>array(-148.875379,61.279584),99568=>array(-151.407528,60.205405),99569=>array(-158.530092,58.80518),99571=>array(-162.776107,55.215583),99572=>array(-149.952595,60.529882),99573=>array(-145.951769,61.712313),99574=>array(-145.109037,60.893995),99575=>array(-158.063707,61.824119),99576=>array(-159.092876,60.261108),99577=>array(-149.248419,61.201578),99578=>array(-162.030483,60.21405),99579=>array(-157.408565,58.202719),99580=>array(-157.491032,59.365538),99581=>array(-164.552449,62.785415),99583=>array(-163.410644,54.890097),99585=>array(-162.288486,61.918711),99586=>array(-143.433106,62.827361),99587=>array(-148.956469,60.968258),99588=>array(-146.766777,62.434895),99589=>array(-161.568774,59.127491),99590=>array(-160.111792,62.895443),99591=>array(-169.598681,56.570519),99602=>array(-159.856076,62.187014),99603=>array(-151.184937,59.538682),99604=>array(-166.121735,61.535469),99605=>array(-149.533736,60.81094),99606=>array(-154.556392,59.851196),99607=>array(-159.967961,61.740823),99609=>array(-162.537863,60.864056),99610=>array(-150.499237,60.299886),99611=>array(-151.106328,60.60052),99612=>array(-162.288933,55.066682),99613=>array(-155.813864,58.964708),99614=>array(-164.067409,59.94013),99615=>array(-153.403556,57.613209),99620=>array(-163.535732,63.028875),99621=>array(-161.426777,60.79107),99622=>array(-163.193487,59.863441),99624=>array(-153.913088,57.587682),99625=>array(-156.652476,59.290256),99626=>array(-160.364657,61.516968),99627=>array(-154.784768,63.606003),99628=>array(-159.212133,58.957858),99630=>array(-166.266987,60.37073),99631=>array(-149.45864,60.608742),99632=>array(-163.66439,62.112344),99633=>array(-156.90468,58.798573),99634=>array(-161.998964,60.682896),99636=>array(-157.2905,59.488161),99637=>array(-165.108087,60.552199),99638=>array(-168.943928,52.897502),99639=>array(-151.404177,60.062246),99640=>array(-155.390747,60.002567),99641=>array(-162.460278,60.880266),99643=>array(-153.330498,57.22004),99644=>array(-152.382792,57.910272),99645=>array(-148.979893,61.624503),99647=>array(-154.071529,59.879267),99648=>array(-159.146431,55.930191),99649=>array(-157.281038,57.500442),99650=>array(-162.878297,61.946654),99651=>array(-161.688071,59.000685),99652=>array(-149.97421,61.533837),99653=>array(-154.275431,60.1984),99654=>array(-149.900777,61.449107),99655=>array(-161.887384,59.741444),99656=>array(-157.615034,61.936658),99657=>array(-161.669697,61.728212),99658=>array(-163.242495,62.09115),99659=>array(-162.129262,63.464848),99660=>array(-170.325068,57.179041),99661=>array(-160.684956,55.247308),99662=>array(-165.961546,61.791821),99663=>array(-151.624586,59.40119),99664=>array(-149.492517,60.076367),99665=>array(-159.529529,62.646227),99666=>array(-165.145536,62.440625),99667=>array(-151.742978,61.806352),99668=>array(-157.157593,61.682454),99669=>array(-151.017768,60.360218),99670=>array(-157.011738,58.658126),99671=>array(-162.26201,63.472348),99672=>array(-150.629991,60.752728),99674=>array(-148.219709,61.739171),99676=>array(-149.790598,62.448963),99677=>array(-146.679568,60.897951),99678=>array(-159.891633,59.620102),99679=>array(-160.937572,61.104273),99680=>array(-162.66876,60.412291),99681=>array(-165.12079,60.607991),99682=>array(-152.887215,60.607936),99683=>array(-151.029486,62.515061),99684=>array(-160.395364,63.989306),99685=>array(-166.482804,53.871799),99686=>array(-146.810141,61.15008),99688=>array(-149.959566,61.933176),99689=>array(-139.419639,59.485414),99690=>array(-164.832582,60.523716),99691=>array(-153.374674,62.817681),99692=>array(-166.538324,53.885808),99693=>array(-148.03387,60.850556),99694=>array(-149.785264,61.624101),99695=>array(-159.493298,55.918199),99701=>array(-149.336012,67.094545),99702=>array(-147.052322,64.650615),99703=>array(-147.622719,64.832624),99704=>array(-149.149549,64.296151),99705=>array(-147.313674,64.761825),99706=>array(-144.678658,64.010457),99709=>array(-148.148517,64.877203),99712=>array(-146.147347,64.997864),99714=>array(-146.553512,64.384498),99720=>array(-152.767612,66.56398),99721=>array(-151.70007,68.151791),99722=>array(-145.604061,68.091944),99723=>array(-156.798949,71.254084),99724=>array(-147.337916,66.390584),99726=>array(-152.39108,67.342559),99727=>array(-161.138661,65.975912),99729=>array(-149.400685,63.006169),99730=>array(-145.415175,65.628172),99732=>array(-142.007579,64.071746),99733=>array(-144.179638,65.838956),99734=>array(-149.287534,70.428206),99736=>array(-162.761728,66.085034),99737=>array(-145.311601,63.78987),99738=>array(-141.882011,65.636323),99739=>array(-162.56297,65.058902),99740=>array(-144.59672,67.874641),99741=>array(-156.873009,64.736146),99742=>array(-171.72571,63.777201),99743=>array(-150.026719,63.682732),99744=>array(-149.162919,64.309634),99745=>array(-154.232734,66.049285),99746=>array(-158.190476,65.600328),99747=>array(-143.687203,70.118387),99748=>array(-158.771212,64.34629),99749=>array(-160.431808,66.97843),99750=>array(-164.543454,67.728641),99751=>array(-156.874646,66.922686),99752=>array(-161.919349,67.263117),99753=>array(-161.151272,64.939607),99754=>array(-157.694303,64.902278),99755=>array(-148.52146,63.78493),99756=>array(-151.751657,64.565203),99757=>array(-152.692241,63.806222),99758=>array(-149.372384,65.151781),99759=>array(-162.915965,69.731918),99760=>array(-148.128409,64.250543),99761=>array(-163.057973,67.620987),99762=>array(-164.560425,64.8628),99763=>array(-161.029203,66.827182),99764=>array(-141.453808,63.291758),99765=>array(-158.132388,64.729316),99766=>array(-164.807044,68.702603),99767=>array(-150.151331,65.502172),99768=>array(-154.913209,65.033029),99769=>array(-170.487137,63.680702),99770=>array(-159.511018,66.746266),99771=>array(-161.208357,64.364915),99772=>array(-165.911401,66.003474),99773=>array(-157.1647,66.887644),99774=>array(-149.081592,66.02359),99775=>array(-147.82476,64.85813),99776=>array(-143.40207,63.395181),99777=>array(-152.095711,65.20311),99778=>array(-166.430235,65.058991),99780=>array(-143.102189,63.181525),99781=>array(-146.239696,67.288305),99782=>array(-159.893591,70.645917),99783=>array(-168.07997,65.676582),99784=>array(-163.406036,64.681721),99785=>array(-166.508493,65.34392),99786=>array(-156.153891,67.089483),99788=>array(-143.798881,66.646693),99789=>array(-151.935444,70.001585),99790=>array(-148.326543,65.390183),99791=>array(-156.792476,70.467956),99801=>array(-134.178781,58.3727),99820=>array(-134.178295,57.40931),99824=>array(-134.400852,58.264764),99825=>array(-135.736378,58.159987),99826=>array(-136.749108,58.702742),99827=>array(-135.578102,59.099905),99829=>array(-135.403502,58.106174),99830=>array(-134.12259,56.801841),99832=>array(-136.102505,57.974105),99833=>array(-133.117006,56.925681),99835=>array(-135.078528,57.000413),99836=>array(-134.653498,56.235218),99840=>array(-135.335418,59.575097),99841=>array(-135.184384,57.7943),99901=>array(-131.105347,55.540405),99903=>array(-132.0658,55.818431),99918=>array(-132.695503,55.916873),99919=>array(-132.495647,55.645004),99921=>array(-132.766235,55.407033),99922=>array(-133.046815,55.307528),99923=>array(-130.041026,56.002315),99925=>array(-132.945933,55.550204),99926=>array(-131.470741,55.138069),99927=>array(-133.457924,56.239062),99929=>array(-131.606832,56.413828));
}